datalibrary = {
    "iridl_type": "Source",
    "parent": None,
    "invalid": [],
    "dir": "SOURCES",
    "banned": [
        "dir",
        "invalid",
        "parent",
        "name",
        "banned",
        "banned_long",
        "iridl_ds_name",
        "iridl_type"
    ],
    "iridl_ds_name": "SOURCES",
    "restriction": "Public",
    "ANEEL": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "ANEEL",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "prcp_stadescription": "Precipitation station data for South America, primarily Brazil",
            "dis_stadescription": "Hydrological station data for South America, primarily Brazil",
            "description": "Ag&#234;ncia Nacional de Energia El&#233;trica",
            "iridlhasSemantics": "iridl:ANEEL",
            "Conventions": "IRIDL",
            "references": "ANEEL2000"
        },
        "prcp_sta": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "prcp_sta",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "STATION": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "STATION",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids"
            },
            "RIVER": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "RIVER",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids"
            },
            "prcp": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "prcp",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "maxncolor": "13",
                "colormap": "12800",
                "scale_max": "100.0",
                "ncolor": "13",
                "scale_min": "0.0",
                "CE": "100",
                "CS": "0",
                "missing_value": "-999.0",
                "units": "mm",
                "long_name": "precipitation"
            },
            "MUNICIPALITY": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "MUNICIPALITY",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids"
            },
            "lon": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "lon",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_min": "-90.0",
                "scale_max": "-30.0",
                "units": "degree_east",
                "long_name": "longitude"
            },
            "lat": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "lat",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_min": "-60.0",
                "scale_max": "15.0",
                "units": "degree_north",
                "long_name": "latitude"
            },
            "elev": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "elev",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "elevation",
                "units": "m"
            },
            "basin": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "basin",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_min": "1",
                "scale_max": "8",
                "units": "ids",
                "long_name": "basin_id",
                "CLIST": "Uruguai"
            }
        },
        "dis_sta": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "dis_sta",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "STATION": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "STATION",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids"
            },
            "lon": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "lon",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_min": "-90.0",
                "scale_max": "-30.0",
                "units": "degree_east",
                "long_name": "longitude"
            },
            "lat": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "lat",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_min": "-60.0",
                "scale_max": "15.0",
                "units": "degree_north",
                "long_name": "latitude"
            },
            "elev": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "elev",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "elevation",
                "units": "m"
            },
            "discharge": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "discharge",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "-999.0",
                "units": "m3/sec",
                "long_name": "discharge"
            },
            "basin": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "basin",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "maxncolor": "254",
                "ncolor": "11",
                "colormap": "0",
                "scale_min": "1",
                "scale_max": "8",
                "units": "ids",
                "long_name": "basin id",
                "CLIST": "Atlantico SE"
            },
            "area": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "area",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "drainage area",
                "units": "km2"
            }
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "1.0"
        },
        "ISTA_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ISTA_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "0",
            "long_name": "station"
        },
        "MCODE": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "MCODE",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "0"
        },
        "ISTA_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ISTA_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "0",
            "long_name": "station"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "1.0"
        },
        "ISTA_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ISTA_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "0",
            "long_name": "station"
        },
        "ISTA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ISTA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "0",
            "long_name": "station"
        },
        "dir": "SOURCES/ANEEL"
    },
    "ARCTIC": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "ARCTIC",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "STATIONdescription": "Oceanic station data for the Arctic Region",
            "description": "Oceanic station data for the Arctic Region",
            "iridlhasSemantics": "iridl:LDEO",
            "Conventions": "IRIDL"
        },
        "STATION": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "STATION",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Vint": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Vint",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "tritium vintage age",
                "units": "years",
                "missing_value": "-9999.0"
            },
            "Theta": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Theta",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "potential temperature",
                "units": "Celsius_scale",
                "missing_value": "-9999.0"
            },
            "Sta": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Sta",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "station",
                "units": "unitless",
                "missing_value": "-9999.0"
            },
            "Sil": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Sil",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "silicate",
                "units": "micro-moles per liter",
                "missing_value": "-9999.0"
            },
            "Sal": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Sal",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "salinity",
                "units": "PSU",
                "missing_value": "-9999.0"
            },
            "O18": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "O18",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "delta oxygen 18",
                "units": "ppt",
                "missing_value": "-9999.0"
            },
            "lon": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "lon",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "long_name": "longitude"
            },
            "lat": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "lat",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_north",
                "long_name": "latitude"
            },
            "Fr": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Fr",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "river runoff fraction",
                "units": "percent",
                "missing_value": "-9999.0"
            },
            "Fi": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Fi",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "ice fraction",
                "units": "percent",
                "missing_value": "-9999.0"
            },
            "Fa": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Fa",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "Atlantic fraction",
                "units": "unitless",
                "missing_value": "-9999.0"
            },
            "Depth": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Depth",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "m",
                "missing_value": "-9999.0"
            },
            "He": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "3He",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "tritium/helium age",
                "units": "unitless",
                "missing_value": "-9999.0"
            },
            "Hage": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "3Hage",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "tritium age",
                "units": "years",
                "missing_value": "-9999.0"
            },
            "H": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "3H",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "tritium",
                "units": "TU",
                "missing_value": "-9999.0"
            }
        },
        "IZ": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "IZ",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "1.0"
        },
        "ISTA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ISTA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2"
        },
        "dir": "SOURCES/ARCTIC"
    },
    "BRF": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "BRF",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "WeatherStationdescription": "Hourly and daily weather observations from Black Rock Forest",
            "WeatherStationiridlhasSemantics": "iridl:BRF",
            "SnowStation2005description": "Open Lowland Snow Station Main Hourly Observations",
            "SnowStationStonehousedescription": "Stonehouse main Snow Station Main Hourly Observations",
            "SnowStationOldHQdescription": "Old HQ main Snow Station Main Hourly Observations",
            "description": "Black Rock Forest",
            "iridlhasSemantics": "iridl:BRF",
            "Conventions": "IRIDL",
            "references": "Kastens_etal1998",
            "explorerhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.BRF/.explorer.html"
        },
        "WeatherStation": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "WeatherStation",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "RT_Hourly": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "RT_Hourly",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "wspdmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wspdmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Wind Speed",
                    "units": "m/s",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "wspd": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wspd",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Wind Speed",
                    "units": "m/s",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "wdirsd1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wdirsd1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Wind Direction Std Dev",
                    "units": "degree",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "wdird1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wdird1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Wind Direction",
                    "units": "degree",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "vappresavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "vappresavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Vapor Pressure",
                    "units": "kPa",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "tempmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tempmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-5200.0",
                    "long_name": "Minimum Temperature",
                    "units": "Celsius_scale",
                    "PGtype": "float4"
                },
                "tempmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tempmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "tempavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tempavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "stemp20avg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "stemp20avg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Soil Temperature 20 cm",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "stemp10avg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "stemp10avg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Soil Temperature 10 cm",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "stemp100avg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "stemp100avg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Soil Temperature 100 cm",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "rhmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rhmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Minimum Relative Humidity",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "rhmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rhmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Relative Humidity",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "rhavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rhavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Relative Humidity",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "raintot": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "raintot",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Precipitation Accumulation",
                    "units": "mm",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "partot": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "partot",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "note": "Photosynthetic Photon Flux Density (PPFD): photons in the 400 to 700 nm waveband/s/m2",
                    "long_name": "Photosynthetically-Active Radiation",
                    "units": "PPFD",
                    "missing_value": "99999.0",
                    "PGtype": "float4"
                },
                "gsravg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gsravg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "NG Solar Radiation",
                    "units": "W/m2",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "dewptavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "dewptavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-440.39999",
                    "long_name": "Average Dew Point",
                    "units": "Celsius_scale",
                    "PGtype": "float4"
                },
                "battvolt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "battvolt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Battary Voltage",
                    "units": "volts",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "barpresmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "barpresmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-6999.0",
                    "long_name": "Minimum Barometric Pressure",
                    "units": "hPa",
                    "PGtype": "float4"
                },
                "barpresmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "barpresmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Barometric Pressure",
                    "units": "hPa",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "barpresavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "barpresavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "0.0",
                    "long_name": "Average Barometric Pressure",
                    "units": "hPa",
                    "PGtype": "float4"
                }
            },
            "RT_Daily": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "RT_Daily",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "wspdmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wspdmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Wind Speed",
                    "units": "m/s",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "wspd": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wspd",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Wind Speed",
                    "units": "m/s",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "wdirsd1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wdirsd1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Wind Direction Std Dev",
                    "units": "degree",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "wdird1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wdird1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Wind Direction",
                    "units": "degree",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "vappresavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "vappresavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Vapor Pressure",
                    "units": "kPa",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "tempmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tempmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-5200.0",
                    "long_name": "Minimum Temperature",
                    "units": "Celsius_scale",
                    "PGtype": "float4"
                },
                "tempmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tempmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "tempavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tempavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "stemp20avg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "stemp20avg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Soil Temperature 20 cm",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "stemp10avg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "stemp10avg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Soil Temperature 10 cm",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "rhmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rhmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Minimum Relative Humidity",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "rhmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rhmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Relative Humidity",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "rhavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rhavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Relative Humidity",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "raintot": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "raintot",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Precipitation Accumulation",
                    "units": "mm",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "partot": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "partot",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "note": "Photosynthetic Photon Flux Density (PPFD): photons in the 400 to 700 nm waveband/s/m2",
                    "long_name": "Photosynthetically-Active Radiation",
                    "units": "PPFD",
                    "missing_value": "99999.0",
                    "PGtype": "float4"
                },
                "gsravg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gsravg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "NG Solar Radiation",
                    "units": "W/m2",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "dewptavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "dewptavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Dew Point",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "battvolt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "battvolt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Battary Voltage",
                    "units": "volts",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "barpresmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "barpresmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-6999.0",
                    "long_name": "Minimum Barometric Pressure",
                    "units": "hPa",
                    "PGtype": "float4"
                },
                "barpresmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "barpresmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Barometric Pressure",
                    "units": "hPa",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "barpresavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "barpresavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "0.0",
                    "long_name": "Average Barometric Pressure",
                    "units": "hPa",
                    "PGtype": "float4"
                }
            },
            "OL_Hourly": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "OL_Hourly",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "wspdmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wspdmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Wind Speed",
                    "units": "m/s",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "wspd": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wspd",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "195.5",
                    "long_name": "Wind Speed",
                    "units": "m/s",
                    "PGtype": "float4"
                },
                "wdirsd1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wdirsd1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Wind Direction Std Dev",
                    "units": "degree",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "wdird1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wdird1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Wind Direction",
                    "units": "degree",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "vappresavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "vappresavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Vapor Pressure",
                    "units": "kPa",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "tempmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tempmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Minimum Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "tempmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tempmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "tempavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tempavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "stemp20avg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "stemp20avg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-99999.0",
                    "long_name": "Soil Temperature 20 cm",
                    "units": "Celsius_scale",
                    "PGtype": "float4"
                },
                "stemp10avg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "stemp10avg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Soil Temperature 10 cm",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "stemp100avg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "stemp100avg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Soil Temperature 100 cm",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "rhmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rhmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Minimum Relative Humidity",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "rhmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rhmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Relative Humidity",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "rhavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rhavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Relative Humidity",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "raintot": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "raintot",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Precipitation Accumulation",
                    "units": "mm",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "partot": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "partot",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "note": "Photosynthetic Photon Flux Density (PPFD): photons in the 400 to 700 nm waveband/s/m2",
                    "long_name": "Photosynthetically-Active Radiation",
                    "units": "PPFD",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "gsravg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gsravg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "NG Solar Radiation",
                    "units": "W/m2",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "dewptavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "dewptavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Dew Point",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "co2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "co2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Percent CO2",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "battvolt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "battvolt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-799.0",
                    "long_name": "Battary Voltage",
                    "units": "volts",
                    "PGtype": "float4"
                },
                "barpresmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "barpresmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "102.0",
                    "long_name": "Minimum Barometric Pressure",
                    "units": "hPa",
                    "PGtype": "float4"
                },
                "barpresmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "barpresmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Barometric Pressure",
                    "units": "hPa",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "barpresavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "barpresavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Barometric Pressure",
                    "units": "hPa",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                }
            },
            "OL_Daily": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "OL_Daily",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "wspdmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wspdmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Wind Speed",
                    "units": "m/s",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "wspd": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wspd",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "195.5",
                    "long_name": "Wind Speed",
                    "units": "m/s",
                    "PGtype": "float4"
                },
                "wdirsd1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wdirsd1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Wind Direction Std Dev",
                    "units": "degree",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "wdird1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wdird1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Wind Direction",
                    "units": "degree",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "vappresavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "vappresavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Vapor Pressure",
                    "units": "kPa",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "tempmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tempmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Minimum Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "tempmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tempmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "tempavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tempavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "stemp20avg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "stemp20avg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-99999.0",
                    "long_name": "Soil Temperature 20 cm",
                    "units": "Celsius_scale",
                    "PGtype": "float4"
                },
                "stemp10avg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "stemp10avg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Soil Temperature 10 cm",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "rhmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rhmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Minimum Relative Humidity",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "rhmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rhmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Relative Humidity",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "rhavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rhavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Relative Humidity",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "raintot": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "raintot",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Precipitation Accumulation",
                    "units": "mm",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "partot": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "partot",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "note": "Photosynthetic Photon Flux Density (PPFD): photons in the 400 to 700 nm waveband/s/m2",
                    "long_name": "Photosynthetically-Active Radiation",
                    "units": "PPFD",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "gsravg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gsravg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "NG Solar Radiation",
                    "units": "W/m2",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "dewptavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "dewptavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Dew Point",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "co2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "co2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Percent CO2",
                    "units": "percent",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "battvolt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "battvolt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-799.0",
                    "long_name": "Battary Voltage",
                    "units": "volts",
                    "PGtype": "float4"
                },
                "barpresmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "barpresmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "102.0",
                    "long_name": "Minimum Barometric Pressure",
                    "units": "hPa",
                    "PGtype": "float4"
                },
                "barpresmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "barpresmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Maximum Barometric Pressure",
                    "units": "hPa",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "barpresavg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "barpresavg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Average Barometric Pressure",
                    "units": "hPa",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                }
            }
        },
        "SnowStation2005": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SnowStation2005",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "OLSSM_333_vars": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "OLSSM_333_vars",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "rn_w_m2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rn_w_m2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Rn_W_m2",
                    "units": "watts^m*m",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                }
            },
            "OLSSM_223_trefmux": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "OLSSM_223_trefmux",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "trefmux avg",
                "missing_value": "NaN",
                "units": "unitless",
                "PGtype": "float4",
                "codedstring": "select trefmux_avg from brf_olssm_hrly_223_2005_lt where tid=%d[tid] AND time=\\'%F %R[time]\\' ",
                "myallquery": "select trefmux_avg from brf_olssm_hrly_223_2005_lt where tid=1 AND time=\\'2000-01-01 00:00\\'",
                "pointwidth": "1.0"
            },
            "OLSSM_223_TC2": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "OLSSM_223_TC2",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "TC2 Thermistor Temperature avg",
                "units": "Celsius_scale",
                "missing_value": "NaN",
                "PGtype": "float4",
                "codedstring": "select tc_2_avg from brf_olssm_hrly_223_2005_lt where tid=%d[tid] AND time=\\'%F %R[time]\\' ",
                "myallquery": "select tc_2_avg from brf_olssm_hrly_223_2005_lt where tid=1 AND time=\\'2000-01-01 00:00\\'",
                "pointwidth": "1.0"
            },
            "OLSSM_120_vars": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "OLSSM_120_vars",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "treflog": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "treflog",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "treflog",
                    "missing_value": "NaN",
                    "units": "unitless",
                    "PGtype": "float4"
                },
                "battery": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "battery",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Battery",
                    "units": "volts",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                }
            },
            "OLSSM_113_trefmux": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "OLSSM_113_trefmux",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "trefmux avg",
                "missing_value": "NaN",
                "units": "unitless",
                "PGtype": "float4",
                "codedstring": "select trefmux_avg from brf_olssm_hrly_113_2005_lt where tid=%d[tid] AND time=\\'%F %R[time]\\' ",
                "myallquery": "select trefmux_avg from brf_olssm_hrly_113_2005_lt where tid=1 AND time=\\'2000-01-01 00:00\\'",
                "pointwidth": "1.0"
            },
            "OLSSM_113_TC1": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "OLSSM_113_TC1",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "TC1 Thermistor Temperature Avg",
                "units": "Celsius_scale",
                "missing_value": "NaN",
                "PGtype": "float4",
                "codedstring": "select tc_1_avg from brf_olssm_hrly_113_2005_lt where tid=%d[tid] AND time=\\'%F %R[time]\\' ",
                "myallquery": "select tc_1_avg from brf_olssm_hrly_113_2005_lt where tid=1 AND time=\\'2000-01-01 00:00\\'",
                "pointwidth": "1.0"
            },
            "OLSSM_101_vars": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "OLSSM_101_vars",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "dstime": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "dstime",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "DSTime",
                    "units": "unitless",
                    "PGtype": "int4"
                },
                "dstempf": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "dstempf",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Snow Depth Temperature",
                    "units": "Fahrenheit_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "dsretries": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "dsretries",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Snow Depth Retries",
                    "units": "unitless",
                    "PGtype": "int4"
                },
                "dsdepth": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "dsdepth",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Snow Depth",
                    "units": "inches",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                },
                "battery": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "battery",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Battery",
                    "units": "volts",
                    "missing_value": "NaN",
                    "PGtype": "float4"
                }
            }
        },
        "SnowStation": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SnowStation",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Stonehouse": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Stonehouse",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Stonehouse_Thermistors": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Stonehouse_Thermistors",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Thermistor Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4",
                    "codedstring": "select thrmtem_avg from stonehouse_main_therm where thermid=%d[tid] AND time=\\'%F %R[time]\\' ",
                    "myallquery": "select thrmtem_avg from stonehouse_main_therm where thermid=1 AND time=\\'2000-01-01 00:00\\'",
                    "pointwidth": "1.0"
                },
                "Stonehouse_rad": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Stonehouse_rad",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "uptotalavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "uptotalavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Up_total_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "tempkavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tempkavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Temperature:K",
                        "units": "Kelvin_scale",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "tempcavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tempcavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Temperature:C",
                        "units": "Celcius_scale",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "nettotalavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nettotalavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Net_total_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "netrsavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "netrsavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Net_Rs_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "netrlavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "netrlavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Net_Rl_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "dntotalavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dntotalavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Dn_total_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "cm3upavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cm3upavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "CM_up_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "cm3dnavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cm3dnavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "CM_dn_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "cg3upavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cg3upavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "CG_up_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "cg3dnavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cg3dnavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "CG_dn_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "albedoavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "albedoavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Albedo_AVG",
                        "units": "unitless",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    }
                },
                "Stonehouse_main_1D_vars": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Stonehouse_main_1D_vars",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "windspd_ms_s_wvt": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "windspd_ms_s_wvt",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Wind Speed",
                        "units": "m/s",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "winddir_sd1_wvt": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "winddir_sd1_wvt",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Wind Direction SD1",
                        "units": "degrees",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "winddir_d1_wvt": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "winddir_d1_wvt",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Wind Direction D1",
                        "units": "degrees",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "volumetric_water_content_2_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "volumetric_water_content_2_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Volumetric Water Content 2",
                        "units": "percent",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "volumetric_water_content_1_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "volumetric_water_content_1_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Volumetric Water Content 1",
                        "units": "percent",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "tempairx_max": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tempairx_max",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Maximum Air Temperature",
                        "units": "Celsius_scale",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "tempairn_min": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tempairn_min",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Minimum Air Temperature",
                        "units": "Celsius_scale",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "tempaira_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tempaira_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Average Air Temperature",
                        "units": "Celsius_scale",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "snow_depth_tempf_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "snow_depth_tempf_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Snow Depth Temperature",
                        "units": "Fahrenheit_scale",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "snow_depth_retries_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "snow_depth_retries_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Snow Depth Retries",
                        "units": "unitless",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "snow_depth_depth_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "snow_depth_depth_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Snow Depth",
                        "units": "inches",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "rel_hum": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rel_hum",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Relative Humidity",
                        "units": "percent",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "rain_mm_tot": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rain_mm_tot",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Total Rainfall",
                        "units": "mm",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "paneltemp_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "paneltemp_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Panel Temperature",
                        "units": "Celsius_scale",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "battery_min": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "battery_min",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Battery Minimum",
                        "units": "volts",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "air_press_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "air_press_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Average Air Pressure",
                        "units": "mb",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    }
                }
            },
            "OldHQ": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "OldHQ",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "OldHQ_Thermistors": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "OldHQ_Thermistors",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Thermistor Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "PGtype": "float4",
                    "codedstring": "select thrmtem_avg from oldhq_main_therm where thermid=%d[tid] AND time=\\'%F %R[time]\\' ",
                    "myallquery": "select thrmtem_avg from oldhq_main_therm where thermid=1 AND time=\\'2000-01-01 00:00\\'",
                    "pointwidth": "1.0"
                },
                "OldHQ_rad": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "OldHQ_rad",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "uptotalavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "uptotalavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Up_total_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "tempkavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tempkavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Temperature:K",
                        "units": "Kelvin_scale",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "tempcavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tempcavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Temperature:C",
                        "units": "Celcius_scale",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "nettotalavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nettotalavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Net_total_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "netrsavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "netrsavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Net_Rs_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "netrlavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "netrlavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Net_Rl_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "dntotalavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dntotalavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Dn_total_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "cm3upavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cm3upavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "CM_up_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "cm3dnavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cm3dnavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "CM_dn_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "cg3upavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cg3upavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "CG_up_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "cg3dnavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cg3dnavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "CG_dn_AVG",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "albedoavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "albedoavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Albedo_AVG",
                        "units": "unitless",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    }
                },
                "OldHQ_main_1D_vars": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "OldHQ_main_1D_vars",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "volumetric_water_content_2_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "volumetric_water_content_2_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Volumetric Water Content 2",
                        "units": "percent",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "volumetric_water_content_1_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "volumetric_water_content_1_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Volumetric Water Content 1",
                        "units": "percent",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "uv_temp": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "uv_temp",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "UV-temp",
                        "units": "mV",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "uv_b": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "uv_b",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "UV-B",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "uv_a": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "uv_a",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "UV-A",
                        "units": "watts^m*m",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "snow_depth_tempf_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "snow_depth_tempf_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Snow Depth Temperature",
                        "units": "Fahrenheit_scale",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "snow_depth_retries_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "snow_depth_retries_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Snow Depth Retries",
                        "units": "unitless",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "snow_depth_depth_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "snow_depth_depth_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Snow Depth",
                        "units": "inches",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "paneltemp_avg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "paneltemp_avg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Panel Temperature",
                        "units": "Celsius_scale",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    },
                    "battery_min": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "battery_min",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Battery Minimum",
                        "units": "volts",
                        "missing_value": "NaN",
                        "PGtype": "float4"
                    }
                }
            }
        },
        "time_16": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_16",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1995-01-01 00:00:00",
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.04166667"
        },
        "time_15": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_15",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1995-01-01 00:00:00",
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.04166667"
        },
        "time_14": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_14",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1995-01-01 00:00:00",
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.04166667"
        },
        "time_13": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_13",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1995-01-01 00:00:00",
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.04166667"
        },
        "time_12": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_12",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.04166667",
            "units": "s since 2000-01-01"
        },
        "time_11": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_11",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.04166667",
            "units": "s since 2000-01-01"
        },
        "time_10": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_10",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.04166667",
            "units": "s since 2000-01-01"
        },
        "time_09": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_09",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.04166667",
            "units": "s since 2000-01-01"
        },
        "time_08": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_08",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.04166667",
            "units": "s since 2000-01-01"
        },
        "time_07": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_07",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.04166667",
            "units": "s since 2000-01-01"
        },
        "tid_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "tid_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "1.0"
        },
        "time_06": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_06",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.04166667",
            "units": "s since 2000-01-01"
        },
        "time_05": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_05",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.0",
            "units": "s since 2000-01-01"
        },
        "time_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.006944444",
            "units": "s since 2000-01-01"
        },
        "time_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.0",
            "units": "s since 2000-01-01"
        },
        "time_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.0",
            "units": "s since 2000-01-01"
        },
        "tid": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "tid",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "1.0"
        },
        "time_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.006944444",
            "units": "s since 2000-01-01"
        },
        "time": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0.0",
            "units": "s since 2000-01-01"
        },
        "dir": "SOURCES/BRF"
    },
    "BerkeleyEarth": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "BerkeleyEarth",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "globalgriddeddailylanddeg1p0pc5180description": "Pentad Climatology 1951-1980",
            "globalgriddeddailylanddeg1p0minimuminstitution": "Berkeley Earth Surface Temperature Project, http://www.berkeleyearth.org/",
            "globalgriddeddailylanddeg1p0minimumdata": "http://berkeleyearth.org/data/",
            "globalgriddeddailylanddeg1p0meaninstitution": "Berkeley Earth Surface Temperature Project, http://www.berkeleyearth.org/",
            "globalgriddeddailylanddeg1p0meandata": "http://berkeleyearth.org/data/",
            "globalgriddeddailylanddeg1p0maximuminstitution": "Berkeley Earth Surface Temperature Project, http://www.berkeleyearth.org/",
            "globalgriddeddailylanddeg1p0maximumdata": "http://berkeleyearth.org/data/",
            "globalgriddeddailylanddeg1p0dc5180description": "Daily Climatology 1951-1980",
            "globalgriddeddailylanddeg1p0dc5180institution": "Berkeley Earth Surface Temperature Project, http://www.berkeleyearth.org/",
            "globalgriddeddailylanddeg1p0dc5180data": "http://berkeleyearth.org/data/",
            "globalgriddeddailylanddeg1p0institution": "Berkeley Earth Surface Temperature Project, http://www.berkeleyearth.org/",
            "globalgriddeddailylanddeg1p0Conventions": "Berkeley Earth Internal Convention (based on CF-1.5)",
            "globalgriddeddailylanddeg1p0title": "Gridded Berkeley Earth Surface Temperature Anomaly Field",
            "globalgriddeddailylanddeg1p0data": "http://berkeleyearth.org/data/",
            "globalgriddeddailylanddeg1p0comment": "This file contains surface temperature anomaly field gridded on a 1 deg. (longitude) by 1 deg. (latitude) grid-box basis.",
            "description": "Berkeley Earth",
            "iridlhasSemantics": "iridl:BerkeleyEarth",
            "Conventions": "IRIDL",
            "Berkeley": "http://berkeleyearth.org"
        },
        "_global": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "global",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridded": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gridded",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "daily": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "daily",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "land": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "land",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "deg1p0": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "deg1p0",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "pc5180": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pc5180",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmin": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmin",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "degree_Celsius",
                                    "long_name": "Minimum Surface Air Temperature Climatology (Jan 1951 - Dec 1980)",
                                    "standard_name": "air_temperature",
                                    "coordinates": "latitude longitude",
                                    "history": "[(17-Jun-2018 21:05:54) (Averaged in T2 with overlapping interval 5) (Boxes with less than 0.0% dropped)]"
                                },
                                "tmax": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmax",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "degree_Celsius",
                                    "long_name": "Maximum Surface Air Temperature Climatology (Jan 1951 - Dec 1980)",
                                    "standard_name": "air_temperature",
                                    "coordinates": "latitude longitude",
                                    "history": "[(17-Jun-2018 21:05:54) (Averaged in T2 with overlapping interval 5) (Boxes with less than 0.0% dropped)]"
                                },
                                "tavg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tavg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "degree_Celsius",
                                    "long_name": "Average Surface Air Temperature Climatology (Jan 1951 - Dec 1980)",
                                    "standard_name": "air_temperature",
                                    "coordinates": "latitude longitude",
                                    "history": "[(17-Jun-2018 21:05:54) (Averaged in T2 with overlapping interval 5) (Boxes with less than 0.0% dropped)]"
                                }
                            },
                            "minimum": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "minimum",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "yr": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "yr",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Year",
                                    "units": "year A.D.",
                                    "pointwidth": "0"
                                },
                                "tmin_anomaly": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmin_anomaly",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "valid_max": "32.309147",
                                    "missing_value": "NaN",
                                    "valid_min": "-32.576313",
                                    "long_name": "Minimum Surface Air Temperature Anomaly",
                                    "standard_name": "air_temperature_anomaly",
                                    "units": "degree_Celsius",
                                    "pointwidth": "0"
                                },
                                "month": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "month",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Month",
                                    "units": "month number",
                                    "pointwidth": "0"
                                },
                                "land_mask": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "land_mask",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "valid_max": "1.0",
                                    "missing_value": "NaN",
                                    "valid_min": "0.0",
                                    "long_name": "Land Area Fraction",
                                    "standard_name": "land_area_fraction",
                                    "units": "unitless"
                                },
                                "day_of_year": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "day_of_year",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Day of Year",
                                    "units": "day of year",
                                    "pointwidth": "0"
                                },
                                "day": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "day",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Day of Month",
                                    "units": "day of month",
                                    "pointwidth": "0"
                                },
                                "date_number": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "date_number",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Date Number",
                                    "units": "year A.D.",
                                    "pointwidth": "0"
                                }
                            },
                            "mean": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "mean",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "yr": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "yr",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Year",
                                    "units": "year A.D.",
                                    "pointwidth": "0"
                                },
                                "tavg_anomaly": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tavg_anomaly",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "valid_max": "32.309147",
                                    "missing_value": "NaN",
                                    "valid_min": "-32.576313",
                                    "long_name": "Average Surface Air Temperature Anomaly",
                                    "standard_name": "air_temperature_anomaly",
                                    "units": "degree_Celsius",
                                    "pointwidth": "0"
                                },
                                "month": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "month",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Month",
                                    "units": "month number",
                                    "pointwidth": "0"
                                },
                                "land_mask": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "land_mask",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "valid_max": "1.0",
                                    "missing_value": "NaN",
                                    "valid_min": "0.0",
                                    "long_name": "Land Area Fraction",
                                    "standard_name": "land_area_fraction",
                                    "units": "unitless"
                                },
                                "day_of_year": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "day_of_year",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Day of Year",
                                    "units": "day of year",
                                    "pointwidth": "0"
                                },
                                "day": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "day",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Day of Month",
                                    "units": "day of month",
                                    "pointwidth": "0"
                                },
                                "date_number": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "date_number",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Date Number",
                                    "units": "year A.D.",
                                    "pointwidth": "0"
                                }
                            },
                            "maximum": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "maximum",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "yr": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "yr",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Year",
                                    "units": "year A.D.",
                                    "pointwidth": "0"
                                },
                                "tmax_anomaly": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmax_anomaly",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "valid_max": "32.309147",
                                    "missing_value": "NaN",
                                    "valid_min": "-32.576313",
                                    "long_name": "Maximum Surface Air Temperature Anomaly",
                                    "standard_name": "air_temperature_anomaly",
                                    "units": "degree_Celsius",
                                    "pointwidth": "0"
                                },
                                "month": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "month",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Month",
                                    "units": "month number",
                                    "pointwidth": "0"
                                },
                                "land_mask": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "land_mask",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "valid_max": "1.0",
                                    "missing_value": "NaN",
                                    "valid_min": "0.0",
                                    "long_name": "Land Area Fraction",
                                    "standard_name": "land_area_fraction",
                                    "units": "unitless"
                                },
                                "day_of_year": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "day_of_year",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Day of Year",
                                    "units": "day of year",
                                    "pointwidth": "0"
                                },
                                "day": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "day",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Day of Month",
                                    "units": "day of month",
                                    "pointwidth": "0"
                                },
                                "date_number": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "date_number",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Date Number",
                                    "units": "year A.D.",
                                    "pointwidth": "0"
                                }
                            },
                            "dc5180": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "dc5180",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmin_climatology": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmin_climatology",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "valid_max": "50.0",
                                    "missing_value": "NaN",
                                    "valid_min": "-75.0",
                                    "coordinates": "latitude longitude",
                                    "long_name": "Minimum Surface Air Temperature Climatology (Jan 1951 - Dec 1980)",
                                    "units": "degree_Celsius",
                                    "standard_name": "air_temperature"
                                },
                                "tmax_climatology": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmax_climatology",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "valid_max": "50.0",
                                    "missing_value": "NaN",
                                    "valid_min": "-75.0",
                                    "coordinates": "latitude longitude",
                                    "long_name": "Maximum Surface Air Temperature Climatology (Jan 1951 - Dec 1980)",
                                    "units": "degree_Celsius",
                                    "standard_name": "air_temperature"
                                },
                                "tavg_climatology": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tavg_climatology",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "valid_max": "50.0",
                                    "missing_value": "NaN",
                                    "valid_min": "-75.0",
                                    "coordinates": "latitude longitude",
                                    "long_name": "Average Surface Air Temperature Climatology (Jan 1951 - Dec 1980)",
                                    "units": "degree_Celsius",
                                    "standard_name": "air_temperature"
                                }
                            }
                        }
                    }
                }
            }
        },
        "T_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "pentads since 1960-01-01",
            "gridtype": "1",
            "modulo": "73.0",
            "calendar": "365",
            "modulus": "73.0",
            "pointwidth": "1.0"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1960-01-01",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1960-01-01",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "1.0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days",
            "gridtype": "1",
            "calendar": "365",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "1.0"
        },
        "dir": "SOURCES/BerkeleyEarth"
    },
    "Biosphere": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "Biosphere",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridlhasSemantics": "iridl:LDEO",
            "Conventions": "IRIDL",
            "Biosphere": "http://www.b2science.org/",
            "description": "Biosphere 2 Laboratory"
        },
        "RFSoil50": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "RFSoil50",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "temp": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "temp",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_Fahrenheit",
                "missing_value": "-909090.0",
                "long_name": "Soil_Temp"
            }
        },
        "RFSoil0": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "RFSoil0",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "temp": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "temp",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_Fahrenheit",
                "missing_value": "-909090.0",
                "location": " ISMAP> Rain Forest Sensor Map</A>",
                "sensor_id": "Soil Temp #2225",
                "long_name": "Soil_Temp"
            }
        },
        "example": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "example",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "exlight": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "exlight",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "micro einsteins/m2/s",
                "missing_value": "-99999.0",
                "sensor": "LI-190SA Quantum which measures PAR (Photosynthetically Active Radiation)",
                "location": "outside the Biosphere 2 complex on the top of the Habitat ring",
                "sensorid": "light#1985",
                "long_name": "External Light"
            },
            "co2": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "co2",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ppm",
                "missing_value": "-99999.0",
                "sensor": "3K Priva",
                "location": " Desert Biome of the Biosphere",
                "sensorid": "co2#838",
                "long_name": "Carbon Dioxide"
            }
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "0.01100152",
            "add_offset": "2450084"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "0.01041667",
            "add_offset": "2450084"
        },
        "dir": "SOURCES/Biosphere"
    },
    "BoM": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "BoM",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "POAMAM24Realtimem24cPOAMA": "http://poama.bom.gov.au/",
            "POAMAM24Realtimem24cThe": "http://poama.bom.gov.au/about_poama2.shtml#The_new_POAMA2_System",
            "POAMAM24Realtimem24cexpires": "1615334400",
            "POAMAM24Realtimem24cdescription": "POAMA 2.4C Multiweek Real-time Forecasts",
            "POAMAM24Realtimem24creferences": "Hudson_etal2013",
            "POAMAM24Realtimem24bPOAMA": "http://poama.bom.gov.au/",
            "POAMAM24Realtimem24bThe": "http://poama.bom.gov.au/about_poama2.shtml#The_new_POAMA2_System",
            "POAMAM24Realtimem24bdescription": "POAMA 2.4B Multiweek Real-time Forecasts",
            "POAMAM24Realtimem24breferences": "Hudson_etal2013",
            "POAMAM24Realtimem24aPOAMA": "http://poama.bom.gov.au/",
            "POAMAM24Realtimem24aThe": "http://poama.bom.gov.au/about_poama2.shtml#The_new_POAMA2_System",
            "POAMAM24Realtimem24adescription": "POAMA 2.4A Multiweek Real-time Forecasts",
            "POAMAM24Realtimem24areferences": "Hudson_etal2013",
            "POAMAM24Hindcastm24cdescription": "POAMA 2.4C Hindcast: All Starts",
            "POAMAM24Hindcastm24cThe": "http://poama.bom.gov.au/about_poama2.shtml#The_new_POAMA2_System",
            "POAMAM24Hindcastm24chistory": "Produced by BMRC DP V15 20120813 19:08",
            "POAMAM24Hindcastm24cexpt_id": "m24c    ",
            "POAMAM24Hindcastm24cmodl_vrsn": "3.0d    ",
            "POAMAM24Hindcastm24cPOAMA": "http://poama.bom.gov.au/",
            "POAMAM24Hindcastm24cserved_from": "opendap.bom.gov.au:8080",
            "POAMAM24Hindcastm24cconventions": "COARDS",
            "POAMAM24Hindcastm24carch_vrsn": "g2.0    ",
            "POAMAM24Hindcastm24cNCO": "4.0.0",
            "POAMAM24Hindcastm24creferences": "Hudson_etal2013",
            "POAMAM24Hindcastm24bdescription": "POAMA 2.4B Hindcast: All Starts",
            "POAMAM24Hindcastm24bThe": "http://poama.bom.gov.au/about_poama2.shtml#The_new_POAMA2_System",
            "POAMAM24Hindcastm24bhistory": "Produced by BMRC DP V15 20120813 19:08",
            "POAMAM24Hindcastm24bexpt_id": "m24b    ",
            "POAMAM24Hindcastm24bmodl_vrsn": "3.0d    ",
            "POAMAM24Hindcastm24bPOAMA": "http://poama.bom.gov.au/",
            "POAMAM24Hindcastm24bserved_from": "opendap.bom.gov.au:8080",
            "POAMAM24Hindcastm24bconventions": "COARDS",
            "POAMAM24Hindcastm24barch_vrsn": "g2.0    ",
            "POAMAM24Hindcastm24bNCO": "4.0.0",
            "POAMAM24Hindcastm24breferences": "Hudson_etal2013",
            "POAMAM24Hindcastm24adescription": "POAMA 2.4A Hindcast: All Starts",
            "POAMAM24Hindcastm24aThe": "http://poama.bom.gov.au/about_poama2.shtml#The_new_POAMA2_System",
            "POAMAM24Hindcastm24ahistory": "Produced by BMRC DP V15 20120813 19:08",
            "POAMAM24Hindcastm24aexpt_id": "m24a    ",
            "POAMAM24Hindcastm24amodl_vrsn": "3.0d    ",
            "POAMAM24Hindcastm24aPOAMA": "http://poama.bom.gov.au/",
            "POAMAM24Hindcastm24aserved_from": "opendap.bom.gov.au:8080",
            "POAMAM24Hindcastm24aconventions": "COARDS",
            "POAMAM24Hindcastm24aarch_vrsn": "g2.0    ",
            "POAMAM24Hindcastm24aNCO": "4.0.0",
            "POAMAM24Hindcastm24areferences": "Hudson_etal2013",
            "POAMAM24description": "M24",
            "POAMAM24The": "http://poama.bom.gov.au/about_poama2.shtml#The_new_POAMA2_System",
            "POAMAM24references": "Hudson_etal2013",
            "POAMAdescription": "Predictive Ocean Atmosphere Model for Australia",
            "POAMAreferences": "Hudson_etal2013",
            "POAMAPOAMA": "http://poama.bom.gov.au/",
            "MJORMMdescription": "Real-time Multivariate MJO Index (with components of interannual variability removed)",
            "MJORMMdata": "http://www.bom.gov.au/climate/mjo/graphics/rmm.74toRealtime.txt",
            "MJORMMexpires": "1615161600",
            "MJORMMreferences": "Wheeler_Hendon2004",
            "MJORMMWheeler": "http://journals.ametsoc.org/doi/abs/10.1175/1520-0493(2004)132%3C1917:AARMMI%3E2.0.CO;2",
            "MJORMMsummary": "http://www.bom.gov.au/climate/mjo/",
            "MJOdescription": "Madden-Julian Oscillation",
            "description": "Australian Bureau of Meteorology",
            "Conventions": "IRIDL",
            "BoM": "http://www.bom.gov.au/"
        },
        "POAMA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "POAMA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "M24": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M24",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Realtime": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Realtime",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "m24c": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "m24c",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "tsaira": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "tsaira",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "expires": "1615334400",
                            "dodsname": "tsaira",
                            "standard_name": "air_temperature",
                            "grid_type": "spatial",
                            "long_name": "temperature at 1.5m",
                            "level_type": "single",
                            "units": "Kelvin_scale",
                            "pointwidth": "1.0"
                        },
                        "sfc_temp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "sfc_temp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "expires": "1615334400",
                            "dodsname": "sfc_temp",
                            "standard_name": "surface_temperature",
                            "grid_type": "spatial",
                            "long_name": "surface temperature",
                            "level_type": "single",
                            "units": "Kelvin_scale",
                            "pointwidth": "1.0"
                        },
                        "hr24_prcp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "hr24_prcp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "expires": "1615334400",
                            "dodsname": "hr24_prcp",
                            "standard_name": "precipitation_rate",
                            "grid_type": "spatial",
                            "long_name": "total precipitation",
                            "level_type": "single",
                            "units": "mm",
                            "pointwidth": "1.0"
                        }
                    },
                    "m24b": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "m24b",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "tsaira": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "tsaira",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "tsaira",
                            "standard_name": "air_temperature",
                            "grid_type": "spatial",
                            "long_name": "temperature at 1.5m",
                            "level_type": "single",
                            "units": "Kelvin_scale",
                            "pointwidth": "1.0"
                        },
                        "sfc_temp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "sfc_temp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "sfc_temp",
                            "standard_name": "surface_temperature",
                            "grid_type": "spatial",
                            "long_name": "surface temperature",
                            "level_type": "single",
                            "units": "Kelvin_scale",
                            "pointwidth": "1.0"
                        },
                        "hr24_prcp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "hr24_prcp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "hr24_prcp",
                            "standard_name": "precipitation_rate",
                            "grid_type": "spatial",
                            "long_name": "total precipitation",
                            "level_type": "single",
                            "units": "mm",
                            "pointwidth": "1.0"
                        }
                    },
                    "m24a": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "m24a",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "tsaira": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "tsaira",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "tsaira",
                            "standard_name": "air_temperature",
                            "grid_type": "spatial",
                            "long_name": "temperature at 1.5m",
                            "level_type": "single",
                            "units": "Kelvin_scale",
                            "pointwidth": "1.0"
                        },
                        "sfc_temp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "sfc_temp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "sfc_temp",
                            "standard_name": "surface_temperature",
                            "grid_type": "spatial",
                            "long_name": "surface temperature",
                            "level_type": "single",
                            "units": "Kelvin_scale",
                            "pointwidth": "1.0"
                        },
                        "hr24_prcp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "hr24_prcp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "hr24_prcp",
                            "standard_name": "precipitation_rate",
                            "grid_type": "spatial",
                            "long_name": "total precipitation",
                            "level_type": "single",
                            "units": "mm",
                            "pointwidth": "1.0"
                        }
                    }
                },
                "Hindcast": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Hindcast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "m24c": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "m24c",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "tsaira": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "tsaira",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "tsaira",
                            "standard_name": "air_temperature",
                            "grid_type": "spatial",
                            "long_name": "temperature at 1.5m",
                            "level_type": "single",
                            "units": "Kelvin_scale",
                            "pointwidth": "1.0"
                        },
                        "T": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "T",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "calendar": "360",
                            "units": "months since 1960-01-01",
                            "standard_name": "time",
                            "pointwidth": "1.0"
                        },
                        "sfc_temp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "sfc_temp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "sfc_temp",
                            "standard_name": "surface_temperature",
                            "grid_type": "spatial",
                            "long_name": "surface temperature",
                            "level_type": "single",
                            "units": "Kelvin_scale",
                            "pointwidth": "1.0"
                        },
                        "hr24_prcp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "hr24_prcp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "hr24_prcp",
                            "standard_name": "lwe_precipitation_rate",
                            "grid_type": "spatial",
                            "long_name": "total precipitation",
                            "level_type": "single",
                            "units": "mm/day",
                            "pointwidth": "1.0"
                        }
                    },
                    "m24b": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "m24b",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "tsaira": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "tsaira",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "tsaira",
                            "standard_name": "air_temperature",
                            "grid_type": "spatial",
                            "long_name": "temperature at 1.5m",
                            "level_type": "single",
                            "units": "Kelvin_scale",
                            "pointwidth": "1.0"
                        },
                        "T": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "T",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "calendar": "360",
                            "units": "months since 1960-01-01",
                            "standard_name": "time",
                            "pointwidth": "1.0"
                        },
                        "sfc_temp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "sfc_temp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "sfc_temp",
                            "standard_name": "surface_temperature",
                            "grid_type": "spatial",
                            "long_name": "surface temperature",
                            "level_type": "single",
                            "units": "Kelvin_scale",
                            "pointwidth": "1.0"
                        },
                        "hr24_prcp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "hr24_prcp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "hr24_prcp",
                            "standard_name": "lwe_precipitation_rate",
                            "grid_type": "spatial",
                            "long_name": "total precipitation",
                            "level_type": "single",
                            "units": "mm/day",
                            "pointwidth": "1.0"
                        }
                    },
                    "m24a": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "m24a",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "tsaira": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "tsaira",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "tsaira",
                            "standard_name": "air_temperature",
                            "grid_type": "spatial",
                            "long_name": "temperature at 1.5m",
                            "level_type": "single",
                            "units": "Kelvin_scale",
                            "pointwidth": "1.0"
                        },
                        "T": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "T",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "calendar": "360",
                            "units": "months since 1960-01-01",
                            "standard_name": "time",
                            "pointwidth": "1.0"
                        },
                        "sfc_temp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "sfc_temp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "sfc_temp",
                            "standard_name": "surface_temperature",
                            "grid_type": "spatial",
                            "long_name": "surface temperature",
                            "level_type": "single",
                            "units": "Kelvin_scale",
                            "pointwidth": "1.0"
                        },
                        "hr24_prcp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "hr24_prcp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "dodsname": "hr24_prcp",
                            "standard_name": "lwe_precipitation_rate",
                            "grid_type": "spatial",
                            "long_name": "total precipitation",
                            "level_type": "single",
                            "units": "mm/day",
                            "pointwidth": "1.0"
                        }
                    }
                }
            }
        },
        "MJO": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "MJO",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "RMM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "RMM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "RMM2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "RMM2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "9.99999962E35",
                    "units": "unitless",
                    "expires": "1615161600"
                },
                "RMM1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "RMM1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "9.99999962E35",
                    "units": "unitless",
                    "expires": "1615161600"
                },
                "phase": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "phase",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "999.0",
                    "units": "unitless",
                    "expires": "1615161600"
                },
                "amplitude": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "amplitude",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "9.99999962E35",
                    "units": "unitless",
                    "expires": "1615161600"
                }
            }
        },
        "S_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "S_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1960-01-01",
            "gridtype": "0",
            "calendar": "standard",
            "expires": "1615334400",
            "standard_name": "forecast_reference_time",
            "long_name": "Start Time",
            "pointwidth": "0"
        },
        "S_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "S_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1960-01-01",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "forecast_reference_time",
            "long_name": "Start Time",
            "pointwidth": "0"
        },
        "L": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "L",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months",
            "gridtype": "0",
            "standard_name": "forecast_period",
            "long_name": "Lead",
            "pointwidth": "1.0"
        },
        "S_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "S_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1960-01-01",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "forecast_reference_time",
            "long_name": "Start Time",
            "pointwidth": "0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "long_name": "latitude"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "long_name": "longitude",
            "pointwidth": "2.5"
        },
        "M": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "M",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "standard_name": "realization",
            "long_name": "Ensemble Member",
            "pointwidth": "1.0"
        },
        "S": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "S",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1960-01-01",
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "0"
        },
        "L0": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "L0",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "long_name": "Lead",
            "pointwidth": "1.0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "expires": "1615161600",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "dir": "SOURCES/BoM"
    },
    "CAC": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CAC",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CAC/.dataset_documentation.html",
            "iridlhasSemantics": "iridl:NOAA",
            "Conventions": "IRIDL",
            "history": "Climate Analysis Center SST",
            "references": "Woodruff_etal1993 Reynolds_Smith1994",
            "description": "Climatological, smoothed, and raw sea surface temperature data for the tropical Pacific Ocean from the Climate Analysis Center (now known as the Climate Prediction Center)"
        },
        "ssta": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ssta",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_Celsius",
            "scale_max": "4.1999998",
            "ncolor": "254",
            "scale_min": "-4.1999998",
            "CS": "-4.1999998",
            "colorscalename": "sstacolorscale",
            "CE": "4.1999998",
            "maxncolor": "254",
            "colormap": "2763429",
            "long_name": "Sea Surface Temperature Anomaly"
        },
        "sst": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "sst",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "Celsius_scale",
            "long_name": "Sea Surface Temperature"
        },
        "smoothed": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "smoothed",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "ssta": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ssta",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_Celsius",
                "scale_max": "4.1999998",
                "ncolor": "254",
                "scale_min": "-4.1999998",
                "CS": "-4.1999998",
                "colorscalename": "sstacolorscale",
                "CE": "4.1999998",
                "maxncolor": "254",
                "colormap": "2763429",
                "long_name": "Sea Surface Temperature Anomaly"
            },
            "sst": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "sst",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "Celsius_scale",
                "long_name": "Sea Surface Temperature"
            }
        },
        "climatology": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "climatology",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "sst": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "sst",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "Celsius_scale",
                "long_name": "Sea Surface Temperature"
            }
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "2.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "2.0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "1",
            "modulo": "12.0",
            "modulus": "12.0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "dir": "SOURCES/CAC"
    },
    "CARDONE": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CARDONE",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "description": "ECMWF five day average wind stress; Cardone Level 2B data",
            "iridlhasSemantics": "iridl:Oceanweather",
            "Conventions": "IRIDL"
        },
        "tauy": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "tauy",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "9999.0",
            "scale_factor": "0.001",
            "history": "ECMWF five day average wind stress.  This is Cardone Level 2B data.",
            "long_name": "meridional wind stress",
            "units": "dynes/cm2"
        },
        "taux": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "taux",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "9999.0",
            "scale_factor": "0.001",
            "history": "ECMWF five day average wind stress.  This is Cardone Level 2B data.",
            "long_name": "zonal wind stress",
            "units": "dynes/cm2"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "5.0",
            "add_offset": "2444971"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "1.875"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "1.875"
        },
        "dir": "SOURCES/CARDONE"
    },
    "CARTON": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CARTON",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "SODA3SODA331Creation_date": "October 2016",
            "SODA3SODA331source": "http://www.atmos.umd.edu/~ocean/index_files/soda3.3.1_mn_download.htm",
            "SODA3SODA331Created_by": "Gennady Chepurin and Ligang Chen",
            "SODA3SODA331dataset_documentation": "http://www.atmos.umd.edu/~ocean/index_files/soda3_readme.htm",
            "SODA3SODA331Principal_investigator_email": "carton@atmos.umd.edu",
            "SODA3SODA331Acknowledgement": "The SODA3 project is funded by the US National Science Foundation. Please cite: Carton, Chepurin, and Chen (2017)",
            "SODA3SODA331Institution": "University of Maryland",
            "SODA3SODA331Website": "http://www.soda.umd.edu",
            "SODA3SODA331Title": "SODA3.3.1 ocean state",
            "SODA3SODA331Principal_investigator": "James A. Carton",
            "Conventions": "IRIDL"
        },
        "SODA3": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SODA3",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "SODA331": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SODA3.3.1",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "wt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "100000.0",
                    "cell_methods": "time: mean",
                    "long_name": "dia-surface velocity T-points",
                    "standard_name": "",
                    "units": "m/sec",
                    "pointwidth": "0"
                },
                "v": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "v",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "10.0",
                    "cell_methods": "time: mean",
                    "long_name": "j-current",
                    "standard_name": "sea_water_y_velocity",
                    "units": "m/sec",
                    "pointwidth": "0"
                },
                "u": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "u",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "10.0",
                    "cell_methods": "time: mean",
                    "long_name": "i-current",
                    "standard_name": "sea_water_x_velocity",
                    "units": "m/sec",
                    "pointwidth": "0"
                },
                "temp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "500.0",
                    "cell_methods": "time: mean",
                    "long_name": "Potential temperature",
                    "standard_name": "sea_water_potential_temperature",
                    "units": "degrees C",
                    "pointwidth": "0"
                },
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "10.0",
                    "cell_methods": "time: mean",
                    "long_name": "j-directed wind stress forcing v-velocity",
                    "standard_name": "surface_downward_y_stress",
                    "units": "N/m^2",
                    "pointwidth": "0"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "10.0",
                    "cell_methods": "time: mean",
                    "long_name": "i-directed wind stress forcing u-velocity",
                    "standard_name": "surface_downward_x_stress",
                    "units": "N/m^2",
                    "pointwidth": "0"
                },
                "ssh": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssh",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "1000.0",
                    "cell_methods": "time: mean",
                    "long_name": "effective sea level (eta_t + patm/(rho0*g)) on T cells",
                    "standard_name": "sea_surface_height_above_geoid",
                    "units": "m",
                    "pointwidth": "0"
                },
                "salt_flux_total": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "salt_flux_total",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "10000.0",
                    "cell_methods": "time: mean",
                    "long_name": "sfc_salt_flux_total",
                    "standard_name": "",
                    "units": "kg/(m^2*sec)",
                    "pointwidth": "0"
                },
                "salt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "salt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "100.0",
                    "cell_methods": "time: mean",
                    "long_name": "Practical Salinity",
                    "standard_name": "sea_water_salinity",
                    "units": "psu",
                    "pointwidth": "0"
                },
                "prho": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "prho",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "100000.0",
                    "cell_methods": "time: mean",
                    "long_name": "potential density referenced to 0 dbar",
                    "standard_name": "sea_water_potential_density",
                    "units": "kg/m^3",
                    "pointwidth": "0"
                },
                "net_heating": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "net_heating",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "10000.0",
                    "cell_methods": "time: mean",
                    "long_name": "surface ocean heat flux coming through coupler and mass transfer",
                    "standard_name": "",
                    "units": "W/m2",
                    "pointwidth": "0"
                },
                "mlt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "mlt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "1000000.0",
                    "cell_methods": "time: mean",
                    "long_name": "mixed layer depth determined by temperature criteria",
                    "standard_name": "",
                    "units": "m",
                    "pointwidth": "0"
                },
                "mls": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "mls",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "1000000.0",
                    "cell_methods": "time: mean",
                    "long_name": "mixed layer depth determined by salinity criteria",
                    "standard_name": "",
                    "units": "m",
                    "pointwidth": "0"
                },
                "mlp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "mlp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "1000000.0",
                    "cell_methods": "time: mean",
                    "long_name": "Depth of potential density mixed layer",
                    "standard_name": "",
                    "units": "m",
                    "pointwidth": "0"
                },
                "mi": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "mi",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "cell_methods": "time: mean",
                    "long_name": "Sea Ice Mass",
                    "units": "kg/m^2",
                    "pointwidth": "0"
                },
                "isotemp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "isotemp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "long_name": "potential temperature at the depth of isopycn",
                    "units": "degrees C",
                    "pointwidth": "0"
                },
                "isosalt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "isosalt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "long_name": "salinity at the depth of isopycn",
                    "units": "psu",
                    "pointwidth": "0"
                },
                "isodepth": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "isodepth",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "long_name": "depth of isoypycn",
                    "units": "m",
                    "pointwidth": "0"
                },
                "hs": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "hs",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "cell_methods": "time: mean",
                    "long_name": "Snow Thickness",
                    "units": "m-snow",
                    "pointwidth": "0"
                },
                "hi": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "hi",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "cell_methods": "time: mean",
                    "long_name": "Sea Ice Thickness",
                    "units": "m-ice",
                    "pointwidth": "0"
                },
                "cn": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "cn",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "cell_methods": "time: mean ct: mean",
                    "long_name": "Sea Ice Concentration",
                    "units": "0-1",
                    "pointwidth": "0"
                },
                "anompb": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "anompb",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-1.00000002E20",
                    "valid_range": "1000000.0",
                    "cell_methods": "time: mean",
                    "long_name": "T-cell bottom pressure - rho0*grav*ht",
                    "standard_name": "",
                    "units": "dbar",
                    "pointwidth": "0"
                }
            }
        },
        "depth": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "depth",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0"
        },
        "z": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "z",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0"
        },
        "level": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "level",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0"
        },
        "time": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "latitude": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "latitude",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "0.5"
        },
        "longitude": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "longitude",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "pointwidth": "0.5"
        },
        "dir": "SOURCES/CARTON"
    },
    "CARTONGIESE": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CARTON-GIESE",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "SODAv2p2p4source": "http://dsrs.atmos.umd.edu/DATA/soda_2.2.4/",
            "SODAv2p2p4long_name": "SODA 2.2.4, 1871-2008 Assimilation Run",
            "SODAv2p2p4released": "July 20, 2010",
            "SODAv2p2p4description": "Oceanic and air-sea interface data from the UMD Simple Ocean Data Assimilation Reanalysis",
            "SODAv2p2p4documentation": "http://www.atmos.umd.edu/~carton/pdfs/carton&giese05.pdf",
            "SODAv2p2p4readme": "http://dsrs.atmos.umd.edu/DATA/soda_2.2.4/README.txt",
            "SODAv2p1p6source": "http://dsrs.atmos.umd.edu/DATA/soda_2.1.6/",
            "SODAv2p1p6long_name": "SODA 2.1.6",
            "SODAv2p1p6references": "Carton_Giese2007",
            "SODAv2p1p6SODA": "http://www.atmos.umd.edu/~carton/pdfs/carton&giese05.pdf",
            "SODAv2p1p6description": "Oceanic and air-sea interface data from the UMD Simple Ocean Data Assimilation Reanalysis",
            "SODAv2p1p6iridlhasSemantics": "iridl:Ocean",
            "SODAv2p0p24SODA": "http://www.atmos.umd.edu/~carton/pdfs/carton&giese05.pdf",
            "SODAv2p0p24long_name": "Version 2.0.2-4",
            "SODAv2p0p24references": "Carton_Giese2007",
            "SODAv2p0p24title": "SODA - POP 2.0.2-4 Assimilation Giese/Carton",
            "SODAv2p0p24iridlhasSemantics": "iridl:Ocean",
            "SODAv2p0p23long_name": "Version 2.0.2-3",
            "SODAv2p0p23references": "Carton_Giese2007",
            "SODAv2p0p23SODA": "http://iridl.ldeo.columbia.edu/SOURCES/.CARTON-GIESE/.SODA/.v2p0p2-4/",
            "SODAv2p0p23title": "SODA - POP 2.0.2-3 Assimilation Giese/Carton",
            "SODAv2p0p23iridlhasSemantics": "iridl:Ocean",
            "SODAv1p4p3source": "http://dsrs.atmos.umd.edu/DATA/SODA_1.4.3/",
            "SODAv1p4p3long_name": "Version 1.4.3",
            "SODAv1p4p3references": "Carton_Giese2006",
            "SODAv1p4p3SODA": "http://iridl.ldeo.columbia.edu/SOURCES/.CARTON-GIESE/.SODA/.v2p0p2-3/",
            "SODAv1p4p3title": "SODA - POP 1.4.3 Assimilation TAMU/UMD",
            "SODAv1p4p3iridlhasSemantics": "iridl:Ocean",
            "SODAv1p4p2source": "http://dsrs.atmos.umd.edu/DATA/SODA_1.4.2/",
            "SODAv1p4p2long_name": "Version 1.4.2",
            "SODAv1p4p2references": "Carton_Giese2006",
            "SODAv1p4p2SODA": "http://iridl.ldeo.columbia.edu/SOURCES/.CARTON-GIESE/.SODA/.v2p0p2-3/",
            "SODAv1p4p2title": "SODA - POP 1.4.2 Assimilation TAMU/UMD",
            "SODAv1p4p2iridlhasSemantics": "iridl:Ocean",
            "SODAv1p2SODA": "http://www.atmos.umd.edu/~ocean/soda1.2.pdf",
            "SODAv1p2source": "http://dsrs.atmos.umd.edu/DATA/SODA_1.2/",
            "SODAv1p2long_name": "Version 1.2",
            "SODAv1p2references": "Carton_etal2000a Carton_etal2000b",
            "SODAv1p2title": "SODA - POP 1.2 Assimilation TAMU/UMD",
            "SODAdescription": "SODA: A Reanalysis of Ocean Climate",
            "SODAlong_name": "Simple Ocean Data Assimilation",
            "iridlhasSemantics": "iridl:TAMU",
            "Conventions": "IRIDL",
            "long_name": "Carton/Giese"
        },
        "SODA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SODA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "v2p2p4": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v2p2p4",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "w": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "w",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "VERTICAL VELOCITY",
                    "units": "m/sec",
                    "standard_name": "upward_sea_water_velocity",
                    "pointwidth": "1.0"
                },
                "v": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "v",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "MERIDIONAL VELOCITY",
                    "units": "m/sec",
                    "standard_name": "northward_sea_water_velocity",
                    "pointwidth": "1.0"
                },
                "u": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "u",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "ZONAL VELOCITY",
                    "units": "m/sec",
                    "standard_name": "eastward_sea_water_velocity",
                    "pointwidth": "1.0"
                },
                "temp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TEMPERATURE",
                    "units": "Celsius_scale",
                    "standard_name": "sea_water_temperature",
                    "pointwidth": "1.0"
                },
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAUY",
                    "units": "N/m2",
                    "standard_name": "surface_downward_northward_stress",
                    "pointwidth": "1.0"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAUX",
                    "units": "N/m2",
                    "standard_name": "surface_downward_eastward_stress",
                    "pointwidth": "1.0"
                },
                "ssh": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssh",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "SEA SURFACE HEIGHT",
                    "units": "meters",
                    "standard_name": "sea_surface_height",
                    "pointwidth": "1.0"
                },
                "salt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "salt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "iridlhasSemantics": "iridl:Salinity",
                    "long_name": "SALINITY",
                    "units": "g/kg",
                    "pointwidth": "1.0"
                }
            },
            "v2p1p6": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v2p1p6",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "v": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "v",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "MERIDIONAL VELOCITY",
                    "units": "m/sec",
                    "standard_name": "northward_sea_water_velocity",
                    "pointwidth": "1.0"
                },
                "u": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "u",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "ZONAL VELOCITY",
                    "units": "m/sec",
                    "standard_name": "eastward_sea_water_velocity",
                    "pointwidth": "1.0"
                },
                "temp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TEMPERATURE",
                    "units": "Celsius_scale",
                    "standard_name": "sea_water_temperature",
                    "pointwidth": "1.0"
                },
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAUY",
                    "units": "N/m2",
                    "standard_name": "surface_downward_northward_stress",
                    "pointwidth": "1.0"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAUX",
                    "units": "N/m2",
                    "standard_name": "surface_downward_eastward_stress",
                    "pointwidth": "1.0"
                },
                "ssh": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssh",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "SEA SURFACE HEIGHT",
                    "units": "meters",
                    "standard_name": "sea_surface_height",
                    "pointwidth": "1.0"
                },
                "salt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "salt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "iridlhasSemantics": "iridl:Salinity",
                    "long_name": "SALINITY",
                    "units": "g/kg",
                    "pointwidth": "1.0"
                }
            },
            "v2p0p24": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v2p0p2-4",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "w": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "w",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "VERTICAL VELOCITY",
                    "units": "m/sec",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "v": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "v",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "MERIDIONAL VELOCITY",
                    "units": "m/sec",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "u": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "u",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "ZONAL VELOCITY",
                    "units": "m/sec",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "temp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TEMPERATURE",
                    "units": "Celsius_scale",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAU Y",
                    "units": "N/m2",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAU X",
                    "units": "N/m2",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "ssh": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssh",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "SEA LEVEL HEIGHT",
                    "units": "meters",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "salt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "salt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "iridlhasSemantics": "iridl:Salinity",
                    "long_name": "SALINITY",
                    "units": "g/kg",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                }
            },
            "v2p0p23": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v2p0p2-3",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "w": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "w",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "VERTICAL VELOCITY",
                    "units": "m/sec",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "v": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "v",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "MERIDIONAL VELOCITY",
                    "units": "m/sec",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "u": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "u",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "ZONAL VELOCITY",
                    "units": "m/sec",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "temp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TEMPERATURE",
                    "units": "Celsius_scale",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAU Y",
                    "units": "N/m2",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAU X",
                    "units": "N/m2",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "ssh": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssh",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "SEA LEVEL HEIGHT",
                    "units": "meters",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                },
                "salt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "salt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "iridlhasSemantics": "iridl:Salinity",
                    "long_name": "SALINITY",
                    "units": "g/kg",
                    "fnname": "flaggt",
                    "pointwidth": "1.0"
                }
            },
            "v1p4p3": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v1p4p3",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "v": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "v",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "MERIDIONAL VELOCITY",
                    "units": "cm/sec",
                    "pointwidth": "1.0"
                },
                "u": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "u",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "ZONAL VELOCITY",
                    "units": "cm/sec",
                    "pointwidth": "1.0"
                },
                "temp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TEMPERATURE",
                    "units": "Celsius_scale",
                    "pointwidth": "1.0"
                },
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAU Y",
                    "units": "dynes/cm^2",
                    "pointwidth": "1.0"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAU X",
                    "units": "dynes/cm^2",
                    "pointwidth": "1.0"
                },
                "ssh": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssh",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "SEA LEVEL HEIGHT",
                    "units": "cm",
                    "pointwidth": "1.0"
                },
                "salt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "salt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "SALINITY",
                    "units": "ppt",
                    "pointwidth": "1.0"
                }
            },
            "v1p4p2": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v1p4p2",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "v": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "v",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "MERIDIONAL VELOCITY",
                    "units": "cm/sec",
                    "pointwidth": "1.0"
                },
                "u": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "u",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "ZONAL VELOCITY",
                    "units": "cm/sec",
                    "pointwidth": "1.0"
                },
                "temp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TEMPERATURE",
                    "units": "Celsius_scale",
                    "pointwidth": "1.0"
                },
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAU Y",
                    "units": "dynes/cm^2",
                    "pointwidth": "1.0"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAU X",
                    "units": "dynes/cm^2",
                    "pointwidth": "1.0"
                },
                "ssh": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssh",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "SEA LEVEL HEIGHT",
                    "units": "cm",
                    "pointwidth": "1.0"
                },
                "salt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "salt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "iridlhasSemantics": "iridl:Salinity",
                    "long_name": "SALINITY",
                    "units": "ppt",
                    "pointwidth": "1.0"
                }
            },
            "v1p2": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v1p2",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "v": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "v",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "MERIDIONAL VELOCITY",
                    "units": "cm/sec",
                    "pointwidth": "1.0"
                },
                "u": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "u",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "ZONAL VELOCITY",
                    "units": "cm/sec",
                    "pointwidth": "1.0"
                },
                "temp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TEMPERATURE",
                    "units": "Celsius_scale",
                    "pointwidth": "1.0"
                },
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAU Y",
                    "units": "dynes/cm^2",
                    "pointwidth": "1.0"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "TAU X",
                    "units": "dynes/cm^2",
                    "pointwidth": "1.0"
                },
                "ssh": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssh",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "SEA LEVEL HEIGHT",
                    "units": "cm",
                    "pointwidth": "1.0"
                },
                "salt": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "salt",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-9.98999971E33",
                    "long_name": "SALINITY",
                    "units": "ppt",
                    "pointwidth": "1.0"
                }
            }
        },
        "time_05": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_05",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "time_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "time_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "time_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "depth_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "depth_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "meters",
            "gridtype": "0"
        },
        "time_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "time": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "lon": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "lon",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "0.5"
        },
        "lat": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "lat",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.5"
        },
        "depth": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "depth",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "meters",
            "gridtype": "0"
        },
        "dir": "SOURCES/CARTON-GIESE"
    },
    "CAYAN": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CAYAN",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "description": "Heat flux and irradiance data analysis of COADS from Cayan of Scripps",
            "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CAYAN/.dataset_documentation.html",
            "iridlhasSemantics": "iridl:SIO",
            "Conventions": "IRIDL",
            "references": "Cayan1992"
        },
        "Ti": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Ti",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "W/m2",
            "missing_value": "-99999.0",
            "long_name": "terrestrial irradiance",
            "history": "Cayan Terrestrial Irradiance Derived from COADS"
        },
        "Si": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Si",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "W/m2",
            "missing_value": "-99999.0",
            "long_name": "solar irradiance",
            "history": "Cayan Solar Irradiance Derived from COADS"
        },
        "Qsh": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Qsh",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "W/m2",
            "missing_value": "-99999.0",
            "long_name": "sensible heat flux",
            "history": "Cayan Sensible Heat Flux Derived from COADS"
        },
        "Qnet": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Qnet",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "W/m2",
            "missing_value": "-99999.0",
            "long_name": "net heat flux",
            "history": "Cayan Net Heat Flux Derived from COADS"
        },
        "Qlh": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Qlh",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "W/m2",
            "missing_value": "-99999.0",
            "long_name": "latent heat flux",
            "history": "Cayan Latent Heat Derived from COADS"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "5.0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "long_name": "month",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "5.0"
        },
        "dir": "SOURCES/CAYAN"
    },
    "CCCma": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CCCma",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "DECADALuninitialized55_year_runmonthlyATMhistory": "2011-03-07T23:19:04Z CMOR rewrote data to comply with CF standards and CMIP5 requirements.",
            "DECADALuninitialized55_year_runmonthlyATMexperiment": "10- or 30-year run initialized in year 1960",
            "DECADALuninitialized55_year_runmonthlyATMCCCma_runid": "DHFP1B_E010_I1961_M01",
            "DECADALuninitialized55_year_runmonthlyATMmodel_id": "CanCM4",
            "DECADALuninitialized55_year_runmonthlyATMforcing": "GHG,Oz,SA,BC,OC,LU,Sl,Vl (GHG includes CO2,CH4,N2O,CFC11,effective CFC12)",
            "DECADALuninitialized55_year_runmonthlyATMtable_id": "Table Amon (31 January 2011) 53b766a395ac41696af40aab76a49ae5",
            "DECADALuninitialized55_year_runmonthlyATMinstitution": "CCCma (Canadian Centre for Climate Modelling and Analysis, Victoria, BC, Canada)",
            "DECADALuninitialized55_year_runmonthlyATMsource": "CanCM4 2010 atmosphere: CanAM4 (AGCM15i, T63L35) ocean: CanOM4 (OGCM4.0, 256x192L40) sea ice: CanSIM1 (Cavitating Fluid, T63 Gaussian Grid) land: CLASS2.7",
            "DECADALuninitialized55_year_runmonthlyATMmodeling_realm": "atmos",
            "DECADALuninitialized55_year_runmonthlyATMexperiment_id": "decadal1960",
            "DECADALuninitialized55_year_runmonthlyATMcreation_date": "2011-03-07T23:19:04Z",
            "DECADALuninitialized55_year_runmonthlyATMinstitute_id": "CCCma",
            "DECADALuninitialized55_year_runmonthlyATMtitle": "CanCM4 model output prepared for CMIP5 10- or 30-year run initialized in year 1960",
            "DECADALuninitialized55_year_runmonthlyATMConventions": "CF-1.4",
            "DECADALuninitialized55_year_runmonthlyATMcontact": "cccma_info@ec.gc.ca",
            "DECADALuninitialized55_year_runmonthlyATMcmor_version": "2.5.4",
            "DECADALuninitialized55_year_runmonthlyATMphysics_version": "1",
            "DECADALuninitialized55_year_runmonthlyATMparent_experiment_rip": "N/A",
            "DECADALuninitialized55_year_runmonthlyATMproject_id": "CMIP5",
            "DECADALinitialized30_year_runmonthlyATMhistory": "2011-03-07T23:19:04Z CMOR rewrote data to comply with CF standards and CMIP5 requirements.",
            "DECADALinitialized30_year_runmonthlyATMexperiment": "10- or 30-year run initialized in year 1960",
            "DECADALinitialized30_year_runmonthlyATMCCCma_runid": "DHFP1B_E010_I1961_M01",
            "DECADALinitialized30_year_runmonthlyATMmodel_id": "CanCM4",
            "DECADALinitialized30_year_runmonthlyATMforcing": "GHG,Oz,SA,BC,OC,LU,Sl,Vl (GHG includes CO2,CH4,N2O,CFC11,effective CFC12)",
            "DECADALinitialized30_year_runmonthlyATMtable_id": "Table Amon (31 January 2011) 53b766a395ac41696af40aab76a49ae5",
            "DECADALinitialized30_year_runmonthlyATMinstitution": "CCCma (Canadian Centre for Climate Modelling and Analysis, Victoria, BC, Canada)",
            "DECADALinitialized30_year_runmonthlyATMsource": "CanCM4 2010 atmosphere: CanAM4 (AGCM15i, T63L35) ocean: CanOM4 (OGCM4.0, 256x192L40) sea ice: CanSIM1 (Cavitating Fluid, T63 Gaussian Grid) land: CLASS2.7",
            "DECADALinitialized30_year_runmonthlyATMmodeling_realm": "atmos",
            "DECADALinitialized30_year_runmonthlyATMexperiment_id": "decadal1960",
            "DECADALinitialized30_year_runmonthlyATMcreation_date": "2011-03-07T23:19:04Z",
            "DECADALinitialized30_year_runmonthlyATMinstitute_id": "CCCma",
            "DECADALinitialized30_year_runmonthlyATMtitle": "CanCM4 model output prepared for CMIP5 10- or 30-year run initialized in year 1960",
            "DECADALinitialized30_year_runmonthlyATMConventions": "CF-1.4",
            "DECADALinitialized30_year_runmonthlyATMcontact": "cccma_info@ec.gc.ca",
            "DECADALinitialized30_year_runmonthlyATMcmor_version": "2.5.4",
            "DECADALinitialized30_year_runmonthlyATMphysics_version": "1",
            "DECADALinitialized30_year_runmonthlyATMparent_experiment_rip": "N/A",
            "DECADALinitialized30_year_runmonthlyATMproject_id": "CMIP5",
            "DECADALinitialized10_year_runmonthlyATMhistory": "2011-03-07T23:19:04Z CMOR rewrote data to comply with CF standards and CMIP5 requirements.",
            "DECADALinitialized10_year_runmonthlyATMexperiment": "10- or 30-year run initialized in year 1960",
            "DECADALinitialized10_year_runmonthlyATMCCCma_runid": "DHFP1B_E010_I1961_M01",
            "DECADALinitialized10_year_runmonthlyATMmodel_id": "CanCM4",
            "DECADALinitialized10_year_runmonthlyATMforcing": "GHG,Oz,SA,BC,OC,LU,Sl,Vl (GHG includes CO2,CH4,N2O,CFC11,effective CFC12)",
            "DECADALinitialized10_year_runmonthlyATMtable_id": "Table Amon (31 January 2011) 53b766a395ac41696af40aab76a49ae5",
            "DECADALinitialized10_year_runmonthlyATMinstitution": "CCCma (Canadian Centre for Climate Modelling and Analysis, Victoria, BC, Canada)",
            "DECADALinitialized10_year_runmonthlyATMsource": "CanCM4 2010 atmosphere: CanAM4 (AGCM15i, T63L35) ocean: CanOM4 (OGCM4.0, 256x192L40) sea ice: CanSIM1 (Cavitating Fluid, T63 Gaussian Grid) land: CLASS2.7",
            "DECADALinitialized10_year_runmonthlyATMmodeling_realm": "atmos",
            "DECADALinitialized10_year_runmonthlyATMexperiment_id": "decadal1960",
            "DECADALinitialized10_year_runmonthlyATMcreation_date": "2011-03-07T23:19:04Z",
            "DECADALinitialized10_year_runmonthlyATMinstitute_id": "CCCma",
            "DECADALinitialized10_year_runmonthlyATMtitle": "CanCM4 model output prepared for CMIP5 10- or 30-year run initialized in year 1960",
            "DECADALinitialized10_year_runmonthlyATMConventions": "CF-1.4",
            "DECADALinitialized10_year_runmonthlyATMcontact": "cccma_info@ec.gc.ca",
            "DECADALinitialized10_year_runmonthlyATMcmor_version": "2.5.4",
            "DECADALinitialized10_year_runmonthlyATMphysics_version": "1",
            "DECADALinitialized10_year_runmonthlyATMparent_experiment_rip": "N/A",
            "DECADALinitialized10_year_runmonthlyATMproject_id": "CMIP5",
            "DECADALdescription": "CanCM4 model output",
            "DECADALsource": "http://www.ec.gc.ca/ccmac-cccma/default.asp?lang=En&n=8A6F8F67-1",
            "DECADALreferences": "Arora_VK_etal_2011 Merryfield_WJ_etal2011",
            "description": "The Canadian Centre for Climate Modelling and Analysis",
            "Conventions": "IRIDL"
        },
        "DECADAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "DECADAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "uninitialized": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "uninitialized",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "_year_run": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "55_year_run",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "monthly": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "monthly",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ATM": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ATM",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "standard_name": "time",
                                "long_name": "Forecast time",
                                "units": "months since 1960-01-01",
                                "calendar": "360",
                                "pointwidth": "1"
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "long_name": "Near-Surface Air Temperature",
                                    "units": "Kelvin_scale",
                                    "standard_name": "air_temperature",
                                    "pointwidth": "1.0"
                                },
                                "pr": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pr",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "long_name": "Precipitation",
                                    "units": "kg m-2 s-1",
                                    "standard_name": "precipitation_flux",
                                    "pointwidth": "1.0"
                                }
                            }
                        }
                    }
                }
            },
            "initialized": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "initialized",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "_year_run": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "10_year_run",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "monthly": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "monthly",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ATM": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ATM",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "standard_name": "time",
                                "long_name": "Forecast time",
                                "units": "months since 1960-01-01",
                                "calendar": "360",
                                "pointwidth": "1"
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "institution": "Canadian Centre for Climate Modelling and Analysis, Victoria, BC, Canada",
                                    "long_name": "Near-Surface Air Temperature",
                                    "units": "Kelvin_scale",
                                    "standard_name": "air_temperature",
                                    "pointwidth": "0"
                                },
                                "pr": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pr",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "long_name": "Precipitation",
                                    "units": "kg m-2 s-1",
                                    "standard_name": "precipitation_flux",
                                    "pointwidth": "0"
                                }
                            }
                        }
                    }
                }
            }
        },
        "L_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "L_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "forecast_period",
            "long_name": "Lead time",
            "pointwidth": "1"
        },
        "S_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "S_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "forecast_reference_time",
            "long_name": "Start time",
            "pointwidth": "0"
        },
        "L_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "L_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "forecast_period",
            "long_name": "Lead time",
            "pointwidth": "1"
        },
        "S_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "S_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "forecast_reference_time",
            "long_name": "Start time",
            "pointwidth": "0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude"
        },
        "L": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "L",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months",
            "gridtype": "0",
            "long_name": "Lead time",
            "calendar": "360",
            "standard_name": "forecast_period",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "2.8125"
        },
        "M": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "M",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "long_name": "Member",
            "pointwidth": "1.0"
        },
        "S": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "S",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "forecast_reference_time",
            "long_name": "Start time",
            "pointwidth": "0"
        },
        "dir": "SOURCES/CCCma"
    },
    "CCROM": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CCROM",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "description": "Centre for Climate Risk and Opportunity Management in Southeast Asia Pacific",
            "Conventions": "IRIDL"
        },
        "Lao": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Lao",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "stations": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "stations",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Tmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Tmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "ncolor": "254",
                    "colorscalename": "temp_colors",
                    "maxncolor": "254",
                    "colormap": "255",
                    "long_name": "Minimum Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "-999.0"
                },
                "Tmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Tmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "ncolor": "254",
                    "colorscalename": "temp_colors",
                    "maxncolor": "254",
                    "colormap": "255",
                    "long_name": "Maximum Temperature",
                    "units": "Celsius_scale",
                    "missing_value": "NaN",
                    "fnname": "maskle",
                    "file_missing_value": "-999.0"
                },
                "Rainfall": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Rainfall",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "0.0",
                    "CS": "0",
                    "maxncolor": "254",
                    "colorscalename": "precip_colors",
                    "colormap": "290304",
                    "ncolor": "254",
                    "long_name": "Total Rainfall",
                    "units": "mm",
                    "missing_value": "-999.0"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "108.0",
                    "long_name": "Longitude",
                    "units": "degree_east",
                    "scale_min": "100.0"
                },
                "location": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "location",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "OpenGISSimpleFeature": "Point",
                    "long_name": "location",
                    "SpatialReferenceSystemWKT": "]]",
                    "scale_max": "108.0",
                    "units": "degree_east",
                    "scale_min": "100.0"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "23.0",
                    "long_name": "Latitude",
                    "units": "degree_north",
                    "scale_min": "13.5"
                },
                "label": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "label",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "label"
                }
            }
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "scale_min": "2444239.5",
            "scale_max": "2455562.5",
            "units": "julian_day",
            "add_offset": "2444239.5",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "Station": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Station",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2"
        },
        "dir": "SOURCES/CCROM"
    },
    "CDIAC": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CDIAC",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "USHCNdailyUSHCN": "http://cdiac.ornl.gov/epubs/ndp/ushcn/daily_doc.html",
            "USHCNdailycitation": "M. J. Menne, C. N. Williams, Jr., and R. S. Vose, 2015. United States Historical Climatology Network Daily Temperature, Precipitation, and Snow Data. Carbon Dioxide Information Analysis Center, Oak Ridge National Laboratory, Oak Ridge, Tennessee",
            "USHCNdailyreferences": "Easterling_etal1996 Hughes_etal1992 Karl_etal1990 Quinlan_etal1987 Williams_etal2004",
            "USHCNdescription": "United States Historical Climatology Network",
            "tr051references": "Eischeid_etal1991",
            "tr051description": "Comprehensive preciptation anomaly data set for global land areas",
            "tr051dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CDIAC/.tr051.dataset_documentation.html",
            "ndp043adescription": "Coastal hazards data base for United States East Coast",
            "ndp043airidlhasSemantics": "iriref:White_TW",
            "ndb017references": "Olson_etal1983",
            "ndb017description": "Major world ecosystem complexes ranked by carbon in live vegetation",
            "ndb017source": ">Olson Vegetation Complexes</a>",
            "ndb017dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CDIAC/.ndb017.dataset_documentation.html",
            "ndb017long_name": "MAJOR WORLD ECOSYSTEM COMPLEXES RANKED BY CARBON IN LIVE VEGETATION",
            "msudescription": "MSU-measured precipitation from CDIAC",
            "description": "Carbon Dioxide Information Analysis Center",
            "iridlhasSemantics": "CDIAC",
            "Conventions": "IRIDL"
        },
        "USHCN": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "USHCN",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "daily": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "daily",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "tmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "Fahrenheit_scale",
                    "missing_value": "-99.0",
                    "standard_name": "air_temperature",
                    "long_name": "minimum temperature"
                },
                "tmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "Fahrenheit_scale",
                    "missing_value": "-99.0",
                    "standard_name": "air_temperature",
                    "long_name": "maximum temperature"
                },
                "state": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "state",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "state abbreviation",
                    "units": "ids"
                },
                "snowfall": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "snowfall",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "inches/day",
                    "missing_value": "-99.900002",
                    "standard_name": "thickness_of_snowfall_amount"
                },
                "snow_depth": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "snow_depth",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "inches",
                    "missing_value": "-99.0",
                    "standard_name": "thickness_of_snowfall_amount"
                },
                "prcp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "prcp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "inches/day",
                    "missing_value": "-99.989998",
                    "standard_name": "lwe_precipitation_rate",
                    "long_name": "precipitation"
                },
                "Name": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Name",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "-132.0",
                    "scale_max": "-60.0",
                    "units": "degree_east",
                    "long_name": "longitude"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "20.0",
                    "scale_max": "52.0",
                    "units": "degree_north",
                    "long_name": "latitude"
                },
                "elev": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "elev",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "elevation",
                    "units": "m"
                },
                "comp3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "comp3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Coop ID for third station used to create time series",
                    "units": "ids"
                },
                "comp2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "comp2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Coop ID for second station used to create time series",
                    "units": "ids"
                },
                "comp1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "comp1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Coop ID for first station used to create time series",
                    "units": "ids"
                }
            }
        },
        "tr051": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "tr051",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "precipitation": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "precipitation",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "anomalies": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "anomalies",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "mm",
                    "missing_value": "-9999.9902"
                }
            }
        },
        "ndp043a": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ndp043a",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "WHSD": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "WHSD",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "standard deviation of the 20-year mean wave height",
                "units": "m"
            },
            "WHMAX": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "WHMAX",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "maximum significant wave height",
                "units": "m"
            },
            "WHAVG": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "WHAVG",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "20-year mean wave height",
                "units": "m"
            },
            "TRNUM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "TRNUM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "number of tide gauge stations used in tide calculations",
                "units": "unitless"
            },
            "TRMAX": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "TRMAX",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "maximum tide range",
                "units": "m"
            },
            "TRLVL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "TRLVL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "mean tide level",
                "units": "m"
            },
            "TRAVG": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "TRAVG",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "mean tide range",
                "units": "m"
            },
            "SLYR": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SLYR",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "years of record used in sea level trend",
                "units": "unitless"
            },
            "SLS": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SLS",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "local subsidence trend",
                "units": "mm/year"
            },
            "SLR": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SLR",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "relative sea level trend",
                "units": "mm/year"
            },
            "SLG": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SLG",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "long-term geologic-trend  derived from 14C data",
                "units": "mm/year"
            },
            "SLC": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SLC",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "corrected sea level trend",
                "units": "mm/year"
            },
            "GM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "GM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.0",
                "long_name": "landform inundation-and-erosion susceptibility index",
                "units": "unitless"
            },
            "GL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "GL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.0",
                "long_name": "rock erosion resistance index",
                "units": "unitless"
            },
            "ERNUM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ERNUM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "number of 3\\', 7.5\\', or 15\\' grid cells used in calculating erosion",
                "units": "unitless"
            },
            "ERMIN": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ERMIN",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "minimum long-term erosion trend",
                "units": "m"
            },
            "ERMAX": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ERMAX",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "maximum long-term erosion trend",
                "units": "m"
            },
            "ERAVG": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ERAVG",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "mean long-term erosion trend",
                "units": "m"
            },
            "ELNUM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ELNUM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "number of cells used in elevation",
                "units": "unitless"
            },
            "ELMIN": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ELMIN",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "minimum non-negative elevation",
                "units": "m"
            },
            "ELMAX": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ELMAX",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "maximum non-negative elevation",
                "units": "m"
            },
            "ELAVG": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ELAVG",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "9999.9902",
                "long_name": "mean non-negative elevation",
                "units": "m"
            }
        },
        "ndb017": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ndb017",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "_class": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "class",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "long_name": "land ecosystem class"
            }
        },
        "msu": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "msu",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "precipitation": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "precipitation",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "-99.900002",
                "units": "mm",
                "long_name": "precipitation"
            }
        },
        "STNID_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "STNID_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "0"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "STNID": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "STNID",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "0"
        },
        "X_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "5.0"
        },
        "Y_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "4.0"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "3.0"
        },
        "X_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.25"
        },
        "Y_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.25"
        },
        "X_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "0.5"
        },
        "Y_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.5"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "2.5"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "2.5"
        },
        "dir": "SOURCES/CDIAC"
    },
    "CEREGE": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CEREGE",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Indonesia_station_preciptitle": "Indonesia Station Rainfall Observations",
            "Indonesia_station_precipDescription": "Compilation of station rainfall data over Indonesia 1961--2010 , from Hamada and GSOD (NCDC and CPC).Compiled by V. Moron (moron@cerege.fr).",
            "Conventions": "IRIDL"
        },
        "Indonesia_station_precip": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Indonesia_station_precip",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "prec": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "prec",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "-999.0",
                "units": "mm",
                "long_name": "precipitation_amount"
            },
            "lon": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "lon",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "-999.0",
                "units": "degree_east",
                "long_name": "longitude"
            },
            "lat": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "lat",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "-999.0",
                "units": "degree_north",
                "long_name": "latitude"
            },
            "elev": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "elev",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "-999.0",
                "units": "m",
                "long_name": "elevation"
            }
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1973-01-01",
            "gridtype": "0",
            "calendar": "standard",
            "long_name": "time",
            "pointwidth": "1.0"
        },
        "ISTA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ISTA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "1.0"
        },
        "dir": "SOURCES/CEREGE"
    },
    "CHRIS": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CHRIS",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "SMIhistory": "Christine wind stress calculated from Christine pseudo stress and Cd from Smith",
            "LPhistory": "Christine wind stress calculated from Christine pseudo stress and Cd from Large & Pond",
            "LIUhistory": "Christine wind stress calculated from Christine pseudo stress and Cd from Liu",
            "IHAShistory": "Christine wind stress calculated from Christine pseudo stress and Cd from Isemer & Hasse",
            "CLIMOhistory": "a wind field calculated from a Servain wind field with EOF analysis factored in.",
            "CARDhistory": "Christine wind stress calculated from Christine pseudo stress and Cd from Cardone",
            "YRRMhistory": "a wind field calculated from a Servain wind field with EOF analysis factored in.",
            "YRHhistory": "a wind field calculated from a Servain wind field with EOF analysis factored in.  Hellerman75 mean and 4yr detrend.",
            "description": "Wind stress calculated from EOF-filtered Servain stress and various drag formulations for the tropical Atlantic",
            "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CHRIS/.dataset_documentation.html",
            "iridlhasSemantics": "iridl:LDEO",
            "Conventions": "IRIDL"
        },
        "SMI": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SMI",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "tauy": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "tauy",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "meridional wind stress",
                "units": "dynes/cm2",
                "history": "Christine wind stress calculated from Christine pseudo stress and Cd from Smith",
                "missing_value": "9998.0"
            },
            "taux": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "taux",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "zonal wind stress",
                "units": "dynes/cm2",
                "history": "Christine wind stress calculated from Christine pseudo stress and Cd from Smith",
                "missing_value": "9998.0"
            }
        },
        "LP": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "LP",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "tauy": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "tauy",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "meridional wind stress",
                "units": "dynes/cm2",
                "history": "Christine wind stress calculated from Christine pseudo stress and Cd from Large & Pond",
                "missing_value": "9998.0"
            },
            "taux": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "taux",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "zonal wind stress",
                "units": "dynes/cm2",
                "history": "Christine wind stress calculated from Christine pseudo stress and Cd from Large & Pond",
                "missing_value": "9998.0"
            }
        },
        "LIU": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "LIU",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "tauy": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "tauy",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "meridional wind stress",
                "units": "dynes/cm2",
                "history": "Christine wind stress calculated from Christine pseudo stress and Cd from Liu",
                "missing_value": "9998.0"
            },
            "taux": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "taux",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "zonal wind stress",
                "units": "dynes/cm2",
                "history": "Christine wind stress calculated from Christine pseudo stress and Cd from Liu",
                "missing_value": "9998.0"
            }
        },
        "IHAS": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "IHAS",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "tauy": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "tauy",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "meridional wind stress",
                "units": "dynes/cm2",
                "history": "Christine wind stress calculated from Christine pseudo stress and Cd from Isemer & Hasse",
                "missing_value": "9998.0"
            },
            "taux": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "taux",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "zonal wind stress",
                "units": "dynes/cm2",
                "history": "Christine wind stress calculated from Christine pseudo stress and Cd from Isemer & Hasse",
                "missing_value": "9998.0"
            }
        },
        "CLIMO": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "CLIMO",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "absuv": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "absuv",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "meridional pseudostress",
                "units": "m2/s2",
                "history": "a wind field calculated from a Servain wind field with EOF analysis factored in."
            },
            "absuu": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "absuu",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "zonal pseudostress",
                "units": "m2/s2",
                "history": "a wind field calculated from a Servain wind field with EOF analysis factored in."
            }
        },
        "CARD": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "CARD",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "tauy": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "tauy",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "meridional wind stress",
                "units": "dynes/cm2",
                "history": "Christine wind stress calculated from Christine pseudo stress and Cd from Cardone",
                "missing_value": "9998.0"
            },
            "taux": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "taux",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "zonal wind stress",
                "units": "dynes/cm2",
                "history": "Christine wind stress calculated from Christine pseudo stress and Cd from Cardone",
                "missing_value": "9998.0"
            }
        },
        "YRRM": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "4YRRM",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "absuv": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "absuv",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "meridional pseudostress",
                "units": "m2/s2",
                "history": "a wind field calculated from a Servain wind field with EOF analysis factored in."
            },
            "absuu": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "absuu",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "zonal pseudostress",
                "units": "m2/s2",
                "history": "a wind field calculated from a Servain wind field with EOF analysis factored in."
            }
        },
        "YRH": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "4YRH",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "absuv": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "absuv",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "meridional pseudostress",
                "units": "m2/s2",
                "history": "a wind field calculated from a Servain wind field with EOF analysis factored in.  Hellerman75 mean and 4yr detrend."
            },
            "absuu": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "absuu",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "zonal pseudostress",
                "units": "m2/s2",
                "history": "a wind field calculated from a Servain wind field with EOF analysis factored in.  Hellerman75 mean and 4yr detrend."
            }
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "1",
            "modulo": "12.0",
            "modulus": "12.0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "2.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "2.0"
        },
        "dir": "SOURCES/CHRIS"
    },
    "CIAT": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/CIAT",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "CIAT",
        "restriction": "Public",
        "CSI": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/CIAT/CSI",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "CSI",
            "restriction": "Public",
            "SRTM": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/CIAT/CSI/SRTM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "SRTM",
                "restriction": "Public",
                "version4p1": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/CIAT/CSI/SRTM/version4p1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "version4p1",
                    "restriction": "Public",
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "version4p1"
                ]
            },
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type",
                "SRTM"
            ]
        },
        "banned_long": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type",
            "CSI"
        ]
    },
    "CIESIN": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/CIESIN",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "CIESIN",
        "restriction": "Public",
        "GPWv2": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/CIESIN/GPWv2",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "GPWv2",
            "restriction": "requires dlauth tokens"
        },
        "GPWv3": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/CIESIN/GPWv3",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "GPWv3",
            "restriction": "requires dlauth tokens"
        },
        "Poverty": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Poverty",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "globalbetagrid0p25deginfantmortalitydataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CIESIN/.Poverty/.global.beta.grid0p25deg.infantmortality.dataset_documentation.html",
                "globalbetagrid0p25deginfantmortalitylong_name": "Infant Mortality Rates",
                "globalbetagrid0p25deghungerdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CIESIN/.Poverty/.global.beta.grid0p25deg.hunger.dataset_documentation.html",
                "globalbetagrid0p25deghungerlong_name": "Prevalence of Child Malnutrition",
                "globalbetagrid0p25degancillarylong_name": "Ancillary Grid Data",
                "globalbetagrid0p25degdescription": "Global Distribution of Poverty, beta version, from the Socioeconomic Data and Applications Center (SEDAC) at CIESIN, gridded at 0.25 degree resolution",
                "globalbetagrid0p25degdata": "http://sedac.ciesin.org/povmap/ds_global.jsp",
                "globalbetagrid0p25degGlobal": "http://sedac.ciesin.org/povmap/",
                "description": "Global Distribution of Poverty",
                "Conventions": "IRIDL",
                "Global": "http://sedac.ciesin.org/povmap/"
            },
            "_global": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "global",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "beta": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "beta",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "grid0p25deg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "grid0p25deg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "infantmortality": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "infantmortality",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "imr": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "imr",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Infant deaths per 10,000 live births",
                                "missing_value": "-9999.0",
                                "long_name": "Infant mortality rates, year 2000"
                            },
                            "deaths": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "deaths",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Number of Persons",
                                "missing_value": "-9999.0",
                                "long_name": "Infant Deaths, year 2000"
                            },
                            "births": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "births",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Number of Persons",
                                "missing_value": "-9999.0",
                                "long_name": "Births, year 2000"
                            }
                        },
                        "hunger": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "hunger",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "uwu5pop": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "uwu5pop",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Number of Persons",
                                "missing_value": "-9999.0",
                                "long_name": "Estimate of children, under the age of 5, who are underweight, year 2000"
                            },
                            "uw": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "uw",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.90002",
                                "units": "percent",
                                "long_name": "Percent of children, under the age of 5, who are underweight (year period: 1990-2002)"
                            },
                            "u5pop": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "u5pop",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Number of Persons",
                                "missing_value": "-9999.0",
                                "long_name": "Count of children under age 5, year 2000"
                            }
                        },
                        "ancillary": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ancillary",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "sequence": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sequence",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "missing_value": "-9999.0",
                                "long_name": "Unique grid cell identifier, counting from NW to SE by rows"
                            },
                            "popdens": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "popdens",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Number of Persons/km2",
                                "missing_value": "-9999.0",
                                "long_name": "Population density, year 2000"
                            },
                            "pop2000": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pop2000",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Number of Persons",
                                "missing_value": "-9999.0",
                                "long_name": "Population count, year 2000"
                            },
                            "longitude": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "longitude",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "missing_value": "-9999.0",
                                "long_name": "Longitude of the center point of a grid cell"
                            },
                            "latitude": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "latitude",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "missing_value": "-9999.0",
                                "long_name": "Latitude of the center point of a grid cell"
                            },
                            "landarea": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "landarea",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "km2",
                                "missing_value": "-9999.0",
                                "long_name": "Land area from GPWv3"
                            },
                            "cntry4q": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "cntry4q",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "missing_value": "-9999.0",
                                "long_name": "The country with the fourth-most land area within a given grid cell"
                            },
                            "cntry3q": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "cntry3q",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "missing_value": "-9999.0",
                                "long_name": "The country with the third-most land area within a given grid cell"
                            },
                            "cntry2q": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "cntry2q",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "missing_value": "-9999.0",
                                "long_name": "The country with the second-most land area within a given grid cell"
                            },
                            "cntry1q": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "cntry1q",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "missing_value": "-9999.0",
                                "long_name": "The country with the most land area within a given grid cell"
                            }
                        }
                    }
                }
            },
            "X": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "gridtype": "1",
                "standard_name": "longitude",
                "pointwidth": "0.25"
            },
            "Y": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_north",
                "gridtype": "0",
                "standard_name": "latitude",
                "pointwidth": "0.25"
            },
            "dir": "SOURCES/CIESIN/Poverty"
        },
        "banned_long": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type",
            "GPWv2",
            "GPWv3",
            "Poverty"
        ]
    },
    "CIMH": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/CIMH",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "CIMH",
        "restriction": "requires dlauth tokens"
    },
    "CLARIS_LPB": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CLARIS_LPB",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "SESATencer_tempreferences": ">Tencer, B\\xc3\\xa1rbara, Matilde Rusticucci, Phil Jones, David Lister, 2011: A Southeastern South American Daily Gridded Dataset of Observed Surface Minimum and Maximum Temperature for 1961\\xe2\\x80\\x932000. Bull. Amer. Meteor. Soc., 92, 1339\\xe2\\x80\\x931346.doi</a>",
            "SESAdescription": "South-East South America",
            "description": "CLARIS La Plata Basin",
            "Conventions": "IRIDL",
            "CLARISLPB": "http://www.claris-eu.org/"
        },
        "SESA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SESA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Tencer_temp": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Tencer_temp",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "tx": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tx",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "400",
                    "ncolor": "254",
                    "scale_min": "-400",
                    "CS": "-40",
                    "colorscalename": "temp_colors",
                    "CE": "40",
                    "maxncolor": "254",
                    "colormap": "255",
                    "scale_factor": "0.1",
                    "missing_value": "-9999",
                    "long_name": "maximum temperature",
                    "units": "Celsius_scale"
                },
                "tn": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tn",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "400",
                    "ncolor": "254",
                    "scale_min": "-400",
                    "CS": "-40",
                    "colorscalename": "temp_colors",
                    "CE": "40",
                    "maxncolor": "254",
                    "colormap": "255",
                    "scale_factor": "0.1",
                    "missing_value": "-9999",
                    "long_name": "minimum temperature",
                    "units": "Celsius_scale"
                }
            }
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "long_name": "Latitude",
            "pointwidth": "0.5"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1961-01-01",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "long_name": "Time",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "long_name": "Longitude",
            "pointwidth": "0.5"
        },
        "dir": "SOURCES/CLARIS_LPB"
    },
    "CLIMAP": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CLIMAP",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "MODdescription": "Modern soil and vegetation characteristics from the World Data Center for Paleoclimatology",
            "MODlong_name": "Modern",
            "LGMdescription": "Last glacial maximum (18 KBP) soil and vegetation characteristics from the World Data Center for Paleoclimatology",
            "LGMlong_name": "Last Glacial Maximum",
            "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CLIMAP/.dataset_documentation.html",
            "iridlhasSemantics": "iridl:NOAA",
            "Conventions": "IRIDL",
            "references": "CLIMAP1984",
            "description": "Modern and last glacial maximum (18 KBP) comparison of soil and vegetation characteristics from the World Data Center for Paleoclimatology"
        },
        "MOD": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "MOD",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "water": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "water",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "percent": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "percent",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "long_name": "percentage of grid cell"
                }
            },
            "vegetative": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "vegetative",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "percent": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "percent",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "long_name": "percentage of grid cell"
                }
            },
            "vegetation": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "vegetation",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "scale_min": "11.0",
                "missing_value": "0.0",
                "scale_max": "91.0",
                "long_name": "vegetation type",
                "CLIST": "arctic"
            },
            "topo": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "topo",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "m",
                "long_name": "elevation"
            },
            "soil": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "soil",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "ncolor": "52",
                "missing_value": "0.0",
                "scale_max": "59.0",
                "colormap": "16777215",
                "long_name": "soil type",
                "CLIST": "bright white unclassified",
                "scale_min": "11.0"
            },
            "relief": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "relief",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "ncolor": "57",
                "missing_value": "0.0",
                "scale_max": "64.0",
                "colormap": "16711680",
                "long_name": "relief type",
                "CLIST": "mountainous random orientation, unclassified",
                "scale_min": "11.0"
            },
            "glacial_ice": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "glacial_ice",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "percent": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "percent",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "long_name": "percentage of grid cell"
                }
            },
            "feb": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "feb",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "sst": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sst",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "missing_value": "55.5",
                    "long_name": "sea surface temperature"
                }
            },
            "exposed_soil": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "exposed_soil",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "percent": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "percent",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "long_name": "percentage of grid cell"
                }
            },
            "aug": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "aug",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "sst": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sst",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "missing_value": "55.5",
                    "long_name": "sea surface temperature"
                }
            }
        },
        "LGM": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "LGM",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "water": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "water",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "percent": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "percent",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "long_name": "percentage of grid cell"
                }
            },
            "vegetative": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "vegetative",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "percent": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "percent",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "long_name": "percentage of grid cell"
                }
            },
            "vegetation": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "vegetation",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "scale_min": "11.0",
                "missing_value": "0.0",
                "scale_max": "93.0",
                "long_name": "vegetation type",
                "CLIST": "arctic"
            },
            "topo": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "topo",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "m",
                "long_name": "elevation"
            },
            "soil": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "soil",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "scale_max": "59.0",
                "ncolor": "52",
                "scale_min": "11.0",
                "CS": "11.0",
                "colorscalename": "custom",
                "CE": "59.0",
                "maxncolor": "52",
                "colormap": "16777215",
                "CLIST": "bright white unclassified",
                "long_name": "soil type"
            },
            "relief": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "relief",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "maxncolor": "57",
                "colormap": "16711680",
                "scale_max": "64.0",
                "ncolor": "57",
                "scale_min": "11.0",
                "CE": "64.0",
                "CS": "11.0",
                "missing_value": "0.0",
                "CLIST": "mountainous random orientation, unclassified",
                "long_name": "relief type"
            },
            "glacial_ice": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "glacial_ice",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "percent": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "percent",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "long_name": "percentage of grid cell"
                }
            },
            "feb": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "feb",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "sst": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sst",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "missing_value": "55.5",
                    "long_name": "sea surface temperature"
                }
            },
            "exposed_soil": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "exposed_soil",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "percent": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "percent",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "long_name": "percentage of grid cell"
                }
            },
            "aug": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "aug",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "sst": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sst",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "missing_value": "55.5",
                    "long_name": "sea surface temperature"
                }
            }
        },
        "Y_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "2.0"
        },
        "X_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "2.0"
        },
        "Y_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "2.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "2.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "2.0"
        },
        "dir": "SOURCES/CLIMAP"
    },
    "CMA": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CMA",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "BCCRegCM3_NCPdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CMA/.BCC.RegCM3_NCP.dataset_documentation.html",
            "BCCRegCM3_NCPlong_name": "RegCM with 0.1126deg grids over North China Plain",
            "BCCRegCM3_NCPreferences": "Giorgi_F_etal1993a Giorgi_F_etal1993b",
            "BCCGODASreferences": "Liu_etal2005a Liu_etal2005b",
            "BCCGODASdescription": "global ocean data assimilation operational system",
            "BCCGODASdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CMA/.BCC.GODAS.dataset_documentation.html",
            "BCCGODASiridlhasSemantics": "iridl:Ocean",
            "BCCCGCMMONTHLYSurfacecomment": "IMPORTANT:  It was discovered in December 2020 that the latitude coordinate was erroneously reversed in the Precipitation_Total, U, and V variables in this dataset.  This error has been corrected as of 07 January 2021.",
            "BCCCGCMMONTHLYPressureLevelcomment": "IMPORTANT:  It was discovered in December 2020 that the latitude coordinate was erroneously reversed in the Precipitation_Total, U, and V variables in this dataset.  This error has been corrected as of 07 January 2021.",
            "BCCCGCMMONTHLYcomment": "IMPORTANT:  It was discovered in December 2020 that the latitude coordinate was erroneously reversed in the Precipitation_Total, U, and V variables in this dataset.  This error has been corrected as of 07 January 2021.",
            "BCCdescription": "Beijing Climate Center",
            "BCCHome": "http://ncc.cma.gov.cn/bcc/main.htm",
            "BCCiridlhasSemantics": "iridl:BCC",
            "description": "China Meteorological Administration",
            "iridlhasSemantics": "iridl:CMA",
            "Conventions": "IRIDL",
            "home": "http://www.cma.gov.cn/ywwz/"
        },
        "station": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "station",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "daily": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "daily",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "WSPD": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WSPD",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.90002",
                    "units": "m/s",
                    "long_name": "Wind_Speed"
                },
                "TMIN": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "TMIN",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.90002",
                    "units": "Celsius_scale",
                    "long_name": "Minimum_Temperature"
                },
                "TMEAN": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "TMEAN",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.90002",
                    "units": "Celsius_scale",
                    "long_name": "Mean_Temperature"
                },
                "TMAX": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "TMAX",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.90002",
                    "units": "Celsius_scale",
                    "long_name": "Maximum_Temperature"
                },
                "SUN": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SUN",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.90002",
                    "units": "hours/day",
                    "long_name": "Sunlight_Duration"
                },
                "RH": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "RH",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.90002",
                    "units": "percent",
                    "long_name": "Relative_Humidity"
                },
                "Province": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Province",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids"
                },
                "PRCP": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "PRCP",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.90002",
                    "units": "mm/day",
                    "long_name": "Precipitation"
                },
                "Name": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Name",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "110.0",
                    "missing_value": "-999.0",
                    "scale_max": "123.0",
                    "units": "degree_east",
                    "long_name": "longitude"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "30.0",
                    "missing_value": "-999.0",
                    "scale_max": "42.0",
                    "units": "degree_north",
                    "long_name": "latitude"
                },
                "altitude": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "altitude",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.0",
                    "units": "m"
                }
            }
        },
        "BCC": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "BCC",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "RegCM3_NCP": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "RegCM3_NCP",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Surface": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Surface",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "t2min": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "t2min",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Min air temperature at 2 meters AGL",
                        "units": "Kelvin_scale",
                        "cNZ": "0",
                        "missing_value": "-9.99999979E33",
                        "pointwidth": "0.0"
                    },
                    "t2max": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "t2max",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Max air temperature at 2 meters AGL",
                        "units": "Kelvin_scale",
                        "cNZ": "0",
                        "missing_value": "-9.99999979E33",
                        "pointwidth": "0.0"
                    },
                    "swi": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "swi",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Solar incident",
                        "units": "W/m2",
                        "cNZ": "0",
                        "missing_value": "-1.00000002E30",
                        "pointwidth": "0.0"
                    },
                    "slp": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "slp",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Sea level pressure",
                        "units": "mb",
                        "cNZ": "0",
                        "missing_value": "-1.00000002E30",
                        "pointwidth": "0.0"
                    },
                    "rt": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rt",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Total precipitation",
                        "units": "mm",
                        "cNZ": "0",
                        "missing_value": "-1.00000002E30",
                        "pointwidth": "0.0"
                    }
                },
                "PressureLevel": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "PressureLevel",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "v": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "v",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "V wind",
                        "units": "m/s",
                        "cNZ": "1",
                        "missing_value": "-9.99999979E33",
                        "pointwidth": "0.0"
                    },
                    "u": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "u",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "U wind",
                        "units": "m/s",
                        "cNZ": "1",
                        "missing_value": "-9.99999979E33",
                        "pointwidth": "0.0"
                    },
                    "q": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "q",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "specific humidity",
                        "units": "g/kg",
                        "cNZ": "1",
                        "missing_value": "-9.99999979E33",
                        "pointwidth": "0.0"
                    },
                    "gz": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gz",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "geopotential geight",
                        "units": "gm",
                        "cNZ": "1",
                        "missing_value": "-9.99999979E33",
                        "pointwidth": "0.0"
                    }
                }
            },
            "GODAS": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "GODAS",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "v": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "v",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "m/s",
                    "missing_value": "9999.0",
                    "pointwidth": "1.0"
                },
                "u": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "u",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "m/s",
                    "missing_value": "9999.0",
                    "pointwidth": "1.0"
                },
                "temp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "Celsius_scale",
                    "missing_value": "9999.0",
                    "pointwidth": "1.0"
                },
                "sal": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sal",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridlhasSemantics": "iridl:Salinity",
                    "units": "1e-3 PSU above 35",
                    "missing_value": "9999.0",
                    "pointwidth": "1.0"
                }
            },
            "CGCM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CGCM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "MONTHLY": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "MONTHLY",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Surface": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Surface",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "Precipitation_Total": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Precipitation_Total",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Surface Total Precipitation",
                            "units": "mm",
                            "cNZ": "48"
                        }
                    },
                    "PressureLevel": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PressureLevel",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "V": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "V",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "V-wind",
                            "units": "m/s",
                            "cNZ": "48"
                        },
                        "U": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "U",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "U-wind",
                            "units": "m/s",
                            "cNZ": "48"
                        }
                    }
                }
            }
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "long_name": "Time",
            "pointwidth": "1.0"
        },
        "STNID": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "STNID",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2"
        },
        "P_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "P_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "650.0"
        },
        "P_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "P_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "0"
        },
        "P_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "P_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "0"
        },
        "X_06": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_06",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.1126"
        },
        "Y_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.1126"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1960-01-01",
            "gridtype": "0",
            "calendar": "365",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X_05": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_05",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "calendar": "standard",
            "pointwidth": "1.875"
        },
        "X_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "calendar": "standard",
            "pointwidth": "1.875"
        },
        "Z_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Z_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0"
        },
        "Y_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude"
        },
        "X_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "1.875"
        },
        "X_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "1.875"
        },
        "Z_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Z_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0"
        },
        "Y_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "Y_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude"
        },
        "X_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "1.875"
        },
        "Z": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Z",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "long_name": "Ensemble member",
            "pointwidth": "1.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "2.5"
        },
        "L": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "L",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months",
            "gridtype": "0",
            "long_name": "Lead time",
            "standard_time": "forecast_period",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "2.5"
        },
        "S": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "S",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "long_name": "Start time",
            "calendar": "360",
            "pointwidth": "0"
        },
        "P": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "P",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "mb",
            "gridtype": "0",
            "pointwidth": "650.0"
        },
        "dir": "SOURCES/CMA"
    },
    "CNES": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CNES",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "SPOTiridlhasSemantics": "iridl:SPOT",
            "SPOTabout": "http://www.auslig.gov.au/acres/prod_ser/spotdata.htm",
            "SPOTspot": "http://www.spotimage.fr/home/",
            "description": "Centre National d\\'Etudes Spatiale",
            "iridlhasSemantics": "iridl:CNES",
            "Conventions": "IRIDL"
        },
        "SPOT": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SPOT",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "vegetation": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "vegetation",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "westasia": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "west-asia",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NDVI": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NDVI",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "NDVIcolorscale",
                        "colormap": "16777215",
                        "scale_max": "229.09999",
                        "ncolor": "254",
                        "scale_min": "-24.9",
                        "CE": "0.916",
                        "CS": "-0.1",
                        "missing_value": "255",
                        "units": "unitless",
                        "long_name": "Normalized Difference Vegetation Index",
                        "add_offset": "-0.1",
                        "scale_factor": "0.004",
                        "iridlhasSemantics": "iridl:NDVI"
                    }
                },
                "southeastasia": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "southeast-asia",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NDVI": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NDVI",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "NDVIcolorscale",
                        "colormap": "16777215",
                        "scale_max": "229.09999",
                        "ncolor": "254",
                        "scale_min": "-24.9",
                        "CE": "0.916",
                        "CS": "-0.1",
                        "missing_value": "255",
                        "units": "unitless",
                        "long_name": "Normalized Difference Vegetation Index",
                        "add_offset": "-0.1",
                        "scale_factor": "0.004",
                        "iridlhasSemantics": "iridl:NDVI"
                    }
                },
                "southamerica": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "south-america",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NDVI": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NDVI",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "NDVIcolorscale",
                        "colormap": "16777215",
                        "scale_max": "229.09999",
                        "ncolor": "254",
                        "scale_min": "-24.9",
                        "CE": "0.916",
                        "CS": "-0.1",
                        "missing_value": "255",
                        "units": "unitless",
                        "long_name": "Normalized Difference Vegetation Index",
                        "add_offset": "-0.1",
                        "scale_factor": "0.004",
                        "iridlhasSemantics": "iridl:NDVI"
                    }
                },
                "northasia": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "north-asia",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NDVI": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NDVI",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "NDVIcolorscale",
                        "colormap": "16777215",
                        "scale_max": "229.09999",
                        "ncolor": "254",
                        "scale_min": "-24.9",
                        "CE": "0.916",
                        "CS": "-0.1",
                        "missing_value": "255",
                        "units": "unitless",
                        "long_name": "Normalized Difference Vegetation Index",
                        "add_offset": "-0.1",
                        "scale_factor": "0.004",
                        "iridlhasSemantics": "iridl:NDVI"
                    }
                },
                "northamerica": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "north-america",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NDVI": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NDVI",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "NDVIcolorscale",
                        "colormap": "16777215",
                        "scale_max": "229.09999",
                        "ncolor": "254",
                        "scale_min": "-24.9",
                        "CE": "0.916",
                        "CS": "-0.1",
                        "missing_value": "255",
                        "units": "unitless",
                        "long_name": "Normalized Difference Vegetation Index",
                        "add_offset": "-0.1",
                        "scale_factor": "0.004",
                        "iridlhasSemantics": "iridl:NDVI"
                    }
                },
                "europe": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "europe",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NDVI": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NDVI",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "NDVIcolorscale",
                        "colormap": "16777215",
                        "scale_max": "229.09999",
                        "ncolor": "254",
                        "scale_min": "-24.9",
                        "CE": "0.916",
                        "CS": "-0.1",
                        "missing_value": "255",
                        "units": "unitless",
                        "long_name": "Normalized Difference Vegetation Index",
                        "add_offset": "-0.1",
                        "scale_factor": "0.004",
                        "iridlhasSemantics": "iridl:NDVI"
                    }
                },
                "colombia": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "colombia",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NDVI": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NDVI",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "NDVIcolorscale",
                        "colormap": "16777215",
                        "scale_max": "229.09999",
                        "ncolor": "254",
                        "scale_min": "-24.9",
                        "CE": "0.916",
                        "CS": "-0.1",
                        "scale_factor": "0.004",
                        "iridlhasSemantics": "iridl:NDVI",
                        "units": "unitless",
                        "add_offset": "-0.1"
                    }
                },
                "centralamerica": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "central-america",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NDVI": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NDVI",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "NDVIcolorscale",
                        "colormap": "16777215",
                        "scale_max": "229.09999",
                        "ncolor": "254",
                        "scale_min": "-24.9",
                        "CE": "0.916",
                        "CS": "-0.1",
                        "missing_value": "255",
                        "units": "unitless",
                        "long_name": "Normalized Difference Vegetation Index",
                        "add_offset": "-0.1",
                        "scale_factor": "0.004",
                        "iridlhasSemantics": "iridl:NDVI"
                    }
                },
                "australiaasia": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "australia-asia",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NDVI": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NDVI",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "NDVIcolorscale",
                        "colormap": "16777215",
                        "scale_max": "229.09999",
                        "ncolor": "254",
                        "scale_min": "-24.9",
                        "CE": "0.916",
                        "CS": "-0.1",
                        "missing_value": "255",
                        "units": "unitless",
                        "long_name": "Normalized Difference Vegetation Index",
                        "add_offset": "-0.1",
                        "scale_factor": "0.004",
                        "iridlhasSemantics": "iridl:NDVI"
                    }
                },
                "asianislands": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "asian-islands",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NDVI": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NDVI",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "NDVIcolorscale",
                        "colormap": "16777215",
                        "scale_max": "229.09999",
                        "ncolor": "254",
                        "scale_min": "-24.9",
                        "CE": "0.916",
                        "CS": "-0.1",
                        "missing_value": "255",
                        "units": "unitless",
                        "long_name": "Normalized Difference Vegetation Index",
                        "add_offset": "-0.1",
                        "scale_factor": "0.004",
                        "iridlhasSemantics": "iridl:NDVI"
                    }
                },
                "africa": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "africa",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NDVI": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NDVI",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "NDVIcolorscale",
                        "colormap": "16777215",
                        "scale_max": "229.09999",
                        "ncolor": "254",
                        "scale_min": "-24.9",
                        "CE": "0.916",
                        "CS": "-0.1",
                        "missing_value": "255",
                        "units": "unitless",
                        "long_name": "Normalized Difference Vegetation Index",
                        "add_offset": "-0.1",
                        "scale_factor": "0.004",
                        "iridlhasSemantics": "iridl:NDVI",
                        "calendar": "standard"
                    }
                }
            }
        },
        "Y_10": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_10",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.008928572"
        },
        "X_10": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_10",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.008928572"
        },
        "Y_09": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_09",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.008928572"
        },
        "X_09": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_09",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.008928572"
        },
        "Y_08": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_08",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.008928572"
        },
        "X_08": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_08",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.008928572"
        },
        "Y_07": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_07",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.008928572"
        },
        "X_07": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_07",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.008928572"
        },
        "Y_06": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_06",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.00867347"
        },
        "X_06": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_06",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.008928572"
        },
        "Y_05": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_05",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.008928572"
        },
        "X_05": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_05",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.008928572"
        },
        "X_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.008928572"
        },
        "Y_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.008928572"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "Y_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.008928572"
        },
        "X_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.008928572"
        },
        "Y_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.008928572"
        },
        "X_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.008928572"
        },
        "Y_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.008928572"
        },
        "X_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.008928572"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.008928572"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "0",
            "calendar": "standard",
            "add_offset": "-3653.0",
            "units": "days since 1970-01-01"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.008928572"
        },
        "dir": "SOURCES/CNES"
    },
    "COADS": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "COADS",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "ylatdescription": "Average latitude for gridbox",
            "xlondescription": "Average longitude for gridbox",
            "stdevdescription": "Monthly average standard deviation of data for gridbox",
            "nobsdescription": "Number of observations for gridbox",
            "meandescription": "Monthly average data for gridbox",
            "description": "Comprehensive Ocean-Atmosphere Data Set: Trimmed monthly summaries",
            "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.COADS/.dataset_documentation.html",
            "iridlhasSemantics": "iridl:NCAR",
            "Conventions": "IRIDL",
            "references": "Slutz_etal1985"
        },
        "ylat": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ylat",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "umag": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "umag",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_north",
                "precision": "0.2"
            },
            "v": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_north",
                "precision": "0.2"
            },
            "u": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "u",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_north",
                "precision": "0.2"
            },
            "tair": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "tair",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_north",
                "precision": "0.2"
            },
            "sst": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "sst",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_north",
                "precision": "0.2"
            },
            "slp": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "slp",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_north",
                "precision": "0.2"
            },
            "shum": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "shum",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_north",
                "precision": "0.2"
            }
        },
        "xlon": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "xlon",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "umag": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "umag",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_east",
                "precision": "0.2"
            },
            "v": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_east",
                "precision": "0.2"
            },
            "u": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "u",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_east",
                "precision": "0.2"
            },
            "tair": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "tair",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_east",
                "precision": "0.2"
            },
            "sst": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "sst",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_east",
                "precision": "0.2"
            },
            "slp": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "slp",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_east",
                "precision": "0.2"
            },
            "shum": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "shum",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_east",
                "precision": "0.2"
            }
        },
        "stdev": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "stdev",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "umag": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "umag",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "m/s",
                "long_name": "wind speed",
                "precision": "0.01"
            },
            "v": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "m/s",
                "long_name": "meridional wind",
                "precision": "0.01"
            },
            "u": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "u",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "m/s",
                "long_name": "zonal wind",
                "precision": "0.01"
            },
            "tair": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "tair",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_Celsius",
                "long_name": "air temperature",
                "precision": "0.01"
            },
            "sst": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "sst",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "degree_Celsius",
                "long_name": "sea surface temperature",
                "precision": "0.01"
            },
            "slp": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "slp",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "mb",
                "long_name": "sea level pressure",
                "precision": "0.01"
            },
            "shum": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "shum",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "g/kg",
                "long_name": "specific humidity",
                "precision": "0.01"
            }
        },
        "nobs": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "nobs",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "umag": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "umag",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "unitless",
                "precision": "1"
            },
            "v": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "unitless",
                "precision": "1"
            },
            "u": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "u",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "unitless",
                "precision": "1"
            },
            "tair": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "tair",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "unitless",
                "precision": "1"
            },
            "sst": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "sst",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "unitless",
                "precision": "1"
            },
            "slp": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "slp",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "unitless",
                "precision": "1"
            },
            "shum": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "shum",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "unitless",
                "precision": "1"
            }
        },
        "mean": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "mean",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "umag": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "umag",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "m/s",
                "long_name": "wind speed",
                "precision": "0.01"
            },
            "v": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "m/s",
                "long_name": "meridional wind",
                "precision": "0.01"
            },
            "u": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "u",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "m/s",
                "long_name": "zonal wind",
                "precision": "0.01"
            },
            "tair": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "tair",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "Celsius_scale",
                "long_name": "air temperature",
                "precision": "0.01"
            },
            "sst": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "sst",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "Celsius_scale",
                "long_name": "sea surface temperature",
                "precision": "0.01"
            },
            "slp": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "slp",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "mb",
                "long_name": "sea level pressure",
                "precision": "0.01"
            },
            "shum": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "shum",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "NaN",
                "units": "g/kg",
                "long_name": "specific humidity",
                "precision": "0.01"
            }
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "2.0",
            "long_name": "Latitude"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0",
            "long_name": "Time"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "modulus": "360.0",
            "pointwidth": "2.0",
            "long_name": "Longitude"
        },
        "dir": "SOURCES/COADS"
    },
    "COLA": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "COLA",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Decadal_HindcastsCFSv2iridlhasSemantics": "iriref:Schneider_EK",
            "Conventions": "IRIDL"
        },
        "Decadal_Hindcasts": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Decadal_Hindcasts",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "CFSv2": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CFSv2",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "PGBF": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "PGBF",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "T": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "T",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "pointwidth": "1.0",
                        "long_name": "Forecast Time",
                        "units": "months since 1960-01-01",
                        "standard_name": "time"
                    },
                    "pressure_level": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pressure_level",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "HGT": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "HGT",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Geopotential Height",
                            "units": "gpm",
                            "standard_name": "geopotential_height",
                            "cNZ": "1",
                            "gribfield": "1",
                            "missing_value": "9.99900026E20",
                            "pointwidth": "0.0"
                        }
                    }
                },
                "OCNH": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "OCNH",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "T": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "T",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "pointwidth": "1.0",
                        "long_name": "Forecast Time",
                        "units": "months since 1960-01-01",
                        "standard_name": "time"
                    },
                    "surface": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "surface",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "TMP": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "TMP",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Temperature",
                            "units": "Kelvin_scale",
                            "standard_name": "sea surface temperature",
                            "cNZ": "0",
                            "gribfield": "1",
                            "missing_value": "9.99900026E20",
                            "pointwidth": "0.0"
                        }
                    }
                },
                "FLXF": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "FLXF",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "T": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "T",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "pointwidth": "1.0",
                        "long_name": "Forecast Time",
                        "units": "months since 1960-01-01",
                        "standard_name": "time"
                    },
                    "surface": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "surface",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "PRATE": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "PRATE",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Precipitation Rate",
                            "units": "kg m-2 s-1",
                            "standard_name": "precipitation flux",
                            "cNZ": "0",
                            "gribfield": "1",
                            "missing_value": "9.99900026E20",
                            "pointwidth": "0.0"
                        }
                    },
                    "m_above_ground": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "2m_above_ground",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "TMP": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "TMP",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Temperature",
                            "units": "Kelvin_scale",
                            "standard_name": "air_temperature",
                            "cNZ": "0",
                            "gribfield": "1",
                            "missing_value": "9.99900026E20",
                            "pointwidth": "0.0"
                        }
                    }
                }
            }
        },
        "Y_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "1.0"
        },
        "X_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "1.0"
        },
        "P": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "P",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "mb",
            "gridtype": "0",
            "standard_name": "air_pressure",
            "long_name": "Pressure level",
            "pointwidth": "0"
        },
        "Y_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.5"
        },
        "X_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "0.5"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0"
        },
        "L": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "L",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months",
            "gridtype": "0",
            "standard_name": "forecast_period",
            "pointwidth": "1"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "0.9375"
        },
        "M": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "M",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "1.0"
        },
        "S": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "S",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "forecast_reference_time",
            "pointwidth": "0.0"
        },
        "dir": "SOURCES/COLA"
    },
    "CORAL": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CORAL",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Seychellesdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CORAL/.Seychelles.dataset_documentation.html",
            "description": "Isotope d18O data from coral colonies",
            "Conventions": "IRIDL"
        },
        "Tarawa": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Tarawa",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ]
        },
        "Seychelles": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Seychelles",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ]
        },
        "dir": "SOURCES/CORAL"
    },
    "Chile": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "Chile",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "DGAmeteorologicalregionIVstationdailydescription": "Daily Precipitation of the Coquimbo Region",
            "DGAhydrologicalregionIVstationmonthlydescription": "Monthly Streamflow for the Elqui River Basin",
            "DGAhydrologicalregionIVstationdailydescription": "Daily Streamflow for Region IV",
            "DGAdescription": "Direcci&#243;n General de Aguas",
            "DGAiridlhasSemantics": "iridl:DGA_Chile",
            "DGAlong_name": "Direcci&#243;n General de Aguas",
            "DGADGA": "http://www.dga.cl/",
            "Conventions": "IRIDL"
        },
        "DGA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "DGA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "meteorological": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "meteorological",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "regionIV": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "regionIV",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "station": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "station",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "daily": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "daily",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "UTM_North": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "UTM_North",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "meters"
                            },
                            "UTM_East": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "UTM_East",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "meters"
                            },
                            "Suspension_Date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Suspension_Date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            },
                            "Region": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Region",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            },
                            "PRCP": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PRCP",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-99.900002",
                                "units": "mm/day",
                                "long_name": "Precipitation",
                                "standard_name": "lwe_precipitation_rate"
                            },
                            "Name": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Name",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            },
                            "lon": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lon",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "-71.5",
                                "missing_value": "-999.0",
                                "scale_max": "-69.800003",
                                "units": "degree_east",
                                "long_name": "longitude"
                            },
                            "lat": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lat",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "-32.0",
                                "missing_value": "-999.0",
                                "scale_max": "-29.299999",
                                "units": "degree_north",
                                "long_name": "latitude"
                            },
                            "Installation_Date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Installation_Date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            },
                            "Altitude": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Altitude",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "standard_name": "surface_altitude",
                                "units": "meters"
                            },
                            "Alt_ID": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Alt_ID",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            }
                        }
                    }
                }
            },
            "hydrological": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "hydrological",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "regionIV": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "regionIV",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "station": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "station",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "monthly": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "monthly",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "streamflow": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "streamflow",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m3/s",
                                "missing_value": "-999.0",
                                "long_name": "streamflow"
                            },
                            "Region": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Region",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            },
                            "Name": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Name",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            },
                            "lon": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lon",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "-71.5",
                                "missing_value": "-999.0",
                                "scale_max": "-69.800003",
                                "units": "degree_east",
                                "long_name": "longitude"
                            },
                            "lat": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lat",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "-30.5",
                                "missing_value": "-999.0",
                                "scale_max": "-29.5",
                                "units": "degree_north",
                                "long_name": "latitude"
                            },
                            "Elevation": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Elevation",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "meters"
                            },
                            "Alt_ID": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Alt_ID",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            }
                        },
                        "daily": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "daily",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "UTM_North": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "UTM_North",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "meters"
                            },
                            "UTM_East": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "UTM_East",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "meters"
                            },
                            "Suspension_Date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Suspension_Date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            },
                            "STRFLOW": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "STRFLOW",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-99.900002",
                                "units": "m3/s",
                                "long_name": "Streamflow",
                                "standard_name": "surface_runoff_flux"
                            },
                            "Region": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Region",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            },
                            "Name": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Name",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            },
                            "lon": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lon",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "-72.0",
                                "scale_max": "-70.0",
                                "units": "degree_east",
                                "long_name": "longitude"
                            },
                            "lat": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lat",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "-32.5",
                                "scale_max": "-29.299999",
                                "units": "degree_north",
                                "long_name": "latitude"
                            },
                            "Installation_Date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Installation_Date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            },
                            "altitude": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "altitude",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "meters"
                            }
                        }
                    }
                }
            }
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "1.0",
            "long_name": "Time",
            "standard_name": "time"
        },
        "ID_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ID_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "ID_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ID_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "0",
            "pointwidth": "1.0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "pointwidth": "1.0",
            "long_name": "Time",
            "standard_name": "time"
        },
        "ID": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ID",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2"
        },
        "dir": "SOURCES/Chile"
    },
    "CountrySTAT": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "CountrySTAT",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "PhilippinesSubnationalProductionFisheriesC40PNVFPdescription": "Fisheries: Volume of Production by Subsector, by Region and by Province, 1980-2012",
            "PhilippinesSubnationalProductionFisheriesC40PNVFPsource": "http://countrystat.psa.gov.ph/?cont=10&pageid=1&ma=C40PNVFP",
            "PhilippinesSubnationalProductionFisheriesC40PNVFPdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CountrySTAT/.Philippines.Sub-national.Production.Fisheries.C40PNVFP.dataset_documentation.html",
            "PhilippinesSubnationalProductionCropsYieldAH_Catdescription": "Palay and Corn: Categories of Areas by Province and Quarter",
            "PhilippinesSubnationalProductionCropsYielddescription": "Palay and Corn: Yield anomalies estimate by Year, Period",
            "PhilippinesSubnationalProductionCropsYielddataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CountrySTAT/.Philippines.Sub-national.Production.Crops.Yield.dataset_documentation.html",
            "Philippineshome": "http://countrystat.psa.gov.ph/",
            "NigerSubnationalProductionLivestockPVdescription": "Distribution of Meat Production by Region, 2000-2010",
            "NigerSubnationalProductionLivestockPVsource": "http://countrystat.org/home.aspx?c=NER&ta=158SPD050&tr=21",
            "NigerSubnationalProductionLivestockPVdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CountrySTAT/.Niger.Sub-national.Production.Livestock.PV.dataset_documentation.html",
            "NigerSubnationalProductionLivestockEAVsource": "http://countrystat.org/home.aspx?c=NER&ta=158SPD035&tr=21",
            "NigerSubnationalProductionLivestockEAVdescription": "Distribution of Live Animals by Region, 1970-2010",
            "NigerSubnationalProductionLivestockEAVdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CountrySTAT/.Niger.Sub-national.Production.Livestock.EAV.dataset_documentation.html",
            "NigerSubnationalProductionCropsSRdescription": "Distribution of the Area Harvested by Region, 2000-2011",
            "NigerSubnationalProductionCropsSRsource": "http://countrystat.org/home.aspx?c=NER&ta=158SPD015&tr=21",
            "NigerSubnationalProductionCropsSRdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CountrySTAT/.Niger.Sub-national.Production.Crops.SR.dataset_documentation.html",
            "NigerSubnationalProductionCropsPCPdescription": "Distribution of Main Crops Production by Region, 2000-2011",
            "NigerSubnationalProductionCropsPCPsource": "http://countrystat.org/home.aspx?c=NER&ta=158SPD010&tr=21",
            "NigerSubnationalProductionCropsPCPdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.CountrySTAT/.Niger.Sub-national.Production.Crops.PCP.dataset_documentation.html",
            "Conventions": "IRIDL"
        },
        "Philippines": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Philippines",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Subnational": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Sub-national",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Production": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Production",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Fisheries": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Fisheries",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "C40PNVFP": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "C40PNVFP",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "VoP_MMF": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "VoP_MMF",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Volume of Production of Marine Municipal Fisheries",
                                "units": "tons"
                            },
                            "VoP_IMF": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "VoP_IMF",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Volume of Production of Inland Municipal Fisheries",
                                "units": "tons"
                            },
                            "VoP_CF": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "VoP_CF",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Volume of Production of Commercial Fisheries",
                                "units": "tons"
                            },
                            "VoP_A": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "VoP_A",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Volume of Production of Aquaculture",
                                "units": "tons"
                            },
                            "the_geom": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "the_geom",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Provinces Geometry",
                                "units": "unitless",
                                "PGtype": "bytea",
                                "OpenGISSimpleFeature": "MULTIPOLYGON",
                                "SpatialReferenceSystemWKT": "]]"
                            },
                            "regcode": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "regcode",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Region Code",
                                "missing_value": "NaN",
                                "units": "unitless",
                                "PGtype": "float8"
                            },
                            "provname": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "provname",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Province Name",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "label": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "label",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "PGtype": "text"
                            }
                        }
                    },
                    "Crops": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Crops",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "Yield": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Yield",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Yano_YC": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Yano_YC",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "ncolor": "254",
                                "colorscalename": "correlationcolorscale",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "long_name": "Yield Anomalies estimate of Yellow Corn",
                                "missing_value": "NaN",
                                "units": "0.090718474 kilogram meter-2",
                                "history": "Averaged over T2[1987, 2015] minimum 0.0% data present",
                                "file_missing_value": "-9"
                            },
                            "Yano_WC": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Yano_WC",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "ncolor": "254",
                                "colorscalename": "correlationcolorscale",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "long_name": "Yield Anomalies estimate of White Corn",
                                "missing_value": "NaN",
                                "units": "0.090718474 kilogram meter-2",
                                "history": "Averaged over T2[1987, 2015] minimum 0.0% data present",
                                "file_missing_value": "-9"
                            },
                            "Yano_RP": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Yano_RP",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "ncolor": "254",
                                "colorscalename": "correlationcolorscale",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "long_name": "Yield Anomalies estimate of Rainfed Palay",
                                "missing_value": "NaN",
                                "units": "0.090718474 kilogram meter-2",
                                "history": "Averaged over T2[1987, 2015] minimum 0.0% data present",
                                "file_missing_value": "-9"
                            },
                            "Yano_P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Yano_P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "ncolor": "254",
                                "colorscalename": "correlationcolorscale",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "long_name": "Yield Anomalies estimate of Palay",
                                "missing_value": "NaN",
                                "units": "0.090718474 kilogram meter-2",
                                "history": "Averaged over T2[1987, 2015] minimum 0.0% data present",
                                "file_missing_value": "-9"
                            },
                            "Yano_IP": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Yano_IP",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "ncolor": "254",
                                "colorscalename": "correlationcolorscale",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "long_name": "Yield Anomalies estimate of Irrigated Palay",
                                "missing_value": "NaN",
                                "units": "0.090718474 kilogram meter-2",
                                "history": "Averaged over T2[1987, 2015] minimum 0.0% data present",
                                "file_missing_value": "-9"
                            },
                            "Yano_C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Yano_C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "ncolor": "254",
                                "colorscalename": "correlationcolorscale",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "long_name": "Yield Anomalies estimate of Corn",
                                "missing_value": "NaN",
                                "units": "0.090718474 kilogram meter-2",
                                "history": "Averaged over T2[1987, 2015] minimum 0.0% data present",
                                "file_missing_value": "-9"
                            },
                            "the_geom": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "the_geom",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Provinces Geometry",
                                "units": "unitless",
                                "PGtype": "bytea",
                                "OpenGISSimpleFeature": "MULTIPOLYGON",
                                "SpatialReferenceSystemWKT": "]]"
                            },
                            "regcode": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "regcode",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Region Code",
                                "missing_value": "NaN",
                                "units": "unitless",
                                "PGtype": "float8"
                            },
                            "provname": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "provname",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Province Name",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "label": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "label",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "PGtype": "text"
                            },
                            "AH_Cat": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "AH_Cat",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "the_geom": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "the_geom",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Provinces Geometry",
                                    "units": "unitless",
                                    "PGtype": "bytea",
                                    "OpenGISSimpleFeature": "MULTIPOLYGON",
                                    "SpatialReferenceSystemWKT": "]]"
                                },
                                "regcode": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "regcode",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Region Code",
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "PGtype": "float8"
                                },
                                "provname": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "provname",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Province Name",
                                    "units": "ids",
                                    "PGtype": "varchar"
                                },
                                "label": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "label",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "ids",
                                    "PGtype": "text"
                                },
                                "AH_YC_Cat": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AH_YC_Cat",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "ncolor": "5",
                                    "colormap": "16711680",
                                    "maxncolor": "254",
                                    "long_name": "Type of Variance of Area for Yellow Corn",
                                    "scale_min": "1",
                                    "missing_value": "0",
                                    "CLIST": "lowVar",
                                    "scale_max": "2",
                                    "units": "ids",
                                    "CE": "2",
                                    "CS": "1",
                                    "valid_min": "1",
                                    "valid_max": "2",
                                    "history": "dominant_class over flag[highVar, lowVar]",
                                    "colorscalename": "halfgreyscale",
                                    "fnname": "flaglt",
                                    "file_missing_value": "-9"
                                },
                                "AH_WC_Cat": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AH_WC_Cat",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "ncolor": "5",
                                    "colormap": "16711680",
                                    "maxncolor": "254",
                                    "long_name": "Type of Variance of Area for White Corn",
                                    "scale_min": "1",
                                    "missing_value": "0",
                                    "CLIST": "lowVar",
                                    "scale_max": "2",
                                    "units": "ids",
                                    "CE": "2",
                                    "CS": "1",
                                    "valid_min": "1",
                                    "valid_max": "2",
                                    "history": "dominant_class over flag[highVar, lowVar]",
                                    "colorscalename": "halfgreyscale",
                                    "fnname": "flaglt",
                                    "file_missing_value": "-9"
                                },
                                "AH_RP_Cat": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AH_RP_Cat",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "ncolor": "5",
                                    "colormap": "16711680",
                                    "maxncolor": "254",
                                    "long_name": "Type of Variance of Area for Rainfed Palay",
                                    "scale_min": "1",
                                    "missing_value": "0",
                                    "CLIST": "lowVar",
                                    "scale_max": "2",
                                    "units": "ids",
                                    "CE": "2",
                                    "CS": "1",
                                    "valid_min": "1",
                                    "valid_max": "2",
                                    "history": "dominant_class over flag[highVar, lowVar]",
                                    "colorscalename": "halfgreyscale",
                                    "fnname": "flaglt",
                                    "file_missing_value": "-9"
                                },
                                "AH_P_Cat": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AH_P_Cat",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "ncolor": "5",
                                    "colormap": "16711680",
                                    "maxncolor": "254",
                                    "long_name": "Type of Variance of Area for Palay",
                                    "scale_min": "1",
                                    "missing_value": "0",
                                    "CLIST": "lowVar",
                                    "scale_max": "2",
                                    "units": "ids",
                                    "CE": "2",
                                    "CS": "1",
                                    "valid_min": "1",
                                    "valid_max": "2",
                                    "history": "dominant_class over flag[highVar, lowVar]",
                                    "colorscalename": "halfgreyscale",
                                    "fnname": "flaglt",
                                    "file_missing_value": "-9"
                                },
                                "AH_IP_Cat": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AH_IP_Cat",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "ncolor": "5",
                                    "colormap": "16711680",
                                    "maxncolor": "254",
                                    "long_name": "Type of Variance of Area for Irrigated Palay",
                                    "scale_min": "1",
                                    "missing_value": "0",
                                    "CLIST": "lowVar",
                                    "scale_max": "2",
                                    "units": "ids",
                                    "CE": "2",
                                    "CS": "1",
                                    "valid_min": "1",
                                    "valid_max": "2",
                                    "history": "dominant_class over flag[highVar, lowVar]",
                                    "colorscalename": "halfgreyscale",
                                    "fnname": "flaglt",
                                    "file_missing_value": "-9"
                                },
                                "AH_C_Cat": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AH_C_Cat",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "ncolor": "5",
                                    "colormap": "16711680",
                                    "maxncolor": "254",
                                    "long_name": "Type of Variance of Area for Corn",
                                    "scale_min": "1",
                                    "missing_value": "0",
                                    "CLIST": "lowVar",
                                    "scale_max": "2",
                                    "units": "ids",
                                    "CE": "2",
                                    "CS": "1",
                                    "valid_min": "1",
                                    "valid_max": "2",
                                    "history": "dominant_class over flag[highVar, lowVar]",
                                    "colorscalename": "halfgreyscale",
                                    "fnname": "flaglt",
                                    "file_missing_value": "-9"
                                }
                            }
                        },
                        "O80LUAHC": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "O80LUAHC",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "the_geom": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "the_geom",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Provinces Geometry",
                                "units": "unitless",
                                "PGtype": "bytea",
                                "OpenGISSimpleFeature": "MULTIPOLYGON",
                                "SpatialReferenceSystemWKT": "]]"
                            },
                            "regcode": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "regcode",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Region Code",
                                "missing_value": "NaN",
                                "units": "unitless",
                                "PGtype": "float8"
                            },
                            "provname": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "provname",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Province Name",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "label": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "label",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "PGtype": "text"
                            },
                            "AH_YC": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "AH_YC",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Area Harvested of Yellow Corn",
                                "units": "hectares"
                            },
                            "AH_WC": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "AH_WC",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Area Harvested of White Corn",
                                "units": "hectares"
                            },
                            "AH_RP": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "AH_RP",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Area Harvested of Rainfed Palay",
                                "units": "hectares"
                            },
                            "AH_P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "AH_P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Area Harvested of Palay",
                                "units": "hectares"
                            },
                            "AH_IP": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "AH_IP",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Area Harvested of Irrigated Palay",
                                "units": "hectares"
                            },
                            "AH_C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "AH_C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Area Harvested of Corn",
                                "units": "hectares"
                            }
                        },
                        "A10PNCVP": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "A10PNCVP",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "VoP_YC": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "VoP_YC",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Volume of Production of Yellow Corn",
                                "units": "tons"
                            },
                            "VoP_WC": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "VoP_WC",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Volume of Production of White Corn",
                                "units": "tons"
                            },
                            "VoP_RP": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "VoP_RP",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Volume of Production of Rainfed Palay",
                                "units": "tons"
                            },
                            "VoP_P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "VoP_P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Volume of Production of Palay",
                                "units": "tons"
                            },
                            "VoP_IP": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "VoP_IP",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Volume of Production of Irrigated Palay",
                                "units": "tons"
                            },
                            "VoP_C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "VoP_C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "long_name": "Volume of Production of Corn",
                                "units": "tons"
                            },
                            "the_geom": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "the_geom",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Provinces Geometry",
                                "units": "unitless",
                                "PGtype": "bytea",
                                "OpenGISSimpleFeature": "MULTIPOLYGON",
                                "SpatialReferenceSystemWKT": "]]"
                            },
                            "regcode": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "regcode",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Region Code",
                                "missing_value": "NaN",
                                "units": "unitless",
                                "PGtype": "float8"
                            },
                            "provname": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "provname",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Province Name",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "label": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "label",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "PGtype": "text"
                            }
                        }
                    }
                }
            }
        },
        "Niger": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Niger",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Subnational": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Sub-national",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Production": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Production",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Livestock": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Livestock",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "PV": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "PV",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "the_geom": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "the_geom",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Admin1 geometry",
                                "units": "unitless",
                                "PGtype": "bytea",
                                "OpenGISSimpleFeature": "MULTIPOLYGON",
                                "SpatialReferenceSystemWKT": "]]"
                            },
                            "RPV_O": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "RPV_O",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Meat Production - Sheep"
                            },
                            "RPV_CP": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "RPV_CP",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Meat Production - Goats"
                            },
                            "RPV_CM": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "RPV_CM",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Meat Production - Camelids"
                            },
                            "RPV_B": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "RPV_B",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Meat Production - Cattle"
                            },
                            "label": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "label",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Label",
                                "units": "ids",
                                "PGtype": "text"
                            },
                            "adm1_name": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "adm1_name",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Admin Level1 Name",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "adm1_code": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "adm1_code",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Admin Level1 id",
                                "units": "unitless",
                                "PGtype": "int4"
                            }
                        },
                        "EAV": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "EAV",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "the_geom": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "the_geom",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Admin1 geometry",
                                "units": "unitless",
                                "PGtype": "bytea",
                                "OpenGISSimpleFeature": "MULTIPOLYGON",
                                "SpatialReferenceSystemWKT": "]]"
                            },
                            "REAV_O": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "REAV_O",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Live Animals - Sheep"
                            },
                            "REAV_E": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "REAV_E",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Live Animals - Horses"
                            },
                            "REAV_CP": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "REAV_CP",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Live Animals - Goats"
                            },
                            "REAV_CM": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "REAV_CM",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Live Animals - Camelids"
                            },
                            "REAV_B": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "REAV_B",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Live Animals - Cattle"
                            },
                            "REAV_A": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "REAV_A",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Live Animals - Donkeys"
                            },
                            "label": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "label",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Label",
                                "units": "ids",
                                "PGtype": "text"
                            },
                            "adm1_name": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "adm1_name",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Admin Level1 Name",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "adm1_code": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "adm1_code",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Admin Level1 id",
                                "units": "unitless",
                                "PGtype": "int4"
                            }
                        }
                    },
                    "Crops": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Crops",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "SR": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "SR",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "the_geom": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "the_geom",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Admin1 geometry",
                                "units": "unitless",
                                "PGtype": "bytea",
                                "OpenGISSimpleFeature": "MULTIPOLYGON",
                                "SpatialReferenceSystemWKT": "]]"
                            },
                            "RSR_S": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "RSR_S",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Area Harvested - Sorghum"
                            },
                            "RSR_N": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "RSR_N",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Area Harvested - Cowpea"
                            },
                            "RSR_M": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "RSR_M",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Area Harvested - Millet"
                            },
                            "RSR_A": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "RSR_A",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Area Harvested - Groundnuts"
                            },
                            "label": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "label",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Label",
                                "units": "ids",
                                "PGtype": "text"
                            },
                            "adm1_name": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "adm1_name",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Admin Level1 Name",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "adm1_code": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "adm1_code",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Admin Level1 id",
                                "units": "unitless",
                                "PGtype": "int4"
                            }
                        },
                        "PCP": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "PCP",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "the_geom": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "the_geom",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Admin1 geometry",
                                "units": "unitless",
                                "PGtype": "bytea",
                                "OpenGISSimpleFeature": "MULTIPOLYGON",
                                "SpatialReferenceSystemWKT": "]]"
                            },
                            "RPCP_S": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "RPCP_S",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Main Crops Production - Sorghum"
                            },
                            "RPCP_N": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "RPCP_N",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Main Crops Production - Cowpea"
                            },
                            "RPCP_M": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "RPCP_M",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Main Crops Production - Millet"
                            },
                            "RPCP_A": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "RPCP_A",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-9.0",
                                "units": "tons",
                                "long_name": "Distribution of Main Crops Production - Groundnuts"
                            },
                            "label": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "label",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Label",
                                "units": "ids",
                                "PGtype": "text"
                            },
                            "adm1_name": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "adm1_name",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Admin Level1 Name",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "adm1_code": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "adm1_code",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Admin Level1 id",
                                "units": "unitless",
                                "PGtype": "int4"
                            }
                        }
                    }
                }
            }
        },
        "T_05": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_05",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "3.0"
        },
        "provcode_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "provcode_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "2",
            "long_name": "Province Code"
        },
        "provcode": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "provcode",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridtype": "2",
            "units": "ids"
        },
        "T_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "1",
            "modulo": "12.0",
            "modulus": "12.0",
            "calendar": "360",
            "pointwidth": "3.0"
        },
        "T_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "3.0"
        },
        "gid_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "gid_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "2"
        },
        "gid_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "gid_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "1.0"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "12.0"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "12.0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "12.0"
        },
        "gid": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "gid",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "1.0"
        },
        "dir": "SOURCES/CountrySTAT"
    },
    "DASILVA": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "DASILVA",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "SMD94halfbyhalfclimatologyiridlhasSemantics": "iridl:climatology",
            "SMD94climatologyiridlhasSemantics": "iridl:climatology",
            "SMD94description": "a five-volume atlas series depicting the seasonal and yearly variations of the surface marine atmosphere over the global oceans",
            "SMD94dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.DASILVA/.SMD94.dataset_documentation.html",
            "SMD94iridlhasSemantics": "iridl:NOAA",
            "SMD94GCMD_id": "NOAA_ATLAS_SURFACE_MARINE_DATA",
            "SMD94long_name": "Atlas of Surface Marine Data 1994",
            "SMD94references": "daSilva:etal1994",
            "description": "Atlas of Surface Marine Data 1994 from da Silva et. al",
            "Conventions": "IRIDL"
        },
        "SMD94": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SMD94",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "halfbyhalf": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "halfbyhalf",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "climatology": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "climatology",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "zdl": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zdl",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "unitless",
                        "long_name": "10m / (Monin Obukov length)",
                        "history": "surface marine climatology 1945-89"
                    },
                    "w3": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "w3",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "m/s",
                        "long_name": "wind speed",
                        "history": "surface marine climatology 1945-89"
                    },
                    "vq": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "vq",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "m/s",
                        "long_name": "meridional moisture flux",
                        "history": "surface marine climatology 1945-89"
                    },
                    "virtemp": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "virtemp",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "Celsius_scale",
                        "long_name": "virtual temperature",
                        "history": "surface marine climatology 1945-89"
                    },
                    "vappres": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "vappres",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "hPa",
                        "long_name": "vapor pressure",
                        "history": "surface marine climatology 1945-89"
                    },
                    "va": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "va",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "kelvin meter/second",
                        "long_name": "meridional heat flux",
                        "history": "surface marine climatology 1945-89"
                    },
                    "v3": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "v3",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "m/s",
                        "long_name": "meridional wind",
                        "history": "surface marine climatology 1945-89"
                    },
                    "uq": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "uq",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "m/s",
                        "long_name": "zonal moisture flux",
                        "history": "surface marine climatology 1945-89"
                    },
                    "ua": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ua",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "kelvin meter/second",
                        "long_name": "zonal heat flux",
                        "history": "surface marine climatology 1945-89"
                    },
                    "u3": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "u3",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "m/s",
                        "long_name": "zonal wind",
                        "history": "surface marine climatology 1945-89"
                    },
                    "tauy": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tauy",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "N/m2",
                        "long_name": "meridional wind stress",
                        "history": "surface marine climatology 1945-89"
                    },
                    "taux": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "taux",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "N/m2",
                        "long_name": "zonal wind stress",
                        "history": "surface marine climatology 1945-89"
                    },
                    "sstsat": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sst-sat",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "Celsius_scale",
                        "long_name": "sea minus air temperature",
                        "history": "surface marine climatology 1945-89"
                    },
                    "sst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "Celsius_scale",
                        "long_name": "sea surface temperature",
                        "history": "surface marine climatology 1945-89"
                    },
                    "slp": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "slp",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "hPa",
                        "long_name": "sea level air presure",
                        "history": "surface marine climatology 1945-89"
                    },
                    "shortrad": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "shortrad",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "W/m2",
                        "long_name": "net short wave radiation",
                        "history": "surface marine climatology 1945-89"
                    },
                    "sensib": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sensib",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "N/m2",
                        "long_name": "sensible heat flux",
                        "history": "surface marine climatology 1945-89"
                    },
                    "sat": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sat",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "Celsius_scale",
                        "long_name": "sea level air temperature",
                        "history": "surface marine climatology 1945-89"
                    },
                    "rh": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rh",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "percent",
                        "long_name": "relative humidity",
                        "history": "surface marine climatology 1945-89"
                    },
                    "qsea": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "qsea",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "g/kg",
                        "long_name": "sea level specific humidity",
                        "history": "surface marine climatology 1945-89"
                    },
                    "qsqa": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "qs-qa",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "g/kg",
                        "long_name": "qsea minus qair",
                        "history": "surface marine climatology 1945-89"
                    },
                    "qair": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "qair",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "g/kg",
                        "long_name": "specific humidity",
                        "history": "surface marine climatology 1945-89"
                    },
                    "precip": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "precip",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "mm/(3hours)",
                        "long_name": "precipitation rate",
                        "history": "surface marine climatology 1945-89"
                    },
                    "netheat": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "netheat",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "W/m2",
                        "long_name": "constrained new outgoing heat flux",
                        "history": "surface marine climatology 1945-89"
                    },
                    "longrad": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "longrad",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "W/m2",
                        "long_name": "outgoing longwave radiation",
                        "history": "surface marine climatology 1945-89"
                    },
                    "latent": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "latent",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "W/m2",
                        "long_name": "latent heat flux",
                        "history": "surface marine climatology 1945-89"
                    },
                    "ice": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ice",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "none",
                        "long_name": "ice mask",
                        "history": "surface marine climatology 1945-89"
                    },
                    "fvcubed": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "fvcubed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "N/m2",
                        "long_name": "ocean friction velocity cubed",
                        "history": "surface marine climatology 1945-89"
                    },
                    "emp": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "emp",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "mm/(3hours)",
                        "long_name": "constrained evaporation minus precipitation",
                        "history": "surface marine climatology 1945-89"
                    },
                    "cloud": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cloud",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "percent/100.",
                        "long_name": "cloudiness",
                        "history": "surface marine climatology 1945-89"
                    },
                    "buoy": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "buoy",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "kg/(meter*second3)",
                        "long_name": "constrained buoyancy flux",
                        "history": "surface marine climatology 1945-89"
                    },
                    "airdens": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "airdens",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "kg/m3",
                        "long_name": "sea level air density",
                        "history": "surface marine climatology 1945-89"
                    },
                    "ae": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ae",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "W/m2",
                        "long_name": "long wave vapor pressure sensitivity parameter",
                        "history": "surface marine climatology 1945-89"
                    },
                    "achi": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "achi",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "W/m2",
                        "long_name": "long wave Chi sensitivity parameter",
                        "history": "surface marine climatology 1945-89"
                    },
                    "ac": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ac",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.00000000E10",
                        "Version": "UWM-1.00 05/01/93",
                        "units": "W/m2",
                        "long_name": "short wave cloudiness sensitivity parameter",
                        "history": "surface marine climatology 1945-89"
                    }
                }
            },
            "climatology": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "climatology",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "zdl": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "zdl",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "6.39830032E-05",
                    "add_offset": "0.0895",
                    "units": "unitless",
                    "long_name": "10m / (Monin Obukov length)",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "w3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "w3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "2.43830000E-04",
                    "add_offset": "7.3150001",
                    "units": "m/s",
                    "long_name": "wind speed",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "vq": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "vq",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "7.38669996E-06",
                    "add_offset": "-0.0186",
                    "units": "degK m/s",
                    "long_name": "meridional moisture flux",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "va": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "va",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.10922",
                    "add_offset": "-0.050049",
                    "units": "m/s",
                    "long_name": "meridional heat flux",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "v3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "v3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "5.18670015E-04",
                    "add_offset": "1.35",
                    "units": "m/s",
                    "long_name": "meridional wind",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "uq": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "uq",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "6.84830002E-06",
                    "add_offset": "0.01065",
                    "units": "m/s",
                    "long_name": "zonal moisture flux",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "ua": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ua",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.18212",
                    "add_offset": "-1716.5",
                    "units": "degK m/s",
                    "long_name": "zonal heat flux",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "u3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "u3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "6.79670018E-04",
                    "add_offset": "-3.97",
                    "units": "m/s",
                    "long_name": "zonal wind",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "tauy3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "6.58169984E-06",
                    "add_offset": "0.00655",
                    "units": "N/m2",
                    "long_name": "meridional wind stress",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "taux3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "9.68499990E-06",
                    "add_offset": "-0.03455",
                    "units": "N/m2",
                    "long_name": "zonal wind stress",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "sstsat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sst-sat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "5.92330005E-04",
                    "add_offset": "12.74",
                    "units": "degree_Celsius",
                    "long_name": "sea minus air temperature            ",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "sst": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sst",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "7.25499995E-04",
                    "add_offset": "11.815",
                    "units": "Celsius_scale",
                    "long_name": "sea surface temperature",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "slp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "slp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "8.71170021E-04",
                    "add_offset": "1003.7",
                    "units": "hPa",
                    "long_name": "sea level air presure",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "shortrad": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "shortrad",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.0066022",
                    "add_offset": "198.07001",
                    "units": "W/m2",
                    "long_name": "incoming short wave radiation",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "sensib3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sensib3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.0036573",
                    "add_offset": "57.16",
                    "units": "W/m2",
                    "long_name": "sensible heat flux",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "sat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.0013675",
                    "add_offset": "-6.855",
                    "units": "Celsius_scale",
                    "long_name": "sea level air temperature",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "rh": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rh",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.0018512",
                    "add_offset": "82.775002",
                    "units": "percent",
                    "long_name": "relative humidity",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "qsea": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "qsea",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "5.24399977E-04",
                    "add_offset": "16.504",
                    "units": "g/kg",
                    "long_name": "sea level specific humidity",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "qsqa": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "qs-qa",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "1.72669999E-04",
                    "add_offset": "4.04",
                    "units": "g/kg",
                    "long_name": "qsea minus qair",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "qair": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "qair",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "5.46119991E-04",
                    "add_offset": "16.384001",
                    "units": "g/kg",
                    "long_name": "specific humidity",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "precip7": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "precip7",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "3.83330007E-05",
                    "add_offset": "1.15",
                    "units": "mm/(3hours)",
                    "long_name": "precipitation rate",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "precip6": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "precip6",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "1.14429997E-04",
                    "add_offset": "3.4330001",
                    "units": "mm/(3hours)",
                    "long_name": "precipitation rate",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "netheat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "netheat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.012595",
                    "add_offset": "-97.550003",
                    "units": "W/m2",
                    "long_name": "constrained net outgoing",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "longrad": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "longrad",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.0035487",
                    "add_offset": "90.269997",
                    "units": "W/m2",
                    "long_name": "outgoing longwave radiation",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "latent3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "latent3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.00626",
                    "add_offset": "97.639999",
                    "units": "W/m2",
                    "long_name": "latent heat flux",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "fvcubed": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "fvcubed",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "5.34680022E-10",
                    "add_offset": "8.64649974E-06",
                    "units": "m3/s3",
                    "long_name": "ocean friction velocity cubed",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "evaprate": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "evaprate",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "2.78169991E-05",
                    "add_offset": "0.6065",
                    "units": "mm/(3hours)",
                    "long_name": "evaporation rate",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "cloud": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "cloud",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "2.94649999E-05",
                    "add_offset": "0.88395",
                    "units": "unitless",
                    "long_name": "fractional cloudiness",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "airdens": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "airdens",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "7.18499996E-06",
                    "add_offset": "1.3301001",
                    "units": "kg/m3",
                    "long_name": "sea level air density",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                }
            },
            "anomalies": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "anomalies",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "zdl": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "zdl",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "6.32000010E-05",
                    "add_offset": "-0.041",
                    "units": "unitless",
                    "long_name": "10m/(Monin Obukov length)",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "w3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "w3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "5.69169992E-04",
                    "add_offset": "0.045",
                    "units": "m/s",
                    "long_name": "wind speed",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "vq": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "vq",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "1.17279997E-05",
                    "add_offset": "-0.02495",
                    "units": "degK m/s",
                    "long_name": "meridional moisture flux",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "vappress": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "vappress",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "3.03329987E-04",
                    "units": "hPa",
                    "long_name": "vapor pressure",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "va": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "va",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.107",
                    "add_offset": "-37.200001",
                    "units": "m/s",
                    "long_name": "meridional heat flux",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "v3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "v3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "5.48170006E-04",
                    "add_offset": "0.035",
                    "units": "m/s",
                    "long_name": "meridional wind",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "uq": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "uq",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "1.13579999E-05",
                    "add_offset": "0.02235",
                    "units": "m/s",
                    "long_name": "zonal moisture flux",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "ua": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ua",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.15233",
                    "add_offset": "-118.0",
                    "units": "degK m/s",
                    "long_name": "zonal heat flux",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "u3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "u3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "5.95829973E-04",
                    "add_offset": "-0.615",
                    "units": "m/s",
                    "long_name": "zonal wind",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "tauy3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "1.82669992E-05",
                    "add_offset": "-0.0357",
                    "units": "N/m2",
                    "long_name": "meridional wind stress",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "taux3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "1.66699992E-05",
                    "add_offset": "0.0106",
                    "units": "N/m2",
                    "long_name": "zonal wind stress",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "sstsat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sst-sat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "3.54499993E-04",
                    "add_offset": "-0.025",
                    "units": "degree_Celsius",
                    "long_name": "sea minus air temperature",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "sst": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sst",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "2.43169998E-04",
                    "add_offset": "-0.465",
                    "units": "degree_Celsius",
                    "long_name": "sea surface temperature",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "slp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "slp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.0026342",
                    "add_offset": "-19.084999",
                    "units": "hPa",
                    "long_name": "sea level air presure",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "shortrad": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "shortrad",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.005167",
                    "add_offset": "30.43",
                    "units": "W/m2",
                    "long_name": "incoming short wave radiation",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "sensib3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sensib3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.0076502",
                    "add_offset": "-5.5450001",
                    "units": "W/m2",
                    "long_name": "sensible heat flux",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "sat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "7.37669994E-04",
                    "add_offset": "-0.02",
                    "units": "degree_Celsius",
                    "long_name": "sea level air temperature",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "rh": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rh",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "8.83169996E-04",
                    "add_offset": "-3.375",
                    "units": "percent",
                    "long_name": "relative humidity",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "qsea": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "qsea",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "2.44619994E-04",
                    "add_offset": "0.3995",
                    "units": "g/kg",
                    "long_name": "sea level specific humidity",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "qsqa": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "qs-qa",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "3.31329997E-04",
                    "add_offset": "0.51",
                    "units": "g/kg",
                    "long_name": "qsea minus qair",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "qair": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "qair",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "3.19749990E-04",
                    "add_offset": "0.1515",
                    "units": "g/kg",
                    "long_name": "specific humidity",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "q": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "q",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "3.19749990E-04",
                    "add_offset": "0.1515",
                    "units": "g/kg",
                    "long_name": "specific humidity",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "precip6": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "precip6",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "1.25830004E-04",
                    "add_offset": "1.375",
                    "units": "mm/3hours  ",
                    "long_name": "precipitation rate",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "precip": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "precip",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "1.25649996E-04",
                    "add_offset": "0.8425",
                    "units": "mm/3hours  ",
                    "long_name": "precipitation rate",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "netheat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "netheat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.013058",
                    "add_offset": "-37.450001",
                    "units": "W/m2",
                    "long_name": "constrained net outgoing",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "longrad": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "longrad",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.0020448",
                    "add_offset": "1.455",
                    "units": "W/m2",
                    "long_name": "outgoing longwave radiation",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "latent3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "latent3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.0078372",
                    "add_offset": "3.2049999",
                    "units": "W/m2",
                    "long_name": "latent heat flux",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "fvcubed": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "fvcubed",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "3.77500003E-10",
                    "add_offset": "-4.11000002E-07",
                    "units": "m3/s3",
                    "long_name": "ocean friction velocity cubed",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "evaprate": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "evaprate",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "3.19499995E-05",
                    "add_offset": "0.0685",
                    "units": "mm/3hours  ",
                    "long_name": "evaporation rate",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "cloud": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "cloud",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "4.45869991E-05",
                    "add_offset": "-0.2844",
                    "units": "unitless",
                    "long_name": "fractional cloudiness",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "airdens": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "airdens",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "5.34499986E-06",
                    "add_offset": "0.00555",
                    "units": "kg/m3",
                    "long_name": "sea level air density",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "ae": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ae",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.0012715",
                    "add_offset": "-1.585",
                    "units": "W/m2",
                    "long_name": "longwave vapor pressure sensitivity coefficient",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "achi": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "achi",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.0012473",
                    "add_offset": "0.030001",
                    "units": "W/m2",
                    "long_name": "longwave Chi sensitivity coefficient",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                },
                "ac": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ac",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "32767",
                    "scale_factor": "0.005512",
                    "add_offset": "34.669998",
                    "units": "W/m2",
                    "long_name": "shortwave cloud sensitivity coefficient",
                    "history": "da Silva et al. 1994: Atlas of Surface Marine Data"
                }
            }
        },
        "Y_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "0.5",
            "long_name": "latitude"
        },
        "X_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "modulus": "360.0",
            "pointwidth": "0.5",
            "long_name": "longitude"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "1",
            "modulo": "12.0",
            "calendar": "360",
            "modulus": "12.0",
            "pointwidth": "1.0",
            "long_name": "Time"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0",
            "long_name": "Time"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "1.0",
            "long_name": "latitude"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0",
            "long_name": "Time"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "modulus": "360.0",
            "pointwidth": "1.0",
            "long_name": "longitude"
        },
        "dir": "SOURCES/DASILVA"
    },
    "DEKLIM": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "DEKLIM",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "VASClimOPrcpClimResolution2p5x2p5description": "VASClimO Precipitation Climatology (2.5 x 2.5)",
            "VASClimOPrcpClimResolution1p0x1p0description": "VASClimO Precipitation Climatology (1.0 x 1.0)",
            "VASClimOPrcpClimResolution0p5x0p5description": "VASClimO Precipitation Climatology (0.5 x 0.5)",
            "VASClimOPrcpClimdescription": "VASClimO Precipitation Climatology",
            "VASClimOPrcpClimdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.DEKLIM/.VASClimO.PrcpClim.dataset_documentation.html",
            "VASClimOPrcpClimreferences": "Beck_etal2005",
            "VASClimOdescription": "Variability Analysis of Surface Climate Observations - a joint project of the German Weather Service (DWD/GPCC)and the Johann Wolfgang Goethe-University Frankfurt",
            "description": "German Climate Research Program",
            "iridlhasSemantics": "iridl:DEKLIM",
            "Conventions": "IRIDL"
        },
        "VASClimO": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "VASClimO",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "PrcpClim": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "PrcpClim",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Resolution2p5x2p5": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Resolution-2p5x2p5",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "prcp": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "prcp",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-999.0",
                        "units": "mm",
                        "long_name": "precipitation"
                    }
                },
                "Resolution1p0x1p0": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Resolution-1p0x1p0",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "prcp": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "prcp",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-999.0",
                        "units": "mm",
                        "long_name": "precipitation"
                    }
                },
                "Resolution0p5x0p5": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Resolution-0p5x0p5",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "prcp": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "prcp",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-999.0",
                        "units": "mm",
                        "long_name": "precipitation"
                    }
                }
            }
        },
        "Y_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "2.5"
        },
        "X_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "2.5"
        },
        "Y_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "1.0"
        },
        "X_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "1.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.5"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "0.5"
        },
        "dir": "SOURCES/DEKLIM"
    },
    "DGM": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/DGM",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "DGM",
        "restriction": "Public",
        "Madagascar_v2": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/DGM/Madagascar_v2",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "Madagascar_v2",
            "restriction": "requires dlauth tokens"
        },
        "banned_long": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type",
            "Madagascar_v2"
        ]
    },
    "EC9293": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "EC9293",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "description": "Zonal and meridional wind stress data",
            "Conventions": "IRIDL"
        },
        "tauy": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "tauy",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "long_name": "meridional wind stress",
            "units": "dynes/cm2"
        },
        "taux": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "taux",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "long_name": "zonal wind stress",
            "units": "dynes/cm2"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "1.1214733"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "1.1179686"
        },
        "dir": "SOURCES/EC9293"
    },
    "ECHAM": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "ECHAM",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.ECHAM/.dataset_documentation.html",
            "iridlhasSemantics": "iriref:Latif_M",
            "Conventions": "IRIDL",
            "description": "ECHAM surface stresses"
        },
        "tauy": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "tauy",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless"
        },
        "taux": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "taux",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "format": "ensotime",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "pointwidth": "2.8125",
            "modulus": "360.0"
        },
        "dir": "SOURCES/ECHAM"
    },
    "ECMWF": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/ECMWF",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "ECMWF",
        "restriction": "Public",
        "DEMETER": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/ECMWF/DEMETER",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "DEMETER",
            "restriction": "requires dlauth tokens"
        },
        "ENSEMBLES": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ENSEMBLES",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "STREAM2SEASONALdata_description": "http://www.ecmwf.int/products/forecasts/seasonal/documentation/system3/ch2.html",
                "STREAM2Malariamaydescription": "Ensembles/system-3 hindcasts from ECMWF",
                "STREAM2MalariaBotswanaENSEMBLES_Botswana_Malaria_Page": "http://www.ecmwf.int/research/EU_projects/ENSEMBLES/results/Malariadata.html",
                "STREAM2MalariaBotswanadataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.ECMWF/.ENSEMBLES/.STREAM2.Malaria.Botswana.dataset_documentation.html",
                "Conventions": "IRIDL",
                "ECMWF_DAP": "http://ensembles.ecmwf.int/thredds/dodsC/"
            },
            "STREAM2": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "STREAM2",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "SEASONAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SEASONAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "surface": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "surface",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "tp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "tp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "m s-1",
                            "gribfield": "1",
                            "long_name": "total precipitation",
                            "pointwidth": "0"
                        },
                        "t": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "2t",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "Kelvin_scale",
                            "gribfield": "1",
                            "long_name": "2 meter teperature",
                            "pointwidth": "0"
                        }
                    }
                },
                "Malaria": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Malaria",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "may": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "may",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "surface": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "surface",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "V10": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "V10",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "10m v wind component",
                                "units": "m s**-1",
                                "cNZ": "0",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "U10": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "U10",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "10m u wind component",
                                "units": "m s**-1",
                                "cNZ": "0",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "TP": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "TP",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Accumulated precipitation",
                                "units": "mm",
                                "scale_factor": "1000",
                                "cNZ": "0",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "TEMP2": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "TEMP2",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Mean 2m temperature",
                                "units": "K",
                                "cNZ": "0",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "TCWV": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "TCWV",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Total column water vapor",
                                "units": "mm",
                                "cNZ": "0",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "T2MIN": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T2MIN",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Min 2m temperature",
                                "units": "K",
                                "cNZ": "0",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "T2MAX": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T2MAX",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Max 2m temperature",
                                "units": "K",
                                "cNZ": "0",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "ST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "ST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Soil/sea surface temperature",
                                "units": "K",
                                "cNZ": "0",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "OLR": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "OLR",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Out long wave radiation",
                                "units": "W m**2",
                                "cNZ": "0",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "MSLP": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MSLP",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Mean sea level pressure",
                                "units": "Pa",
                                "cNZ": "0",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "EVAP": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "EVAP",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Surface Evaporation",
                                "units": "m s**-1",
                                "cNZ": "0",
                                "gribfield": "1",
                                "pointwidth": "0"
                            }
                        },
                        "PressureLevel": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "PressureLevel",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "V": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "V",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "V wind",
                                "units": "m s**-1",
                                "cNZ": "3",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "U": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "U",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "U wind",
                                "units": "m s**-1",
                                "cNZ": "3",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Temperature",
                                "units": "K",
                                "cNZ": "3",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "q": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "q",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Specific humidity",
                                "units": "kg kg**-1",
                                "cNZ": "3",
                                "gribfield": "1",
                                "pointwidth": "0"
                            },
                            "Geo": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Geo",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Geopotential height",
                                "units": "g m",
                                "cNZ": "3",
                                "gribfield": "1",
                                "pointwidth": "0"
                            }
                        }
                    },
                    "Botswana": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Botswana",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "METOFFICE": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "METOFFICE",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "precip": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "precip",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0"
                            }
                        },
                        "METEOFR": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "METEOFR",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "precip": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "precip",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0"
                            }
                        },
                        "ECMWF": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ECMWF",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "precip": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "precip",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0"
                            }
                        }
                    }
                }
            },
            "STREAM1": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "STREAM1",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ]
            },
            "L_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "L_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months",
                "gridtype": "0",
                "long_name": "Lead Time",
                "pointwidth": "1"
            },
            "X_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "gridtype": "1",
                "standard_name": "longitude",
                "pointwidth": "1.5"
            },
            "S_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "forecast_reference_time",
                "long_name": "Start time",
                "pointwidth": "0"
            },
            "Y_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_north",
                "gridtype": "0",
                "standard_name": "latitude",
                "pointwidth": "1.5"
            },
            "L_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "L_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "days",
                "gridtype": "0",
                "long_name": "Integration Time",
                "pointwidth": "1"
            },
            "X_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "gridtype": "1",
                "standard_name": "longitude",
                "pointwidth": "1.5"
            },
            "M_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "Member",
                "pointwidth": "1.0"
            },
            "S_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "forecast_reference_time",
                "long_name": "Start time",
                "pointwidth": "0"
            },
            "P": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "P",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "mb",
                "gridtype": "0"
            },
            "Y": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_north",
                "gridtype": "0",
                "standard_name": "latitude",
                "pointwidth": "2.5"
            },
            "L": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "L",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months",
                "gridtype": "0",
                "long_name": "Integration Time",
                "pointwidth": "0"
            },
            "X": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "gridtype": "1",
                "standard_name": "longitude",
                "pointwidth": "2.5"
            },
            "M": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "Member",
                "pointwidth": "1.0"
            },
            "S": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "forecast_reference_time",
                "long_name": "Start time",
                "pointwidth": "0"
            },
            "dir": "SOURCES/ECMWF/ENSEMBLES"
        },
        "ERA15": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/ECMWF/ERA-15",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "ERA-15",
            "restriction": "Public",
            "ERA15pdf": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/ERA-15/ERA15.pdf",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "ERA15.pdf",
                "restriction": "Public",
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ]
            },
            "indextex": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/ERA-15/index.tex",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "index.tex",
                "restriction": "Public",
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ]
            },
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type",
                "ERA15pdf",
                "indextex"
            ]
        },
        "ERA40": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/ECMWF/ERA-40",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "ERA-40",
            "restriction": "Public",
            "MONTHLY": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/ERA-40/MONTHLY",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "MONTHLY",
                "restriction": "Public",
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ]
            },
            "SIXHOURLY": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/ERA-40/SIX-HOURLY",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "SIX-HOURLY",
                "restriction": "requires dlauth tokens"
            },
            "TimeInv": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/ERA-40/TimeInv",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "TimeInv",
                "restriction": "Public",
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ]
            },
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type",
                "MONTHLY",
                "SIXHOURLY",
                "TimeInv"
            ]
        },
        "ERAInterim": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/ECMWF/ERA-Interim",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "ERA-Interim",
            "restriction": "Public",
            "SIXHOURLY": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/ERA-Interim/SIX-HOURLY",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "SIX-HOURLY",
                "restriction": "Public",
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ]
            },
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type",
                "SIXHOURLY"
            ]
        },
        "GGA": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/ECMWF/GGA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "GGA",
            "restriction": "Public",
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ]
        },
        "S2S": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/ECMWF/S2S",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "S2S",
            "restriction": "Public",
            "BOM": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/S2S/BOM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "BOM",
                "restriction": "Public",
                "forecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/BOM/forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "forecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/BOM/forecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/BOM/forecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/BOM/forecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "reforecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/BOM/reforecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "reforecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/BOM/reforecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/BOM/reforecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/BOM/reforecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "forecast",
                    "reforecast"
                ]
            },
            "CMA": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/S2S/CMA",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "CMA",
                "restriction": "Public",
                "BCCCPSS2Sv1": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "BCC-CPS-S2Sv1",
                    "restriction": "Public",
                    "forecast": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv1/forecast",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "forecast",
                        "restriction": "Public",
                        "control": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv1/forecast/control",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "control",
                            "restriction": "Public",
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ]
                        },
                        "perturbed": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv1/forecast/perturbed",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "perturbed",
                            "restriction": "Public",
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ]
                        },
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type",
                            "control",
                            "perturbed"
                        ]
                    },
                    "reforecast": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv1/reforecast",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "reforecast",
                        "restriction": "Public",
                        "control": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv1/reforecast/control",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "control",
                            "restriction": "Public",
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ]
                        },
                        "perturbed": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv1/reforecast/perturbed",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "perturbed",
                            "restriction": "Public",
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ]
                        },
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type",
                            "control",
                            "perturbed"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "forecast",
                        "reforecast"
                    ]
                },
                "BCCCPSS2Sv2": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "BCC-CPS-S2Sv2",
                    "restriction": "Public",
                    "forecast": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv2/forecast",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "forecast",
                        "restriction": "Public",
                        "control": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv2/forecast/control",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "control",
                            "restriction": "Public",
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ]
                        },
                        "perturbed": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv2/forecast/perturbed",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "perturbed",
                            "restriction": "Public",
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ]
                        },
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type",
                            "control",
                            "perturbed"
                        ]
                    },
                    "reforecast": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv2/reforecast",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "reforecast",
                        "restriction": "Public",
                        "control": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv2/reforecast/control",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "control",
                            "restriction": "Public",
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ]
                        },
                        "perturbed": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/ECMWF/S2S/CMA/BCC-CPS-S2Sv2/reforecast/perturbed",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "perturbed",
                            "restriction": "Public",
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ]
                        },
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type",
                            "control",
                            "perturbed"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "forecast",
                        "reforecast"
                    ]
                },
                "forecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/CMA/forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "forecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CMA/forecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CMA/forecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CMA/forecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "reforecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/CMA/reforecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "reforecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CMA/reforecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CMA/reforecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CMA/reforecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "BCCCPSS2Sv1",
                    "BCCCPSS2Sv2",
                    "forecast",
                    "reforecast"
                ]
            },
            "CNRM": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/S2S/CNRM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "CNRM",
                "restriction": "Public",
                "forecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/CNRM/forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "forecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CNRM/forecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CNRM/forecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CNRM/forecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "reforecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/CNRM/reforecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "reforecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CNRM/reforecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CNRM/reforecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/CNRM/reforecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "forecast",
                    "reforecast"
                ]
            },
            "ECCC": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/S2S/ECCC",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "ECCC",
                "restriction": "Public",
                "forecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/ECCC/forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "forecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ECCC/forecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ECCC/forecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ECCC/forecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "reforecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/ECCC/reforecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "reforecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ECCC/reforecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ECCC/reforecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ECCC/reforecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "forecast",
                    "reforecast"
                ]
            },
            "ECMF": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/S2S/ECMF",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "ECMF",
                "restriction": "Public",
                "forecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/ECMF/forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "forecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ECMF/forecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ECMF/forecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ECMF/forecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "reforecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/ECMF/reforecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "reforecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ECMF/reforecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ECMF/reforecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ECMF/reforecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "forecast",
                    "reforecast"
                ]
            },
            "EI": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/S2S/EI",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "EI",
                "restriction": "Public",
                "reanalysis": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/EI/reanalysis",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "reanalysis",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/EI/reanalysis/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "reanalysis"
                ]
            },
            "HMCR": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/S2S/HMCR",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "HMCR",
                "restriction": "Public",
                "forecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/HMCR/forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "forecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/HMCR/forecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/HMCR/forecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/HMCR/forecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "reforecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/HMCR/reforecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "reforecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/HMCR/reforecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/HMCR/reforecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/HMCR/reforecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "forecast",
                    "reforecast"
                ]
            },
            "ISAC": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/S2S/ISAC",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "ISAC",
                "restriction": "Public",
                "forecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/ISAC/forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "forecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ISAC/forecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ISAC/forecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ISAC/forecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "reforecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/ISAC/reforecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "reforecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ISAC/reforecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/ISAC/reforecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "forecast",
                    "reforecast"
                ]
            },
            "JMA": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/S2S/JMA",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "JMA",
                "restriction": "Public",
                "forecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/JMA/forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "forecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/JMA/forecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/JMA/forecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/JMA/forecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbedM49": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/JMA/forecast/perturbedM49",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbedM49",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed",
                        "perturbedM49"
                    ]
                },
                "reforecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/JMA/reforecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "reforecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/JMA/reforecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/JMA/reforecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/JMA/reforecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "forecast",
                    "reforecast"
                ]
            },
            "KMA": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/S2S/KMA",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "KMA",
                "restriction": "Public",
                "forecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/KMA/forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "forecast",
                    "restriction": "Public",
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/KMA/forecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/KMA/forecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "control",
                        "perturbed"
                    ]
                },
                "reforecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/KMA/reforecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "reforecast",
                    "restriction": "Public",
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/KMA/reforecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/KMA/reforecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "control",
                        "perturbed"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "forecast",
                    "reforecast"
                ]
            },
            "NCEP": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/S2S/NCEP",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "NCEP",
                "restriction": "Public",
                "forecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/NCEP/forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "forecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/NCEP/forecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/NCEP/forecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/NCEP/forecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "reforecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/NCEP/reforecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "reforecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/NCEP/reforecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/NCEP/reforecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/NCEP/reforecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "forecast",
                    "reforecast"
                ]
            },
            "UKMO": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/S2S/UKMO",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "UKMO",
                "restriction": "Public",
                "forecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/UKMO/forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "forecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/UKMO/forecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/UKMO/forecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/UKMO/forecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed"
                    ]
                },
                "reforecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/UKMO/reforecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "reforecast",
                    "restriction": "Public",
                    "RMMS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/UKMO/reforecast/RMMS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "RMMS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "control": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/UKMO/reforecast/control",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "control",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbed": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/UKMO/reforecast/perturbed",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbed",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "perturbedM6": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/UKMO/reforecast/perturbedM6",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "perturbedM6",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "RMMS",
                        "control",
                        "perturbed",
                        "perturbedM6"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "forecast",
                    "reforecast"
                ]
            },
            "climatologies": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/ECMWF/S2S/climatologies",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "climatologies",
                "restriction": "Public",
                "hindcast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/climatologies/hindcast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "hindcast",
                    "restriction": "Public",
                    "BOM": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/climatologies/hindcast/BOM",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "BOM",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "CMA": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/climatologies/hindcast/CMA",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "CMA",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "CNRM": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/climatologies/hindcast/CNRM",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "CNRM",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "ECCC": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/climatologies/hindcast/ECCC",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "ECCC",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "ECMF": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/climatologies/hindcast/ECMF",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "ECMF",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "ISAC": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/climatologies/hindcast/ISAC",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "ISAC",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "JMA": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/climatologies/hindcast/JMA",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "JMA",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "KMA": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/climatologies/hindcast/KMA",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "KMA",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "NCEP": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/climatologies/hindcast/NCEP",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "NCEP",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "UKMO": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/climatologies/hindcast/UKMO",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "UKMO",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "BOM",
                        "CMA",
                        "CNRM",
                        "ECCC",
                        "ECMF",
                        "ISAC",
                        "JMA",
                        "KMA",
                        "NCEP",
                        "UKMO"
                    ]
                },
                "observed": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/ECMWF/S2S/climatologies/observed",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "observed",
                    "restriction": "Public",
                    "CHIRPS": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/climatologies/observed/CHIRPS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "CHIRPS",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "CPC": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/climatologies/observed/CPC",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "CPC",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "GPCP": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/ECMWF/S2S/climatologies/observed/GPCP",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "GPCP",
                        "restriction": "Public",
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "CHIRPS",
                        "CPC",
                        "GPCP"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "hindcast",
                    "observed"
                ]
            },
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type",
                "BOM",
                "CMA",
                "CNRM",
                "ECCC",
                "ECMF",
                "EI",
                "HMCR",
                "ISAC",
                "JMA",
                "KMA",
                "NCEP",
                "UKMO",
                "climatologies"
            ]
        },
        "TCs": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "TCs",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "reforecastsWNPdescription": "West Northern Pacific basin",
                "bestTrackWNPdescription": "West Northern Pacific basin",
                "bestTrackWNPdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.ECMWF/.TCs/.bestTrack.WNP.dataset_documentation.html",
                "description": "Tropical Cyclones",
                "Conventions": "IRIDL"
            },
            "reforecasts": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "reforecasts",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "WNP": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WNP",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "vmax": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "vmax",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "0.0",
                        "CS": "0",
                        "maxncolor": "254",
                        "colorscalename": "windspeed_colors",
                        "colormap": "2622920",
                        "ncolor": "254",
                        "missing_value": "9.96920997E36",
                        "units": "m/s",
                        "long_name": "Maximum wind velocity",
                        "pointwidth": "0"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Forecast Time",
                        "pointwidth": "0",
                        "calendar": "standard",
                        "units": "days since 1960-01-01"
                    },
                    "StormId": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "StormId",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "9.96920997E36",
                        "long_name": "Storm ID",
                        "units": "unitless",
                        "pointwidth": "0"
                    },
                    "pmin": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pmin",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "9.96920997E36",
                        "units": "hPa",
                        "long_name": "Minimum Pressure",
                        "pointwidth": "0"
                    },
                    "lon": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lon",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "9.96920997E36",
                        "units": "degree_east",
                        "long_name": "longitude",
                        "scale_max": "225.0",
                        "scale_min": "85.0",
                        "pointwidth": "0"
                    },
                    "location": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "location",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "OpenGISSimpleFeature": "Point",
                        "long_name": "location",
                        "SpatialReferenceSystemWKT": "]]",
                        "units": "degree_east",
                        "scale_max": "225.0",
                        "scale_min": "85.0",
                        "pointwidth": "0"
                    },
                    "lat": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lat",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "9.96920997E36",
                        "units": "degree_north",
                        "long_name": "latitude",
                        "scale_max": "54.0",
                        "scale_min": "-4.0",
                        "pointwidth": "0"
                    }
                }
            },
            "forecasts": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "forecasts",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "WNP": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WNP",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "vmax": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "vmax",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "0.0",
                        "CS": "0",
                        "maxncolor": "254",
                        "colorscalename": "windspeed_colors",
                        "colormap": "2622920",
                        "ncolor": "254",
                        "missing_value": "9.96920997E36",
                        "units": "knot",
                        "long_name": "Maximum wind velocity",
                        "pointwidth": "0"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Forecast Time",
                        "pointwidth": "0",
                        "calendar": "standard",
                        "units": "days since 2015-01-01"
                    },
                    "StormId": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "StormId",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "9.96920997E36",
                        "long_name": "Storm ID",
                        "units": "unitless",
                        "pointwidth": "0"
                    },
                    "pmin": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pmin",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "9.96920997E36",
                        "units": "mb",
                        "long_name": "Minimum Pressure",
                        "pointwidth": "0"
                    },
                    "lon": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lon",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "9.96920997E36",
                        "units": "degree_east",
                        "long_name": "longitude",
                        "scale_max": "225.0",
                        "scale_min": "85.0",
                        "pointwidth": "0"
                    },
                    "location": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "location",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "OpenGISSimpleFeature": "Point",
                        "long_name": "location",
                        "SpatialReferenceSystemWKT": "]]",
                        "units": "degree_east",
                        "scale_max": "225.0",
                        "scale_min": "85.0",
                        "pointwidth": "0"
                    },
                    "lat": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lat",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "9.96920997E36",
                        "units": "degree_north",
                        "long_name": "latitude",
                        "scale_max": "54.0",
                        "scale_min": "-4.0",
                        "pointwidth": "0"
                    }
                }
            },
            "bestTrack": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "bestTrack",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "WNP": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WNP",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "vmax": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "vmax",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "0.0",
                        "CS": "0",
                        "maxncolor": "254",
                        "colorscalename": "windspeed_colors",
                        "colormap": "2622920",
                        "ncolor": "254",
                        "missing_value": "9.96920997E36",
                        "units": "knot",
                        "long_name": "Maximum wind velocity",
                        "pointwidth": "0"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Forecast Time",
                        "pointwidth": "0",
                        "calendar": "standard",
                        "units": "days since 1960-01-01"
                    },
                    "StormId": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "StormId",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "9.96920997E36",
                        "long_name": "Storm ID",
                        "units": "unitless",
                        "pointwidth": "0"
                    },
                    "pmin": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pmin",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "9.96920997E36",
                        "units": "hPa",
                        "long_name": "Minimum Pressure",
                        "pointwidth": "0"
                    },
                    "lon": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lon",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "9.96920997E36",
                        "units": "degree_east",
                        "long_name": "longitude",
                        "scale_max": "225.0",
                        "scale_min": "85.0",
                        "pointwidth": "0"
                    },
                    "location": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "location",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "OpenGISSimpleFeature": "Point",
                        "long_name": "location",
                        "SpatialReferenceSystemWKT": "]]",
                        "units": "degree_east",
                        "scale_max": "225.0",
                        "scale_min": "85.0",
                        "pointwidth": "0"
                    },
                    "lat": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lat",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "9.96920997E36",
                        "units": "degree_north",
                        "long_name": "latitude",
                        "scale_max": "54.0",
                        "scale_min": "-4.0",
                        "pointwidth": "0"
                    }
                }
            },
            "L_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "L_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "days",
                "gridtype": "0",
                "long_name": "lead time",
                "pointwidth": "1.0"
            },
            "M_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "ensemble member",
                "pointwidth": "1.0"
            },
            "L_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "L_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "days",
                "gridtype": "0",
                "long_name": "lead time",
                "pointwidth": "0.5"
            },
            "M": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "ensemble member",
                "pointwidth": "1.0"
            },
            "S_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "gridtype": "0",
                "calendar": "standard",
                "long_name": "Start time",
                "units": "days since 2015-01-01",
                "pointwidth": "0"
            },
            "StormNum": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "StormNum",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "L": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "L",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "days",
                "gridtype": "0",
                "long_name": "lead time",
                "pointwidth": "0.25"
            },
            "S": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "days since 1960-01-01",
                "gridtype": "0",
                "calendar": "standard",
                "long_name": "Start time",
                "pointwidth": "0"
            },
            "dir": "SOURCES/ECMWF/TCs"
        },
        "banned_long": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type",
            "DEMETER",
            "ENSEMBLES",
            "ERA15",
            "ERA40",
            "ERAInterim",
            "GGA",
            "S2S",
            "TCs"
        ]
    },
    "ECOSYSTEMS": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "ECOSYSTEMS",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Olsonreferences": "Olson_etal1983",
            "Olsondescription": "Global vegetation and ecosystems data",
            "Olsondataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.ECOSYSTEMS/.Olson.dataset_documentation.html",
            "OlsoniridlhasSemantics": "iridl:ORNL",
            "Olsonlong_name": "Olson Ecosystem Complexes",
            "Matthewsdescription": "Global vegetation and ecosystems data",
            "Matthewssource": ">Matthews Global Vegetation Index</a>",
            "Matthewsdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.ECOSYSTEMS/.Matthews.dataset_documentation.html",
            "MatthewsiridlhasSemantics": "iridl:GISS",
            "Matthewslong_name": "Matthews Vegetation Index",
            "Matthewsreferences": "Matthews1983 Matthews1984",
            "Holdridgechangeslong_name": "Areas with Life-Zone Changes in doubled CO2 senario",
            "Holdridgereferences": "Leemans1990",
            "Holdridgesource": ">Holdridge Life Zones Data Set</a>",
            "HoldridgeiridlhasSemantics": "iridl:IIASA",
            "Holdridgelong_name": "Holdridge Life Zones",
            "description": "Vegetation and ecosystem data from the IIASA, GISS, and USGS",
            "Conventions": "IRIDL"
        },
        "Olson": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Olson",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "_class": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "class",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "scale_min": "17.0",
                "scale_max": "70.0",
                "iridlhasSemantics": "iridl:LandCover",
                "long_name": "land ecosystem class",
                "CLIST": "ice"
            }
        },
        "Matthews": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Matthews",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "vegetation": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "vegetation",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "scale_min": "1.0",
                "scale_max": "32.0",
                "source": ">Matthews Global Vegetation Index</a>",
                "iridlhasSemantics": "iridl:LandCover",
                "long_name": "vegetation index",
                "missing_values": "99999",
                "CLIST": "cultivation"
            }
        },
        "Holdridge": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Holdridge",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "present": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "present",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "lifezone": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "life-zone",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "maxncolor": "41",
                    "colormap": "1710726",
                    "scale_max": "38.0",
                    "ncolor": "41",
                    "scale_min": "1.0",
                    "CE": "38",
                    "CS": "1",
                    "iridlhasSemantics": "iridl:LandCover",
                    "long_name": "life-zone class",
                    "CLIST": "Tropical rain forest"
                }
            },
            "doubleCO2": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "doubleCO2",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "lifezone": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "life-zone",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "scale_max": "38.0",
                    "ncolor": "41",
                    "scale_min": "1.0",
                    "CS": "1",
                    "CE": "38",
                    "maxncolor": "41",
                    "colormap": "1710726",
                    "CLIST": "Tropical rain forest",
                    "iridlhasSemantics": "iridl:LandCover",
                    "long_name": "life-zone class"
                }
            },
            "changes": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "changes",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "present": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "present",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "lifezone": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "life-zone",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "scale_max": "38.0",
                        "ncolor": "41",
                        "scale_min": "1.0",
                        "CS": "1",
                        "iridlhasSemantics": "iridl:LandCover",
                        "CE": "38",
                        "maxncolor": "41",
                        "colormap": "1710726",
                        "CLIST": "Tropical rain forest",
                        "long_name": "life-zone class"
                    }
                },
                "doubleCO2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "doubleCO2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "lifezone": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "life-zone",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "scale_max": "38.0",
                        "ncolor": "41",
                        "scale_min": "1.0",
                        "CS": "1",
                        "iridlhasSemantics": "iridl:LandCover",
                        "CE": "38",
                        "maxncolor": "41",
                        "colormap": "1710726",
                        "CLIST": "Tropical rain forest",
                        "long_name": "life-zone class"
                    }
                }
            }
        },
        "Y_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "1.0"
        },
        "X_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "1.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.5"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "0.5"
        },
        "dir": "SOURCES/ECOSYSTEMS"
    },
    "ECP9293": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "ECP9293",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "description": "Zonal and meridional wind stress data",
            "Conventions": "IRIDL"
        },
        "tauy": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "tauy",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "long_name": "meridional wind stress",
            "units": "dynes/cm2"
        },
        "taux": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "taux",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "long_name": "zonal wind stress",
            "units": "dynes/cm2"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "1",
            "modulo": "12.0",
            "modulus": "12.0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "1.1214733"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "1.1179686"
        },
        "dir": "SOURCES/ECP9293"
    },
    "ENSOFORECAST": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "ENSOFORECAST",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "LDEO2CACSMdescription": "observed ssta fields",
            "LDEO212MONdescription": "forecast ssta fields",
            "LDEO209MONdescription": "forecast ssta fields",
            "LDEO206MONdescription": "forecast ssta fields",
            "LDEO203MONdescription": "forecast ssta fields",
            "LDEO2Y": "Y",
            "LDEO2description": "LDEO2 Forecasts of Tropical Pacific SSTA at 3-12 month lead times",
            "LDEO2T": "T",
            "LDEO2X": "X",
            "LDEO1CACSMdescription": "observed ssta fields",
            "LDEO112MONdescription": "forecast ssta fields",
            "LDEO109MONdescription": "forecast ssta fields",
            "LDEO106MONdescription": "forecast ssta fields",
            "LDEO103MONdescription": "forecast ssta fields",
            "LDEO1Y": "Y",
            "LDEO1description": "Forecasts of Tropical Pacific SSTA at 3-12 month lead times",
            "LDEO1T": "T",
            "LDEO1X": "X",
            "description": "Equatorial Pacific SSTA forecasts from the Lamont-Doherty Earth Observatory Climate Group",
            "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.ENSOFORECAST/.dataset_documentation.html",
            "iridlhasSemantics": "iridl:forecast",
            "Conventions": "IRIDL",
            "references": "Zebiak_Cane1987"
        },
        "LDEO2": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "LDEO2",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "CACSM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CACSM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ssta": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssta",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "history": "CACSM SSTA with land gridded as in the forecasts",
                    "missing_value": "-999.0",
                    "units": "degC"
                }
            },
            "MON": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "03MON",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ssta": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssta",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.0",
                    "units": "degC",
                    "long_name": "temperature anomaly"
                }
            }
        },
        "LDEO1": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "LDEO1",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "CACSM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CACSM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ssta": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssta",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "history": "CACSM SSTA with land gridded as in the forecasts",
                    "missing_value": "-999.0",
                    "units": "degC"
                }
            },
            "MON": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "03MON",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ssta": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssta",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.0",
                    "units": "degC"
                }
            }
        },
        "T_08": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_08",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "T_07": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_07",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "T_06": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_06",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "T_05": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_05",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "T_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "T_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "pointwidth": "4.0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "2.0"
        },
        "dir": "SOURCES/ENSOFORECAST"
    },
    "EPCU": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "EPCU",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "long_name": "EPCU",
            "references": "vanGeen_etal1992",
            "description": "Eastern pacific coastal upwelling data for the Americas from the Lamont-Doherty Earth Observatory",
            "Conventions": "IRIDL",
            "iridlhasSemantics": "iridl:LDEO",
            "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.EPCU/.dataset_documentation.html"
        },
        "TIME": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "TIME",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "-999.0",
            "add_offset": "2448257.0",
            "calendar": "standard",
            "units": "julian_day",
            "pointwidth": "0"
        },
        "Si": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Si",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "-999.0",
            "units": "micro mole/L",
            "long_name": "Silicate"
        },
        "SALINITY": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SALINITY",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "-999.0",
            "units": "PSU"
        },
        "P": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "P",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "-999.0",
            "units": "micro mole/L",
            "long_name": "Phosphate"
        },
        "N": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "N",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "-999.0",
            "units": "micro mole/L",
            "long_name": "Nitrate and Nitrite"
        },
        "lon": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "lon",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "scale_min": "-130.0",
            "scale_max": "-60.0",
            "units": "degree_east",
            "long_name": "longitude"
        },
        "lat": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "lat",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "scale_min": "-50.0",
            "scale_max": "50.0",
            "units": "degree_north",
            "long_name": "latitude"
        },
        "Cd": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Cd",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "-999.0",
            "units": "nano mole/kg",
            "long_name": "Cadmium"
        },
        "IT": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "IT",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "0.5",
            "add_offset": "372.0"
        },
        "STA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "STA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2",
            "long_name": "station"
        },
        "dir": "SOURCES/EPCU"
    },
    "ERBE": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "ERBE",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "partdescription": "Shortwave radiation budget data 60S-60N derived from 5 Years of ERBE measurements",
            "globalmeanforcinglong_name": "cloud forcing",
            "globalmeanclrlong_name": "clear-sky",
            "globalmeancldlong_name": "all-sky",
            "globaldescription": "Global shortwave radiation budget data derived from 5 Years of ERBE measurements",
            "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.ERBE/.dataset_documentation.html",
            "iridlhasSemantics": "iridl:NOAA",
            "Conventions": "IRIDL",
            "references": "Li_Leighton1993 Li_etal1993a Li_etal1993b",
            "description": "Earth Radiation Budget Experiment"
        },
        "part": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "part",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "monthly": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "monthly",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "srb": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "srb",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "source": ">ERBE description</A>",
                    "units": "W/m2",
                    "long_name": "surface radiation budget",
                    "history": "ERBE Surface Radiation Budget"
                }
            }
        },
        "_global": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "global",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "monthly": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "monthly",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "srb": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "srb",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "source": ">ERBE description</A>",
                    "units": "W/m2",
                    "long_name": "surface radiation budget",
                    "history": "ERBE Surface Radiation Budget"
                }
            },
            "mean": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "mean",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "forcing": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "forcing",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "srb": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "srb",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "source": ">ERBE description</A>",
                        "units": "W/m2",
                        "long_name": "surface radiation budget",
                        "history": "ERBE Surface Radiation Budget"
                    }
                },
                "clr": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "clr",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "srb": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "srb",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "source": ">ERBE description</A>",
                        "units": "W/m2",
                        "long_name": "surface radiation budget",
                        "history": "ERBE Surface Radiation Budget"
                    }
                },
                "cld": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "cld",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "srb": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "srb",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "source": ">ERBE description</A>",
                        "units": "W/m2",
                        "long_name": "surface radiation budget",
                        "history": "ERBE Surface Radiation Budget"
                    }
                }
            }
        },
        "Y_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "2.5"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "2.5"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "1",
            "modulo": "12.0",
            "calendar": "360",
            "modulus": "12.0",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "modulus": "360.0",
            "pointwidth": "2.5"
        },
        "dir": "SOURCES/ERBE"
    },
    "EU": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/EU",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "EU",
        "restriction": "Public",
        "Copernicus": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Copernicus",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "CDSC3SUKMOGloSea5GC2System15hindcastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SUKMOGloSea5GC2System15hindcastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SUKMOGloSea5GC2System15hindcastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SUKMOGloSea5GC2System15forecastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SUKMOGloSea5GC2System15forecastexpires": "1614582000",
                "CDSC3SUKMOGloSea5GC2System15forecastlicense": "https://cds.climate.copernicus.eu/api/v2/terms/static/20180314_Copernicus_License_V1.1.pdf",
                "CDSC3SUKMOGloSea5GC2System15forecastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SUKMOGloSea5GC2System14hindcastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SUKMOGloSea5GC2System14hindcastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SUKMOGloSea5GC2System14hindcastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SUKMOGloSea5GC2System14forecastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SUKMOGloSea5GC2System14forecastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SUKMOGloSea5GC2System14forecastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SUKMOGloSea5GC2System13hindcastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SUKMOGloSea5GC2System13hindcastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SUKMOGloSea5GC2System13hindcastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SUKMOGloSea5GC2System13forecastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SUKMOGloSea5GC2System13forecastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SUKMOGloSea5GC2System13forecastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SMeteo_FranceSystem7hindcastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SMeteo_FranceSystem7hindcastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SMeteo_FranceSystem7hindcastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SMeteo_FranceSystem7forecastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SMeteo_FranceSystem7forecastexpires": "1614582000",
                "CDSC3SMeteo_FranceSystem7forecastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SMeteo_FranceSystem7forecastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SMeteo_FranceSystem6hindcastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SMeteo_FranceSystem6hindcastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SMeteo_FranceSystem6hindcastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SMeteo_FranceSystem6forecastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SMeteo_FranceSystem6forecastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SMeteo_FranceSystem6forecastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SMeteo_FranceSystem5hindcastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SMeteo_FranceSystem5hindcastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SMeteo_FranceSystem5hindcastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SMeteo_FranceSystem5forecastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SMeteo_FranceSystem5forecastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SMeteo_FranceSystem5forecastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SECMWFSEAS5hindcastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SECMWFSEAS5hindcastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SECMWFSEAS5hindcastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SECMWFSEAS5forecastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SECMWFSEAS5forecastexpires": "1614582000",
                "CDSC3SECMWFSEAS5forecastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SECMWFSEAS5forecastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SDWDGCFS2p1hindcastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SDWDGCFS2p1hindcastlicense": "https://cds.climate.copernicus.eu/api/v2/terms/static/20180314_Copernicus_License_V1.1.pdf",
                "CDSC3SDWDGCFS2p1hindcastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SDWDGCFS2p1forecastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SDWDGCFS2p1forecastexpires": "1614582000",
                "CDSC3SDWDGCFS2p1forecastlicense": "https://cds.climate.copernicus.eu/api/v2/terms/static/20180314_Copernicus_License_V1.1.pdf",
                "CDSC3SDWDGCFS2p1forecastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SDWDGCFS2p0hindcastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SDWDGCFS2p0hindcastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SDWDGCFS2p0hindcastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SDWDGCFS2p0forecastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SDWDGCFS2p0forecastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SDWDGCFS2p0forecastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SCMCCSPSv3p5hindcastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SCMCCSPSv3p5hindcastlicense": "https://cds.climate.copernicus.eu/api/v2/terms/static/20180314_Copernicus_License_V1.1.pdf",
                "CDSC3SCMCCSPSv3p5hindcastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SCMCCSPSv3p5forecastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SCMCCSPSv3p5forecastexpires": "1614582000",
                "CDSC3SCMCCSPSv3p5forecastlicense": "https://cds.climate.copernicus.eu/api/v2/terms/static/20180314_Copernicus_License_V1.1.pdf",
                "CDSC3SCMCCSPSv3p5forecastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SCMCCSPSv3hindcastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SCMCCSPSv3hindcastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SCMCCSPSv3hindcastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3SCMCCSPSv3forecastsource": "https://cds.climate.copernicus.eu/cdsapp#!/home",
                "CDSC3SCMCCSPSv3forecastlicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3SCMCCSPSv3forecastnote": "Generated using Copernicus Climate Change Service information [2018]",
                "CDSC3Shome": "https://climate.copernicus.eu/",
                "CDSC3Slicense": "https://iridl.ldeo.columbia.edu/documentation/eu/copernicus/cds/c3s/licence-to-use-copernicus-products.pdf",
                "CDSC3Sdescription": "Copernicus Climate Change Service",
                "CDSdescription": "Climate Data Store",
                "Conventions": "IRIDL",
                "description": "Copernicus Earth Observation Programme"
            },
            "CDS": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CDS",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "C3S": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "C3S",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "UKMO": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "UKMO",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "GloSea5GC2": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "GloSea5-GC2",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "System15": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "System15",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "hindcast": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hindcast",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "geopotential",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m2 s-2",
                                        "gribfield": "1",
                                        "gribparam": "129",
                                        "grib_name": "Z",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "geopotential",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "va": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "va",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "V-component of wind",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "gribparam": "132",
                                        "grib_name": "VGRD",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "northward_wind",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "ua": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ua",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "U-component of wind",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "gribparam": "131",
                                        "grib_name": "UGRD",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "eastward_wind",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "2-meter temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "scale_max": "330.0",
                                        "scale_min": "180.0",
                                        "gribparam": "167",
                                        "grib_name": "2T",
                                        "standard_name": "air_temperature",
                                        "process": "128",
                                        "gribNumBits": "24",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "sea surface temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "scale_max": "365.39999",
                                        "scale_min": "180.0",
                                        "gribparam": "34",
                                        "grib_name": "SSTK",
                                        "standard_name": "sea_surface_temperature",
                                        "process": "128",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "total precipitation",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "scale_min": "0.0",
                                        "gribparam": "228",
                                        "grib_name": "TP",
                                        "standard_name": "lwe_precipitation_rate",
                                        "process": "255",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    }
                                },
                                "forecast": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "forecast",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "geopotential",
                                        "file_missing_value": "9.99900026E20",
                                        "expires": "1614582000",
                                        "units": "m2 s-2",
                                        "gribfield": "1",
                                        "gribparam": "129",
                                        "grib_name": "Z",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "geopotential",
                                        "gribNumBits": "24",
                                        "defaultvalue": "733.0",
                                        "pointwidth": "0"
                                    },
                                    "va": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "va",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "V-component of wind",
                                        "file_missing_value": "9.99900026E20",
                                        "expires": "1614582000",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "gribparam": "132",
                                        "grib_name": "VGRD",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "northward_wind",
                                        "gribNumBits": "24",
                                        "defaultvalue": "733.0",
                                        "pointwidth": "0"
                                    },
                                    "ua": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ua",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "U-component of wind",
                                        "file_missing_value": "9.99900026E20",
                                        "expires": "1614582000",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "gribparam": "131",
                                        "grib_name": "UGRD",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "eastward_wind",
                                        "gribNumBits": "24",
                                        "defaultvalue": "733.0",
                                        "pointwidth": "0"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "2-meter temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "expires": "1614582000",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "scale_max": "330.0",
                                        "scale_min": "180.0",
                                        "gribparam": "167",
                                        "grib_name": "2T",
                                        "standard_name": "air_temperature",
                                        "process": "128",
                                        "gribNumBits": "24",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "defaultvalue": "733.0",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "expires": "1614582000",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0",
                                        "defaultvalue": "733.0",
                                        "bounds": "S"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "sea surface temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "expires": "1614582000",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "scale_max": "365.39999",
                                        "scale_min": "180.0",
                                        "gribparam": "34",
                                        "grib_name": "SSTK",
                                        "standard_name": "sea_surface_temperature",
                                        "process": "128",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "defaultvalue": "733.0",
                                        "pointwidth": "0"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "total precipitation",
                                        "file_missing_value": "9.99900026E20",
                                        "expires": "1614582000",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "scale_min": "0.0",
                                        "gribparam": "228",
                                        "grib_name": "TP",
                                        "standard_name": "lwe_precipitation_rate",
                                        "process": "255",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "defaultvalue": "733.0",
                                        "pointwidth": "0"
                                    }
                                }
                            },
                            "System14": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "System14",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "hindcast": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hindcast",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "geopotential",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m2 s-2",
                                        "gribfield": "1",
                                        "gribparam": "129",
                                        "grib_name": "Z",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "geopotential",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "va": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "va",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "V-component of wind",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "gribparam": "132",
                                        "grib_name": "VGRD",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "northward_wind",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "ua": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ua",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "U-component of wind",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "gribparam": "131",
                                        "grib_name": "UGRD",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "eastward_wind",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "2-meter temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "scale_max": "330.0",
                                        "scale_min": "180.0",
                                        "gribparam": "167",
                                        "grib_name": "2T",
                                        "standard_name": "air_temperature",
                                        "process": "128",
                                        "gribNumBits": "24",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "sea surface temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "scale_max": "365.39999",
                                        "scale_min": "180.0",
                                        "gribparam": "34",
                                        "grib_name": "SSTK",
                                        "standard_name": "sea_surface_temperature",
                                        "process": "128",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "total precipitation",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "scale_min": "0.0",
                                        "gribparam": "228",
                                        "grib_name": "TP",
                                        "standard_name": "lwe_precipitation_rate",
                                        "process": "255",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    }
                                },
                                "forecast": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "forecast",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "geopotential",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m2 s-2",
                                        "gribfield": "1",
                                        "gribparam": "129",
                                        "grib_name": "Z",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "geopotential",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "va": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "va",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "V-component of wind",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "gribparam": "132",
                                        "grib_name": "VGRD",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "northward_wind",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "ua": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ua",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "U-component of wind",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "gribparam": "131",
                                        "grib_name": "UGRD",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "eastward_wind",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "2-meter temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "scale_max": "330.0",
                                        "scale_min": "180.0",
                                        "gribparam": "167",
                                        "grib_name": "2T",
                                        "standard_name": "air_temperature",
                                        "process": "128",
                                        "gribNumBits": "24",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "sea surface temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "scale_max": "365.39999",
                                        "scale_min": "180.0",
                                        "gribparam": "34",
                                        "grib_name": "SSTK",
                                        "standard_name": "sea_surface_temperature",
                                        "process": "128",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "total precipitation",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "scale_min": "0.0",
                                        "gribparam": "228",
                                        "grib_name": "TP",
                                        "standard_name": "lwe_precipitation_rate",
                                        "process": "255",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    }
                                }
                            },
                            "System13": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "System13",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "hindcast": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hindcast",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "geopotential",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m2 s-2",
                                        "gribfield": "1",
                                        "gribparam": "129",
                                        "grib_name": "Z",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "geopotential",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "va": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "va",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "V-component of wind",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "gribparam": "132",
                                        "grib_name": "VGRD",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "northward_wind",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "ua": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ua",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "U-component of wind",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "gribparam": "131",
                                        "grib_name": "UGRD",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "eastward_wind",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "2-meter temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "scale_max": "330.0",
                                        "scale_min": "180.0",
                                        "gribparam": "167",
                                        "grib_name": "2T",
                                        "standard_name": "air_temperature",
                                        "process": "128",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "sea surface temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "scale_max": "365.39999",
                                        "scale_min": "180.0",
                                        "gribparam": "34",
                                        "grib_name": "SSTK",
                                        "standard_name": "sea_surface_temperature",
                                        "process": "128",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "total precipitation",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "scale_min": "0.0",
                                        "gribparam": "228",
                                        "grib_name": "TP",
                                        "standard_name": "lwe_precipitation_rate",
                                        "process": "255",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    }
                                },
                                "forecast": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "forecast",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "geopotential",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m2 s-2",
                                        "gribfield": "1",
                                        "gribparam": "129",
                                        "grib_name": "Z",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "geopotential",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "va": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "va",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "V-component of wind",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "gribparam": "132",
                                        "grib_name": "VGRD",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "northward_wind",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "ua": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ua",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "U-component of wind",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "gribparam": "131",
                                        "grib_name": "UGRD",
                                        "process": "128",
                                        "gribcenter": "74",
                                        "standard_name": "eastward_wind",
                                        "gribNumBits": "24",
                                        "pointwidth": "0"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "2-meter temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "scale_max": "330.0",
                                        "scale_min": "180.0",
                                        "gribparam": "167",
                                        "grib_name": "2T",
                                        "standard_name": "air_temperature",
                                        "process": "128",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "sea surface temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "scale_max": "365.39999",
                                        "scale_min": "180.0",
                                        "gribparam": "34",
                                        "grib_name": "SSTK",
                                        "standard_name": "sea_surface_temperature",
                                        "process": "128",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "fnname": "maskge",
                                        "long_name": "total precipitation",
                                        "file_missing_value": "9.99900026E20",
                                        "units": "m s-1",
                                        "gribfield": "1",
                                        "scale_min": "0.0",
                                        "gribparam": "228",
                                        "grib_name": "TP",
                                        "standard_name": "lwe_precipitation_rate",
                                        "process": "255",
                                        "gribNumBits": "16",
                                        "gribcenter": "74",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    }
                                }
                            }
                        }
                    },
                    "Meteo_France": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Meteo_France",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "System7": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "System7",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "hindcast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "231",
                                    "gribcenter": "85",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "128",
                                    "gribcenter": "85",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "128",
                                    "gribcenter": "85",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "365.39999",
                                    "scale_min": "180.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "142",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                }
                            },
                            "forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "231",
                                    "gribcenter": "85",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "16",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "128",
                                    "gribcenter": "85",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "16",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "128",
                                    "gribcenter": "85",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "16",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "expires": "1614582000",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0",
                                    "defaultvalue": "733.0",
                                    "bounds": "S"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "365.39999",
                                    "scale_min": "180.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "142",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                }
                            }
                        },
                        "System6": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "System6",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "hindcast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "231",
                                    "gribcenter": "85",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "128",
                                    "gribcenter": "85",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "128",
                                    "gribcenter": "85",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "365.39999",
                                    "scale_min": "180.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "142",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                }
                            },
                            "forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "231",
                                    "gribcenter": "85",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "128",
                                    "gribcenter": "85",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "128",
                                    "gribcenter": "85",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "365.39999",
                                    "scale_min": "180.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "142",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                }
                            }
                        },
                        "System5": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "System5",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "hindcast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "231",
                                    "gribcenter": "85",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "365.39999",
                                    "scale_min": "180.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "142",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                }
                            },
                            "forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "231",
                                    "gribcenter": "85",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "365.39999",
                                    "scale_min": "180.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "142",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                }
                            }
                        }
                    },
                    "ECMWF": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ECMWF",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "SEAS5": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "SEAS5",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "hindcast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "147",
                                    "gribcenter": "98",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "147",
                                    "gribcenter": "98",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "147",
                                    "gribcenter": "98",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "16",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "365.39999",
                                    "scale_min": "180.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "142",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                }
                            },
                            "forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "147",
                                    "gribcenter": "98",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "16",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "147",
                                    "gribcenter": "98",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "16",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "147",
                                    "gribcenter": "98",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "16",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "expires": "1614582000",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0",
                                    "defaultvalue": "733.0",
                                    "bounds": "S"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "365.39999",
                                    "scale_min": "180.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "142",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "147",
                                    "gribNumBits": "16",
                                    "gribcenter": "98",
                                    "gribleveltype": "1",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                }
                            }
                        }
                    },
                    "DWD": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "DWD",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "GCFS2p1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "GCFS2p1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "hindcast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "128",
                                    "gribcenter": "78",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "128",
                                    "gribcenter": "78",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "128",
                                    "gribcenter": "78",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "78",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "320.0",
                                    "scale_min": "270.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "128",
                                    "gribNumBits": "16",
                                    "gribcenter": "78",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "78",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                }
                            },
                            "forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "128",
                                    "gribcenter": "78",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "24",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "128",
                                    "gribcenter": "78",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "24",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "128",
                                    "gribcenter": "78",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "24",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "78",
                                    "gribleveltype": "1",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "expires": "1614582000",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0",
                                    "defaultvalue": "733.0",
                                    "bounds": "S"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "320.0",
                                    "scale_min": "270.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "128",
                                    "gribNumBits": "16",
                                    "gribcenter": "78",
                                    "gribleveltype": "1",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "78",
                                    "gribleveltype": "1",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                }
                            }
                        },
                        "GCFS2p0": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "GCFS2p0",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "hindcast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "128",
                                    "gribcenter": "78",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "128",
                                    "gribcenter": "78",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "128",
                                    "gribcenter": "78",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "78",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "320.0",
                                    "scale_min": "270.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "128",
                                    "gribNumBits": "16",
                                    "gribcenter": "78",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "78",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                }
                            },
                            "forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "128",
                                    "gribcenter": "78",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "128",
                                    "gribcenter": "78",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "128",
                                    "gribcenter": "78",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "78",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "320.0",
                                    "scale_min": "270.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "128",
                                    "gribNumBits": "16",
                                    "gribcenter": "78",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "78",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                }
                            }
                        }
                    },
                    "CMCC": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "CMCC",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "SPSv3p5": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "SPSv3p5",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "hindcast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "128",
                                    "gribcenter": "80",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "128",
                                    "gribcenter": "80",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "128",
                                    "gribcenter": "80",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "80",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "320.0",
                                    "scale_min": "270.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "128",
                                    "gribNumBits": "16",
                                    "gribcenter": "80",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "80",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                }
                            },
                            "forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "128",
                                    "gribcenter": "80",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "24",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "128",
                                    "gribcenter": "80",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "24",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "128",
                                    "gribcenter": "80",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "24",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "80",
                                    "gribleveltype": "1",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "expires": "1614582000",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0",
                                    "defaultvalue": "733.0",
                                    "bounds": "S"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "320.0",
                                    "scale_min": "270.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "128",
                                    "gribNumBits": "16",
                                    "gribcenter": "80",
                                    "gribleveltype": "1",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "expires": "1614582000",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "80",
                                    "gribleveltype": "1",
                                    "defaultvalue": "733.0",
                                    "pointwidth": "0"
                                }
                            }
                        },
                        "SPSv3": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "SPSv3",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "hindcast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "128",
                                    "gribcenter": "80",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "128",
                                    "gribcenter": "80",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "128",
                                    "gribcenter": "80",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "80",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "320.0",
                                    "scale_min": "270.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "128",
                                    "gribNumBits": "16",
                                    "gribcenter": "80",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "80",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                }
                            },
                            "forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "geopotential",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m2 s-2",
                                    "gribfield": "1",
                                    "gribparam": "129",
                                    "grib_name": "Z",
                                    "process": "128",
                                    "gribcenter": "80",
                                    "standard_name": "geopotential",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "va": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "va",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "V-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "132",
                                    "grib_name": "VGRD",
                                    "process": "128",
                                    "gribcenter": "80",
                                    "standard_name": "northward_wind",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "ua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "U-component of wind",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "gribparam": "131",
                                    "grib_name": "UGRD",
                                    "process": "128",
                                    "gribcenter": "80",
                                    "standard_name": "eastward_wind",
                                    "gribNumBits": "24",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "2-meter temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "330.0",
                                    "scale_min": "180.0",
                                    "gribparam": "167",
                                    "grib_name": "2T",
                                    "standard_name": "air_temperature",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "80",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Time",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "sea surface temperature",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "Kelvin_scale",
                                    "gribfield": "1",
                                    "scale_max": "320.0",
                                    "scale_min": "270.0",
                                    "gribparam": "34",
                                    "grib_name": "SSTK",
                                    "standard_name": "sea_surface_temperature",
                                    "process": "128",
                                    "gribNumBits": "16",
                                    "gribcenter": "80",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "fnname": "maskge",
                                    "long_name": "total precipitation",
                                    "file_missing_value": "9.99900026E20",
                                    "units": "m s-1",
                                    "gribfield": "1",
                                    "scale_min": "0.0",
                                    "gribparam": "228",
                                    "grib_name": "TP",
                                    "standard_name": "lwe_precipitation_rate",
                                    "process": "128",
                                    "gribNumBits": "24",
                                    "gribcenter": "80",
                                    "gribleveltype": "1",
                                    "pointwidth": "0"
                                }
                            }
                        }
                    }
                }
            },
            "S_13": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_13",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "expires": "1614582000",
                "calendar": "360",
                "defaultvalue": "733.0",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "M_08": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M_08",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "member",
                "pointwidth": "1.0"
            },
            "S_12": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_12",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "M_07": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M_07",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "member",
                "pointwidth": "1.0"
            },
            "M_06": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M_06",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "member",
                "pointwidth": "1.0"
            },
            "S_11": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_11",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "S_10": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_10",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "expires": "1614582000",
                "calendar": "360",
                "defaultvalue": "733.0",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "S_09": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_09",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "M_05": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M_05",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "member",
                "pointwidth": "1.0"
            },
            "S_08": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_08",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "P_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "P_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "hPa",
                "gridtype": "0",
                "standard_name": "air_pressure",
                "long_name": "Pressure Level"
            },
            "S_07": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_07",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "M_04": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M_04",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "member",
                "pointwidth": "1.0"
            },
            "S_06": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_06",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "Y_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_north",
                "gridtype": "0",
                "standard_name": "latitude",
                "pointwidth": "1.0"
            },
            "X_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "gridtype": "1",
                "standard_name": "longitude",
                "pointwidth": "1.0"
            },
            "M_03": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M_03",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "member",
                "pointwidth": "1.0"
            },
            "S_05": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_05",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "expires": "1614582000",
                "calendar": "360",
                "defaultvalue": "733.0",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "S_04": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_04",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "expires": "1614582000",
                "calendar": "360",
                "defaultvalue": "733.0",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "M_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "member",
                "pointwidth": "1.0"
            },
            "S_03": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_03",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "S_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "expires": "1614582000",
                "calendar": "360",
                "defaultvalue": "733.0",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "M_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "member",
                "pointwidth": "1.0"
            },
            "S_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "P": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "P",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "hPa",
                "gridtype": "0",
                "standard_name": "air_pressure",
                "long_name": "Pressure Level"
            },
            "Y": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_north",
                "gridtype": "0",
                "standard_name": "latitude",
                "pointwidth": "1.0"
            },
            "L": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "L",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months",
                "gridtype": "0",
                "standard_name": "forecast_period",
                "long_name": "Lead",
                "pointwidth": "1.0"
            },
            "X": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "gridtype": "1",
                "standard_name": "longitude",
                "pointwidth": "1.0"
            },
            "M": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "member",
                "pointwidth": "1.0"
            },
            "S": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "S",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "forecast_reference_time",
                "long_name": "Forecast Start Time",
                "pointwidth": "0"
            },
            "dir": "SOURCES/EU/Copernicus"
        },
        "EUMETSAT": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "EUMETSAT",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.EU/.EUMETSAT/.dataset_documentation.html",
                "Conventions": "IRIDL"
            },
            "Meteosat_3712": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Meteosat_3712",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "temperature": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temperature",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "valid_min": "2",
                    "COFF": "1250.5",
                    "LFAC": "521518918",
                    "short_name": "temperature",
                    "SpatialReferenceSystemDims": "Y",
                    "LOFF": "1250.5",
                    "units": "Kelvin_scale",
                    "CFAC": "521518918",
                    "long_name": "Brightness temperature",
                    "SpatialReferenceSystemWKT": ",0]]",
                    "ssp_lon": "0.0",
                    "Meteosat": "2-7",
                    "missing_value": "-99",
                    "pointwidth": "0.0"
                }
            },
            "Meteosat_3711": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Meteosat_3711",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "temperature": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temperature",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "valid_min": "2",
                    "COFF": "1250.5",
                    "LFAC": "521518918",
                    "short_name": "temperature",
                    "SpatialReferenceSystemDims": "Y",
                    "LOFF": "1250.5",
                    "units": "Kelvin_scale",
                    "CFAC": "521518918",
                    "long_name": "Brightness temperature",
                    "SpatialReferenceSystemWKT": ",0]]",
                    "ssp_lon": "0.0",
                    "Meteosat": "2-7",
                    "missing_value": "-99",
                    "pointwidth": "0.0"
                }
            },
            "Meteosat_2500": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Meteosat_2500",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "temperature": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temperature",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "valid_min": "2",
                    "COFF": "1250.5",
                    "LFAC": "521518918",
                    "short_name": "temperature",
                    "SpatialReferenceSystemDims": "Y",
                    "LOFF": "1250.5",
                    "units": "Kelvin_scale",
                    "CFAC": "521518918",
                    "long_name": "Brightness temperature",
                    "SpatialReferenceSystemWKT": ",0]]",
                    "ssp_lon": "0.0",
                    "Meteosat": "2-7",
                    "missing_value": "-99",
                    "pointwidth": "0.0"
                }
            },
            "Y_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "m",
                "gridtype": "0",
                "pointwidth": "3003.0498"
            },
            "T_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "minutes since 1983-01-01 0:0:0",
                "gridtype": "0",
                "calendar": "standard",
                "standard_name": "time",
                "pointwidth": "0.0"
            },
            "X_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "m",
                "gridtype": "0",
                "pointwidth": "3015.2649"
            },
            "Y_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "m",
                "gridtype": "0",
                "pointwidth": "3003.0496"
            },
            "T_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "minutes since 1983-01-01 0:0:0",
                "gridtype": "0",
                "calendar": "standard",
                "standard_name": "time",
                "pointwidth": "0.0"
            },
            "X_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "m",
                "gridtype": "0",
                "pointwidth": "3015.2646"
            },
            "Y": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "m",
                "gridtype": "0",
                "pointwidth": "4517.0977"
            },
            "T": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "minutes since 1983-01-01 0:0:0",
                "gridtype": "0",
                "calendar": "standard",
                "standard_name": "time",
                "pointwidth": "0.0"
            },
            "X": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "m",
                "gridtype": "0",
                "pointwidth": "4517.2559"
            },
            "dir": "SOURCES/EU/EUMETSAT"
        },
        "JRC": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "JRC",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "IESGVMGLC2000V1p1globaldescription": "Gridded global land cover data set from the Global Vegetation Monitoring Unit of the Institute for Environment and Sustainability of the EC Joint Research Centre",
                "IESGVMGLC2000V1p1globalhome_page": "http://www-gvm.jrc.it/glc2000/defaultGLC2000.htm",
                "IESGVMGLC2000V1p1description": "Version 1.1",
                "IESGVMGLC2000description": "Global Landcover Classification 2000",
                "IESGVMFAPARWestAfricaProcessing_Center": "Joint Research Centre - IMW - GVM / IES",
                "IESGVMFAPARWestAfricaSoftware_Version": "ReMap Aggregate - Version 1.0",
                "IESGVMFAPARWestAfricaMission": "Seastar SeaWiFS",
                "IESGVMFAPARWestAfricaSoftware_Name": "ReMap Aggregate - JRC - GVM / IES",
                "IESGVMFAPARsource": "http://fapar.jrc.it/WWW/Home.php",
                "IESGVMFAPARreferences": "Gobron_etal2002 Gobron_etal2006",
                "IESGVMdescription": "Global Vegetation Monitoring Unit",
                "IESGVMhome_page": "http://www-gvm.jrc.it/",
                "IESdescription": "Institute for Environment and Sustainability",
                "IESiridlhasSemantics": "iridl:IES",
                "IEShome_page": "http://ies.jrc.cec.eu.int/",
                "description": "Joint Research Centre",
                "iridlhasSemantics": "iridl:JRC",
                "Conventions": "IRIDL",
                "home_page": "http://www.jrc.cec.eu.int/"
            },
            "IES": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "IES",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "GVM": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "GVM",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "GLC2000": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "GLC2000",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "V1p1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "V1p1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "_global": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "global",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "_class": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "class",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "maxncolor": "26",
                                    "colormap": "16777215",
                                    "scale_max": "23.0",
                                    "ncolor": "26",
                                    "scale_min": "1.0",
                                    "CE": "23",
                                    "CS": "1",
                                    "iridlhasSemantics": "iridl:LandCover",
                                    "units": "ids",
                                    "long_name": "land cover class",
                                    "CLIST": "No data"
                                }
                            }
                        }
                    },
                    "FAPAR": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "FAPAR",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "WestAfrica": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "WestAfrica",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "tenday": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tenday",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "version": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "version",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "nb_temporal_fapar": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "nb_temporal_fapar",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Number of daily FAPAR estimates used in time composite",
                                    "missing_value": "255",
                                    "units": "unitless"
                                },
                                "fapar": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "fapar",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Fraction of Absorbed Photosynthetically Active Radiation (FAPAR)",
                                    "missing_value": "255",
                                    "scale_factor": "0.004",
                                    "valid_range": "250",
                                    "units": "unitless"
                                },
                                "dev_temporal_fapar": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dev_temporal_fapar",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Temporal deviation of FAPAR during the time composite period",
                                    "units": "unitless"
                                },
                                "day_fapar": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "day_fapar",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Day selected for FAPAR value during the time composite",
                                    "missing_value": "255",
                                    "units": "unitless"
                                }
                            },
                            "monthly": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "monthly",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "nb_temporal_fapar": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "nb_temporal_fapar",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Number of daily FAPAR estimates used in time composite",
                                    "missing_value": "255",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "fapar": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "fapar",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Fraction of Absorbed Photosynthetically Active Radiation (FAPAR)",
                                    "missing_value": "255",
                                    "scale_factor": "0.004",
                                    "valid_range": "250",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "dev_temporal_fapar": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dev_temporal_fapar",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Temporal deviation of FAPAR during the time composite period",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "day_fapar": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "day_fapar",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Day selected for FAPAR value during the time composite",
                                    "missing_value": "255",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                }
                            }
                        }
                    }
                }
            },
            "Y_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_north",
                "gridtype": "0",
                "standard_name": "latitude",
                "pointwidth": "0.008928572"
            },
            "X_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "gridtype": "1",
                "standard_name": "longitude",
                "pointwidth": "0.008928572"
            },
            "T_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "days since 1960-01-01",
                "gridtype": "0",
                "calendar": "standard"
            },
            "Y": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_north",
                "gridtype": "0",
                "standard_name": "latitude",
                "pointwidth": "0.01949026"
            },
            "T": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "time",
                "pointwidth": "1.0"
            },
            "X": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "gridtype": "0",
                "standard_name": "longitude",
                "pointwidth": "0.01983003"
            },
            "dir": "SOURCES/EU/JRC"
        },
        "VITO": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/EU/VITO",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "VITO",
            "restriction": "Public",
            "DevCoCast": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/EU/VITO/DevCoCast",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "DevCoCast",
                "restriction": "Public",
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ]
            },
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type",
                "DevCoCast"
            ]
        },
        "banned_long": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type",
            "Copernicus",
            "EUMETSAT",
            "JRC",
            "VITO"
        ]
    },
    "Ethiopia": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/Ethiopia",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "Ethiopia",
        "restriction": "Public",
        "NMA": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/Ethiopia/NMA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "NMA",
            "restriction": "requires dlauth tokens"
        },
        "WASPqueries": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "WASPqueries",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "countryquerylong_name": "country info",
                "Conventions": "IRIDL"
            },
            "provincequery": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "provincequery",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "the_geom": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "the_geom",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "PGtype": "bytea",
                    "OpenGISSimpleFeature": "MULTIPOLYGON",
                    "SpatialReferenceSystemWKT": "]]"
                },
                "province": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "province",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Province info",
                    "units": "ids",
                    "PGtype": "varchar"
                }
            },
            "paENACTSlast_WASP12": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "paENACTS-last_WASP12",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "Province-Average ENACTS 12-Month WASP",
                "scale_max": "2.5",
                "scale_min": "-2.5",
                "missing_value": "NaN",
                "units": "unitless",
                "history": "Boxes with less than 0.0% dropped",
                "ncolor": "254",
                "CS": "-3.5",
                "colorscalename": "std_wasp_colors",
                "CE": "3.5",
                "maxncolor": "254",
                "colormap": "360960"
            },
            "pabaseline_full": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "pabaseline_full",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "Province-Average ENACTS 12-Month WASP Baseline",
                "missing_value": "NaN",
                "units": "unitless",
                "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                "ncolor": "254",
                "colorscalename": "std_wasp_colors",
                "maxncolor": "254",
                "colormap": "360960"
            },
            "districtquery": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "districtquery",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "the_geom": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "the_geom",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "PGtype": "bytea",
                    "OpenGISSimpleFeature": "MULTIPOLYGON",
                    "SpatialReferenceSystemWKT": "]]"
                },
                "district": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "district",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "District info",
                    "units": "ids",
                    "PGtype": "varchar"
                }
            },
            "daENACTSlast_WASP12": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "daENACTS-last_WASP12",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "District-Average ENACTS 12-Month WASP",
                "scale_max": "2.5",
                "scale_min": "-2.5",
                "missing_value": "NaN",
                "units": "unitless",
                "history": "Boxes with less than 0.0% dropped",
                "ncolor": "254",
                "CS": "-3.5",
                "colorscalename": "std_wasp_colors",
                "CE": "3.5",
                "maxncolor": "254",
                "colormap": "360960"
            },
            "dabaseline_full": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "dabaseline_full",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "District-Average ENACTS 12-Month WASP Baseline",
                "missing_value": "NaN",
                "units": "unitless",
                "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                "ncolor": "254",
                "colorscalename": "std_wasp_colors",
                "maxncolor": "254",
                "colormap": "360960"
            },
            "countryquery": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "countryquery",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "the_geom": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "the_geom",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "PGtype": "bytea",
                    "OpenGISSimpleFeature": "MULTIPOLYGON",
                    "SpatialReferenceSystemWKT": "]]"
                },
                "cntry_name": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "cntry_name",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "PGtype": "varchar"
                }
            },
            "caENACTSlast_WASP12": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "caENACTS-last_WASP12",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "Country-Average ENACTS 12-Month WASP",
                "scale_max": "2.5",
                "scale_min": "-2.5",
                "missing_value": "NaN",
                "history": "Boxes with less than 0.0% dropped",
                "units": "unitless",
                "ncolor": "254",
                "CS": "-3.5",
                "colorscalename": "std_wasp_colors",
                "CE": "3.5",
                "maxncolor": "254",
                "colormap": "360960"
            },
            "cabaseline_full": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "cabaseline_full",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "Country-Average ENACTS 12-Month WASP Baseline",
                "missing_value": "NaN",
                "units": "unitless",
                "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                "ncolor": "254",
                "colorscalename": "std_wasp_colors",
                "maxncolor": "254",
                "colormap": "360960"
            },
            "prov_na": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "prov_na",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "gridtype": "2",
                "units": "ids"
            },
            "province": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "province",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "gridtype": "2",
                "units": "ids"
            },
            "dist_na": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "dist_na",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "gridtype": "2",
                "units": "ids"
            },
            "district": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "district",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "gridtype": "2",
                "units": "ids"
            },
            "country": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "country",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "gridtype": "0",
                "pointwidth": "0",
                "units": "ids"
            },
            "BaseYears": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "BaseYears",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "pointwidth": "12.0"
            },
            "Baseline": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Baseline",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "1",
                "modulo": "12.0",
                "modulus": "12.0",
                "calendar": "360",
                "pointwidth": "1.0"
            },
            "T": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "pointwidth": "12.0"
            },
            "dir": "SOURCES/Ethiopia/WASPqueries"
        },
        "wasp_functions": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "wasp_functions",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Conventions": "IRIDL"
            },
            "ENACT1210_WASP12": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ENACT-1210_WASP12",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_max": "3.5",
                "ncolor": "254",
                "scale_min": "-3.5",
                "CS": "-3.5",
                "colorscalename": "std_wasp_colors",
                "CE": "3.5",
                "maxncolor": "254",
                "colormap": "360960",
                "long_name": "ENACT-1210_WASP12",
                "missing_value": "NaN",
                "units": "unitless",
                "history": "Averaged over T[Jan, Dec] minimum 0.0% data present"
            },
            "ENACT1210_lag_WASP12": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ENACT-1210_lag_WASP12",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_max": "3.5",
                "ncolor": "254",
                "scale_min": "-3.5",
                "CS": "-3.5",
                "colorscalename": "std_wasp_colors",
                "CE": "3.5",
                "maxncolor": "254",
                "colormap": "360960",
                "long_name": "ENACT-1210_WASP12",
                "missing_value": "NaN",
                "units": "unitless",
                "history": "Averaged over T[Jan, Dec] minimum 0.0% data present"
            },
            "T_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "pointwidth": "12.0"
            },
            "Y": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_north",
                "gridtype": "0",
                "standard_name": "latitude",
                "pointwidth": "0.09999999"
            },
            "T": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "pointwidth": "12.0"
            },
            "X": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "gridtype": "0",
                "standard_name": "longitude",
                "pointwidth": "0.1"
            },
            "mylag": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "mylag",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "dir": "SOURCES/Ethiopia/wasp_functions"
        },
        "banned_long": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type",
            "NMA",
            "WASPqueries",
            "wasp_functions"
        ]
    },
    "FAO": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "FAO",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NRMEDSDClimateDerivedlong_name": "Derived Climate Products",
            "NRMEDSDdescription": "Sustainable Development",
            "NRMEDdescription": "Natural Resources Management and Environment Department",
            "NRMEDNRMED_Home": "http://www.fao.org/nr/index_en.htm",
            "GeoNetworkagrometeorologicalETdeg0p5edition1c6190source": ">FAO</a>",
            "GeoNetworkagrometeorologicalETdeg0p5edition1c6190FAO_GeoNetwork": "http://www.fao.org/geonetwork/srv/en/main.home",
            "GeoNetworkagrometeorologicalETdeg0p5edition1c6190history": "prepared according to the FAO Penman-Monteith method from University of East Anglia Climate Research Unit CRU CL 1.0 climate dataset, 1961-1990",
            "GeoNetworkagrometeorologicalETdeg0p5edition1c6190dataset_documentation": "http://www.fao.org/geonetwork/srv/en/metadata.show?id=5017&currTab=simple",
            "description": "Food and Agriculture Organization",
            "iridlhasSemantics": "iridl:FAO",
            "Conventions": "IRIDL",
            "FAO_Home": "http://www.fao.org/"
        },
        "NRMED": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NRMED",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "SD": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SD",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Climate": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Climate",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Derived": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Derived",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "_class": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "class",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "maxncolor": "51",
                            "colormap": "708330",
                            "scale_max": "48.0",
                            "ncolor": "51",
                            "scale_min": "1.0",
                            "CE": "48",
                            "CS": "1",
                            "missing_value": "-999.0",
                            "iridlhasSemantics": "iridl:Classification",
                            "long_name": "Koeppen Climate Classification",
                            "CLIST": "Dry BWk\\'"
                        }
                    }
                }
            }
        },
        "GeoNetwork": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "GeoNetwork",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "agrometeorological": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "agrometeorological",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ET": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ET",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "deg0p5": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "deg0p5",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "edition1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "edition1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "c6190": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "c6190",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "etref": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "etref",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_factor": "0.1",
                                    "units": "mm/day",
                                    "long_name": "reference evapotranspiration",
                                    "missing_value": "-9999",
                                    "modulo": "12.0",
                                    "modulus": "12.0",
                                    "pointwidth": "1.0"
                                }
                            }
                        }
                    }
                }
            }
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.5"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "1",
            "modulo": "12.0",
            "modulus": "12.0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "0.5"
        },
        "dir": "SOURCES/FAO"
    },
    "FSU": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "FSU",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "SMOOTH4yrFULLdescription": "Anomalies from SMOOTH4yr ANOM plus mean values",
            "SMOOTH4yrANOMdescription": "Spatial and temporal smoothing of FSU 4yr ANOM",
            "SMOOTH4yrdescription": "Spatial and temporal smoothing of FSU monthly wind stress data",
            "FULLdescription": "Full wind speeds",
            "DETRENDEDSMOOTHFULLdescription": "Detrended and smoothed FSU wind stress data",
            "DETRENDEDSMOOTHdescription": "Detrended and smoothed FSU wind stress data",
            "DETRENDEDFULLdescription": "Detrended FSU wind stress data",
            "DETRENDEDCLIMATOLOGYdescription": "Detrended FSU wind stress climatological data",
            "DETRENDEDANOMdescription": "Detrended FSU wind stress anomalies",
            "DETRENDEDdescription": "Detrended FSU wind stress data",
            "DETRENDEDsource": "FSU winds detrended according to Neil Ward",
            "CLIMATOLOGYdescription": "Climatology used in computing anomalies",
            "ANOMdescription": "Raw wind stress data from FSU converted to anomalies by subtraction of the climatology",
            "yrANOMdescription": "The monthly wind stress anomaly relative to the four year running mean",
            "yrdescription": "Monthly wind stress anomaly relative to the four year running mean",
            "description": "Florida State University wind analysis",
            "Conventions": "IRIDL",
            "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.FSU/.dataset_documentation.html",
            "iridlhasSemantics": "iridl:FSU",
            "references": "Legler_OBrien1988"
        },
        "SMOOTH4yr": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SMOOTH4yr",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "FULL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "FULL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "meridional wind stress",
                    "units": "dynes/cm2",
                    "missing_value": "19.98"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "zonal wind stress",
                    "units": "dynes/cm2",
                    "missing_value": "19.98"
                }
            },
            "ANOM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ANOM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "meridional wind stress",
                    "units": "dynes/cm2"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "zonal wind stress",
                    "units": "dynes/cm2"
                }
            }
        },
        "FULL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "FULL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "tauy": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "tauy",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "meridional wind stress",
                "units": "dynes/cm2",
                "missing_value": "NaN",
                "file_missing_value": "999.0"
            },
            "taux": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "taux",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "zonal wind stress",
                "units": "dynes/cm2",
                "missing_value": "NaN",
                "file_missing_value": "999.0"
            },
            "absuv": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "absuv",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "meridional wind pseudo-stress",
                "units": "m2/s2",
                "missing_value": "999.0"
            },
            "absuu": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "absuu",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "zonal wind pseudo-stress",
                "units": "m2/s2",
                "missing_value": "999.0"
            }
        },
        "DETRENDED": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "DETRENDED",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "SMOOTH": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SMOOTH",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "FULL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "FULL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "tauy": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tauy",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "meridional wind stress",
                        "units": "dynes/cm2",
                        "missing_value": "19.98"
                    },
                    "taux": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "taux",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "zonal wind stress",
                        "units": "dynes/cm2",
                        "missing_value": "19.98"
                    }
                }
            },
            "FULL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "FULL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "meridional wind stress",
                    "units": "dynes/cm2",
                    "missing_value": "NaN",
                    "file_missing_value": "999.0"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "zonal wind stress",
                    "units": "dynes/cm2",
                    "missing_value": "NaN",
                    "file_missing_value": "999.0"
                },
                "absuv": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "absuv",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "meridional wind pseudo-stress",
                    "units": "m2/s2",
                    "missing_value": "999.0"
                },
                "absuu": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "absuu",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "zonal wind pseudo-stress",
                    "units": "m2/s2",
                    "missing_value": "999.0"
                }
            },
            "CLIMATOLOGY": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CLIMATOLOGY",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "meridional wind stress",
                    "units": "dynes/cm2",
                    "missing_value": "19.98"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "zonal wind stress",
                    "units": "dynes/cm2",
                    "missing_value": "19.98"
                }
            },
            "ANOM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ANOM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "meridional wind stress",
                    "units": "dynes/cm2",
                    "missing_value": "19.98"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "zonal wind stress",
                    "units": "dynes/cm2",
                    "missing_value": "19.98"
                }
            }
        },
        "CLIMATOLOGY": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "CLIMATOLOGY",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "tauy": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "tauy",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "meridional wind stress",
                "units": "dynes/cm2",
                "missing_value": "19.98"
            },
            "taux": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "taux",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "zonal wind stress",
                "units": "dynes/cm2",
                "missing_value": "19.98"
            }
        },
        "ANOM": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ANOM",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "tauy": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "tauy",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "meridional wind stress",
                "units": "dynes/cm2"
            },
            "taux": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "taux",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "zonal wind stress",
                "units": "dynes/cm2"
            }
        },
        "yr": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "4yr",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "ANOM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ANOM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "tauy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tauy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "meridional wind stress",
                    "units": "dynes/cm2"
                },
                "taux": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "taux",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "zonal wind stress",
                    "units": "dynes/cm2"
                }
            }
        },
        "T_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "1",
            "modulo": "12.0",
            "modulus": "12.0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "2.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "2.0"
        },
        "dir": "SOURCES/FSU"
    },
    "FUNCEME": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "FUNCEME",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Tropical_Atlanticmonthlydescription": "Monthly sea surface temperature and wind pseudo-stress data for the tropical Atlantic Ocean",
            "Tropical_Atlanticclimatologyc6403description": "Climatological sea surface temperature and wind pseudo-stress data for the tropical Atlantic Ocean",
            "Tropical_Atlanticclimatologyc6403iridlhasSemantics": "iridl:climatology",
            "Tropical_Atlanticclimatologyc6403long_name": "1964-2003 Climatology",
            "Tropical_Atlanticdescription": "Sea surface temperature and wind pseudo-stress data for the tropical Atlantic Ocean",
            "Tropical_Atlanticdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.FUNCEME/.Tropical_Atlantic.dataset_documentation.html",
            "description": "Funda&#231;&#227;o Cearense de Meteorologia e Recursos H&#237;dricos",
            "iridlhasSemantics": "iriref:Durand_B",
            "Conventions": "IRIDL"
        },
        "Tropical_Atlantic": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Tropical_Atlantic",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "monthly": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "monthly",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ssta": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssta",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "5.0",
                    "scale_min": "-5.0",
                    "units": "degree_Celsius",
                    "long_name": "sea surface temperature anomaly",
                    "missing_value": "9999.7998"
                },
                "sst": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sst",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "31.5",
                    "scale_min": "0.0",
                    "units": "Celsius_scale",
                    "long_name": "sea surface temperature",
                    "missing_value": "9999.7998"
                },
                "pwsyanom": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "pwsyanom",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "63.0",
                    "scale_min": "-78.0",
                    "units": "m2/s2",
                    "long_name": "meridional wind pseudo-stress anomaly",
                    "missing_value": "9999.7998"
                },
                "pwsy": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "pwsy",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "123.0",
                    "scale_min": "-106.0",
                    "units": "m2/s2",
                    "long_name": "meridional wind pseudo-stress",
                    "missing_value": "9999.7998"
                },
                "pwsxanom": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "pwsxanom",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "122.0",
                    "scale_min": "-100.0",
                    "units": "m2/s2",
                    "long_name": "zonal wind pseudo-stress anomaly",
                    "missing_value": "9999.7998"
                },
                "pwsx": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "pwsx",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "123.0",
                    "scale_min": "-132.0",
                    "units": "m2/s2",
                    "long_name": "zonal wind pseudo-stress",
                    "missing_value": "9999.7998"
                }
            },
            "climatology": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "climatology",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "c6403": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "c6403",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "sst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_max": "29.5",
                        "scale_min": "13.0",
                        "units": "degree_Celsius",
                        "long_name": "sea surface temperature",
                        "missing_value": "9999.7998"
                    },
                    "pwsy": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pwsy",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_max": "60.0",
                        "scale_min": "-70.0",
                        "units": "m2/s2",
                        "long_name": "meridional wind pseudo-stress",
                        "missing_value": "9999.7998"
                    },
                    "pwsx": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pwsx",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_max": "27.0",
                        "scale_min": "-90.0",
                        "units": "m2/s2",
                        "long_name": "zonal wind pseudo-stress",
                        "missing_value": "9999.7998"
                    }
                }
            }
        },
        "Nordeste": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Nordeste",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "daily": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "daily",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "station": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "station",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "PCPN": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PCPN",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-1.0",
                        "units": "mm",
                        "long_name": "Precipitation"
                    },
                    "Name1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Name1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids"
                    },
                    "Name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids"
                    },
                    "lon": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lon",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "-42.0",
                        "scale_max": "-37.5",
                        "units": "degree_east",
                        "long_name": "longitude"
                    },
                    "lat": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lat",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "-8.0",
                        "scale_max": "-2.5",
                        "units": "degree_north",
                        "long_name": "latitude"
                    },
                    "elev": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "elev",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-999.0",
                        "units": "m",
                        "long_name": "Elevation"
                    }
                }
            }
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "2.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "2.0"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "1",
            "modulo": "12.0",
            "modulus": "12.0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "long_name": "Time",
            "pointwidth": "1.0"
        },
        "STNID": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "STNID",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "0",
            "long_name": "Station"
        },
        "dir": "SOURCES/FUNCEME"
    },
    "Features": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/Features",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "Features",
        "restriction": "Public",
        "Agricultural": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Agricultural",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "WFPdescription": " Livelihood Zones in Mali from WFP",
                "SriLanka_agridescription": " Agricultural Zones in Sri Lanka",
                "PhilippinesBicolsoilTypedescription": "Soil Types",
                "PhilippinesBicollandCoverdescription": "Land Cover",
                "PhilippinesBicoldescription": "Bicol Agricultural Information",
                "PhilippinesBicoliridlhasSemantics": "irigaz:Philippines_119_1",
                "Mali_agriLivelihood_Mali_2010description": "Livelihood Zones in Mali 2010",
                "Mali_agriLivelihood_Mali_2005description": "Livelihood Zones in Mali 2005",
                "EmbrapaBrazilRio_Grande_do_Sulsolos_tipodescription": "Tipo Solos Rio Grande do Sul",
                "EmbrapaBrazilRio_Grande_do_Sulsolosdescription": "Solos Rio Grande do Sul",
                "EmbrapaBrazilRio_Grande_do_Suljoindescription": "Join Rio Grande do Sul",
                "EmbrapaBrazilRio_Grande_do_Sularea_tipodescription": "Area Tipo Rio Grande do Sul",
                "Colombia_soilsdescription": " Soil types of Colombia",
                "Africa_agriculturedescription": " Agricultural Zones in Africa",
                "Africa_agriculturedataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Agricultural/.Africa_agriculture.dataset_documentation.html",
                "Africa_agricultureiridlhasSemantics": "irigaz:Africa_3327_1",
                "description": " Agricultural zones",
                "Conventions": "IRIDL"
            },
            "WFP": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "WFP",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Livelihood_Mali_PAM_SAP": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Livelihood_Mali_PAM_SAP",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Livelihood zone geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "libelle_zo": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "libelle_zo",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Libelle Zone",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "code_zone": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "code_zone",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "colormap": "16777215",
                        "scale_max": "8",
                        "maxncolor": "11",
                        "ncolor": "11",
                        "scale_min": "1",
                        "CS": "1",
                        "CE": "8",
                        "CLIST": "Bamako",
                        "long_name": "Zone Code",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "Livelihood_Mali": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Livelihood_Mali",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "zonage_sap": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zonage_sap",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zonage SAP",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Livelihood zone geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "orig_fid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "orig_fid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "colormap": "16777215",
                        "scale_max": "11",
                        "maxncolor": "15",
                        "ncolor": "15",
                        "scale_min": "0",
                        "CS": "0",
                        "CE": "11",
                        "CLIST": "Salariat-commerce (Ville)",
                        "long_name": "Original File ID",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                }
            },
            "SriLanka_agri": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SriLanka_agri",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Agri_zones": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Agri_zones",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "zone1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zone1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zone Type, Rainfall, Elevation",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "zone": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zone",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Rainfall Zone",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Agricultural zone geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "region": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zone Type, Rainfall, Elevation, Soils",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "rain75": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rain75",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Rainfall amount",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "perimeter": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "perimeter",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Perimeter",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zone Code",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Area",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "agroeco_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "agroeco_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Agro Eco id",
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "agroeco_": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "agroeco_",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Agro Eco",
                        "units": "unitless",
                        "PGtype": "int8"
                    }
                }
            },
            "Philippines": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Philippines",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Bicol": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Bicol",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "soilType": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "soilType",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Soil Type Geometries",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "soildesc": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "soildesc",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Soil Description",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "soilcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "soilcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Soil Code",
                            "missing_value": "NaN",
                            "units": "unitless",
                            "PGtype": "float8"
                        },
                        "philbuo_id": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "philbuo_id",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Phillipines buoID",
                            "missing_value": "NaN",
                            "units": "unitless",
                            "PGtype": "float8"
                        },
                        "philbuo": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "philbuo",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Phillipines buo",
                            "missing_value": "NaN",
                            "units": "unitless",
                            "PGtype": "float8"
                        },
                        "ph": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ph",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "unitless",
                            "PGtype": "float8"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    },
                    "landCover": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "landCover",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Land Cover Geometries",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "perimeter": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "perimeter",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Perimeter",
                            "units": "km",
                            "missing_value": "NaN",
                            "PGtype": "float8"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "id": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "id",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "ID",
                            "missing_value": "NaN",
                            "units": "unitless",
                            "PGtype": "float8"
                        },
                        "hectares": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "hectares",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Area",
                            "units": "hectare",
                            "missing_value": "NaN",
                            "PGtype": "float8"
                        },
                        "envi_lmu_i": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "envi_lmu_i",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Environment lmu i",
                            "missing_value": "NaN",
                            "units": "unitless",
                            "PGtype": "float8"
                        },
                        "desc3": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "desc3",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Description",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "desc2": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "desc2",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Description",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "desc1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "desc1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Description",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "count": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "count",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "unitless",
                            "PGtype": "float8"
                        },
                        "area": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "area",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Area",
                            "units": "m2",
                            "missing_value": "NaN",
                            "PGtype": "float8"
                        }
                    }
                }
            },
            "Mali_agri": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Mali_agri",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Livelihood_Mali_2010": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Livelihood_Mali_2010",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Livelihood zone geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "lznum": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lznum",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "colormap": "16777215",
                        "scale_max": "13.0",
                        "maxncolor": "16",
                        "ncolor": "16",
                        "scale_min": "1.0",
                        "CS": "1",
                        "CE": "13",
                        "CLIST": "Bamako urban",
                        "long_name": "Livelihood Number",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "lznamef": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lznamef",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Livelihood-French",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "lznamee": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lznamee",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Livelihood-English",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "lzcode": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lzcode",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Livelihood Code",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "country": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "country",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Country Code",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "_class": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "class",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Livelihood Class",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Livelihood_Mali_2005": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Livelihood_Mali_2005",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Livelihood zone geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "lznum": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lznum",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "colormap": "16777215",
                        "scale_max": "11.0",
                        "maxncolor": "14",
                        "ncolor": "14",
                        "scale_min": "1.0",
                        "CS": "1",
                        "CE": "11",
                        "CLIST": "Rainfed millet/sorghum/fruits",
                        "long_name": "Livelihood Number",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "lznamef": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lznamef",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Livelihood-French",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "lznamee": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lznamee",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Livelihood-English",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "gavprimary": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gavprimary",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "GAV Primary",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "cccode": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cccode",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "CC Code",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                }
            },
            "Embrapa": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Embrapa",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Brazil": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Brazil",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Rio_Grande_do_Sul": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Rio_Grande_do_Sul",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "solos_tipo": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "solos_tipo",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "tipo": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tipo",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Tipo",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "the_geom": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "the_geom",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Geometry",
                                "units": "unitless",
                                "PGtype": "bytea",
                                "OpenGISSimpleFeature": "MULTIPOLYGON",
                                "SpatialReferenceSystemWKT": "]]"
                            },
                            "textura": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "textura",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Textura",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "solos": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "solos",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Solos",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "solo": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "solo",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Solo",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "sbcs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sbcs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "sbcs",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "codigo": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "codigo",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Codigo",
                                "units": "ids",
                                "PGtype": "varchar"
                            }
                        },
                        "solos": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "solos",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "the_geom": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "the_geom",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Geometry",
                                "units": "unitless",
                                "PGtype": "bytea",
                                "OpenGISSimpleFeature": "MULTIPOLYGON",
                                "SpatialReferenceSystemWKT": "]]"
                            },
                            "textura": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "textura",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Textura",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "simbolo": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simbolo",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Simbolo",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "sibcs_desc": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sibcs_desc",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "SIBCS Description",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "nova_leg": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "nova_leg",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Nova leg",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "nivel1": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "nivel1",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Nivel 1",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "n_3_sibcs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "n_3_sibcs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "nome 3 SIBCS",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "n_3_sibc_1": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "n_3_sibc_1",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "nome 3 SIBC 1",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "n_2_sibcs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "n_2_sibcs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "nome 2 SIBCS",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "fid_1": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "fid_1",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "FID 1",
                                "units": "unitless",
                                "PGtype": "int4"
                            },
                            "comp_3": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "comp_3",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "COMP 3",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "comp_2": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "comp_2",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "COMP 2",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "comp_1": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "comp_1",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "COMP 1",
                                "units": "ids",
                                "PGtype": "varchar"
                            }
                        },
                        "join": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "join",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "tipo": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tipo",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Tipo",
                                "units": "unitless",
                                "PGtype": "int4"
                            },
                            "the_geom": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "the_geom",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Geometry",
                                "units": "unitless",
                                "PGtype": "bytea",
                                "OpenGISSimpleFeature": "MULTIPOLYGON",
                                "SpatialReferenceSystemWKT": "]]"
                            },
                            "textura": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "textura",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Textura",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "solos": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "solos",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Solos",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "solo": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "solo",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Solo",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "sbcs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sbcs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "sbcs",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "r": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "r",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "r",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "pct": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pct",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "pct",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "p": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "p",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "p",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "n19": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "n19",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "N 19",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "n18": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "n18",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "N 18",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "m",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "legenda_1": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "legenda_1",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Legenda 1",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "legenda": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "legenda",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Legenda",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "id1": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "id1",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "ID 1",
                                "units": "unitless",
                                "PGtype": "int4"
                            },
                            "i": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "i",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "i",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "edafica": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "edafica",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Edafica",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "codigo": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "codigo",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Codigo",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "autonumber": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "autonumber",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Autonumber",
                                "missing_value": "NaN",
                                "units": "unitless",
                                "PGtype": "float8"
                            },
                            "aptidxc3xa3o": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "aptid\\xc3\\xa3o",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Aptid\\xc3\\xa3o",
                                "units": "ids",
                                "PGtype": "varchar"
                            }
                        },
                        "area_tipo": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "area_tipo",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "xc3x81rea": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "\\xc3\\x81rea",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "\\xc3\\x81rea",
                                "missing_value": "NaN",
                                "units": "unitless",
                                "PGtype": "float8"
                            },
                            "tipo": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tipo",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Tipo",
                                "units": "ids",
                                "PGtype": "varchar"
                            },
                            "the_geom": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "the_geom",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Geometry",
                                "units": "unitless",
                                "PGtype": "bytea",
                                "OpenGISSimpleFeature": "MULTIPOLYGON",
                                "SpatialReferenceSystemWKT": "]]"
                            },
                            "area_ha": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "area_ha",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Area",
                                "units": "hectare",
                                "missing_value": "NaN",
                                "PGtype": "float8"
                            }
                        }
                    }
                }
            },
            "Colombia_soils": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Colombia_soils",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Soils_Colombia": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Soils_Colombia",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "soil type geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "ord": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ord",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "ORD",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                }
            },
            "Africa_agriculture": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Africa_agriculture",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Agri_zones": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Agri_zones",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "zone_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zone_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Agricultural zone index",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Agricultural zone geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "sq_km": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sq_km",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zone area sq_km",
                        "units": "km2",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "perimeter": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "perimeter",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zone perimeter",
                        "units": "m",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "descrip": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "descrip",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zone type description",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "code_fs": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "code_fs",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "colormap": "16777215",
                        "scale_max": "14",
                        "maxncolor": "17",
                        "ncolor": "17",
                        "scale_min": "1",
                        "CS": "1",
                        "CE": "14",
                        "CLIST": "Coastal artisanal fishing",
                        "long_name": "Zone type code",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                }
            },
            "gid_11": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_11",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_10": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_10",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_09": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_09",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_08": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_08",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_07": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_07",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_06": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_06",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_05": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_05",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_04": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_04",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_03": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_03",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "theid": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "theid",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "dir": "SOURCES/Features/Agricultural"
        },
        "Climatological": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Climatological",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Vietnam_climatedescription": "Climate Zones in Vietnam",
                "Vietnam_climatedataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Climatological/.Vietnam_climate.dataset_documentation.html",
                "Vietnam_climateiridlhasSemantics": "iridl:Vietnam",
                "US_climate_regionsdescription": " Climate Regions in the U.S.",
                "US_climate_regionsdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Climatological/.US_climate_regions.dataset_documentation.html",
                "US_climate_regionsiridlhasSemantics": "irigaz:United_States_156_1",
                "US_climatedescription": " Climate divisions in the U.S.",
                "US_climatedataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Climatological/.US_climate.dataset_documentation.html",
                "US_climateiridlhasSemantics": "irigaz:United_States_156_1",
                "SriLanka_climatedescription": " Climate zones in Sri Lanka",
                "SriLanka_climatedataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Climatological/.SriLanka_climate.dataset_documentation.html",
                "SriLanka_climateiridlhasSemantics": "irigaz:Sri_Lanka_136_1",
                "Ethiopia_climatedescription": "Ethiopia Rainfall Climate Zones",
                "Ethiopia_climatedataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Climatological/.Ethiopia_climate.dataset_documentation.html",
                "Ethiopia_climateiridlhasSemantics": "iridl:Ethiopia_49_1",
                "description": " Climate zones",
                "Conventions": "IRIDL"
            },
            "Vietnam_climate": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Vietnam_climate",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Climate_Zones_Vietnam": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Climate_Zones_Vietnam",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Climate Zone geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Climate Zone label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "clim_zone_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "clim_zone_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Climate Zone ID",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    }
                }
            },
            "US_climate_regions": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "US_climate_regions",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Regions": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Regions",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Climate Region Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    }
                }
            },
            "US_climate": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "US_climate",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Divisions": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Divisions",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "State-Climate Div. geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "st": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "st",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "State",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "div_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "div_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Name of Climate Div. within a state",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "div_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "div_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Index of Climate Div. within a state",
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                }
            },
            "SriLanka_climate": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SriLanka_climate",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Czones": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Czones",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Climate Zone geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Climate Zone index",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "czone": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "czone",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zone Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                }
            },
            "Ethiopia_climate": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Ethiopia_climate",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "eth_clim": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eth_clim",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Climate Zone geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Climate Zone Label",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "clim_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "clim_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Climate Zone Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "clim_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "clim_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Climate Zone ID",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                }
            },
            "gid_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "region_name": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "region_name",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "gridtype": "2",
                "long_name": "Climate Region Name",
                "units": "ids"
            },
            "division_i": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "division_i",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "long_name": "Unique State-Climate Div. index"
            },
            "gid_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "dir": "SOURCES/Features/Climatological"
        },
        "Epidemiological": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Epidemiological",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "VCAPmergeddescription": " Vectoral Capacity Epidemic map for Africa as one geometry",
                "VCAPdescription": " Vectoral Capacity Epidemic map for Africa",
                "Malariadescription": " Risk map for malaria in Africa",
                "Malariadataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Epidemiological/.Malaria.dataset_documentation.html",
                "MalariairidlhasSemantics": "irigaz:Africa_3327_1",
                "description": " Risk maps",
                "Conventions": "IRIDL"
            },
            "VCAPmerged": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "VCAPmerged",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "epidemic_map": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "epidemic_map",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    }
                }
            },
            "VCAP": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "VCAP",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "epidemic_map": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "epidemic_map",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    }
                }
            },
            "Malaria": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Malaria",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Risk_map": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Risk_map",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    }
                }
            },
            "gid": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "id": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "id",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "dir": "SOURCES/Features/Epidemiological"
        },
        "Hydrological": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Hydrological",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Riversdescription": " Rivers of the World",
                "Riversdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Hydrological/.Rivers.dataset_documentation.html",
                "River_BasinsUpper_Colo_basindescription": "Upper Colorado River Basin",
                "River_BasinsIransubbasinsdescription": "Iran Sub River Basins",
                "River_BasinsIranbasinsdescription": "Iran River Basins",
                "River_BasinsEth_sub_basinsdescription": "River Sub Basins in Ethiopia",
                "River_BasinsEth_River_Basinsdescription": "River Basins in Ethiopia",
                "River_Basinsdescription": "River Basins of the World",
                "River_Basinsdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Hydrological/.River_Basins.dataset_documentation.html",
                "PhilippinesWatershedsdescription": "Watersheds of the Philippines",
                "PhilippinesRiversdescription": "Rivers of the Philippines",
                "PhilippinesLakesdescription": "Lakes of the Philippines",
                "PeruSubBasinsdescription": "GR2M Sub-Basins of Peru",
                "Lakes_level1description": "Global Lakes and Wetlands Database Boundaries",
                "Lakesdescription": " Lakes of the World",
                "Lakesdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Hydrological/.Lakes.dataset_documentation.html",
                "description": " Rivers, Streams, Lakes, Drainage Basins",
                "iridlhasSemantics": "iridl:Global",
                "Conventions": "IRIDL"
            },
            "Rivers": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Rivers",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "MajorRivers": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "MajorRivers",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTILINESTRING",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "system": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "system",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "River System name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "r_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "r_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "River name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry id",
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                }
            },
            "River_Basins": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "River_Basins",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Upper_Colo_basin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Upper_Colo_basin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Basin": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Basin",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "ext_typ_id": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ext_typ_id",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "unitless",
                            "PGtype": "float8"
                        },
                        "ext_id": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ext_id",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "unitless",
                            "PGtype": "float8"
                        },
                        "basin_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "basin_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    }
                },
                "Upper_Blue_Nile": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Upper_Blue_Nile",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    }
                },
                "Sri_Lanka_Sub_Catchments": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Sri_Lanka_Sub_Catchments",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "perimeter": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "perimeter",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "name_sub": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_sub",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "Name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "basin_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "basin_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "basin_": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "basin_",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    }
                },
                "Sri_Lanka_River_Basins": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Sri_Lanka_River_Basins",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "perimeter": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "perimeter",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "name_sub": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_sub",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "Name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "basin_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "basin_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    }
                },
                "LaPlata_basin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "LaPlata_basin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "gridcode": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gridcode",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    }
                },
                "Iran": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Iran",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "subbasins": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "subbasins",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Geometry",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "mantaghe": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "mantaghe",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "unitless",
                            "PGtype": "int2"
                        },
                        "linkcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "linkcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Link Code",
                            "units": "unitless",
                            "PGtype": "int2"
                        },
                        "code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Code",
                            "missing_value": "NaN",
                            "units": "unitless",
                            "PGtype": "float8"
                        }
                    },
                    "basins": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "basins",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Geometry",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "hozeh6": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "hozeh6",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "unitless",
                            "PGtype": "float8"
                        },
                        "count": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "count",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Count",
                            "missing_value": "NaN",
                            "units": "unitless",
                            "PGtype": "float8"
                        }
                    }
                },
                "GTN_River_Basins": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "GTN_River_Basins",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "subbas_num": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "subbas_num",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "in_out": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "in_out",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "gtn_r_sta": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gtn_r_sta",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "drainage": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "drainage",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "basin_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "basin_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "area_calc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "area_calc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    }
                },
                "Eth_sub_basins": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Eth_sub_basins",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Sub_Basins": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Sub_Basins",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "sqkm": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "sqkm",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "unitless",
                            "PGtype": "int4"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "PGtype": "text"
                        },
                        "etwshed0_1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "etwshed0_1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "unitless",
                            "PGtype": "int4"
                        },
                        "etwshed01c": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "etwshed01c",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "unitless",
                            "PGtype": "int4"
                        },
                        "basin_nr": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "basin_nr",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "unitless",
                            "PGtype": "int2"
                        },
                        "basin_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "basin_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "basin_cod": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "basin_cod",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "basin": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "basin",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "unitless",
                            "PGtype": "int4"
                        }
                    }
                },
                "Eth_River_Basins": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Eth_River_Basins",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Basins": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Basins",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "short_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "short_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "basin_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "basin_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "area_km2": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "area_km2",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "unitless",
                            "PGtype": "float8"
                        }
                    }
                }
            },
            "Philippines": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Philippines",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Watersheds": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Watersheds",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "wfp_waters": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "wfp_waters",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "WFP Waters",
                        "units": "unitless",
                        "PGtype": "int2"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "leng": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "leng",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Perimeter",
                        "units": "km",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "first_leve": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "first_leve",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "First Level",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "ave_treeco": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ave_treeco",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Average Tree Cover",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Area",
                        "units": "km2",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    }
                },
                "Rivers": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Rivers",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "tile_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tile_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Tile ID",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTILINESTRING",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "nam": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nam",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "leng": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "leng",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Length",
                        "units": "km",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "hyc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "hyc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "globalid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "globalid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Global ID",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "fac_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "fac_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "fac ID",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "f_code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "f_code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "F Code",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Lakes": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Lakes",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "type_code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "type_code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Type Code",
                        "units": "unitless",
                        "PGtype": "int2"
                    },
                    "Type": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Type",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Type",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "swb_flag": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "swb_flag",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Flag",
                        "units": "unitless",
                        "PGtype": "int2"
                    },
                    "src_rank": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "src_rank",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Rank",
                        "units": "unitless",
                        "PGtype": "int2"
                    },
                    "src_layer": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "src_layer",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Layer",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "Name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "leng": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "leng",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Perimeter",
                        "units": "km",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "code_flag": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "code_flag",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Code Flag",
                        "units": "unitless",
                        "PGtype": "int2"
                    },
                    "code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Code",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Area",
                        "units": "km2",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    }
                }
            },
            "Peru": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Peru",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "SubBasins": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SubBasins",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "Region": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Region",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region ID",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    }
                }
            },
            "Lakes_level1": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Lakes_level1",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Lakes": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Lakes",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "lake_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lake_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                }
            },
            "Lakes": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Lakes",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "MajorLakes": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "MajorLakes",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "surf_elev": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "surf_elev",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Surface Elevation",
                        "units": "feet",
                        "PGtype": "int4"
                    },
                    "sqmi": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sqmi",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Area sqmi",
                        "units": "mile2",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "sqkm": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sqkm",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Area sqkm",
                        "units": "km2",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "l_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "l_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "depth": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "depth",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Depth",
                        "units": "feet",
                        "PGtype": "int4"
                    }
                }
            },
            "gid_09": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_09",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_08": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_08",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "basin_": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "basin_",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_07": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_07",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "0"
            },
            "gid_06": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_06",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_05": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_05",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_04": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_04",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_03": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_03",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "objectid_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "objectid_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0"
            },
            "objectid": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "objectid",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0"
            },
            "uniq_id": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "uniq_id",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0"
            },
            "gid_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "glwd_id": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "glwd_id",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "dir": "SOURCES/Features/Hydrological"
        },
        "Political": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/Features/Political",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "Political",
            "restriction": "Public",
            "Africa": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Africa",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Africa 1st and 2nd Order Administrative Boundaries",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Africa/.dataset_documentation.html",
                    "Conventions": "IRIDL"
                },
                "Provinces": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Provinces",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "prov_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "prov_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "country_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "country_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Prov_SALB_2008": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Prov_SALB_2008",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "name2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "name1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "code1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "code1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "prov_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "prov_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "dist_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dist_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "country_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "country_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "feature_id_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "feature_id_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "feature_id": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "feature_id",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "dir": "SOURCES/Features/Political/Africa"
            },
            "Bangladesh": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Bangladesh",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Banglades Division, District, and Upazilla Admin. boundaries",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Bangladesh/.dataset_documentation.html",
                    "Conventions": "IRIDL"
                },
                "Upazillas": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Upazillas",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "type_3": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "type_3",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Admin level 3 Type",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Upazilla Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "name_3": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_3",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Upazilla Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "name_2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "name_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Division Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "id_3": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_3",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Upazilla id",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "id_2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District id",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "id_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Division id",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "cc_3": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cc_3",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Upazila CC",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Divisions": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Divisions",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Division Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "name_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Division Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "id_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Division id",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "coastal": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "coastal",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Coastal",
                        "units": "unitless",
                        "PGtype": "int2"
                    },
                    "area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Division area",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    }
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "name_2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "name_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Division Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "id_2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District id",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "id_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Division id",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "divcode": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "divcode",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Division code",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "dis_code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dis_code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District code",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "coastal": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "coastal",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Coastal",
                        "units": "unitless",
                        "PGtype": "int2"
                    },
                    "area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Division area",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    }
                },
                "gid_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Bangladesh"
            },
            "Bihar": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Bihar",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Conventions": "IRIDL"
                },
                "the_geom": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "the_geom",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Admin2 geometry",
                    "units": "unitless",
                    "PGtype": "bytea",
                    "OpenGISSimpleFeature": "MULTIPOLYGON",
                    "SpatialReferenceSystemWKT": "]]"
                },
                "label": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "label",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Label",
                    "units": "ids",
                    "PGtype": "text"
                },
                "adm2_name": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "adm2_name",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Admin Level2 Name",
                    "units": "ids",
                    "PGtype": "varchar"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Bihar"
            },
            "Botswana": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Botswana",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "15,16, and 17 Districts",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Botswana/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Botswana_18_1",
                    "Conventions": "IRIDL"
                },
                "Districts17": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts17",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    }
                },
                "Districts16": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts16",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    }
                },
                "Districts15": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts15",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "epidemio": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "epidemio",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Epidemiological Districts",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "districts": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "districts",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Political Districts",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "idr_id_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "idr_id_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "long_name": "IDR id",
                    "pointwidth": "1.0"
                },
                "idr_id_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "idr_id_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "long_name": "IDR id",
                    "pointwidth": "1.0"
                },
                "idr_id": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "idr_id",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "long_name": "IDR id",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Botswana"
            },
            "Brazil": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Brazil",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": " Municipios",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Brazil/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Brazil_19_1",
                    "Conventions": "IRIDL"
                },
                "Municipios": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Municipios",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Municipio geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "nome": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nome",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Municipio name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "muni6": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "muni6",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Municipio code - 6 digit",
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "municode": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "municode",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "dir": "SOURCES/Features/Political/Brazil"
            },
            "BurkinaFaso": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "BurkinaFaso",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Health Districts",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.BurkinaFaso/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Burkina_Faso_22_1",
                    "Conventions": "IRIDL"
                },
                "Regions": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Regions",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "grp": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "grp",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region Abbrev.",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry id",
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "Health_Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Health_Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Health District geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "sqkm": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sqkm",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Area",
                        "units": "km2",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "namemaj": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "namemaj",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Health District name in caps",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "lvlid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lvlid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "LVL id",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "h_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "h_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Health District name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry id",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "amap11": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "amap11",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "AMAP 11 code",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/BurkinaFaso"
            },
            "CentralWestAfrica": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CentralWestAfrica",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": " Regions",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.CentralWestAfrica/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Africa_West_302_0",
                    "Conventions": "IRIDL"
                },
                "Regions": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Regions",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "neww": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "neww",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region name abbrev.",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry id",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "country": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "country",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Country id",
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/CentralWestAfrica"
            },
            "Chile": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Chile",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Chile Admin boundaries",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Chile/.dataset_documentation.html",
                    "iridlhasSemantics": "iridl:Chile_31_1",
                    "Conventions": "IRIDL"
                },
                "admin3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "admin3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Distrito geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "com_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "com_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Commun Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Distrito Area",
                        "units": "m^2",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "admin3_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "admin3_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Distrito Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "a_homog": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "a_homog",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Homog Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "admin2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "admin2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Provincia geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "admin2_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "admin2_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Provincia Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "admin1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "admin1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "admin1_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "admin1_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "distripol1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "distripol1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "pro10": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "pro10",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "reg10": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "reg10",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Chile"
            },
            "Colombia": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Colombia",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Districtsdescription": "Municipios",
                    "Departamentosdescription": "Departamentos",
                    "description": "Departamentos and Municipios",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Colombia/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Colombia_33_1",
                    "Conventions": "IRIDL"
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "nom_muni": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nom_muni",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Municipio/District name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "departamen": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "departamen",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Departamento/State name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "codmu": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "codmu",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Municipio/District Code",
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "Departamentos": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Departamentos",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "departamen": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "departamen",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Departamento/State name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "dane": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "dane",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Colombia"
            },
            "Colombia_CIAT": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Colombia_CIAT",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "CIAT provided admin boundaries",
                    "Conventions": "IRIDL"
                },
                "States": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "States",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "adm1_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm1_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Municipalities": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Municipalities",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "adm2_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm2_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm1_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm1_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm1_code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm1_code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "adm1_code": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "adm1_code",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "adm2_code": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "adm2_code",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Colombia_CIAT"
            },
            "CotedIvoire": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CotedIvoire",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": " Regions",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.CotedIvoire/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Cote_d_Ivoire_75_1",
                    "Conventions": "IRIDL"
                },
                "Regions": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Regions",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "grp": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "grp",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Group Abbrev.",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry id",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "count": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "count",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Count",
                        "units": "unitless",
                        "PGtype": "int8"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/CotedIvoire"
            },
            "Eritrea": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Eritrea",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Ministry of Health Sub Zobas",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Eritrea/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Eritrea_47_1",
                    "Conventions": "IRIDL"
                },
                "MOH_SubZobas": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "MOH_SubZobas",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "zonename_2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zonename_2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zone name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "zonecode_2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zonecode_2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zone code",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ministry of Health Sub-Zoba geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "mohname_2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mohname_2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ministry of Health Sub-Zoba name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "mohcode": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mohcode",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ministry of Health Sub-Zoba code",
                        "units": "unitless",
                        "PGtype": "int8"
                    }
                },
                "mohcode_2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "mohcode_2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "long_name": "Ministry of Health Sub-Zoba code"
                },
                "dir": "SOURCES/Features/Political/Eritrea"
            },
            "Ethiopia": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Ethiopia",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": " Zones, Sub-Zones/Woderas",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Ethiopia/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Ethiopia_49_1",
                    "Conventions": "IRIDL"
                },
                "Zones": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Zones",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "zone_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zone_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zone name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "zid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zone id",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zone geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "region": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Tigray_Wards": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Tigray_Wards",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "warname": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "warname",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ward name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "w_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "w_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ward id",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ward geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "short": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "short",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Abbrev. Ward name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "SubZones": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Sub-Zones",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "wid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "wid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Wodera id",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "w_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "w_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Wodera name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Wodera/Sub-District geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "region_r2i": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region_r2i",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region id",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "ease_zonen": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ease_zonen",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ease Zone name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "ease_z4id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ease_z4id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ease Zone id",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "ease_wored": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ease_wored",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ease Wodera name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "ease_w6id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ease_w6id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ease Wodera id",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Health_District": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Health_District",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "zone_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zone_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Zone name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "wid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "wid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "W id",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Health District geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "h_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "h_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Health District name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "h_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "h_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Health District id",
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "z4id": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "z4id",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "gridtype": "2",
                    "long_name": "Zone id",
                    "units": "ids"
                },
                "w6id_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "w6id_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "gridtype": "2",
                    "long_name": "Ward id",
                    "units": "ids"
                },
                "w6id": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "w6id",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "long_name": "Wodera id"
                },
                "id": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "id",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "long_name": "Health District id"
                },
                "dir": "SOURCES/Features/Political/Ethiopia"
            },
            "Ethiopia_adm1": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Ethiopia_adm1",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Ethiopia 1st level of Administrative Boundaries",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Ethiopia_adm1/.dataset_documentation.html",
                    "Conventions": "IRIDL"
                },
                "Ethiopia_level1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Ethiopia_level1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "varname_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "varname_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "shape_area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "shape_area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "regionbb": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "regionbb",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region bbox",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "name_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "name_0": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_0",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "iso": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "iso",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "id_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "id_0": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_0",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "hasc_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "hasc_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "engtype_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "engtype_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "cc_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cc_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Ethiopia_adm1"
            },
            "Ethiopia_adm2": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Ethiopia_adm2",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Ethiopia 2nd level of Administrative Boundaries",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Ethiopia_adm2/.dataset_documentation.html",
                    "Conventions": "IRIDL"
                },
                "Ethiopia_level2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Ethiopia_level2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "type_2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "type_2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "shape_area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "shape_area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "regionbb": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "regionbb",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region bbox",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "name_2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "name_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "name_0": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_0",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "iso": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "iso",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "id_2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "id_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "id_0": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_0",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "cc_2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cc_2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Ethiopia_adm2"
            },
            "Ethiopia_adm3": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Ethiopia_adm3",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Ethiopia 3rd level of Administrative Boundaries",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Ethiopia_adm3/.dataset_documentation.html",
                    "Conventions": "IRIDL"
                },
                "Ethiopia_level3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Ethiopia_level3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "regionbb": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "regionbb",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region bbox",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "id_2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "id_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "id_0": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id_0",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "adm3": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm3",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm0": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm0",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Ethiopia_adm3"
            },
            "Ethiopia_adm3_reduced": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Ethiopia_adm3_reduced",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Reduced set of Ethiopia 3rd level of Admin. Boundaries ",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Ethiopia_adm3_reduced/.dataset_documentation.html",
                    "Conventions": "IRIDL"
                },
                "Ethiopia_level3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Ethiopia_level3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "adm3": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm3",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm0": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm0",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "dir": "SOURCES/Features/Political/Ethiopia_adm3_reduced"
            },
            "Guatemala": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Guatemala",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "GAULsecondOrder_GAULlong_name": "Second_Order_GAUL_Guatemala",
                    "GAULfirstOrder_GAULlong_name": "First_Order_GAUL_Guatemala",
                    "GAULCountries_GAULlong_name": "Countries_GAUL_Guatemala",
                    "GAULFirst_Order": "def",
                    "GAULCountries": "def",
                    "GAULSecond_Order": "def",
                    "Conventions": "IRIDL"
                },
                "GAUL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "GAUL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "secondOrder_GAUL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "secondOrder_GAUL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin2 geometry",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Label",
                            "units": "ids",
                            "PGtype": "text"
                        },
                        "adm2_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level2 Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm2_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level2 id",
                            "units": "unitless",
                            "PGtype": "int4"
                        },
                        "adm1_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level1 Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level1 id",
                            "units": "unitless",
                            "PGtype": "int4"
                        },
                        "adm0_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country id",
                            "units": "unitless",
                            "PGtype": "int4"
                        }
                    },
                    "firstOrder_GAUL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "firstOrder_GAUL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin1 geometry",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Label",
                            "units": "ids",
                            "PGtype": "text"
                        },
                        "adm1_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level1 Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level1 id",
                            "units": "unitless",
                            "PGtype": "int4"
                        },
                        "adm0_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country id",
                            "units": "unitless",
                            "PGtype": "int4"
                        }
                    },
                    "Countries_GAUL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Countries_GAUL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country geometry",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Label",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    }
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "adm0_code": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "adm0_code",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "dir": "SOURCES/Features/Political/Guatemala"
            },
            "Honduras": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Honduras",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Honduras Municipalities",
                    "Conventions": "IRIDL"
                },
                "Municipalities": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Municipalities",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "mname": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mname",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "mlabel": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mlabel",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Honduras"
            },
            "Humdata": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Humdata",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Zambiazmb_admbnda_adm2_2020description": "Zambia Admin Level 2 (humdata.org)",
                    "Zambiazmb_admbnda_adm1_2020description": "Zambia Admin Level 1 (humdata.org)",
                    "Zambiazmb_admbnda_adm0_2020description": "Zambia Admin Level 0 (humdata.org)",
                    "Madagascarmdg_admbnda_adm4_bngrc_ocha_20181031description": "Madagascar Admin Level 4 (humdata.org)",
                    "Madagascarmdg_admbnda_adm3_bngrc_ocha_20181031description": "Madagascar Admin Level 3 (humdata.org)",
                    "Madagascarmdg_admbnda_adm2_bngrc_ocha_20181031description": "Madagascar Admin Level 2 (humdata.org)",
                    "Madagascarmdg_admbnda_adm1_bngrc_ocha_20181031description": "Madagascar Admin Level 1 (humdata.org)",
                    "Madagascarmdg_admbnda_adm0_bngrc_ocha_20181031description": "Madagascar Admin Level 0 (humdata.org)",
                    "Conventions": "IRIDL"
                },
                "Zambia": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Zambia",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "zmb_admbnda_adm2_2020": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zmb_admbnda_adm2_2020",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "x": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "x",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "x",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "the_geom",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "label",
                            "units": "ids",
                            "PGtype": "text"
                        },
                        "adm2_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm2_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm2_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm2_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm2_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm2_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    },
                    "zmb_admbnda_adm1_2020": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zmb_admbnda_adm1_2020",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "the_geom",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "label",
                            "units": "ids",
                            "PGtype": "text"
                        },
                        "adm1_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    },
                    "zmb_admbnda_adm0_2020": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zmb_admbnda_adm0_2020",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "the_geom",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "label",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    }
                },
                "Madagascar": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Madagascar",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "mdg_admbnda_adm4_bngrc_ocha_20181031": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mdg_admbnda_adm4_bngrc_ocha_20181031",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "the_geom",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "source": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "source",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "source",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "prov_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "prov_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "prov_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "prov_code_": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "prov_code_",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "prov_code_",
                            "units": "unitless",
                            "PGtype": "int8"
                        },
                        "old_provin": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "old_provin",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "old_provin",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "notes": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "notes",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "notes",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "label",
                            "units": "ids",
                            "PGtype": "text"
                        },
                        "adm4_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm4_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm4_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm4_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm4_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm4_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm4_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm4_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm4_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm3_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm3_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm3_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm3_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm3_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm3_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm3_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm3_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm3_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm2_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm2_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm2_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm2_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm2_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm2_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    },
                    "mdg_admbnda_adm3_bngrc_ocha_20181031": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mdg_admbnda_adm3_bngrc_ocha_20181031",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "the_geom",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "source": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "source",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "source",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "prov_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "prov_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "prov_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "prov_code_": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "prov_code_",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "prov_code_",
                            "units": "unitless",
                            "PGtype": "int8"
                        },
                        "old_provin": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "old_provin",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "old_provin",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "notes": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "notes",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "notes",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "label",
                            "units": "ids",
                            "PGtype": "text"
                        },
                        "adm3_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm3_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm3_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm3_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm3_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm3_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm3_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm3_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm3_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm2_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm2_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm2_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm2_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm2_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm2_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    },
                    "mdg_admbnda_adm2_bngrc_ocha_20181031": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mdg_admbnda_adm2_bngrc_ocha_20181031",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "the_geom",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "source": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "source",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "source",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "prov_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "prov_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "prov_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "prov_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "prov_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "prov_code",
                            "units": "unitless",
                            "PGtype": "int8"
                        },
                        "old_provin": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "old_provin",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "old_provin",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "notes": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "notes",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "notes",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "label",
                            "units": "ids",
                            "PGtype": "text"
                        },
                        "adm2_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm2_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm2_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm2_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm2_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm2_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    },
                    "mdg_admbnda_adm1_bngrc_ocha_20181031": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mdg_admbnda_adm1_bngrc_ocha_20181031",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "the_geom",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "source": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "source",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "source",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "prov_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "prov_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "prov_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "prov_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "prov_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "prov_code",
                            "units": "unitless",
                            "PGtype": "int8"
                        },
                        "old_provin": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "old_provin",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "old_provin",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "label",
                            "units": "ids",
                            "PGtype": "text"
                        },
                        "adm1_type": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_type",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_type",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm1_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    },
                    "mdg_admbnda_adm0_bngrc_ocha_20181031": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mdg_admbnda_adm0_bngrc_ocha_20181031",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "the_geom",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "source": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "source",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "source",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "label",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_pcode": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_pcode",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_pcode",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_en": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_en",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "adm0_en",
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    }
                },
                "gid_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "0"
                },
                "dir": "SOURCES/Features/Political/Humdata"
            },
            "India": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "India",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Bihar_distBihar_dist": "district",
                    "description": "Districts and Provinces in India",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.India/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:India_68_1",
                    "Conventions": "IRIDL"
                },
                "Provinces_WHO": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Provinces_WHO",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "provname": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "provname",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "lvlid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lvlid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "LVL ID",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "label",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Province_WHO_disputed": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Province_WHO_disputed",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "provname": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "provname",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "India_K": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "India_K",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Country geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "state": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "state",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Sate Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "pcode": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pcode",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province code",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "name2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "name1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Provicne name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "label",
                        "units": "ids",
                        "PGtype": "text"
                    }
                },
                "Bihar_dist": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Bihar_dist",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "state": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "state",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "State name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "objectid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "objectid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District code",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "district": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "district",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "0"
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dcode": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "dcode",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/India"
            },
            "Indonesia": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Indonesia",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": " Provinces and Districts",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Indonesia/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Indonesia_69_1",
                    "Conventions": "IRIDL"
                },
                "Provinces": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Provinces",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "name1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry_id",
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "name2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "name1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry_id",
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Indonesia"
            },
            "MVPSites": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "MVPSites",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Earth Institute Millennium Villages",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.MVPSites/.dataset_documentation.html",
                    "Conventions": "IRIDL"
                },
                "MillenniumVillages": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "MillenniumVillages",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "village": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "village",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Village Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Village point geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "POINT",
                        "SpatialReferenceSystemWKT": "]]"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/MVPSites"
            },
            "Madagascar": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Madagascar",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "SubDistrictsdescription": "Delimitations administratives Communes Madagascar",
                    "Regionsdescription": "Delimitations administratives Regions Madagascar",
                    "Provincesdescription": "Delimitations administratives Provinces Madagascar",
                    "ProvincesProvinces": "description",
                    "Districtsdescription": "Delimitations administratives Districts Madagascar",
                    "description": "Delimitations administratives Madagascar",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Madagascar/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Madagascar_94_1",
                    "Conventions": "IRIDL"
                },
                "SubDistricts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SubDistricts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "nomprov": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nomprov",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "nomdist": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nomdist",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "nomcomm": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nomcomm",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "lvlid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lvlid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "codefiv": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "codefiv",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "codefar": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "codefar",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "Regions": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Regions",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "nomreg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nomreg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "nomprov": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nomprov",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "fir_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "fir_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "fir": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "fir",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "codefar": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "codefar",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "Provinces": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Provinces",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "p_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "p_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "lvlid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lvlid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "LVL ID",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province code",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "nomprov": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nomprov",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "nomdist": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nomdist",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "fir_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "fir_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "fir": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "fir",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "codefar": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "codefar",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "codefir": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "codefir",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "codefiv_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "codefiv_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "id": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "id",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "codefiv": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "codefiv",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "dir": "SOURCES/Features/Political/Madagascar"
            },
            "Mali": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Mali",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Health Districts",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Mali/.dataset_documentation.html",
                    "Conventions": "IRIDL"
                },
                "Regions": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Regions",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "region": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "grp": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "grp",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Group abbrev.",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry id",
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "Provinces": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Provinces",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "prov_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "prov_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Health_Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Health_Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "lvlid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lvlid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "LVL id",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "d_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "d_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District code",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "prov_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "prov_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "dist_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dist_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "id": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "id",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Mali"
            },
            "Nepal": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Nepal",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Nepal_districtsdescription": "Nepal Districts from maplibrary.org",
                    "iridlhasSemantics": "iridl:Nepal",
                    "Conventions": "IRIDL"
                },
                "Nepal_districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Nepal_districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "the_geom",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "name2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "name1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Admin level 1",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "mm_uid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mm_uid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "mm u ID",
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "division": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "division",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Division",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Code",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Nepal"
            },
            "Nepal_Prov": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Nepal_Prov",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Nepal Provinces from Francis Colledge, UK Metoffice 2020",
                    "Conventions": "IRIDL"
                },
                "Provinces": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Provinces",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "state_code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "state_code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Code",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Nepal_Prov"
            },
            "Niger": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Niger",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Districtsdescription": "Niger District Boundaries",
                    "Districtsdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Niger/.Districts.dataset_documentation.html",
                    "Conventions": "IRIDL"
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "dist_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dist_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "idr_id": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "idr_id",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Niger"
            },
            "Nigeria": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Nigeria",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Districts",
                    "iridlhasSemantics": "irigaz:Nigeria_111_1",
                    "Conventions": "IRIDL"
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Admin Lev 2 geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "pop_9798": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pop_9798",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Population 1998-97",
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "pop_90": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pop_90",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Population 1990",
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "oldvlid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "oldvlid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Old LVL ID",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "oldlvlid2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "oldlvlid2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Old LVL ID2",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "lvlid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lvlid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "LVL ID",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "dens90": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dens90",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Density 1990",
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "admin2_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "admin2_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Admin Lev 2 Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm1name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm1name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Admin Lev 1 Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Nigeria"
            },
            "Pakistan": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Pakistan",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Pakistan/.dataset_documentation.html",
                    "Conventions": "IRIDL"
                },
                "the_geom": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "the_geom",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "District geometry",
                    "units": "unitless",
                    "PGtype": "bytea",
                    "OpenGISSimpleFeature": "MULTIPOLYGON",
                    "SpatialReferenceSystemWKT": "]]"
                },
                "first_prov": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "first_prov",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Province Name",
                    "units": "ids",
                    "PGtype": "varchar"
                },
                "first_pro": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "first_pro",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Province ID",
                    "units": "ids",
                    "PGtype": "varchar"
                },
                "first_dist": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "first_dist",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "District Name",
                    "units": "ids",
                    "PGtype": "varchar"
                },
                "first_code": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "first_code",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "gridtype": "2",
                    "units": "ids"
                },
                "dir": "SOURCES/Features/Political/Pakistan"
            },
            "Philippines": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Philippines",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Regionsdescription": "Regions",
                    "Provincesdescription": "Provinces",
                    "Municipalitiesdescription": "Municipalities",
                    "Districtsdescription": "Districts",
                    "description": "Philippines Districts, Municipalities, Provinces and Regions",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Philippines/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Philippines_119_1",
                    "Conventions": "IRIDL"
                },
                "Regions": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Regions",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Regions Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "region": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "regcode": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "regcode",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region Code",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "count": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "count",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    }
                },
                "Provinces": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Provinces",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Provinces Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "regcode": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "regcode",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region Code",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "provname": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "provname",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "provcode": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "provcode",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Code",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "text"
                    }
                },
                "Municipalities": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Municipalities",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Municipality Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "region": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "regcode": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "regcode",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region Code",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "provname1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "provname1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "provname": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "provname",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "provcode": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "provcode",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Code",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "munoldname": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "munoldname",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Municipality Old Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "munctycode": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "munctycode",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Municipality Code",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "muncity": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "muncity",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Municipaity",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "dist": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dist",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "name2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry id",
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "gid_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Philippines"
            },
            "Rwanda": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Rwanda",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Rwanda 1st and 2nd Order Administrative Boundaries",
                    "Conventions": "IRIDL"
                },
                "Provinces": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Provinces",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "prov_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "prov_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "prov_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "prov_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "dist_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dist_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Rwanda"
            },
            "Senegal": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Senegal",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": " Sub-Districts, Wards",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Senegal/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Senegal_128_1",
                    "Conventions": "IRIDL"
                },
                "SubDistricts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Sub-Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ward/Sub-District geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry id",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "adm2_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm2_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "2nd Order Admin. name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm2_code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm2_code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "2nd Order Admin. code",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm1_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm1_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "1st Order Admin. name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm1_code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm1_code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "1st Order Admin. code",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Senegal"
            },
            "Senegal2008": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Senegal2008",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Departmentdescirption": "D\\xc3\\xa9partements",
                    "description": "Senegal 2008 2nd Administrative Boundaries",
                    "Conventions": "IRIDL"
                },
                "Department": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Department",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "eff_year": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "eff_year",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Eff Year",
                        "units": "unitless",
                        "PGtype": "int2"
                    },
                    "country": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "country",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Country ID",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "aliases": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "aliases",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Aliases",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "admin2fr": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "admin2fr",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "D\\xc3\\xa9partement",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "admin2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "admin2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Department",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "admin1fr": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "admin1fr",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "R\\xc3\\xa9gion",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "admin1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "admin1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "admin0": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "admin0",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Country Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "fnid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "fnid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "gridtype": "2",
                    "units": "ids"
                },
                "dir": "SOURCES/Features/Political/Senegal2008"
            },
            "SenegalARV": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SenegalARV",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Departmentdescirption": "D\\xc3\\xa9partements",
                    "description": "Afircan Risk View Senegal 2nd Administrative Boundaries",
                    "Conventions": "IRIDL"
                },
                "Department": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Department",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "Region": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Region",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "last_updat": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "last_updat",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Last Update YYYYMMDD",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "continent": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "continent",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Cntinent",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm2_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm2_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Department Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm1_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm1_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm1_code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm1_code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region Code",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "adm0_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm0_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Country Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "adm0_code": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm0_code",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Country Code",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    }
                },
                "adm2_code": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "adm2_code",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "dir": "SOURCES/Features/Political/SenegalARV"
            },
            "Senegal_Adm": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Senegal_Adm",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Senegal Country\\', \\'1st\\', \\'2nd\\', \\'3rd and 4th Order Administrative Boundaries",
                    "Conventions": "IRIDL"
                },
                "Region": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Region",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "region_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Pays": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Pays",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "iso3": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "iso3",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "iso2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "iso2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "country_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "country_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Department": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Department",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "region_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "dept_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dept_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Commune": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Commune",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "region_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "dept_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dept_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "commune_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "commune_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "arrondissement_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "arrondissement_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Arrondissement": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Arrondissement",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "region_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "dept_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dept_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "arrondissement_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "arrondissement_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "id_1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "id_1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "id_0": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "id_0",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "0"
                },
                "id_2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "id_2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "id_4": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "id_4",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "id_3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "id_3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Senegal_Adm"
            },
            "SriLanka": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SriLanka",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": " Provinces, Districts, Sub-districts, Villages, and Ministry of Health Districts",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.SriLanka/.dataset_documentation.html",
                    "Conventions": "IRIDL"
                },
                "Villages": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Villages",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "province_n": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "province_n",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "gnd_n": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gnd_n",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Village Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "gnd_c": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gnd_c",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Village Code",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "dsd_n": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dsd_n",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Sub-District Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "district_n": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "district_n",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Area",
                        "units": "m2",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    }
                },
                "SubDistricts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SubDistricts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "province_n": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "province_n",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry id",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "dsd_n": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dsd_n",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Sub-District Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "district_n": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "district_n",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Provinces": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Provinces",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "sum_area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sum_area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Area",
                        "units": "m2",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "name1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "MOH_115": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "MOH_115",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "moh_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "moh_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "MOH id",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "moh115_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "moh115_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "MOH District Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "MinistryOfHealth_Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "MinistryOfHealth_Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "province": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "province",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "moh_area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "moh_area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ministry of Health District Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "iri_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "iri_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "MOH id for 115 districts",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry id",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "district": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "district",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "czone_gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "czone_gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Climate zone gid",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "cezone_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cezone_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Elevation zone name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "cezone_gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "cezone_gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Elevation zone gid",
                        "units": "unitless",
                        "PGtype": "int4"
                    }
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "sum_area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sum_area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Area",
                        "units": "m2",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    },
                    "name1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "iri_id": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "iri_id",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "new_distid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "new_distid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/SriLanka"
            },
            "Sudan": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Sudan",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "GAULsecondOrder_GAULlong_name": "Second_Order_GAUL",
                    "GAULfirstOrder_GAULlong_name": "First_Order_GAUL",
                    "GAULCountries_GAULlong_name": "Countries_GAUL",
                    "GAULSecond_Order": "def",
                    "GAULCountries": "def",
                    "GAULFirst_Order": "def",
                    "description": "Horn Region",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Sudan/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Sudan_137_1",
                    "Conventions": "IRIDL"
                },
                "Horn_Region": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Horn_Region",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "suadmn1_": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "suadmn1_",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Sudan admn1",
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "region": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "GAUL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "GAUL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "secondOrder_GAUL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "secondOrder_GAUL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin2 geometry",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Label",
                            "units": "ids",
                            "PGtype": "text"
                        },
                        "adm2_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level2 Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm2_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level2 id",
                            "units": "unitless",
                            "PGtype": "int4"
                        },
                        "adm1_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level1 Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level1 id",
                            "units": "unitless",
                            "PGtype": "int4"
                        },
                        "adm0_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country id",
                            "units": "unitless",
                            "PGtype": "int4"
                        }
                    },
                    "firstOrder_GAUL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "firstOrder_GAUL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin1 geometry",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Label",
                            "units": "ids",
                            "PGtype": "text"
                        },
                        "adm1_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level1 Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level1 id",
                            "units": "unitless",
                            "PGtype": "int4"
                        },
                        "adm0_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country id",
                            "units": "unitless",
                            "PGtype": "int4"
                        }
                    },
                    "Countries_GAUL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Countries_GAUL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country geometry",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Label",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    }
                },
                "suadmn1_id": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "suadmn1_id",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "0"
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "adm0_code": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "adm0_code",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "dir": "SOURCES/Features/Political/Sudan"
            },
            "TZA_DHIS2": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "TZA_DHIS2",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Tanzania 2nd Order Administrative Boundaries used in DHIS2",
                    "Conventions": "IRIDL"
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "district_n": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "district_n",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "district_c": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "district_c",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/TZA_DHIS2"
            },
            "Tanzania": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Tanzania",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": " Sub-Districts, Wards",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Tanzania/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Tanzania_145_1",
                    "Conventions": "IRIDL"
                },
                "SubDistricts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Sub-Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "wardid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "wardid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ward id",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "ward_shehi": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ward_shehi",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ward name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ward/Sub-District geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "region": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "reg_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "reg_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Region id",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "geom_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry id",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "district": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "district",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "dist_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dist_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District id",
                        "units": "unitless",
                        "PGtype": "int4"
                    },
                    "area_km2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "area_km2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Ward area",
                        "units": "km2",
                        "missing_value": "NaN",
                        "PGtype": "float8"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Tanzania"
            },
            "Tanzania_2017": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Tanzania_2017",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Tanzania 1st and 2nd Order Administrative Boundaries updated in 2017",
                    "Conventions": "IRIDL"
                },
                "Regions": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Regions",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "region_nam": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region_nam",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "region_cod": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "region_cod",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "district_n": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "district_n",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "district_c": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "district_c",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Tanzania_2017"
            },
            "Togo": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Togo",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": " Districts",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Togo/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:Togo_147_1",
                    "Conventions": "IRIDL"
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "newfield1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "newfield1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "New Field1 code",
                        "units": "unitless",
                        "PGtype": "int8"
                    },
                    "first_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "first_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "id": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "id",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Togo"
            },
            "Uganda": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/Features/Political/Uganda",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "Uganda",
                "restriction": "requires dlauth tokens"
            },
            "UnitedStates": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "UnitedStates",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": " Counties",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.UnitedStates/.dataset_documentation.html",
                    "iridlhasSemantics": "irigaz:United_States_156_1",
                    "Conventions": "IRIDL"
                },
                "Counties": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Counties",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "County geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "state": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "state",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "State code",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "county": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "county",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "County code",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "co_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "co_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "County name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "co_id": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "co_id",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "County id",
                        "units": "unitless",
                        "PGtype": "int8"
                    }
                },
                "co99_d00_i": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "co99_d00_i",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/UnitedStates"
            },
            "Uruguay": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Uruguay",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Seccionales_Policialesdescription": "Seccionales Policiales 2010",
                    "Conventions": "IRIDL"
                },
                "Seccionales_Policiales": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Seccionales_Policiales",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "shape_leng": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "shape_leng",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Shape Leng",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "shape_area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "shape_area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Shape Area",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "perimeter": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "perimeter",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Perimeter",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "deptosec": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "deptosec",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Deptosec",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "area": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "area",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Area",
                        "missing_value": "NaN",
                        "units": "unitless",
                        "PGtype": "float8"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Features/Political/Uruguay"
            },
            "Vietnam": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Vietnam",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Vietnam Provinces and Districts Admin boundaries",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.Features/.Political/.Vietnam/.dataset_documentation.html",
                    "Conventions": "IRIDL"
                },
                "Provinces": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Provinces",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "adm1_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm1_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Name - Admin Level 1 Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "adm2_name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "adm2_name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District Name - Admin Level 2 Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dcode": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "dcode",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "dir": "SOURCES/Features/Political/Vietnam"
            },
            "World": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/Features/Political/World",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "World",
                "restriction": "Public",
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ]
            },
            "Zambia": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Zambia",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Provincesdescription": "Zambia Provincial Boundaries",
                    "Districtsdescription": "Zambia District Boundaries",
                    "Countrydescription": "Zambia Political Boundaries",
                    "Conventions": "IRIDL"
                },
                "Provinces": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Provinces",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "prov_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "prov_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Province Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    }
                },
                "Districts": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Districts",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "dist_na": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dist_na",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "District Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "Country": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Country",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "name_engli": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "name_engli",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Name",
                        "units": "ids",
                        "PGtype": "varchar"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "varchar"
                    }
                },
                "gid_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "0"
                },
                "dir": "SOURCES/Features/Political/Zambia"
            },
            "Zimbabwe": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Zimbabwe",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "GAULsecondOrder_GAULlong_name": "Second_Order_GAUL_Zimbabwe",
                    "GAULfirstOrder_GAULlong_name": "First_Order_GAUL_Zimbabwe",
                    "GAULCountries_GAULlong_name": "Countries_GAUL_Zimbabwe",
                    "GAULCountries": "def",
                    "GAULFirst_Order": "def",
                    "GAULSecond_Order": "def",
                    "Conventions": "IRIDL"
                },
                "GAUL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "GAUL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "secondOrder_GAUL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "secondOrder_GAUL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin2 geometry",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Label",
                            "units": "ids",
                            "PGtype": "text"
                        },
                        "adm2_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level2 Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm2_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm2_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level2 id",
                            "units": "unitless",
                            "PGtype": "int4"
                        },
                        "adm1_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level1 Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level1 id",
                            "units": "unitless",
                            "PGtype": "int4"
                        },
                        "adm0_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country id",
                            "units": "unitless",
                            "PGtype": "int4"
                        }
                    },
                    "firstOrder_GAUL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "firstOrder_GAUL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin1 geometry",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Label",
                            "units": "ids",
                            "PGtype": "text"
                        },
                        "adm1_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level1 Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm1_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm1_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Admin Level1 id",
                            "units": "unitless",
                            "PGtype": "int4"
                        },
                        "adm0_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_code": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_code",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country id",
                            "units": "unitless",
                            "PGtype": "int4"
                        }
                    },
                    "Countries_GAUL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Countries_GAUL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country geometry",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Label",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "adm0_name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adm0_name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    }
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "adm0_code": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "adm0_code",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0"
                },
                "dir": "SOURCES/Features/Political/Zimbabwe"
            },
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type",
                "Africa",
                "Bangladesh",
                "Bihar",
                "Botswana",
                "Brazil",
                "BurkinaFaso",
                "CentralWestAfrica",
                "Chile",
                "Colombia",
                "Colombia_CIAT",
                "CotedIvoire",
                "Eritrea",
                "Ethiopia",
                "Ethiopia_adm1",
                "Ethiopia_adm2",
                "Ethiopia_adm3",
                "Ethiopia_adm3_reduced",
                "Guatemala",
                "Honduras",
                "Humdata",
                "India",
                "Indonesia",
                "MVPSites",
                "Madagascar",
                "Mali",
                "Nepal",
                "Nepal_Prov",
                "Niger",
                "Nigeria",
                "Pakistan",
                "Philippines",
                "Rwanda",
                "Senegal",
                "Senegal2008",
                "SenegalARV",
                "Senegal_Adm",
                "SriLanka",
                "Sudan",
                "TZA_DHIS2",
                "Tanzania",
                "Tanzania_2017",
                "Togo",
                "Uganda",
                "UnitedStates",
                "Uruguay",
                "Vietnam",
                "World",
                "Zambia",
                "Zimbabwe"
            ]
        },
        "banned_long": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type",
            "Agricultural",
            "Climatological",
            "Epidemiological",
            "Hydrological",
            "Political"
        ]
    },
    "GEDEX": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "GEDEX",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "isccp_c2description": "Monthly mean cloud product from the Greenhouse Effect Detection Experiment",
            "isccp_c2title": "ISCCP-C2 Monthly Mean Cloud Product",
            "iridlhasSemantics": "iridl:NASA",
            "Conventions": "IRIDL"
        },
        "isccp_c2": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "isccp_c2",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "TMP_SSFC": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "TMP_SSFC",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "description": "Mean Skin Surface Temp for Clear Sky Composite",
                "units": "/K",
                "long_name": "Mn Skin Sfc Tmp",
                "FORTRAN_format": "F10.3",
                "title": "ISCCP-C2 Monthly Mean Cloud Product",
                "missing_value": "-1000.0",
                "valid_max": "345.0",
                "valid_min": "165.0"
            },
            "TMP_CLDT": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "TMP_CLDT",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "description": "Mean Cloud Top Temperature",
                "units": "/K",
                "long_name": "Mn Cld Top Tmp",
                "FORTRAN_format": "F10.3",
                "title": "ISCCP-C2 Monthly Mean Cloud Product",
                "missing_value": "-1000.0",
                "valid_max": "345.0",
                "valid_min": "165.0"
            },
            "SNOW_ICE": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SNOW_ICE",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "description": "Average Snow Ice Cover",
                "units": "/%",
                "long_name": "Ave Snow Ice Cover",
                "FORTRAN_format": "F10.3",
                "title": "ISCCP-C2 Monthly Mean Cloud Product",
                "missing_value": "-1000.0",
                "valid_max": "100.0",
                "valid_min": "0.0"
            },
            "SFC_CODE": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SFC_CODE",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "description": "Code_1,2,3_Day H2O,Land,Coast 101,102,103_Night",
                "units": "unitless",
                "long_name": "Surface Type",
                "FORTRAN_format": "F10.3",
                "title": "ISCCP-C2 Monthly Mean Cloud Product",
                "missing_value": "-1000.0",
                "valid_max": "103.0",
                "valid_min": "0.0"
            },
            "RFL_SFC": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "RFL_SFC",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "description": "Mean Surface Reflectance for Clear Sky Composite",
                "units": "unitless",
                "long_name": "Mn Surface Reflec",
                "FORTRAN_format": "F10.3",
                "title": "ISCCP-C2 Monthly Mean Cloud Product",
                "missing_value": "-1000.0",
                "valid_max": "1.0",
                "valid_min": "0.0"
            },
            "PRS_CLDT": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "PRS_CLDT",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "description": "Mean Cloud Top Pressure",
                "units": "/Mb",
                "long_name": "Mn Cld Top Pres",
                "FORTRAN_format": "F10.3",
                "title": "ISCCP-C2 Monthly Mean Cloud Product",
                "missing_value": "-1000.0",
                "valid_max": "1100.0",
                "valid_min": "1.0"
            },
            "OPT_DPTH": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "OPT_DPTH",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "description": "Mean Optical Thickness (TAU)",
                "units": "unitless",
                "long_name": "Optical Thickness",
                "FORTRAN_format": "F10.3",
                "title": "ISCCP-C2 Monthly Mean Cloud Product",
                "missing_value": "-1000.0",
                "valid_max": "120.0",
                "valid_min": "0.0"
            },
            "FQ_MCLD": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "FQ_MCLD",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "description": "Ave Freq Middle Clouds  Alto- and Nimbostratus",
                "units": "/%",
                "long_name": "Middle Cld Freq",
                "FORTRAN_format": "F10.3",
                "title": "ISCCP-C2 Monthly Mean Cloud Product",
                "missing_value": "-1000.0",
                "valid_max": "100.0",
                "valid_min": "0.0"
            },
            "FQ_LCLD": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "FQ_LCLD",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "description": "Ave Freq Low Clouds  Cumulus and Stratus",
                "units": "/%",
                "long_name": "Low Cld Freq",
                "FORTRAN_format": "F10.3",
                "title": "ISCCP-C2 Monthly Mean Cloud Product",
                "missing_value": "-1000.0",
                "valid_max": "100.0",
                "valid_min": "0.0"
            },
            "FQ_HCLD": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "FQ_HCLD",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "description": "Ave Freq High Clds_Cirrus Cirrostr & Deep Conv",
                "units": "/%",
                "long_name": "High Cld Freq",
                "FORTRAN_format": "F10.3",
                "title": "ISCCP-C2 Monthly Mean Cloud Product",
                "missing_value": "-1000.0",
                "valid_max": "100.0",
                "valid_min": "0.0"
            },
            "CLD_PATH": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CLD_PATH",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "description": "Cloud Water Mass Per Unit Area",
                "units": "/g/m**2",
                "long_name": "Cloud Water Path",
                "FORTRAN_format": "F5.2",
                "title": "ISCCP-C2 Monthly Mean Cloud Product",
                "missing_value": "-1000.0",
                "valid_max": "800.0",
                "valid_min": "0.0"
            },
            "CLD_AMT": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CLD_AMT",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "description": "Average Frequency of Cloudy Pixels",
                "units": "/%",
                "long_name": "Cloud Fraction",
                "FORTRAN_format": "F10.3",
                "title": "ISCCP-C2 Monthly Mean Cloud Product",
                "missing_value": "-1000.0",
                "valid_max": "100.0",
                "valid_min": "0.0"
            }
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "2.5",
            "long_name": "Latitude"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0",
            "long_name": "Time"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "modulus": "360.0",
            "pointwidth": "2.5",
            "long_name": "Longitude"
        },
        "dir": "SOURCES/GEDEX"
    },
    "GEOSECS": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "GEOSECS",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "description": "Geochemical Ocean Sections Study, a global survey of the three-dimensional distribution of chemical, isotopic, and radiochemical tracers in the ocean.  The expeditions were in the Atlantic from July 1972 to May 1973; the Pacific from  August 1973 to June 1974, and the Indian Ocean from December 1977 to March 1978",
            "Conventions": "IRIDL",
            "iridlhasSemantics": "iridl:SIO",
            "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.GEOSECS/.dataset_documentation.html"
        },
        "Tritium_TU": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Tritium_TU",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "unitless",
            "long_name": "tritium TU"
        },
        "THETA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "THETA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "Celsius_scale",
            "long_name": "potential temperature"
        },
        "TEMP": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "TEMP",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "Celsius_scale",
            "long_name": "temperature"
        },
        "TCO2": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "TCO2",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "micromole/kg",
            "long_name": "total $@ CO sub 2$"
        },
        "TALK": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "TALK",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "microEquivalents/kg",
            "long_name": "total alkalinity"
        },
        "STA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "STA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "unitless",
            "long_name": "station"
        },
        "SIO3": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SIO3",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "micromole/kg",
            "long_name": "$@ SiO sub 3$"
        },
        "SIGMA4": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SIGMA4",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "sigma",
            "long_name": "$sigma sub 4$"
        },
        "SIGMA2": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SIGMA2",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "sigma",
            "long_name": "$sigma sub 2$"
        },
        "SIGMA0": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SIGMA0",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "sigma",
            "long_name": "$sigma sub 0$"
        },
        "SAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "PSU",
            "long_name": "salinity"
        },
        "PRESS": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "PRESS",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "dbar",
            "long_name": "pressure"
        },
        "PO4": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "PO4",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "micromole/kg",
            "long_name": "phosphate"
        },
        "PCO2_TEMP": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "PCO2_TEMP",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "Celsius_scale"
        },
        "PCO2": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "PCO2",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "microatm"
        },
        "OXY": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "OXY",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "micromole/kg",
            "long_name": "oxygen"
        },
        "NO3": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NO3",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "micromole/kg",
            "long_name": "nitrate"
        },
        "NO2": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NO2",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "micromole/kg",
            "long_name": "nitrite"
        },
        "lon": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "lon",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "long_name": "longitude",
            "units": "degree_east"
        },
        "lat": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "lat",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "long_name": "latitude",
            "units": "degree_north"
        },
        "DEPTH": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "DEPTH",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "m",
            "long_name": "depth"
        },
        "Delta_C14": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Delta_C-14",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "per mil",
            "long_name": "$Delta sup 14 @ C$"
        },
        "Delta_C13": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Delta_C-13",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "per mil",
            "long_name": "$Delta sup 13 @ C$"
        },
        "BOTTLE": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "BOTTLE",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "unitless",
            "long_name": "bottle number"
        },
        "AOU": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "AOU",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "missing_value": "NaN",
            "units": "micromole/kg",
            "long_name": "apparent oxygen utilization"
        },
        "ISTA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ISTA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2",
            "long_name": "ISTA"
        },
        "IZ": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "IZ",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "1.0",
            "long_name": "IZ"
        },
        "dir": "SOURCES/GEOSECS"
    },
    "GISS": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/GISS",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "GISS",
        "restriction": "Public",
        "AMIP": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "AMIP",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "contact": "Gary L. Russell <I>cmglr@isis.giss.nasa.gov</I>",
                "source": "Run C027AM",
                "description": "The surface diagnostics from an atmospheric model simulation with AMIP boundary conditions.",
                "Conventions": "IRIDL",
                "iridlhasSemantics": "iriref:Russell_GL"
            },
            "TOTCLOUD": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "TOTCLOUD",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "percent",
                "long_name": "TOTAL CLOUD COVER"
            },
            "SENSHEAT": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SENSHEAT",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "W/m2",
                "long_name": "SENSIBLE HEAT FLUX"
            },
            "SATEM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SATEM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "Kelvin_scale",
                "long_name": "Surface Air Temperature"
            },
            "SAHUM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SAHUM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "g/kg",
                "long_name": "SURFACE AIR SPECIFIC HUMIDITY"
            },
            "PRECIPITATION": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "PRECIPITATION",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "mm/day",
                "long_name": "PRECIPITATION"
            },
            "NLWRADS": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NLWRADS",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "W/m2",
                "long_name": "NET THERMAL RADIATION at SURFACE"
            },
            "LOWCLOUD": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "LOWCLOUD",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "percent",
                "long_name": "CLOUD COVER from Layers 1, 2 and 3"
            },
            "INCSRADS": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "INCSRADS",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "W/m2",
                "long_name": "INCIDENT SOLAR RADIATION at SURFACE"
            },
            "GTEM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "GTEM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "Kelvin_scale",
                "long_name": "GROUND TEMPERATURE of Layer 1"
            },
            "EVAP": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "EVAP",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "mm/day",
                "long_name": "EVAPORATAION"
            },
            "ABSSRADS": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ABSSRADS",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "W/m2",
                "long_name": "ABSORBED SOLAR RADIATION at SURFACE"
            },
            "X": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "gridtype": "1",
                "standard_name": "longitude",
                "pointwidth": "5.0"
            },
            "Y": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_north",
                "gridtype": "0",
                "standard_name": "latitude",
                "pointwidth": "4.0"
            },
            "T": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "time",
                "pointwidth": "1.0"
            },
            "dir": "SOURCES/GISS/AMIP"
        },
        "CMATM1": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "CMATM1",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "source": "Run C027AM",
                "Conventions": "IRIDL",
                "contact": "Gary L. Russell <I>cmglr@isis.giss.nasa.gov</I>",
                "history": "The surface diagnostics from a coupled model run"
            },
            "sst": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "sst",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "C",
                "history": "The surface diagnostics from a coupled model run",
                "long_name": "Sea Surface Temperature"
            },
            "X": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "gridtype": "1",
                "standard_name": "longitude",
                "pointwidth": "5.0"
            },
            "Y": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_north",
                "gridtype": "0",
                "standard_name": "latitude",
                "pointwidth": "4.0"
            },
            "T": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "time",
                "pointwidth": "1.0"
            },
            "dir": "SOURCES/GISS/CMATM1"
        },
        "GlobalFWI": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/GISS/GlobalFWI",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "GlobalFWI",
            "restriction": "Public",
            "v1p4": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/GISS/GlobalFWI/v1p4",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "v1p4",
                "restriction": "Public",
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ]
            },
            "v1p5": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/GISS/GlobalFWI/v1p5",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "v1p5",
                "restriction": "Public",
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ]
            },
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type",
                "v1p4",
                "v1p5"
            ]
        },
        "SCENARIOA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SCENARIO-A",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Conventions": "IRIDL"
            },
            "ssta": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ssta",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_Celsius",
                "history": "10 year mean anomalies from giss A scenario simulation.",
                "long_name": "Sea Surface Temperature Anomalies"
            },
            "X": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "gridtype": "0",
                "standard_name": "longitude",
                "pointwidth": "5.625"
            },
            "Y": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_north",
                "gridtype": "0",
                "standard_name": "latitude",
                "pointwidth": "2.0"
            },
            "T": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "time",
                "pointwidth": "1.0"
            },
            "dir": "SOURCES/GISS/SCENARIO-A"
        },
        "SI2000": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "SI2000",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "MONTHLYB424description": " with radiative forcings",
                "MONTHLYB424references": "Hansen_etal2002",
                "MONTHLYB399description": " with no radiative forcings",
                "MONTHLYB399references": "Hansen_etal2002",
                "MONTHLYdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.GISS/.SI2000/.MONTHLY.dataset_documentation.html",
                "Conventions": "IRIDL"
            },
            "MONTHLY": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "MONTHLY",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "B424": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "B424",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Surface": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Surface",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "w": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "w",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "wind speed",
                            "units": "m/s"
                        },
                        "v": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "v",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "meridional velocity",
                            "units": "m/s"
                        },
                        "u": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "u",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "zonal velocity",
                            "units": "m/s"
                        },
                        "temp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "temp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "temperature",
                            "units": "Celsius_scale"
                        },
                        "psl": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "psl",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "sea level pressure",
                            "units": "mb",
                            "add_offset": "1000.0"
                        },
                        "prcp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "prcp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "precipitation",
                            "units": "mm/day"
                        }
                    },
                    "PressureLevel": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PressureLevel",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "V": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "V",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "meridional velocity",
                            "units": "m/s"
                        },
                        "U": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "U",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "zonal velocity",
                            "units": "m/s"
                        },
                        "temp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "temp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "temperaturey",
                            "units": "Celsius_scale"
                        },
                        "RH": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "RH",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "relative humidity",
                            "units": "percent"
                        },
                        "Hoffset": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Hoffset",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "m"
                        },
                        "H": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "H",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "height",
                            "units": "m"
                        }
                    },
                    "Ground": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Ground",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "vegetated": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "vegetated",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "gwet": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "gwet",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "missing_value": "-9999.0",
                                "scale_max": "100.0",
                                "long_name": "ground wetness",
                                "units": "percent"
                            }
                        },
                        "root": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "root",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "gwet": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "gwet",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "missing_value": "-9999.0",
                                "scale_max": "100.0",
                                "long_name": "ground wetness",
                                "units": "percent"
                            }
                        },
                        "combined": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "combined",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "gwet": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "gwet",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "missing_value": "-9999.0",
                                "scale_max": "100.0",
                                "long_name": "ground wetness",
                                "units": "percent"
                            }
                        },
                        "bare": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "bare",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "gwet": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "gwet",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "missing_value": "-9999.0",
                                "scale_max": "100.0",
                                "long_name": "ground wetness",
                                "units": "percent"
                            }
                        }
                    }
                },
                "B399": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "B399",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Surface": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Surface",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "w": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "w",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "wind speed",
                            "units": "m/s"
                        },
                        "v": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "v",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "meridional velocity",
                            "units": "m/s"
                        },
                        "u": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "u",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "zonal velocity",
                            "units": "m/s"
                        },
                        "temp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "temp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "temperature",
                            "units": "Celsius_scale"
                        },
                        "psl": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "psl",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "sea level pressure",
                            "units": "mb",
                            "add_offset": "1000.0"
                        },
                        "prcp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "prcp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "precipitation",
                            "units": "mm/day"
                        }
                    },
                    "PressureLevel": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PressureLevel",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "V": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "V",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "meridional velocity",
                            "units": "m/s"
                        },
                        "U": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "U",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "zonal velocity",
                            "units": "m/s"
                        },
                        "temp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "temp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "temperaturey",
                            "units": "Celsius_scale"
                        },
                        "RH": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "RH",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "relative humidity",
                            "units": "percent"
                        },
                        "Hoffset": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Hoffset",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "m"
                        },
                        "H": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "H",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "height",
                            "units": "m"
                        }
                    },
                    "Ground": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Ground",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "vegetated": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "vegetated",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "gwet": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "gwet",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "missing_value": "-9999.0",
                                "scale_max": "100.0",
                                "long_name": "ground wetness",
                                "units": "percent"
                            }
                        },
                        "root": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "root",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "gwet": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "gwet",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "missing_value": "-9999.0",
                                "scale_max": "100.0",
                                "long_name": "ground wetness",
                                "units": "percent"
                            }
                        },
                        "combined": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "combined",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "gwet": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "gwet",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "missing_value": "-9999.0",
                                "scale_max": "100.0",
                                "long_name": "ground wetness",
                                "units": "percent"
                            }
                        },
                        "bare": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "bare",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "gwet": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "gwet",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "missing_value": "-9999.0",
                                "scale_max": "100.0",
                                "long_name": "ground wetness",
                                "units": "percent"
                            }
                        }
                    }
                }
            },
            "M_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "gridtype": "2",
                "long_name": "member"
            },
            "P_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "P_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "mb",
                "gridtype": "0"
            },
            "P": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "P",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "mb",
                "gridtype": "0"
            },
            "X": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "X",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_east",
                "gridtype": "1",
                "standard_name": "longitude",
                "pointwidth": "5.0"
            },
            "Y": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Y",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "degree_north",
                "gridtype": "0",
                "standard_name": "latitude",
                "pointwidth": "4.0"
            },
            "T": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "standard_name": "time",
                "pointwidth": "1.0"
            },
            "M": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "M",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "gridtype": "2",
                "long_name": "member"
            },
            "dir": "SOURCES/GISS/SI2000"
        },
        "indextex": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/GISS/index.tex",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "index.tex",
            "restriction": "Public",
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ]
        },
        "banned_long": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type",
            "AMIP",
            "CMATM1",
            "GlobalFWI",
            "SCENARIOA",
            "SI2000",
            "indextex"
        ]
    },
    "GOSTA": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "GOSTA",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "landsstdescription": "Blended Land and SST Data",
            "landsstreferences": "Jones1994",
            "gisst22description": "Global SST and Ice Concentration (GISST)",
            "gisst22references": "Parker_etal1995 Rayner_etal1996",
            "atlas8climatologylong_name": "GISST2.2 Climatology 1961-1990",
            "atlas8description": "Global Ocean Surface Temperature Atlas 8",
            "atlas8references": "Bottomley_etal1990 Parker_etal1995b",
            "atlas7climatologylong_name": "MOHSST4 Climatology 1951-1980",
            "atlas7description": "Global Ocean Surface Temperature Atlas 7",
            "atlas7references": "Bottomley_etal1990",
            "description": "Global Ocean Surface Temperature Atlas",
            "source": "PO DAAC binary Data Format CD-ROM (except for Atlas 7 5 deg sst climatology)",
            "PO": "http://podaac.jpl.nasa.gov/cdrom/gostaplus_binary/order.htm",
            "iridlhasSemantics": "iridl:BADC",
            "UK": "http://badc.nerc.ac.uk/data/gosta/",
            "Conventions": "IRIDL",
            "long_name": "GOSTAplus",
            "disclaimerhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.GOSTA/.disclaimer.html"
        },
        "landsst": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "landsst",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "temp": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "temp",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "-32768",
                "units": "Celsius_scale",
                "scale_factor": "0.01",
                "pointwidth": "0"
            }
        },
        "gisst22": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "gisst22",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "sst": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "sst",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "-32768",
                "units": "Celsius_scale",
                "scale_factor": "0.01",
                "pointwidth": "0"
            },
            "ice": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ice",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "-32768",
                "scale_factor": "0.1",
                "long_name": "ice concentration",
                "units": "unitless",
                "pointwidth": "0"
            }
        },
        "atlas8": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "atlas8",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "MOHSST6": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "MOHSST6",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ssta": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssta",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "4.1999998",
                    "ncolor": "254",
                    "scale_min": "-4.1999998",
                    "CS": "-4.1999998",
                    "colorscalename": "sstacolorscale",
                    "CE": "4.1999998",
                    "maxncolor": "254",
                    "colormap": "2763429",
                    "valid_max": "327.66998",
                    "valid_min": "-327.67999",
                    "missing_value": "NaN",
                    "long_name": "sea surface temperature anomaly",
                    "units": "degree_Celsius"
                }
            },
            "MOHSST5": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "MOHSST5",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ssta": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssta",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "4.1999998",
                    "ncolor": "254",
                    "scale_min": "-4.1999998",
                    "CS": "-4.1999998",
                    "colorscalename": "sstacolorscale",
                    "CE": "4.1999998",
                    "maxncolor": "254",
                    "colormap": "2763429",
                    "valid_max": "327.66998",
                    "valid_min": "-327.67999",
                    "missing_value": "NaN",
                    "units": "degree_Celsius"
                }
            },
            "MOHMAT4N": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "MOHMAT4N",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ta": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ta",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "valid_max": "327.66998",
                    "valid_min": "-327.67999",
                    "long_name": "night marine air temperature anomaly",
                    "missing_value": "NaN",
                    "units": "degree_Celsius"
                }
            },
            "climatology": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "climatology",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "deg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "1deg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "sst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "-2.0",
                        "colorscalename": "sstcolorscale",
                        "scale_max": "35.0",
                        "ncolor": "256",
                        "colormap": "12632256",
                        "CE": "35",
                        "CS": "-2",
                        "valid_max": "327.66998",
                        "valid_min": "-327.67999",
                        "missing_value": "NaN",
                        "units": "Celsius_scale"
                    }
                }
            }
        },
        "atlas7": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "atlas7",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "MOHSST5": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "MOHSST5",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ssta": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssta",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "4.1999998",
                    "ncolor": "254",
                    "scale_min": "-4.1999998",
                    "CS": "-4.1999998",
                    "colorscalename": "sstacolorscale",
                    "CE": "4.1999998",
                    "maxncolor": "254",
                    "colormap": "2763429",
                    "valid_max": "327.66998",
                    "valid_min": "-327.67999",
                    "missing_value": "NaN",
                    "long_name": "sea surface temperature anomaly",
                    "units": "degree_Celsius"
                }
            },
            "MOHMAT2N": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "MOHMAT2N",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ta": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ta",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "night marine air temperature anomaly",
                    "missing_value": "-32768",
                    "units": "degree_Celsius",
                    "scale_factor": "0.01"
                }
            },
            "climatology": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "climatology",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "deg": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "1deg",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "sst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "-2.0",
                        "colorscalename": "sstcolorscale",
                        "scale_max": "35.0",
                        "ncolor": "256",
                        "colormap": "12632256",
                        "CE": "35",
                        "CS": "-2",
                        "valid_max": "327.66998",
                        "valid_min": "-327.67999",
                        "missing_value": "NaN",
                        "units": "Celsius_scale"
                    }
                }
            }
        },
        "T_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "bucket": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "bucket",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2"
        },
        "wspd": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "wspd",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m/s",
            "gridtype": "0",
            "pointwidth": "0"
        },
        "X_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "5.0"
        },
        "Y_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "5.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "1.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "1.0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "1",
            "modulo": "12.0",
            "modulus": "12.0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "dir": "SOURCES/GOSTA"
    },
    "Gambia": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/Gambia",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "Gambia",
        "restriction": "Public",
        "ENACTS": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/Gambia/ENACTS",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "ENACTS",
            "restriction": "Public",
            "dekadly": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "dekadly",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Conventions": "IRIDL"
                },
                "temperature": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temperature",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "tmin": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tmin",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-99.0",
                        "long_name": "Minimum Temperature",
                        "units": "degree_Celsius"
                    },
                    "tmax": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tmax",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-99.0",
                        "long_name": "Maximum Temperature",
                        "units": "degree_Celsius"
                    }
                },
                "rainfall": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rainfall",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "SPIrfe_adj_1dekad": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "SPI-rfe_adj_1-dekad",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Standard Precipitation Index 1-dekad",
                        "maxncolor": "254",
                        "colormap": "45",
                        "scale_max": "3.0999999",
                        "ncolor": "253",
                        "scale_min": "-3.0999999",
                        "CE": "3.0999999",
                        "CS": "-3.0999999",
                        "units": "unitless",
                        "missing_value": "NaN",
                        "file_missing_value": "-9.9899998",
                        "valid_max": "32767.0",
                        "valid_min": "-32768.0"
                    },
                    "rfe_mergeddiff_percent": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rfe_mergeddiff_percent",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "long_name": "Merged Gauge-Satellite Rainfall Difference Expressed as Percent of Long-Term Average (%)",
                        "colormap": "4026644",
                        "scale_max": "500.0",
                        "ncolor": "254",
                        "scale_min": "-100.0",
                        "CE": "500",
                        "CS": "-100",
                        "units": "unitless",
                        "history": "Averaged over T2[0.5, 1044.5] minimum 0.0% data present"
                    },
                    "rfe_mergeddiff": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rfe_mergeddiff",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "long_name": "Merged Gauge-Satellite Rainfall Anomaly",
                        "colormap": "10526303",
                        "scale_max": "200.0",
                        "ncolor": "254",
                        "scale_min": "-120.0",
                        "CE": "200",
                        "CS": "-120",
                        "missing_value": "NaN",
                        "units": "mm",
                        "history": "Averaged over T2[0.5, 1044.5] minimum 0.0% data present"
                    },
                    "rfe_merged_vs_meanrfe_merged": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rfe_merged_vs_meanrfe_merged",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "long_name": "Merged Gauge-Satellite Rainfall Expressed as Percentages of the Long-Term Average",
                        "colormap": "4026644",
                        "scale_max": "600.0",
                        "ncolor": "254",
                        "scale_min": "0.0",
                        "CE": "600",
                        "CS": "0",
                        "units": "unitless",
                        "history": "Averaged over T2[0.5, 1044.5] minimum 0.0% data present"
                    },
                    "rfe": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rfe",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "0",
                        "CS": "0",
                        "ncolor": "16",
                        "colormap": "13434880",
                        "maxncolor": "254",
                        "missing_value": "-9999",
                        "long_name": "Merged Station-Satellite Rainfall",
                        "units": "mm"
                    }
                },
                "climatologies": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "climatologies",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "tmin": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tmin",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "5.0",
                        "scale_max": "27.0",
                        "CE": "27",
                        "CS": "5",
                        "ncolor": "254",
                        "colorscalename": "temp_colors",
                        "maxncolor": "254",
                        "colormap": "255",
                        "long_name": "minimum temperature 1981-2010 average",
                        "history": "Averaged over T2[0.5, 1080.5] minimum 0.0% data present",
                        "missing_value": "NaN",
                        "file_missing_value": "-99.0",
                        "units": "degree_Celsius"
                    },
                    "tmax": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tmax",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "20.0",
                        "scale_max": "43.0",
                        "CE": "43",
                        "CS": "20",
                        "ncolor": "254",
                        "colorscalename": "temp_colors",
                        "maxncolor": "254",
                        "colormap": "255",
                        "long_name": "maximum temperature 1981-2010 average",
                        "history": "Averaged over T2[0.5, 1080.5] minimum 0.0% data present",
                        "missing_value": "NaN",
                        "file_missing_value": "-99.0",
                        "units": "degree_Celsius"
                    },
                    "rfe_stddev": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rfe_stddev",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "cmorph_dekad_colors",
                        "colormap": "2237106",
                        "scale_max": "300.0",
                        "ncolor": "254",
                        "scale_min": "0.0",
                        "CE": "300",
                        "CS": "0",
                        "long_name": "rfe merged 1983-2011 standard deviation",
                        "history": "Averaged over T2[18.5, 1026.5] minimum 0.0% data present",
                        "missing_value": "NaN",
                        "units": "mm"
                    },
                    "rfe": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rfe",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "16",
                        "colormap": "13434880",
                        "maxncolor": "254",
                        "long_name": "rfe merged 1983-2011 average",
                        "history": "Averaged over T2[0.5, 1044.5] minimum 0.0% data present",
                        "missing_value": "NaN",
                        "units": "mm"
                    }
                },
                "T_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "days since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "standard"
                },
                "T_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "days since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "standard"
                },
                "T_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "days since 1981-01-01",
                    "gridtype": "1",
                    "modulo": "365.0",
                    "modulus": "365.0",
                    "calendar": "365"
                },
                "X_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "long_name": "Longitude",
                    "pointwidth": "0.0375"
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "0.0375"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "days since 1983-01-01",
                    "gridtype": "1",
                    "modulo": "365.0",
                    "modulus": "365.0",
                    "calendar": "365"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "long_name": "Longitude",
                    "pointwidth": "0.03750001"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "0.03750001"
                },
                "dir": "SOURCES/Gambia/ENACTS/dekadly"
            },
            "monthly": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "monthly",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Conventions": "IRIDL"
                },
                "climatologies": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "climatologies",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "tmin": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tmin",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "14.0",
                        "scale_max": "26.0",
                        "CE": "26",
                        "CS": "14",
                        "ncolor": "254",
                        "colorscalename": "temp_colors",
                        "maxncolor": "254",
                        "colormap": "255",
                        "long_name": "tmin 1981-2010 average",
                        "history": "Averaged over T2[1981, 2010] minimum 0.0% data present",
                        "missing_value": "NaN",
                        "units": "degree_Celsius",
                        "file_missing_value": "-99.0"
                    },
                    "tmax": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tmax",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "30.0",
                        "scale_max": "43.0",
                        "CE": "43",
                        "CS": "30",
                        "ncolor": "254",
                        "colorscalename": "temp_colors",
                        "maxncolor": "254",
                        "colormap": "255",
                        "long_name": "tmax 1981-2010 average",
                        "history": "Averaged over T2[1981, 2010] minimum 0.0% data present",
                        "missing_value": "NaN",
                        "units": "degree_Celsius",
                        "file_missing_value": "-99.0"
                    },
                    "rfe": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rfe",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "16",
                        "colormap": "13434880",
                        "maxncolor": "254",
                        "long_name": "rfe 1983-2011 average",
                        "history": "Averaged over T2[1983, 2011] minimum 0.0% data present",
                        "missing_value": "NaN",
                        "units": "mm"
                    }
                },
                "X_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "long_name": "Longitude",
                    "pointwidth": "0.0375"
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "0.0375"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "long_name": "Longitude",
                    "pointwidth": "0.03750001"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "0.03750001"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulo": "12.0",
                    "modulus": "12.0",
                    "calendar": "360",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/Gambia/ENACTS/monthly"
            },
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type",
                "dekadly",
                "monthly"
            ]
        },
        "banned_long": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type",
            "ENACTS"
        ]
    },
    "Ghana": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/Ghana",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "Ghana",
        "restriction": "requires dlauth tokens"
    },
    "HADLEY": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "HADLEY",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "HadSLPdataset_documentationhtml": "http://hadobs.metoffice.com/gmslp",
            "ClimateModelDECADALstream2hindcastsnoassimOCEAN30yearrunConventions": "CF-1.0",
            "ClimateModelDECADALstream2hindcastsnoassimOCEAN10yearrunConventions": "CF-1.0",
            "ClimateModelDECADALstream2hindcastsnoassimATM30yearrunConventions": "CF-1.0",
            "ClimateModelDECADALstream2hindcastsnoassimATM10yearrunConventions": "CF-1.0",
            "ClimateModelDECADALstream2hindcastsdepresysOCEAN30yearrunConventions": "CF-1.0",
            "ClimateModelDECADALstream2hindcastsdepresysOCEAN10yearrunConventions": "CF-1.0",
            "ClimateModelDECADALstream2hindcastsdepresysATM30yearrunConventions": "CF-1.0",
            "ClimateModelDECADALstream2hindcastsdepresysATM10yearrunConventions": "CF-1.0",
            "ClimateModelDECADALstream2climatologyOCEANHISTORICConventions": "CF-1.0",
            "ClimateModelDECADALstream2climatologyOCEANA1BConventions": "CF-1.0",
            "ClimateModelDECADALstream2climatologyATMHISTORICConventions": "CF-1.0",
            "ClimateModelDECADALstream2climatologyATMA1BConventions": "CF-1.0",
            "ClimateModelDECADALdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.HADLEY/.ClimateModel.DECADAL.dataset_documentation.html",
            "ClimateModelDECADALreferences": "Gordon_etal2000 Pope_etal2000 Johns_etal2003 Collins_etal2006 Smith_etal2007",
            "ClimateModelDECADALdescription": "HadCM3 ENSEMBLES Stream 2",
            "ClimateModeldescription": "HadCM3 ENSEMBLES Stream 2",
            "ClimateModelreferences": "Gordon_etal2000 Pope_etal2000 Johns_etal2003 Collins_etal2006 Smith_etal2007",
            "iridlhasSemantics": "iridl:HADLEY",
            "hadley_centre": "http://www.hadobs.org/",
            "Conventions": "IRIDL"
        },
        "HadSLP": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "HadSLP",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "sislp": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "sislp",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "missing_value": "-99990",
                "scale_factor": "0.01",
                "long_name": "spatially incomplete sea level pressure",
                "units": "mb"
            },
            "scslp": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "scslp",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "spatially complete sea level pressure",
                "units": "mb",
                "scale_factor": "0.01"
            }
        },
        "ClimateModel": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ClimateModel",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "DECADAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "DECADAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "stream2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "stream2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "hindcasts": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "hindcasts",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "noassim": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "noassim",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "OCEAN": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "OCEAN",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "yearrun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "10yearrun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "calendar": "360",
                                        "long_name": "Forecast time",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "3",
                                        "standard_name": "time"
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "calendar": "360",
                                            "long_name": "Forecast time",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "3",
                                            "standard_name": "time"
                                        },
                                        "sit": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sit",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "sea ice thickness",
                                            "units": "m",
                                            "pointwidth": "1.0"
                                        },
                                        "aic": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "aic",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "sea ice concentration",
                                            "units": "unitless",
                                            "pointwidth": "1.0"
                                        }
                                    },
                                    "belowSeaSurface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "belowSeaSurface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "vo": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vo",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "total v-velocity (ocean)",
                                            "units": "m s-1",
                                            "pointwidth": "1.0"
                                        },
                                        "uo": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uo",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "total u-velocity (ocean)",
                                            "units": "m s-1",
                                            "pointwidth": "1.0"
                                        },
                                        "thetao": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "thetao",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "potential temperature (ocean)",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "1.0"
                                        },
                                        "so": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "so",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "salinity (ocean)",
                                            "units": "psu",
                                            "pointwidth": "1.0"
                                        }
                                    }
                                }
                            },
                            "ATM": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "ATM",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "yearrun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "10yearrun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "rsutcs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rsutcs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "clear sky top upward SW radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rsut": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rsut",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "top upward SW radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rst": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rst",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "top net SW radiation (rsdt-rsut)",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rsdt": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rsdt",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "top downward SW radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rlutcs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rlutcs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "clear sky top upward LW radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rlut": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rlut",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "top upward LW radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        }
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Forecast time",
                                        "units": "months since 1960-01-01",
                                        "calendar": "360",
                                        "pointwidth": "1"
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "ts": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ts",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "surface temp.",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "1.0"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "2-meter air temperature",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "1.0"
                                        },
                                        "snw": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snw",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "snow water equivalent",
                                            "units": "kg m-2",
                                            "pointwidth": "1.0"
                                        },
                                        "rss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "net SW surface radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "net LW surface radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rlds": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rlds",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "downward LW surface radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "psl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "mean sea level pressure",
                                            "units": "Pa",
                                            "pointwidth": "1.0"
                                        },
                                        "pr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "precipitation",
                                            "units": "kg m-2 s-1",
                                            "pointwidth": "1.0"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "sensible heat flux at surface",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "latent heat flux at surface",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "mrsos": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "mrsos",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "soil moisture (profile on model level)",
                                            "units": "kg m-2",
                                            "pointwidth": "1.0"
                                        },
                                        "mrso": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "mrso",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "total soil moisture content",
                                            "units": "kg m-2",
                                            "pointwidth": "1.0"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "geopotential height",
                                            "units": "m",
                                            "pointwidth": "1.0"
                                        },
                                        "va": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "va",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "v wind",
                                            "units": "m s-1",
                                            "pointwidth": "1.0"
                                        },
                                        "ua": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ua",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "u wind",
                                            "units": "m s-1",
                                            "pointwidth": "1.0"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "temperature",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "1.0"
                                        }
                                    }
                                }
                            }
                        },
                        "depresys": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "depresys",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "OCEAN": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "OCEAN",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "yearrun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "10yearrun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "calendar": "360",
                                        "long_name": "Forecast time",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "3",
                                        "standard_name": "time"
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "calendar": "360",
                                            "long_name": "Forecast time",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "3",
                                            "standard_name": "time"
                                        },
                                        "sit": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sit",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "sea ice thickness",
                                            "units": "m",
                                            "pointwidth": "1.0"
                                        },
                                        "aic": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "aic",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "sea ice concentration",
                                            "units": "unitless",
                                            "pointwidth": "1.0"
                                        }
                                    },
                                    "belowSeaSurface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "belowSeaSurface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "vo": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vo",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "total v-velocity (ocean)",
                                            "units": "m s-1",
                                            "pointwidth": "1.0"
                                        },
                                        "uo": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uo",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "total u-velocity (ocean)",
                                            "units": "m s-1",
                                            "pointwidth": "1.0"
                                        },
                                        "thetao": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "thetao",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "potential temperature (ocean)",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "1.0"
                                        },
                                        "so": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "so",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "salinity (ocean)",
                                            "units": "psu",
                                            "pointwidth": "1.0"
                                        }
                                    }
                                }
                            },
                            "ATM": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "ATM",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "yearrun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "10yearrun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "rsutcs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rsutcs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "clear sky top upward SW radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rsut": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rsut",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "top upward SW radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rst": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rst",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "top net SW radiation (rsdt-rsut)",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rsdt": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rsdt",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "top downward SW radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rlutcs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rlutcs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "clear sky top upward LW radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rlut": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rlut",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "top upward LW radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        }
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Forecast time",
                                        "units": "months since 1960-01-01",
                                        "calendar": "360",
                                        "pointwidth": "1"
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "ts": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ts",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "surface temp.",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "1.0"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "2-meter air temperature",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "1.0"
                                        },
                                        "snw": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snw",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "snow water equivalent",
                                            "units": "kg m-2",
                                            "pointwidth": "1.0"
                                        },
                                        "rss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "net SW surface radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "net LW surface radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "rlds": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rlds",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "downward LW surface radiation",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "psl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "mean sea level pressure",
                                            "units": "Pa",
                                            "pointwidth": "1.0"
                                        },
                                        "pr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "precipitation",
                                            "units": "kg m-2 s-1",
                                            "pointwidth": "1.0"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "sensible heat flux at surface",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        },
                                        "hfso": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfso",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless",
                                            "missing_value": "1.00000002E20",
                                            "pointwidth": "1.0"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "latent heat flux at surface",
                                            "units": "W/m2",
                                            "pointwidth": "1.0"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "mrsos": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "mrsos",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "soil moisture (profile on model level)",
                                            "units": "kg m-2",
                                            "pointwidth": "1.0"
                                        },
                                        "mrso": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "mrso",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "total soil moisture content",
                                            "units": "kg m-2",
                                            "pointwidth": "1.0"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "geopotential height",
                                            "units": "m",
                                            "pointwidth": "1.0"
                                        },
                                        "va": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "va",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "v wind",
                                            "units": "m s-1",
                                            "pointwidth": "1.0"
                                        },
                                        "ua": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ua",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "u wind",
                                            "units": "m s-1",
                                            "pointwidth": "1.0"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "1.00000002E20",
                                            "long_name": "temperature",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "1.0"
                                        }
                                    }
                                }
                            }
                        }
                    },
                    "climatology": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "climatology",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "OCEAN": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "OCEAN",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "HISTORIC": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HISTORIC",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "sit": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sit",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "sea ice thickness",
                                        "units": "m"
                                    },
                                    "aic": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "aic",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "sea ice concentration",
                                        "units": "unitless"
                                    }
                                },
                                "belowSeaSurface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "belowSeaSurface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "vo": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vo",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "total v-velocity (ocean)",
                                        "units": "m s-1"
                                    },
                                    "uo": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "uo",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "total u-velocity (ocean)",
                                        "units": "m s-1"
                                    },
                                    "thetao": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "thetao",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "potential temperature (ocean)",
                                        "units": "Kelvin_scale"
                                    },
                                    "so": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "so",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "salinity (ocean)",
                                        "units": "psu"
                                    }
                                }
                            },
                            "A1B": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "A1B",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "sit": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sit",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "sea ice thickness",
                                        "units": "m"
                                    },
                                    "aic": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "aic",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "sea ice concentration",
                                        "units": "unitless"
                                    }
                                },
                                "belowSeaSurface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "belowSeaSurface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "vo": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vo",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "total v-velocity (ocean)",
                                        "units": "m s-1"
                                    },
                                    "uo": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "uo",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "total u-velocity (ocean)",
                                        "units": "m s-1"
                                    },
                                    "thetao": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "thetao",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "potential temperature (ocean)",
                                        "units": "Kelvin_scale"
                                    },
                                    "so": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "so",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "salinity (ocean)",
                                        "units": "psu"
                                    }
                                }
                            }
                        },
                        "ATM": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ATM",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "HISTORIC": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HISTORIC",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "top": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "top",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "rsutcs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rsutcs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "clear sky top upward SW radiation",
                                        "units": "W/m2"
                                    },
                                    "rsut": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rsut",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "top upward SW radiation",
                                        "units": "W/m2"
                                    },
                                    "rst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "top net SW radiation (rsdt-rsut)",
                                        "units": "W/m2"
                                    },
                                    "rsdt": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rsdt",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "top downward SW radiation",
                                        "units": "W/m2"
                                    },
                                    "rlutcs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rlutcs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "clear sky top upward LW radiation",
                                        "units": "W/m2"
                                    },
                                    "rlut": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rlut",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "top upward LW radiation",
                                        "units": "W/m2"
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "ts": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ts",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "surface temp.",
                                        "units": "Kelvin_scale"
                                    },
                                    "tas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "2-meter air temperature",
                                        "units": "Kelvin_scale"
                                    },
                                    "snw": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "snw",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "snow water equivalent",
                                        "units": "kg m-2"
                                    },
                                    "rss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "net SW surface radiation",
                                        "units": "W/m2"
                                    },
                                    "rls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "net LW surface radiation",
                                        "units": "W/m2"
                                    },
                                    "rlds": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rlds",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "downward LW surface radiation",
                                        "units": "W/m2"
                                    },
                                    "psl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "mean sea level pressure",
                                        "units": "Pa"
                                    },
                                    "pr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "pr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "precipitation",
                                        "units": "kg m-2 s-1"
                                    },
                                    "hfss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "sensible heat flux at surface",
                                        "units": "W/m2"
                                    },
                                    "hfls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "latent heat flux at surface",
                                        "units": "W/m2"
                                    }
                                },
                                "soil": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soil",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "mrsos": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mrsos",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "soil moisture (profile on model level)",
                                        "units": "kg m-2"
                                    },
                                    "mrso": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mrso",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "total soil moisture content",
                                        "units": "kg m-2"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "zg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "zg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "geopotential height",
                                        "units": "m"
                                    },
                                    "va": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "va",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "v wind",
                                        "units": "m s-1"
                                    },
                                    "ua": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ua",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "u wind",
                                        "units": "m s-1"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "temperature",
                                        "units": "Kelvin_scale"
                                    }
                                }
                            },
                            "A1B": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "A1B",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "top": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "top",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "rsutcs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rsutcs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "clear sky top upward SW radiation",
                                        "units": "W/m2"
                                    },
                                    "rsut": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rsut",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "top upward SW radiation",
                                        "units": "W/m2"
                                    },
                                    "rst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "top net SW radiation (rsdt-rsut)",
                                        "units": "W/m2"
                                    },
                                    "rsdt": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rsdt",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "top downward SW radiation",
                                        "units": "W/m2"
                                    },
                                    "rlutcs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rlutcs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "clear sky top upward LW radiation",
                                        "units": "W/m2"
                                    },
                                    "rlut": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rlut",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "top upward LW radiation",
                                        "units": "W/m2"
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "ts": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ts",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "surface temp.",
                                        "units": "Kelvin_scale"
                                    },
                                    "tas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "2-meter air temperature",
                                        "units": "Kelvin_scale"
                                    },
                                    "snw": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "snw",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "snow water equivalent",
                                        "units": "kg m-2"
                                    },
                                    "rss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "net SW surface radiation",
                                        "units": "W/m2"
                                    },
                                    "rls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "net LW surface radiation",
                                        "units": "W/m2"
                                    },
                                    "rlds": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rlds",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "downward LW surface radiation",
                                        "units": "W/m2"
                                    },
                                    "psl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "mean sea level pressure",
                                        "units": "Pa"
                                    },
                                    "pr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "pr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "precipitation",
                                        "units": "kg m-2 s-1"
                                    },
                                    "hfss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "sensible heat flux at surface",
                                        "units": "W/m2"
                                    },
                                    "hfls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "latent heat flux at surface",
                                        "units": "W/m2"
                                    }
                                },
                                "soil": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soil",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "mrsos": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mrsos",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "soil moisture (profile on model level)",
                                        "units": "kg m-2"
                                    },
                                    "mrso": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mrso",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "total soil moisture content",
                                        "units": "kg m-2"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "zg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "zg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "geopotential height",
                                        "units": "m"
                                    },
                                    "va": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "va",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "v wind",
                                        "units": "m s-1"
                                    },
                                    "ua": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ua",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "u wind",
                                        "units": "m s-1"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "1.00000002E20",
                                        "long_name": "temperature",
                                        "units": "Kelvin_scale"
                                    }
                                }
                            }
                        }
                    }
                }
            }
        },
        "Y_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "5.0"
        },
        "T_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "5.0"
        },
        "L_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "L_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "forecast_period",
            "long_name": "Lead time",
            "pointwidth": "3"
        },
        "L_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "L_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "forecast_period",
            "long_name": "Lead time",
            "pointwidth": "3"
        },
        "L_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "L_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months",
            "gridtype": "0",
            "long_name": "Lead time",
            "calendar": "360",
            "standard_name": "forecast_period",
            "pointwidth": "1.0"
        },
        "S_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "S_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "forecast_reference_time",
            "long_name": "Start time",
            "pointwidth": "0"
        },
        "z_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "z_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0",
            "long_name": "Soil level",
            "pointwidth": "1.0"
        },
        "L": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "L",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months",
            "gridtype": "0",
            "long_name": "Lead time",
            "calendar": "360",
            "standard_name": "forecast_period",
            "pointwidth": "1.0"
        },
        "S": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "S",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "forecast_reference_time",
            "long_name": "Start time",
            "pointwidth": "0"
        },
        "T_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "Time",
            "long_name": "Time",
            "pointwidth": "3"
        },
        "Y_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "1.25"
        },
        "X_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "1.25"
        },
        "Y_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "1.25"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "Time",
            "long_name": "Time",
            "pointwidth": "3"
        },
        "X_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "1.25"
        },
        "z": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "z",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0",
            "long_name": "Below sea surface"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "Time",
            "long_name": "Time",
            "pointwidth": "0"
        },
        "Z": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Z",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0",
            "long_name": "Soil level",
            "pointwidth": "1.0"
        },
        "Y_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "2.5"
        },
        "X_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "3.75"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "2.5"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "Time",
            "long_name": "Time",
            "pointwidth": "0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "3.7631578"
        },
        "M": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "M",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "long_name": "Member",
            "pointwidth": "1.0"
        },
        "P": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "P",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "mb",
            "gridtype": "0",
            "long_name": "Pressure level"
        },
        "dir": "SOURCES/HADLEY"
    },
    "HELLERMAN": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "HELLERMAN",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.HELLERMAN/.dataset_documentation.html",
            "iridlhasSemantics": "iridl:NOAA",
            "Conventions": "IRIDL",
            "GCMD_id": "HELLERMAN",
            "references": "Hellerman_Rosenstein1983",
            "description": "Hellerman and Rosenstein Global Wind Stress Climatology"
        },
        "tauy": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "tauy",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "long_name": "meridional wind stress",
            "units": "dynes/cm2"
        },
        "taux": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "taux",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "long_name": "zonal wind stress",
            "units": "dynes/cm2"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "1",
            "modulo": "12.0",
            "modulus": "12.0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "standard_name": "longitude",
            "pointwidth": "2.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "2.0"
        },
        "dir": "SOURCES/HELLERMAN"
    },
    "IBGE": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "IBGE",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Municipiolavoura_temporariasource": ">IBGE</a>",
            "Municipiolavoura_permanentesource": ">IBGE</a>",
            "Municipiodescription": "Produ\\xc3\\xa7\\xc3\\xa3o Agr\\xc3\\xadcola Municipal",
            "description": "Instituto Brasileiro de Geografia e Estat\\xc3\\xadstica",
            "Conventions": "IRIDL"
        },
        "Municipio": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Municipio",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "lavoura_temporaria": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "lavoura_temporaria",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "trigo_rendimiento": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "trigo_rendimiento",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "0.0",
                    "missing_value": "-9.0",
                    "units": "kg/hectare",
                    "long_name": "Rendimento m\\xc3\\xa9dio da produ\\xc3\\xa7\\xc3\\xa3o do trigo"
                },
                "the_geom": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "the_geom",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Municipio geometry",
                    "units": "unitless",
                    "PGtype": "bytea",
                    "OpenGISSimpleFeature": "MULTIPOLYGON",
                    "SpatialReferenceSystemWKT": "]]"
                },
                "sorgo_rendimiento": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sorgo_rendimiento",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "0.0",
                    "missing_value": "-9.0",
                    "units": "kg/hectare",
                    "long_name": "Rendimento m\\xc3\\xa9dio da produ\\xc3\\xa7\\xc3\\xa3o do sorgo"
                },
                "soja_rendimiento": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "soja_rendimiento",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "0.0",
                    "missing_value": "-9.0",
                    "units": "kg/hectare",
                    "long_name": "Rendimento m\\xc3\\xa9dio da produ\\xc3\\xa7\\xc3\\xa3o do soja"
                },
                "soja_AcP": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "soja_AcP",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "0.0",
                    "missing_value": "-9.0",
                    "units": "percent",
                    "long_name": "\\xc3\\x81rea colhida do soja",
                    "scale_max": "100.0"
                },
                "municode": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "municode",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless"
                },
                "milho_rendimiento": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "milho_rendimiento",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "0.0",
                    "missing_value": "-9.0",
                    "units": "kg/hectare",
                    "long_name": "Rendimento m\\xc3\\xa9dio da produ\\xc3\\xa7\\xc3\\xa3o do milho"
                },
                "milho_AcP": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "milho_AcP",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "0.0",
                    "missing_value": "-9.0",
                    "units": "percent",
                    "long_name": "\\xc3\\x81rea colhida do milho",
                    "scale_max": "100.0"
                },
                "canaAc_rendimiento": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "canaAc_rendimiento",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "0.0",
                    "missing_value": "-9.0",
                    "units": "kg/hectare",
                    "long_name": "Rendimento m\\xc3\\xa9dio da produ\\xc3\\xa7\\xc3\\xa3o do cana de a\\xc3\\xa7\\xc3\\xbacar"
                },
                "arroz_rendimiento": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "arroz_rendimiento",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "0.0",
                    "missing_value": "-9.0",
                    "units": "kg/hectare",
                    "long_name": "Rendimento m\\xc3\\xa9dio da produ\\xc3\\xa7\\xc3\\xa3o do arroz"
                }
            },
            "lavoura_permanente": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "lavoura_permanente",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "the_geom": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "the_geom",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Municipio geometry",
                    "units": "unitless",
                    "PGtype": "bytea",
                    "OpenGISSimpleFeature": "MULTIPOLYGON",
                    "SpatialReferenceSystemWKT": "]]"
                },
                "municode": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "municode",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless"
                },
                "cafe": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "cafe",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "0.0",
                    "missing_value": "-9.0",
                    "units": "kg/hectare",
                    "long_name": "Rendimento m\\xc3\\xa9dio da produ\\xc3\\xa7\\xc3\\xa3o do caf\\xc3\\xa9"
                }
            }
        },
        "municode_id_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "municode_id_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "0",
            "pointwidth": "1.0"
        },
        "municode_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "municode_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0"
        },
        "municode_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "municode_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0"
        },
        "municode_id": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "municode_id",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "0",
            "pointwidth": "1.0"
        },
        "municode": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "municode",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "long_name": "Time",
            "pointwidth": "12"
        },
        "dir": "SOURCES/IBGE"
    },
    "ICE": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "ICE",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "COREVOSTOKCO2long_name": "$@ CO sub 2$",
            "COREVOSTOKiridlhasSemantics": "iridl:CNRS",
            "COREVOSTOKreferences": "Jouzel_etal1987 Petit_etal1990",
            "COREQUELCCAYAreferences": "Thompson_Mosley-Thompson1989",
            "COREQUELCCAYAiridlhasSemantics": "iridl:OhioStateUniversity",
            "COREGRIPreferences": "Dansgaard_etal1993 GRIPmembers1993",
            "COREGRIPiridlhasSemantics": "iridl:CNRS",
            "COREdescription": "Chemical measurements from ice cores",
            "COREiridlhasSemantics": "iridl:IceCore",
            "description": "Chemical measurements from ice cores",
            "Conventions": "IRIDL"
        },
        "CORE": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "CORE",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "VOSTOK": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "VOSTOK",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "temp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "Celsius_scale",
                    "long_name": "temperature difference from present"
                },
                "ice_age": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ice_age",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "history": "Z regridded on ICE CORE VOSTOK ice_age",
                    "missing_value": "NaN",
                    "file_missing_value": "-99.999901",
                    "long_name": "Ice Age",
                    "units": "kya"
                },
                "gas_age": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gas_age",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "history": "Z regridded on ICE CORE VOSTOK gas_age",
                    "missing_value": "NaN",
                    "file_missing_value": "-99.999901",
                    "long_name": "Gas Age",
                    "units": "kya"
                },
                "dstvlm": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "dstvlm",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "10-9cm3g-1",
                    "missing_value": "-99.999901",
                    "history": "noaa ftp site",
                    "long_name": "dust volume: insoluble microparticles"
                },
                "dstflx": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "dstflx",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "mg m-2 a-1",
                    "missing_value": "-99.999901",
                    "history": "noaa ftp site",
                    "long_name": "dust flux"
                },
                "deuterium": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "deuterium",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless"
                },
                "CO2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "CO2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "min": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "min",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-99.999901",
                        "history": "noaa ftp site",
                        "long_name": "carbon dioxide minimum",
                        "units": "ppmv"
                    },
                    "mean": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mean",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-99.999901",
                        "history": "noaa ftp site",
                        "long_name": "carbon dioxide",
                        "units": "ppmv"
                    },
                    "max": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "max",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-99.999901",
                        "history": "noaa ftp site",
                        "long_name": "carbon dioxide maximum",
                        "units": "ppmv"
                    },
                    "ice_age": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ice_age",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-99.999901",
                        "history": " noaa ftp site",
                        "long_name": "Ice Age",
                        "units": "kya"
                    },
                    "gas_age": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gas_age",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-99.999901",
                        "history": " noaa ftp site",
                        "long_name": "Gas Age",
                        "units": "kya"
                    }
                },
                "ch4": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ch4",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ppbv",
                    "missing_value": "-99.999901",
                    "history": "noaa ftp site",
                    "long_name": "methane"
                }
            },
            "QUELCCAYA": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "QUELCCAYA",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "o18": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "o18",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "0.0",
                    "units": "per mil",
                    "long_name": "Oxygen 18 isotopic ratio",
                    "history": "noaa ftp site"
                }
            },
            "GRIP": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "GRIP",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "o18": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "o18",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-99.999901",
                    "units": "per mil",
                    "long_name": "Oxygen 18 isotopic ratio",
                    "history": "noaa ftp site"
                },
                "ch4": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ch4",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-99.999901",
                    "units": "ppbv",
                    "long_name": "Methane",
                    "history": "noaa ftp site"
                }
            }
        },
        "T_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "years before present",
            "gridtype": "0",
            "long_name": "age",
            "pointwidth": "100.0"
        },
        "Z_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Z_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0",
            "long_name": "Depth"
        },
        "T_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "kya",
            "gridtype": "0",
            "long_name": "time"
        },
        "Z_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Z_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0"
        },
        "Z_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Z_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0",
            "long_name": "Depth"
        },
        "Z": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Z",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0",
            "long_name": "Depth"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "years since 0001-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0",
            "add_offset": "-0.5"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "kya",
            "gridtype": "0",
            "pointwidth": "0.2"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "kya",
            "gridtype": "0"
        },
        "dir": "SOURCES/ICE"
    },
    "IGOSS": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "IGOSS",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "TOPEXUTCSRreferences": "Tapley_etal1994",
            "TOPEXUTCSRdescription": "University of Texas at Austin Center for Space Research TOPEX/POSEIDON Gridded Sea Level Anomalies",
            "TOPEXUTCSRdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.TOPEX.UTCSR.dataset_documentation.html",
            "TOPEXNOAAreferences": "Cheney_etal1994",
            "TOPEXNOAAdescription": "NOAA TOPEX/POSEIDON Altimeter Gridded Sea Level Analysis",
            "TOPEXNOAAdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.TOPEX.NOAA.dataset_documentation.html",
            "TOPEXdescription": "TOPEX/POSEIDON altimeter gridded sea level analysis of sea surface heights and anomalies",
            "TOGATAOreferences": "Mangum_etal1994 Soreide_etal1994",
            "TOGATAOdescription": "Wind vectors and sea surface temperatures from the TOGA-TAO array in the tropical Pacific",
            "TOGATAOiridlhasSemantics": "iridl:PMEL",
            "TOGATAOdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.TOGA-TAO.dataset_documentation.html",
            "siomonthlyheat_storagelong_name": "heat storage",
            "siomonthlyheat_storagedescription": "Monthly heat storage data from Scripps Institution of Oceanography",
            "siomonthlyheat_storagedataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.sio.monthly.heat_storage.dataset_documentation.html",
            "siomonthlyheat_storageiridlhasSemantics": "iriref:White_W",
            "siomonthlydescription": "Monthly heat storage data from Scripps Institution of Oceanography",
            "siomonthlydataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.sio.monthly.dataset_documentation.html",
            "sioclimatologydescription": "Climatological heat storage, mixed layer depth, and temperature data from Scripps Institution of Oceanography. ",
            "sioclimatologyiridlhasSemantics": "iridl:climatology",
            "siodescription": "Climatological and monthly heat storage and mixed layer depth data from Scripps Institution of Oceanography",
            "nmcReyn_SmithOIv2weeklyexpires": "1615161600",
            "nmcReyn_SmithOIv2monthlyexpires": "1615161600",
            "nmcReyn_SmithOIv2monthlydataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.nmc.Reyn_SmithOIv2.monthly.dataset_documentation.html",
            "nmcReyn_SmithOIv2monthlynote": "revised 13 Sep 2005: replaced pre Apr 2002 files with Apr 2002 versions",
            "nmcReyn_SmithOIv2climatologyc8110long_name": "1981-2010",
            "nmcReyn_SmithOIv2climatologyc8110dataset_documentation": "https://iridl.ldeo.columbia.edu/documentation/NOAA/NCEP/EMC/CMB/GLOBAL/Reyn_SmithOIv2/Note_SST_Climatology_1981-2010.pdf",
            "nmcReyn_SmithOIv2climatologyc8110source": "https://www.cpc.ncep.noaa.gov/products/people/yxue/sstclim/",
            "nmcReyn_SmithOIv2climatologyc7100long_name": "1971-2000",
            "nmcReyn_SmithOIv2climatologyc6190long_name": "1961-1990",
            "nmcReyn_SmithOIv2climatologyiridlhasSemantics": "iridl:climatology",
            "nmcReyn_SmithOIv2references": "Reynolds_etal2002",
            "nmcReyn_SmithOIv2description": "SST fields updated from version 1 with more COADS data, new sea-ice to SST conversion algorithm, and 1971-2000 climatology",
            "nmcReyn_SmithOIv2OISST": "http://www.emc.ncep.noaa.gov/research/cmb/sst_analysis/",
            "nmcReyn_SmithOIv1weeklydataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.nmc.Reyn_SmithOIv1.weekly.dataset_documentation.html",
            "nmcReyn_SmithOIv1pentadclimatologydataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.nmc.Reyn_SmithOIv1.pentad-climatology.dataset_documentation.html",
            "nmcReyn_SmithOIv1monthlydataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.nmc.Reyn_SmithOIv1.monthly.dataset_documentation.html",
            "nmcReyn_SmithOIv1climatologydataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.nmc.Reyn_SmithOIv1.climatology.dataset_documentation.html",
            "nmcReyn_SmithOIv1ReynoldsSmithOIv2": "http://iridl.ldeo.columbia.edu/SOURCES/.NOAA/.NCEP/.EMC/.CMB/.GLOBAL/.Reyn_SmithOIv2/",
            "nmcReyn_SmithOIv1references": "Reynolds:Smith1994",
            "nmcReyn_SmithOIv1description": "Sea surface temperature fields blended from ship, buoy and bias-corrected satellite data  (Reynolds and Smith 1994)",
            "leetmadescription": "Pacific surface currents and equatorial thermocline depth",
            "leetmadataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.leetma.dataset_documentation.html",
            "leetmairidlhasSemantics": "iriref:Leetmaa_A",
            "fsudescription": "Florida State University wind analysis",
            "fsudataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.fsu.dataset_documentation.html",
            "ers1references": "Miller_etal1993",
            "ers1description": "Analysis of monthly mean ERS-1 altimeter and tide gauge measurements at 30 island locations in the central and western Pacific",
            "ers1dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.ers1.dataset_documentation.html",
            "australiahistory": "The surface winds are calculated using boundary layer similarity theory. <b>AUSTRALIA</b>",
            "australiadescription": "Surface winds from the Australian Bureau of Meteorology in Melbourne",
            "australiadataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.australia.dataset_documentation.html",
            "australiairidlhasSemantics": "iriref:Parker_P",
            "TOGATAOhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.TOGA-TAO.html",
            "description": "Integrated Global Ocean Services System Products Bulletin",
            "data_productshtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.data_products.html",
            "Conventions": "IRIDL",
            "analyseshtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.analyses.html",
            "iridlhasSemantics": "iriref:Tourre_Y",
            "products_bulletinhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IGOSS/.products_bulletin.html"
        },
        "TOPEX": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "TOPEX",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "UTCSR": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "UTCSR",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ssha": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssha",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "60.0",
                    "scale_min": "-60.0",
                    "colormap": "12632256",
                    "CS": "-60",
                    "CE": "60",
                    "units": "cm",
                    "long_name": "Sea Surface Height Anomaly",
                    "history": "Monthly mean sea surface height. <B>USA</B>",
                    "missing_value": "999.0"
                },
                "ssh": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssh",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "cm",
                    "long_name": "Sea Surface Height",
                    "history": "Monthly mean sea surface height. <B>USA</B>",
                    "missing_value": "999.0"
                }
            },
            "NOAA": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NOAA",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "sshd": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sshd",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "60.0",
                    "scale_min": "-60.0",
                    "colormap": "12632256",
                    "CS": "-60",
                    "CE": "60",
                    "units": "cm",
                    "long_name": "Sea Surface Height Deviations",
                    "history": "Monthly mean sea surface height deviations. <B>USA</B>",
                    "missing_value": "NaN"
                },
                "ssha": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ssha",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "60.0",
                    "scale_min": "-60.0",
                    "colormap": "12632256",
                    "CS": "-60",
                    "CE": "60",
                    "units": "cm",
                    "long_name": "Sea Surface Height Anomaly",
                    "history": "Monthly mean sea surface height anomaly. <B>USA</B>",
                    "missing_value": "NaN"
                }
            }
        },
        "TOGATAOcdf": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "TOGA-TAO.cdf",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "va": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "va",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_max": "10.0",
                "history": "><B>USA-FRANCE-JAPAN-KOREA-TAIWAN</B></a>)]",
                "CE": "10",
                "CSCALE": "0.035",
                "generic_name": "v",
                "long_name": "meridional wind anomaly",
                "CS": "-10",
                "scale_min": "-10.0",
                "FORTRAN_format": "F9.4",
                "CI": "1",
                "epic_code": "423",
                "units": "m s-1",
                "missing_value": "1.00000004E35"
            },
            "v": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_max": "10.0",
                "history": "><B>USA-FRANCE-JAPAN-KOREA-TAIWAN</B></a>)]",
                "CE": "10",
                "CSCALE": "0.035",
                "generic_name": "v",
                "long_name": "meridional wind velocity",
                "CS": "-10",
                "scale_min": "-10.0",
                "FORTRAN_format": "F9.4",
                "CI": "1",
                "epic_code": "423",
                "units": "m s-1",
                "missing_value": "1.00000004E35"
            },
            "ua": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ua",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_max": "10.0",
                "history": "><B>USA-FRANCE-JAPAN-KOREA-TAIWAN</B></a>)]",
                "CE": "10",
                "CSCALE": "0.035",
                "generic_name": "u",
                "long_name": "zonal wind anomaly",
                "CS": "-10",
                "scale_min": "-10.0",
                "FORTRAN_format": "F9.4",
                "CI": "1",
                "epic_code": "422",
                "units": "m s-1",
                "missing_value": "1.00000004E35"
            },
            "u": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "u",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_max": "10.0",
                "history": "><B>USA-FRANCE-JAPAN-KOREA-TAIWAN</B></a>)]",
                "CE": "10",
                "CSCALE": "0.035",
                "generic_name": "u",
                "long_name": "zonal wind velocity",
                "CS": "-10",
                "scale_min": "-10.0",
                "FORTRAN_format": "F9.4",
                "CI": "1",
                "epic_code": "422",
                "units": "m s-1",
                "missing_value": "1.00000004E35"
            },
            "ssta": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ssta",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "maxncolor": "254",
                "colormap": "2763429",
                "scale_max": "4.1999998",
                "ncolor": "254",
                "scale_min": "-4.1999998",
                "CS": "-4.1999998",
                "colorscalename": "sstacolorscale",
                "CE": "4.1999998",
                "FORTRAN_format": "f10.2",
                "units": "C",
                "generic_name": "temp",
                "CI": "0.25",
                "history": "><B>USA-FRANCE-JAPAN-KOREA-TAIWAN</B></a>)]",
                "long_name": "sea surface temperature anomaly",
                "epic_code": "20",
                "missing_value": "1.00000004E35"
            },
            "sst": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "sst",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "colorscalename": "sstcolorscale",
                "scale_max": "35.0",
                "ncolor": "256",
                "scale_min": "-2.0",
                "colormap": "12632256",
                "CS": "-2",
                "CE": "35",
                "FORTRAN_format": "f10.2",
                "units": "C",
                "generic_name": "temp",
                "CI": "0.5",
                "history": "><B>USA-FRANCE-JAPAN-KOREA-TAIWAN</B></a>)]",
                "long_name": "sea surface temperature",
                "epic_code": "20",
                "missing_value": "1.00000004E35"
            }
        },
        "sio": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "sio",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "monthly": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "monthly",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "heat_storage": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "heat_storage",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "error": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "error",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "long_name": "Interpolation Error",
                        "missing_value": "9.99999962E35"
                    },
                    "anomalies": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "anomalies",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "10**9 J/m2",
                        "colormap": "2763429",
                        "scale_max": "2.9880478",
                        "ncolor": "254",
                        "scale_min": "-2.9880478",
                        "CS": "-2.9880478",
                        "CE": "2.9880478",
                        "colorscalename": "custom",
                        "CI": "0.25",
                        "long_name": "Heat Storage Anomalies",
                        "history": "Vertically averaged (0/400m) heat storage anomaly.  1979-1988 climatology",
                        "missing_value": "9.99999962E35"
                    }
                }
            },
            "coastal": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "coastal",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "wv": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wv",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "meridional wind velocity",
                    "units": "m s-1",
                    "missing_value": "999999.0"
                },
                "wu": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wu",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "zonal wind velocity",
                    "units": "m s-1",
                    "missing_value": "999999.0"
                },
                "v": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "v",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "meridional velocity",
                    "units": "m s-1",
                    "missing_value": "999999.0"
                },
                "u": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "u",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "zonal velocity",
                    "units": "m s-1",
                    "missing_value": "999999.0"
                },
                "temp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "temperature",
                    "units": "Celsius_scale",
                    "missing_value": "999999.0"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north"
                }
            },
            "climatology": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "climatology",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "temp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "Celsius_scale",
                    "colormap": "12632256",
                    "scale_max": "35.0",
                    "ncolor": "256",
                    "scale_min": "-2.0",
                    "CS": "-2",
                    "colorscalename": "sstcolorscale",
                    "CE": "35",
                    "long_name": "temperature",
                    "missing_value": "9.99999962E35"
                },
                "mld": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "mld",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "m",
                    "long_name": "Mixed Layer Depth",
                    "missing_value": "9.99999962E35"
                },
                "heat_storage": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "heat_storage",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "10**7 Joules/m2",
                    "long_name": "Heat Storage",
                    "missing_value": "9.99999962E35"
                }
            }
        },
        "nmc": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "nmc",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Reyn_SmithOIv2": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Reyn_SmithOIv2",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "weekly": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "weekly",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "ssta": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ssta",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "PLOTCOAST": "1",
                        "long_name": "Sea Surface Temperature Anomaly",
                        "maxncolor": "254",
                        "colormap": "2763429",
                        "scale_max": "4.1999998",
                        "ncolor": "254",
                        "scale_min": "-4.1999998",
                        "CS": "-4.1999998",
                        "colorscalename": "sstacolorscale",
                        "CE": "4.1999998",
                        "units": "degree_Celsius",
                        "history": "Boxes with less than 0.0% dropped",
                        "missing_value": "NaN",
                        "expires": "1615161600"
                    },
                    "sst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "expires": "1615161600",
                        "units": "Celsius_scale",
                        "colorscalename": "sstcolorscale",
                        "scale_max": "35.0",
                        "ncolor": "256",
                        "scale_min": "-2.0",
                        "colormap": "12632256",
                        "CS": "-2",
                        "CE": "35",
                        "long_name": "Sea Surface Temperature"
                    },
                    "sea_ice": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sea_ice",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "expires": "1615161600",
                        "scale_max": "100",
                        "long_name": "Sea Ice Concentration",
                        "units": "percent",
                        "scale_min": "0"
                    },
                    "mask": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mask",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "long_name": "Land-Sea Mask",
                        "expires": "1615161600"
                    },
                    "err": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "err",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "expires": "1615161600",
                        "scale_max": "1.0",
                        "long_name": "SST Normalized Error Variance",
                        "units": "unitless",
                        "scale_min": "0.0"
                    }
                },
                "pentadclimatology": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "pentad-climatology",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "sst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_max": "35.0",
                        "scale_min": "-2.0",
                        "CS": "-2",
                        "CE": "35",
                        "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                        "units": "Celsius_scale",
                        "missing_value": "NaN",
                        "file_missing_value": "-999.90002",
                        "colormap": "12632256",
                        "ncolor": "256",
                        "colorscalename": "sstcolorscale",
                        "long_name": "Sea Surface Temperature"
                    }
                },
                "monthly": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "monthly",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "ssta": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ssta",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "standard_name": "sea_surface_temperature",
                        "long_name": "Sea Surface Temperature Anomaly",
                        "maxncolor": "254",
                        "colormap": "2763429",
                        "scale_max": "4.1999998",
                        "ncolor": "254",
                        "scale_min": "-4.1999998",
                        "CS": "-4.1999998",
                        "colorscalename": "sstacolorscale",
                        "CE": "4.1999998",
                        "units": "degree_Celsius",
                        "missing_value": "NaN",
                        "expires": "1615161600",
                        "pointwidth": "1.0"
                    },
                    "sst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "expires": "1615161600",
                        "units": "Celsius_scale",
                        "colorscalename": "sstcolorscale",
                        "scale_max": "35.0",
                        "ncolor": "256",
                        "scale_min": "-2.0",
                        "colormap": "12632256",
                        "CS": "-2",
                        "CE": "35",
                        "standard_name": "sea_surface_temperature",
                        "long_name": "Sea Surface Temperature",
                        "pointwidth": "1.0"
                    },
                    "sea_ice": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sea_ice",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "expires": "1615161600",
                        "scale_max": "100",
                        "long_name": "Sea Ice Concentration",
                        "standard_name": "sea_ice_area_fraction",
                        "units": "percent",
                        "scale_min": "0",
                        "valid_max": "100",
                        "valid_min": "0",
                        "pointwidth": "1.0"
                    },
                    "mask": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mask",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "standard_name": "land_binary_mask",
                        "long_name": "Land-Sea Mask",
                        "expires": "1615161600"
                    }
                },
                "climatology": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "climatology",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "mask": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mask",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "long_name": "Land-Sea Mask"
                    },
                    "c8110": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "c8110",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "sst": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "sst",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "Celsius_scale",
                            "colormap": "12632256",
                            "scale_max": "35.0",
                            "ncolor": "256",
                            "scale_min": "-2.0",
                            "CS": "-2",
                            "colorscalename": "sstcolorscale",
                            "CE": "35",
                            "long_name": "Sea Surface Temperature",
                            "missing_value": "-9999.0"
                        }
                    },
                    "c7100": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "c7100",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "sst": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "sst",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "Celsius_scale",
                            "colormap": "12632256",
                            "scale_max": "35.0",
                            "ncolor": "256",
                            "scale_min": "-2.0",
                            "CS": "-2",
                            "colorscalename": "sstcolorscale",
                            "CE": "35",
                            "long_name": "Sea Surface Temperature",
                            "missing_value": "-999.90002"
                        }
                    },
                    "c6190": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "c6190",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "sst": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "sst",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "Celsius_scale",
                            "colormap": "12632256",
                            "scale_max": "35.0",
                            "ncolor": "256",
                            "scale_min": "-2.0",
                            "CS": "-2",
                            "colorscalename": "sstcolorscale",
                            "CE": "35",
                            "long_name": "Sea Surface Temperature",
                            "missing_value": "-999.90002"
                        }
                    }
                }
            },
            "Reyn_SmithOIv1": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Reyn_SmithOIv1",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "weekly": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "weekly",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "ssta": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ssta",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "PLOTCOAST": "1",
                        "long_name": "Sea Surface Temperature Anomaly",
                        "maxncolor": "254",
                        "colormap": "2763429",
                        "scale_max": "4.1999998",
                        "ncolor": "254",
                        "scale_min": "-4.1999998",
                        "CS": "-4.1999998",
                        "colorscalename": "sstacolorscale",
                        "CE": "4.1999998",
                        "units": "degree_Celsius",
                        "history": "T regridded on NOAA NCEP EMC CMB GLOBAL Reyn_SmithOIv1 pentad-climatology sst"
                    },
                    "sst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "Celsius_scale",
                        "colormap": "12632256",
                        "scale_max": "35.0",
                        "ncolor": "256",
                        "scale_min": "-2.0",
                        "CS": "-2",
                        "colorscalename": "sstcolorscale",
                        "CE": "35",
                        "PLOTCOAST": "1",
                        "long_name": "Sea Surface Temperature",
                        "history": "Weekly mean sea surface temperature (blended from ship, buoy, and bias-corrected satellite data)."
                    }
                },
                "pentadclimatology": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "pentad-climatology",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "sst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "Celsius_scale",
                        "colormap": "12632256",
                        "scale_max": "35.0",
                        "ncolor": "256",
                        "scale_min": "-2.0",
                        "CS": "-2",
                        "colorscalename": "sstcolorscale",
                        "CE": "35",
                        "PLOTCOAST": "1",
                        "long_name": "Sea Surface Temperature",
                        "labelinterval": "5.0",
                        "history": "Interpolated Climatological sea surface temperature (blended from ship and buoy, data (1950-1979))."
                    }
                },
                "monthly": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "monthly",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "ssta": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ssta",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_Celsius",
                        "maxncolor": "254",
                        "colormap": "2763429",
                        "history": "Monthly mean sea surface temperature anomaly (blended from ship, buoy, and bias-corrected satellite data)",
                        "scale_max": "4.1999998",
                        "ncolor": "254",
                        "scale_min": "-4.1999998",
                        "CS": "-4.1999998",
                        "colorscalename": "sstacolorscale",
                        "CE": "4.1999998",
                        "PLOTCOAST": "1",
                        "long_name": "Sea Surface Temperature Anomaly"
                    },
                    "sst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "Celsius_scale",
                        "colormap": "12632256",
                        "scale_max": "3500.0",
                        "ncolor": "256",
                        "scale_min": "-200.0",
                        "CS": "-2",
                        "colorscalename": "sstcolorscale",
                        "CE": "35",
                        "PLOTCOAST": "1",
                        "long_name": "Sea Surface Temperature",
                        "history": "Monthly mean sea surface temperature (blended from ship, buoy and bias-corrected satellite data). "
                    }
                },
                "climatology": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "climatology",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "sst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "Celsius_scale",
                        "colormap": "12632256",
                        "scale_max": "3500.0",
                        "ncolor": "256",
                        "scale_min": "-200.0",
                        "CS": "-2",
                        "colorscalename": "sstcolorscale",
                        "CE": "35",
                        "PLOTCOAST": "1",
                        "iridlhasSemantics": "iridl:climatology",
                        "long_name": "Sea Surface Temperature",
                        "references": "Reynolds_Smith1995",
                        "labelinterval": "5.0",
                        "history": "Climatological sea surface temperature (blended from ship and buoy, data (1950-1979))."
                    }
                }
            }
        },
        "leetma": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "leetma",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "v": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "history": "T:  Feb 2005 to Oct 2008 appended from NOAA NCEP EMC CMB Pacific godas v",
                "units": "cm/s",
                "long_name": "meridional velocity",
                "missing_value": "NaN"
            },
            "umag": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "umag",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "history": "T:  Feb 2005 to Oct 2008 appended from NOAA NCEP EMC CMB Pacific godas u",
                "long_name": "surface speed",
                "CI": "50.0",
                "fnname": "sqrt",
                "units": "unitless",
                "missing_value": "NaN"
            },
            "u": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "u",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "history": "T:  Feb 2005 to Oct 2008 appended from NOAA NCEP EMC CMB Pacific godas u",
                "units": "cm/s",
                "long_name": "zonal velocity",
                "missing_value": "NaN"
            },
            "d20C": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "d20C",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "colormap": "2763429",
                "scale_max": "200.0",
                "maxncolor": "254",
                "ncolor": "254",
                "scale_min": "0.0",
                "CS": "0",
                "CE": "200",
                "long_name": "Depth of 20C",
                "missing_value": "NaN",
                "history": "toS: regridded Z to NOAA NCEP EMC CMB Pacific monthly temp",
                "units": "m",
                "bounds": "Z",
                "positive": "down"
            }
        },
        "fsu": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "fsu",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "absuv": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "absuv",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "(m/s)2",
                "long_name": "meridional pseudo-stress",
                "history": ">USA-FRANCE</a></B>",
                "missing_value": "999.0",
                "arrowsperinch": "5",
                "CSCALE": "1.0"
            },
            "absuu": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "absuu",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "(m/s)2",
                "long_name": "zonal pseudo-stress",
                "history": "Monthly mean surface pseudo-stress using variational, subjective, and objective-subjective techniques in the Indian, Pacific, and Atlantic oceans.<B>USA-FRANCE</B>",
                "missing_value": "999.0",
                "arrowsperinch": "5",
                "CSCALE": "1.0"
            }
        },
        "ers1": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ers1",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "stations": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "stations",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north"
                }
            },
            "sealevel": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "sealevel",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "cm",
                "long_name": "Sea Level Anomaly",
                "history": "Annual and semiannual signals have been removed, leaving only the interannual changes relative to the April 1985-86 mean.",
                "CI": "4.0",
                "missing_value": "999.0"
            }
        },
        "canadaplots": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "canadaplots",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ]
        },
        "australiaplots": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "australiaplots",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ]
        },
        "australia": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "australia",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "v": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "meridional surface wind",
                "units": "m s-1",
                "missing_value": "396.0",
                "history": "The surface winds are calculated using boundary layer similarity theory. <b>AUSTRALIA</b>"
            },
            "u": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "u",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "zonal surface wind",
                "units": "m s-1",
                "missing_value": "396.0",
                "history": "The surface winds are calculated using boundary layer similarity theory. <b>AUSTRALIA</b>"
            }
        },
        "Y_09": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_09",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "1.0",
            "standard_name": "latitude"
        },
        "T_15": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_15",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "pointwidth": "1.0",
            "standard_name": "time",
            "calendar": "360"
        },
        "X_10": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_10",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "pointwidth": "1.0",
            "standard_name": "longitude"
        },
        "Y_08": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_08",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "1.0",
            "standard_name": "latitude"
        },
        "T_14": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_14",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "pointwidth": "1.0",
            "standard_name": "time",
            "calendar": "360"
        },
        "X_09": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_09",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "pointwidth": "4.0",
            "standard_name": "longitude"
        },
        "Y_07": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_07",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "epic_code": "500"
        },
        "time_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "X_08": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_08",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "epic_code": "502"
        },
        "Y_06": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_06",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "1.0",
            "epic_code": "500"
        },
        "time": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "time",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "depth": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "depth",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0",
            "epic_code": "3"
        },
        "X_07": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_07",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "pointwidth": "1.0",
            "epic_code": "502"
        },
        "T_13": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_13",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "pointwidth": "2.0",
            "standard_name": "time",
            "calendar": "360"
        },
        "T_12": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_12",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time"
        },
        "T_11": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_11",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0",
            "standard_name": "time"
        },
        "STA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "STA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2",
            "long_name": "Station"
        },
        "Z_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Z_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0"
        },
        "X_06": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_06",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "pointwidth": "5.0",
            "standard_name": "longitude"
        },
        "Y_05": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_05",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "2.0",
            "standard_name": "latitude"
        },
        "T_10": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_10",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "expires": "1615161600",
            "standard_name": "time"
        },
        "T_09": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_09",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "pentads since 1960-01-01",
            "gridtype": "1",
            "modulus": "73.0",
            "calendar": "365",
            "modulo": "73.0",
            "pointwidth": "1.0"
        },
        "T_08": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_08",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "expires": "1615161600",
            "pointwidth": "1.0",
            "standard_name": "time"
        },
        "X_05": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_05",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "pointwidth": "1.0",
            "standard_name": "longitude"
        },
        "T_07": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_07",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "pointwidth": "7.0",
            "standard_name": "time",
            "add_offset": "2444910.0",
            "calendar": "standard"
        },
        "T_06": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_06",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "pentads since 1960-01-01",
            "gridtype": "1",
            "calendar": "365",
            "pointwidth": "1.0",
            "standard_name": "time",
            "modulo": "73.0",
            "modulus": "73.0"
        },
        "T_05": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_05",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "pointwidth": "1.0",
            "standard_name": "time",
            "calendar": "360"
        },
        "Y_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "1.0",
            "standard_name": "latitude"
        },
        "T_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "1",
            "calendar": "360",
            "pointwidth": "1.0",
            "standard_name": "time",
            "modulo": "12.0",
            "modulus": "12.0"
        },
        "X_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "pointwidth": "1.0",
            "standard_name": "longitude"
        },
        "Z": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Z",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "m",
            "gridtype": "0",
            "positive": "down"
        },
        "Y_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "1.0",
            "standard_name": "latitude"
        },
        "T_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "X_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "pointwidth": "1.5",
            "standard_name": "longitude"
        },
        "Y_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "2.0",
            "standard_name": "latitude"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "pointwidth": "1.0",
            "standard_name": "time",
            "calendar": "360"
        },
        "X_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "pointwidth": "2.0",
            "standard_name": "longitude"
        },
        "I": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "I",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "1.0"
        },
        "Y_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "1.3333334",
            "standard_name": "latitude"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "pointwidth": "1.0",
            "standard_name": "time",
            "calendar": "360"
        },
        "X_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "pointwidth": "6.0",
            "standard_name": "longitude"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "pointwidth": "1.0",
            "standard_name": "time",
            "calendar": "360"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "1",
            "pointwidth": "2.5",
            "standard_name": "longitude"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "pointwidth": "2.5",
            "standard_name": "latitude"
        },
        "dir": "SOURCES/IGOSS"
    },
    "IITM": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "IITM",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Subdivisiondescription": "Subdivisional-level precipitation data from the IITM",
            "Subdivisiondataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IITM/.Subdivision.dataset_documentation.html",
            "SubdivisioniridlhasSemantics": "iridl:Climate_Division",
            "Subdivisionreferences": "Pant_RupaKumar1997 Parthasarathy_etal1995b Mooley_etal1981 Parthasarathy_etal1987 Parthasarathy_etal1993 Parthasarathy_etal1995",
            "RegionTemperaturelongname": "Homogeneous Indian Monthly Temperature-Regional",
            "RegionTemperaturedataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IITM/.Region.Temperature.dataset_documentation.html",
            "RegionTemperaturereferences": "Pant_RupaKumar1997 RupaKumar_etal1994",
            "RegionTemperaturedescription": "Region-level temperature data from the IITM",
            "RegionRainfalllongname": "Homogeneous Indian Monthly Rainfall-Regional",
            "RegionRainfalldataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IITM/.Region.Rainfall.dataset_documentation.html",
            "RegionRainfallreferences": "Pant_RupaKumar1997 Parthasarathy_etal1995b Mooley_etal1981 Parthasarathy_etal1987 Parthasarathy_etal1993 Parthasarathy_etal1995",
            "RegionRainfalldescription": "Region-level precipitation data from the IITM",
            "Regiondescription": "Region-level precipitation and temperature data from the IITM",
            "RegioniridlhasSemantics": "iridl:Climate_Division",
            "All_Indiav18712016Rainfalldescription": "County-level precipitation data from the IITM for 1871-2016",
            "All_Indiav18712016Rainfallinstitution": "Indian Institute of Tropical Meteorology (IITM)",
            "All_Indiav18712016RainfallPDF_document": "https://iridl.ldeo.columbia.edu/documentation/IITM/All_India/Readme_v1871-2016.pdf",
            "All_Indiav18712016Rainfallnote": " provided IITM is duly acknowledged as the data source. Any redistribution should necessarily include this document.",
            "All_Indiav18712016Rainfalllong_name": "Indian Monthly Rainfall - All_India",
            "All_Indiav18712016Rainfallreferences": "Pant_RupaKumar1997 Parthasarathy_etal1995b Mooley_etal1981 Parthasarathy_etal1987 Parthasarathy_etal1993 Parthasarathy_etal1995",
            "All_IndiaTemperaturelongname": "Indian Monthly Temperature - All_India",
            "All_IndiaTemperaturedataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IITM/.All_India.Temperature.dataset_documentation.html",
            "All_IndiaTemperaturereferences": "Pant_RupaKumar1997 RupaKumar_etal1994",
            "All_IndiaTemperaturedescription": "County-level temperature data from the IITM",
            "All_IndiaRainfalllongname": "Indian Monthly Rainfall - All_India",
            "All_IndiaRainfalldataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IITM/.All_India.Rainfall.dataset_documentation.html",
            "All_IndiaRainfallreferences": "Pant_RupaKumar1997 Parthasarathy_etal1995b Mooley_etal1981 Parthasarathy_etal1987 Parthasarathy_etal1993 Parthasarathy_etal1995",
            "All_IndiaRainfalldescription": "County-level precipitation data from the IITM",
            "All_Indiadescription": "Country-level precipitation and temperature data from the IITM",
            "description": "Indian Institute of Tropical Meteorology",
            "iridlhasSemantics": "iridl:IITM",
            "Conventions": "IRIDL"
        },
        "Subdivision": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Subdivision",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "PCPN": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "PCPN",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_factor": "0.1",
                "units": "mm",
                "long_name": "Precipitation"
            },
            "Name": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Name",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "Subdivision Name",
                "units": "unitless"
            },
            "lon": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "lon",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_min": "65.0",
                "scale_max": "98.0",
                "units": "degree_east",
                "long_name": "Longitude"
            },
            "lat": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "lat",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "scale_min": "5.0",
                "scale_max": "35.0",
                "units": "degree_north",
                "long_name": "Latitude"
            },
            "Area": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Area",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "km^2"
            }
        },
        "Region": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Region",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Temperature": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Temperature",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "TMIN": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "TMIN",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_factor": "0.1",
                    "units": "Celsius_scale",
                    "long_name": "Minimum Temperature"
                },
                "TMAX": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "TMAX",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_factor": "0.1",
                    "units": "Celsius_scale",
                    "long_name": "Maximum Temperature"
                },
                "Name": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Name",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Region Name",
                    "units": "unitless"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "65.0",
                    "scale_max": "98.0",
                    "units": "degree_east",
                    "long_name": "Longitude"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "5.0",
                    "scale_max": "35.0",
                    "units": "degree_north",
                    "long_name": "Latitude"
                }
            },
            "Rainfall": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Rainfall",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "PCPN": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "PCPN",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_factor": "0.1",
                    "units": "mm",
                    "long_name": "Precipitation"
                },
                "Name": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Name",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Region Name",
                    "units": "unitless"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "65.0",
                    "scale_max": "98.0",
                    "units": "degree_east",
                    "long_name": "Longitude"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "5.0",
                    "scale_max": "35.0",
                    "units": "degree_north",
                    "long_name": "Latitude"
                },
                "Area": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Area",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "km^2"
                }
            }
        },
        "All_India": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "All_India",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "v18712016": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v1871-2016",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Rainfall": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Rainfall",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "PCPN": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PCPN",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm/month",
                        "missing_value": "3.00000006E33",
                        "long_name": "ALL-INDIA  RAINFALL"
                    }
                }
            },
            "Temperature": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Temperature",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "TMIN": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "TMIN",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_factor": "0.1",
                    "units": "Celsius_scale",
                    "long_name": "Minimum Temperature"
                },
                "TMAX": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "TMAX",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_factor": "0.1",
                    "units": "Celsius_scale",
                    "long_name": "Maximum Temperature"
                }
            },
            "Rainfall": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Rainfall",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "PCPN": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "PCPN",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_factor": "0.1",
                    "units": "mm",
                    "long_name": "Precipitation"
                }
            }
        },
        "DIV_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "DIV_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "subdivision ids",
            "gridtype": "0",
            "long_name": "Subdivision",
            "pointwidth": "1.0"
        },
        "DIV_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "DIV_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "region ids",
            "gridtype": "0",
            "long_name": "Region",
            "pointwidth": "1.0"
        },
        "T_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "long_name": "Time",
            "pointwidth": "1.0"
        },
        "DIV": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "DIV",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "region ids",
            "gridtype": "0",
            "long_name": "Region",
            "pointwidth": "1.0"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "long_name": "Time",
            "pointwidth": "1.0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "long_name": "Time",
            "pointwidth": "1.0"
        },
        "dir": "SOURCES/IITM"
    },
    "IMD": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "IMD",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "RF0p5griddeddailyv1p0description": "IMD 0.5 Degree Daily Gridded Precipitation Data Set",
            "RF0p5griddeddailyv1p0iridlhasSemantics": "iridl:India_ERFS",
            "RF0p25griddeddailyv2p0description": "IMD 0.25 Degree Daily Gridded Precipitation Data Set",
            "RF0p25griddeddailyv2p0iridlhasSemantics": "iridl:India_ERFS",
            "RF0p25griddeddailyv19012015description": "IMD 0.25 Degree Daily Gridded Precipitation Data Set",
            "RF0p25griddeddailyv19012015iridlhasSemantics": "iridl:India_ERFS",
            "NCC12008v1p0description": "IMD High Resolution Gridded Precipitation Data Set",
            "NCC12008v1p0references": "Rajeevan_etal2008",
            "NCC12008v1p0dataset_documentation": "http://www.agu.org/journals/gl/gl0818/2008GL035143/",
            "NCC12008description": "NCC1-2008 High Resolution Gridded Precipitation Data Set",
            "NCC12008iridlhasSemantics": "iridl:India_ERFS",
            "NCC12005v4p0description": "IMD High Resolution (1&deg;x1&deg;) Daily Gridded Rainfall Data For the Indian Region 1951-2015 Version 4 (NCC1/2005)",
            "NCC12005v4p0data": "http://www.imd.ernet.in/nccraindata.htm",
            "NCC12005v4p0IMDHP": "http://www.imd.gov.in/",
            "NCC12005v4p0references": "Rajeevan_etal2005 Rajeevan_etal2006",
            "NCC12005v2p0description": "IMD High Resolution (1&deg;x1&deg;) Daily Gridded Rainfall Data For the Indian Region 1951-2004 Version 2 (NCC1/2005)",
            "NCC12005v2p0data": "http://www.imd.ernet.in/nccraindata.htm",
            "NCC12005v2p0dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IMD/.NCC1-2005.v2p0.dataset_documentation.html",
            "NCC12005v2p0IMDHP": "http://www.imd.gov.in/",
            "NCC12005v2p0references": "Rajeevan_etal2005 Rajeevan_etal2006",
            "NCC12005v1p0description": "IMD High Resolution (1&deg;x1&deg;) Daily Gridded Rainfall Data for the Indian Region, (NCC1/2005)",
            "NCC12005v1p0NCC12005": "http://iridl.ldeo.columbia.edu/SOURCES/.IMD/.NCC1-2005/.v2p0/",
            "NCC12005v1p0dataset_documentation": "http://www.imd.ernet.in/nccraindata.htm",
            "NCC12005iridlhasSemantics": "iridl:India_ERFS",
            "HRDGTv1p0description": "IMD High Resolution Daily Gridded Temperature Data Set",
            "HRDGTv1p0references": "Srivastava_etal2008",
            "HRDGTv1p0dataset_documentation": "http://www.imdpune.gov.in/ncc_rept/RESEARCH%20%20REPORT%208.pdf",
            "HRDGTv19512015_monthlydescription": "IMD High Resolution Monthly Gridded Temperature Data Set",
            "HRDGTv19512015_monthlyreferences": "Srivastava_etal2008",
            "HRDGTv19512015description": "IMD High Resolution Daily Gridded Temperature Data Set",
            "HRDGTv19512015references": "Srivastava_etal2008",
            "HRDGTdescription": "High Resolution Daily Gridded Temperature Data Set",
            "HRDGTiridlhasSemantics": "iridl:India_ERFS",
            "note": " section of this page to inquire about obtaining data directly from IMD.",
            "iridlhasSemantics": "iridl:IMD",
            "Conventions": "IRIDL",
            "IMDHP": "http://www.imd.gov.in/",
            "long_name": "India Meteorological Department"
        },
        "RF0p5": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "RF0p5",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridded": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gridded",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "daily": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "daily",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "v1p0": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "v1p0",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "rf": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "rf",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "-999.0",
                            "long_name": "GRIDDED RAINFALL",
                            "calendar": "standard",
                            "pointwidth": "1.0",
                            "standard_name": "rainfall_rate",
                            "units": "mm/day",
                            "step": "1.0"
                        }
                    }
                }
            }
        },
        "RF0p25": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "RF0p25",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "gridded": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gridded",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "daily": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "daily",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "v2p0": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "v2p0",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "rf": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "rf",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "-999.0",
                            "long_name": "GRIDDED RAINFALL",
                            "calendar": "standard",
                            "pointwidth": "1.0",
                            "standard_name": "rainfall_rate",
                            "units": "mm/day",
                            "step": "1.0"
                        }
                    },
                    "v19012015": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "v1901-2015",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "stn": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "stn",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "0.0",
                            "long_name": "Number of Stations",
                            "calendar": "standard",
                            "pointwidth": "1.0",
                            "units": "count",
                            "step": "1.0"
                        },
                        "rf": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "rf",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "-999.0",
                            "long_name": "GRIDDED RAINFALL",
                            "calendar": "standard",
                            "pointwidth": "1.0",
                            "standard_name": "rainfall_rate",
                            "units": "mm/day",
                            "step": "1.0"
                        }
                    }
                }
            }
        },
        "NCC12008": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NCC1-2008",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "v1p0": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v1p0",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "rf": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rf",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.0",
                    "long_name": "GRIDDED RAINFALL",
                    "calendar": "standard",
                    "pointwidth": "1.0",
                    "standard_name": "rainfall_rate",
                    "units": "mm/day",
                    "step": "1.0"
                }
            }
        },
        "NCC12005": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NCC1-2005",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "v4p0": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v4p0",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "stn": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "stn",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "0.0",
                    "long_name": "Number of stations",
                    "calendar": "standard",
                    "pointwidth": "1.0",
                    "units": "unitless",
                    "step": "1.0"
                },
                "rf": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rf",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-99.900002",
                    "long_name": "GRIDDED RAINFALL",
                    "calendar": "standard",
                    "pointwidth": "1.0",
                    "standard_name": "rainfall_rate",
                    "units": "mm/day",
                    "step": "1.0"
                }
            },
            "v2p0": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v2p0",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "rf": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rf",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-99.900002",
                    "long_name": "GRIDDED RAINFALL",
                    "calendar": "standard",
                    "pointwidth": "1.0",
                    "standard_name": "rainfall_rate",
                    "units": "mm/day",
                    "step": "1.0"
                }
            },
            "v1p0": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v1p0",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "rf": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rf",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-99.900002",
                    "long_name": "GRIDDED RAINFALL",
                    "calendar": "standard",
                    "pointwidth": "1.0",
                    "standard_name": "rainfall_rate",
                    "units": "mm/day",
                    "step": "1.0"
                }
            }
        },
        "HRDGT": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "HRDGT",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "v1p0": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v1p0",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "tmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "99.900002",
                    "calendar": "standard",
                    "long_name": "Minimum Temperature",
                    "pointwidth": "1.0",
                    "standard_name": "air_temperature",
                    "units": "Celsius_scale",
                    "step": "1.0"
                },
                "tmean": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tmean",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "99.900002",
                    "calendar": "standard",
                    "long_name": "Mean Temperature",
                    "pointwidth": "1.0",
                    "standard_name": "air_temperature",
                    "units": "Celsius_scale",
                    "step": "1.0"
                },
                "tmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "99.900002",
                    "calendar": "standard",
                    "long_name": "Maximum Temperature",
                    "pointwidth": "1.0",
                    "standard_name": "air_temperature",
                    "units": "Celsius_scale",
                    "step": "1.0"
                }
            },
            "v19512015_monthly": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v1951-2015_monthly",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "tmean_climo": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tmean_climo",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Temperature Monthly Climatology 1951-2015",
                    "history": "Averaged over T2[1951, 2015] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "units": "Celsius_scale",
                    "file_missing_value": "99.900002",
                    "calendar": "standard",
                    "pointwidth": "1.0",
                    "standard_name": "air_temperature",
                    "step": "1.0"
                },
                "tmean": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tmean",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Temperature Monthly Average",
                    "missing_value": "NaN",
                    "history": "Boxes with less than 0.0% dropped",
                    "units": "Celsius_scale",
                    "file_missing_value": "99.900002",
                    "calendar": "standard",
                    "pointwidth": "1.0",
                    "standard_name": "air_temperature",
                    "step": "1.0"
                }
            },
            "v19512015": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "v1951-2015",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "tmin": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tmin",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "99.900002",
                    "calendar": "standard",
                    "long_name": "Minimum Temperature",
                    "pointwidth": "1.0",
                    "standard_name": "air_temperature",
                    "units": "Celsius_scale",
                    "step": "1.0"
                },
                "tmean": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tmean",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "99.900002",
                    "calendar": "standard",
                    "long_name": "Mean Temperature",
                    "pointwidth": "1.0",
                    "standard_name": "air_temperature",
                    "units": "Celsius_scale",
                    "step": "1.0"
                },
                "tmax": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "tmax",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "99.900002",
                    "calendar": "standard",
                    "long_name": "Maximum Temperature",
                    "pointwidth": "1.0",
                    "standard_name": "air_temperature",
                    "units": "Celsius_scale",
                    "step": "1.0"
                }
            }
        },
        "X_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.5"
        },
        "Y_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.5"
        },
        "T_10": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_10",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_09": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_09",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "0.25"
        },
        "Y_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "0.25"
        },
        "T_08": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_08",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_07": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_07",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_06": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_06",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1951-01-01 12:00:00",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "Y_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "1.0"
        },
        "T_05": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_05",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1951-01-01 12:00:00",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1951-01-01 12:00:00",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "X_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "1.0"
        },
        "Y_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "1.0"
        },
        "T_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "1",
            "modulo": "12.0",
            "modulus": "12.0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "pointwidth": "1.0"
        },
        "X": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "X",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_east",
            "gridtype": "0",
            "standard_name": "longitude",
            "pointwidth": "1.0"
        },
        "Y": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Y",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "degree_north",
            "gridtype": "0",
            "standard_name": "latitude",
            "pointwidth": "1.0"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "dir": "SOURCES/IMD"
    },
    "INIA": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "INIA",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "GRASExpStationsMonthlyData_Source": "http://www.inia.org.uy/online/site/143782I1.php",
            "GRASExpStationsMonthlydescription": "Monthly meteorological observations in Uruguay from INIA experimental stations",
            "GRASExpStationsMonthlydataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.INIA/.GRAS.ExpStations.Monthly.dataset_documentation.html",
            "GRASExpStationsDailyData_Source": "http://www.inia.org.uy/online/site/143782I1.php",
            "GRASExpStationsDailydescription": "Daily meteorological observations in Uruguay from INIA experimental stations",
            "GRASExpStationsDailydataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.INIA/.GRAS.ExpStations.Daily.dataset_documentation.html",
            "GRASExpStationsdescription": "INIA Experimental Stations",
            "GRASDNMdescription": "Data from Direcci&#xF3;n Nacional de Meteorolog&#xED;a Uruguay",
            "GRASGRAS_Home": "http://www.inia.uy/gras/",
            "description": "Instituto Nacional de Investigaci&#243;n Agropecuaria - Uruguay",
            "iridlhasSemantics": "iridl:INIA",
            "Conventions": "IRIDL"
        },
        "GRAS": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "GRAS",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "ExpStations": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ExpStations",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Monthly": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Monthly",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "wind": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "wind",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "km/day",
                        "missing_value": "-99.900002",
                        "long_name": "Wind"
                    },
                    "tempmin": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tempmin",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "Celsius_scale",
                        "missing_value": "-99.900002",
                        "long_name": "Minimum Temperature"
                    },
                    "tempmax": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tempmax",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "Celsius_scale",
                        "missing_value": "-99.900002",
                        "long_name": "Maximum Temperature"
                    },
                    "tempavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tempavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "Celsius_scale",
                        "missing_value": "-99.900002",
                        "long_name": "Average Temperature"
                    },
                    "sun": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sun",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hrs",
                        "missing_value": "-99.900002",
                        "long_name": "Hours of Sun"
                    },
                    "rh": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rh",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "percent",
                        "missing_value": "-99.900002",
                        "long_name": "Relative Humidity"
                    },
                    "pet": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pet",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm",
                        "missing_value": "-99.900002",
                        "long_name": "Potential Evapotranspiration"
                    },
                    "pcpn": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pcpn",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm",
                        "missing_value": "-99.900002",
                        "long_name": "Precipitation"
                    },
                    "Name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless"
                    },
                    "lon": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lon",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "-65.0",
                        "scale_max": "-45.0",
                        "units": "degree_east",
                        "long_name": "longitude"
                    },
                    "lat": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lat",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "-45.0",
                        "scale_max": "-25.0",
                        "units": "degree_north",
                        "long_name": "latitude"
                    },
                    "evap": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "evap",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm",
                        "missing_value": "-99.900002",
                        "long_name": "Pan Evaporation"
                    },
                    "elev": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "elev",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "m",
                        "long_name": "elevation"
                    }
                },
                "Daily": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Daily",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "wind": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "wind",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "km/day",
                        "missing_value": "-99.900002",
                        "long_name": "Wind"
                    },
                    "tempmin": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tempmin",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "Celsius_scale",
                        "missing_value": "-99.900002",
                        "long_name": "Minimum Temperature"
                    },
                    "tempmax": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tempmax",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "Celsius_scale",
                        "missing_value": "-99.900002",
                        "long_name": "Maximum Temperature"
                    },
                    "tempavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tempavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "Celsius_scale",
                        "missing_value": "-99.900002",
                        "long_name": "Average Temperature"
                    },
                    "sun": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sun",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hrs",
                        "missing_value": "-99.900002",
                        "long_name": "Hours of Sun"
                    },
                    "rh": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rh",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "percent",
                        "missing_value": "-99.900002",
                        "long_name": "Relative Humidity"
                    },
                    "pet": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pet",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm",
                        "missing_value": "-99.900002",
                        "long_name": "Potential Evapotranspiration"
                    },
                    "pcpn": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pcpn",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm",
                        "missing_value": "-99.900002",
                        "long_name": "Precipitation"
                    },
                    "Name": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Name",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless"
                    },
                    "lon": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lon",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "-65.0",
                        "scale_max": "-45.0",
                        "units": "degree_east",
                        "long_name": "longitude"
                    },
                    "lat": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lat",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "-45.0",
                        "scale_max": "-25.0",
                        "units": "degree_north",
                        "long_name": "latitude"
                    },
                    "evap": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "evap",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm",
                        "missing_value": "-99.900002",
                        "long_name": "Pan Evaporation"
                    },
                    "elev": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "elev",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "m",
                        "long_name": "elevation"
                    }
                }
            },
            "DNM": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "DNM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Stations": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Stations",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Monthly": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Monthly",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "prcp": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "prcp",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "-999.0",
                            "long_name": "Precipitation",
                            "units": "mm/month",
                            "standard_name": "lwe_precipitation_rate"
                        },
                        "Name": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Name",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids"
                        },
                        "lon": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lon",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "-59.5",
                            "missing_value": "-9.0",
                            "scale_max": "-52.5",
                            "units": "degree_east",
                            "long_name": "longitude"
                        },
                        "lat": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lat",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "-35.5",
                            "missing_value": "-9.0",
                            "scale_max": "-29.5",
                            "units": "degree_north",
                            "long_name": "latitude"
                        },
                        "IWMO": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "IWMO",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "-999",
                            "units": "ids"
                        }
                    }
                }
            }
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "julian_day",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "ISTA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ISTA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "STNID": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "STNID",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2"
        },
        "dir": "SOURCES/INIA"
    },
    "INMET": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "INMET",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "sologeodescription": "Solo geo do Brazil",
            "description": "Instituto Nacional de Meteorologia do Brasil",
            "Conventions": "IRIDL"
        },
        "sologeo": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "sologeo",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "the_google": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "the_google",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "the google",
                "units": "ids",
                "PGtype": "varchar"
            },
            "the_geom": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "the_geom",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "geometry",
                "units": "unitless",
                "PGtype": "bytea",
                "OpenGISSimpleFeature": "MULTIPOLYGON",
                "SpatialReferenceSystemWKT": "]]"
            },
            "slgsubclas": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "slgsubclas",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "sub classe solo geo",
                "units": "ids",
                "PGtype": "varchar"
            },
            "slgdescric": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "slgdescric",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "descri\\xc3\\xa7\\xc3\\xa3o solo geo",
                "units": "ids",
                "PGtype": "varchar"
            },
            "slgcodigo": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "slgcodigo",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "codigo solo geo",
                "missing_value": "NaN",
                "units": "unitless",
                "PGtype": "float8"
            },
            "slgclasse": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "slgclasse",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "long_name": "classe solo geo",
                "units": "ids",
                "PGtype": "varchar"
            }
        },
        "Forecast": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "Forecast",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "rain": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "rain",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "rain_HW": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rain_HW",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "rain forecast by HOLTWINTERS",
                    "units": "mm",
                    "missing_value": "-999.0"
                },
                "rain_CPT": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rain_CPT",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "rain forecast by CPT",
                    "units": "mm",
                    "missing_value": "-999.0"
                },
                "rain_ARIMA": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rain_ARIMA",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "rain forecast by ARIMA",
                    "units": "mm",
                    "missing_value": "-999.0"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "-34.0",
                    "long_name": "Longitude",
                    "units": "degree_east",
                    "scale_min": "-74.0",
                    "missing_value": "-999.0"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "6.0",
                    "long_name": "Latitude",
                    "units": "degree_north",
                    "scale_min": "-34.0",
                    "missing_value": "-999.0"
                },
                "Cor_HW": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Cor_HW",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "-1.0",
                    "scale_max": "1.0",
                    "CE": "1",
                    "CS": "-1",
                    "ncolor": "254",
                    "colorscalename": "correlationcolorscale",
                    "maxncolor": "254",
                    "colormap": "2763429",
                    "long_name": "correlation hindcast for HOLTWINTERS",
                    "missing_value": "-999.0",
                    "units": "unitless"
                },
                "Cor_CPT": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Cor_CPT",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "-1.0",
                    "scale_max": "1.0",
                    "CE": "1",
                    "CS": "-1",
                    "ncolor": "254",
                    "colorscalename": "correlationcolorscale",
                    "maxncolor": "254",
                    "colormap": "2763429",
                    "long_name": "correlation hindcast for CPT",
                    "missing_value": "-999.0",
                    "units": "unitless"
                },
                "Cor_ARIMA": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Cor_ARIMA",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "-1.0",
                    "scale_max": "1.0",
                    "CE": "1",
                    "CS": "-1",
                    "ncolor": "254",
                    "colorscalename": "correlationcolorscale",
                    "maxncolor": "254",
                    "colormap": "2763429",
                    "long_name": "correlation hindcast for ARIMA",
                    "missing_value": "-999.0",
                    "units": "unitless"
                }
            },
            "historical": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "historical",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Rio_Grande_do_Sul": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Rio_Grande_do_Sul",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "rain": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "rain",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm",
                        "long_name": "Historical rainfall"
                    },
                    "lon": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lon",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_max": "-48.0",
                        "scale_min": "-58.0",
                        "units": "degree_east",
                        "long_name": "Longitude"
                    },
                    "lat": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lat",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_max": "-26.0",
                        "scale_min": "-34.0",
                        "units": "degree_north",
                        "long_name": "Latitude"
                    }
                }
            },
            "CPT": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CPT",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "target_date": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "target_date",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "forecast time",
                    "pointwidth": "1",
                    "calendar": "360",
                    "units": "months since 1960-01-01",
                    "bounds": "S"
                },
                "rain_vvel": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rain_vvel",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "rain forecast by VERTICAL VELOCITY",
                    "units": "mm",
                    "pointwidth": "0"
                },
                "rain_tsm": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rain_tsm",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "rain forecast by TSM",
                    "units": "mm",
                    "pointwidth": "0"
                },
                "rain_geo": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rain_geo",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "rain forecast by GEOPOTENTIAL HEIGHT",
                    "units": "mm",
                    "pointwidth": "0"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "-34.0",
                    "long_name": "Longitude",
                    "units": "degree_east",
                    "scale_min": "-74.0",
                    "pointwidth": "0"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "6.0",
                    "long_name": "Latitude",
                    "units": "degree_north",
                    "scale_min": "-34.0",
                    "pointwidth": "0"
                },
                "Cor_vvel": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Cor_vvel",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "-1.0",
                    "scale_max": "1.0",
                    "CE": "1",
                    "CS": "-1",
                    "ncolor": "254",
                    "colorscalename": "correlationcolorscale",
                    "maxncolor": "254",
                    "colormap": "2763429",
                    "long_name": "correlation hindcast for VERTICAL VELOCITY",
                    "units": "unitless",
                    "pointwidth": "0"
                },
                "Cor_tsm": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Cor_tsm",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "-1.0",
                    "scale_max": "1.0",
                    "CE": "1",
                    "CS": "-1",
                    "ncolor": "254",
                    "colorscalename": "correlationcolorscale",
                    "maxncolor": "254",
                    "colormap": "2763429",
                    "long_name": "correlation hindcast for TSM",
                    "units": "unitless",
                    "pointwidth": "0"
                },
                "Cor_geo": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Cor_geo",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_min": "-1.0",
                    "scale_max": "1.0",
                    "CE": "1",
                    "CS": "-1",
                    "ncolor": "254",
                    "colorscalename": "correlationcolorscale",
                    "maxncolor": "254",
                    "colormap": "2763429",
                    "long_name": "correlation hindcast for GEOPOTENTIAL HEIGHT",
                    "units": "unitless",
                    "pointwidth": "0"
                }
            }
        },
        "DataBank": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "DataBank",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "Rio_Grande_do_Sul": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Rio_Grande_do_Sul",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "vel_vento_med": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "vel_vento_med",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Velocidade M\\xc3\\xa9dia do Vento",
                    "units": "m/s",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "umidade_med": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "umidade_med",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Umidade Relativa do Ar M\\xc3\\xa9dia",
                    "units": "percent",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "temp_min": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp_min",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Temperatura M\\xc3\\xadnima",
                    "units": "Celsius_scale",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "temp_med": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp_med",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Temperatura M\\xc3\\xa9dia Compensada",
                    "units": "Celsius_scale",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "temp_max": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp_max",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Temperatura M\\xc3\\xa1xima",
                    "units": "Celsius_scale",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "pressao_med": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "pressao_med",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Press\\xc3\\xa3o M\\xc3\\xa9dia ao N\\xc3\\xadvel da Esta\\xc3\\xa7\\xc3\\xa3o",
                    "units": "mb",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "precipitacao": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "precipitacao",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Precipita\\xc3\\xa7\\xc3\\xa3o Total Di\\xc3\\xa1ria",
                    "units": "mm",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "-48.0",
                    "long_name": "Longitude",
                    "units": "degree_east",
                    "scale_min": "-58.0",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "location": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "location",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "OpenGISSimpleFeature": "Point",
                    "long_name": "location",
                    "SpatialReferenceSystemWKT": "]]",
                    "scale_max": "-48",
                    "units": "degree_east",
                    "scale_min": "-58",
                    "pointwidth": "1.0"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "-26.0",
                    "long_name": "Latitude",
                    "units": "degree_north",
                    "scale_min": "-34.0",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "insolacao": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "insolacao",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Insola\\xc3\\xa7\\xc3\\xa3o Total Di\\xc3\\xa1rio",
                    "units": "h",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "evaporacao_piche": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "evaporacao_piche",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Evapora\\xc3\\xa7\\xc3\\xa3o de Piche",
                    "units": "mm",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "elev": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "elev",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "elevation",
                    "units": "m",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "Completos": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Completos",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "vel_vento_med": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "vel_vento_med",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-999.0",
                        "long_name": "Velocidade M\\xc3\\xa9dia do Vento",
                        "units": "m/s"
                    },
                    "umidade_med": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "umidade_med",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-999.0",
                        "long_name": "Umidade Relativa do Ar M\\xc3\\xa9dia",
                        "units": "percent"
                    },
                    "temp_min": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "temp_min",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-999.0",
                        "long_name": "Temperatura M\\xc3\\xadnima",
                        "units": "Celsius_scale"
                    },
                    "temp_med": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "temp_med",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-999.0",
                        "long_name": "Temperatura M\\xc3\\xa9dia Compensada",
                        "units": "Celsius_scale"
                    },
                    "temp_max": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "temp_max",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-999.0",
                        "long_name": "Temperatura M\\xc3\\xa1xima",
                        "units": "Celsius_scale"
                    },
                    "precipitacao": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "precipitacao",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-999.0",
                        "long_name": "Precipita\\xc3\\xa7\\xc3\\xa3o Total Di\\xc3\\xa1ria",
                        "units": "mm"
                    },
                    "lon": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lon",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_max": "-48.0",
                        "long_name": "Longitude",
                        "units": "degree_east",
                        "scale_min": "-58.0"
                    },
                    "location": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "location",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "OpenGISSimpleFeature": "Point",
                        "SpatialReferenceSystemWKT": "]]",
                        "long_name": "location",
                        "scale_max": "-48",
                        "units": "degree_east",
                        "scale_min": "-58"
                    },
                    "lat": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lat",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_max": "-26.0",
                        "long_name": "Latitude",
                        "units": "degree_north",
                        "scale_min": "-34.0"
                    },
                    "insolacao": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "insolacao",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "-999.0",
                        "long_name": "Insola\\xc3\\xa7\\xc3\\xa3o Total Di\\xc3\\xa1rio",
                        "units": "h"
                    },
                    "elev": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "elev",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "elevation",
                        "units": "m"
                    }
                }
            },
            "ESTACOES_CONVENCIONAIS": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ESTACOES_CONVENCIONAIS",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "vel_vento_med": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "vel_vento_med",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Velocidade M\\xc3\\xa9dia do Vento",
                    "units": "m/s",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "umidade_med": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "umidade_med",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Umidade Relativa do Ar M\\xc3\\xa9dia",
                    "units": "percent",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "temp_min": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp_min",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Temperatura M\\xc3\\xadnima",
                    "units": "Celsius_scale",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "temp_med": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp_med",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Temperatura M\\xc3\\xa9dia Compensada",
                    "units": "Celsius_scale",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "temp_max": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp_max",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Temperatura M\\xc3\\xa1xima",
                    "units": "Celsius_scale",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "pressao_med": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "pressao_med",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Press\\xc3\\xa3o M\\xc3\\xa9dia ao N\\xc3\\xadvel da Esta\\xc3\\xa7\\xc3\\xa3o",
                    "units": "mb",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "precipitacao": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "precipitacao",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Precipita\\xc3\\xa7\\xc3\\xa3o Total Di\\xc3\\xa1ria",
                    "units": "mm",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "-34.0",
                    "long_name": "Longitude",
                    "units": "degree_east",
                    "scale_min": "-74.0",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "6.0",
                    "long_name": "Latitude",
                    "units": "degree_north",
                    "scale_min": "-34.0",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "insolacao": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "insolacao",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Insola\\xc3\\xa7\\xc3\\xa3o Total Di\\xc3\\xa1rio",
                    "units": "h",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "evaporaxc3xa7xc3xa3o_piche": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "evapora\\xc3\\xa7\\xc3\\xa3o_piche",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Evapora\\xc3\\xa7\\xc3\\xa3o de Piche",
                    "units": "mm",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "elev": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "elev",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "elevation",
                    "units": "m",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                }
            },
            "ESTACOES_AUTOMATICAS": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ESTACOES_AUTOMATICAS",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "vel_vento_med": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "vel_vento_med",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Velocidade M\\xc3\\xa9dia do Vento",
                    "units": "m/s",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "umidade_min": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "umidade_min",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Umidade Relativa do Ar M\\xc3\\xadnima",
                    "units": "percent",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "umidade_med": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "umidade_med",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Umidade Relativa do Ar M\\xc3\\xa9dia",
                    "units": "percent",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "umidade_max": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "umidade_max",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Umidade Relativa do Ar M\\xc3\\xa1xima",
                    "units": "percent",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "temp_min_po": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp_min_po",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Temperatura Minina de Ponto de Orvalho",
                    "units": "Celsius_scale",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "temp_min": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp_min",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Temperatura M\\xc3\\xadnima",
                    "units": "Celsius_scale",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "temp_med": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp_med",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Temperatura M\\xc3\\xa9dia",
                    "units": "Celsius_scale",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "temp_max": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "temp_max",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Temperatura M\\xc3\\xa1xima",
                    "units": "Celsius_scale",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "raj_vento_max": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "raj_vento_max",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Rajada M\\xc3\\xa1xima de Vento",
                    "units": "m/s",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "radiacao": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "radiacao",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Radia\\xc3\\xa7\\xc3\\xa3o Global",
                    "missing_value": "-999.0",
                    "units": "unitless",
                    "pointwidth": "1.0"
                },
                "pressao_min": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "pressao_min",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Press\\xc3\\xa3o M\\xc3\\xadnima ao N\\xc3\\xadvel da Esta\\xc3\\xa7\\xc3\\xa3o",
                    "units": "mb",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "pressao_med": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "pressao_med",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Press\\xc3\\xa3o M\\xc3\\xa9dia ao N\\xc3\\xadvel da Esta\\xc3\\xa7\\xc3\\xa3o",
                    "units": "mb",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "pressao_max": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "pressao_max",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Press\\xc3\\xa3o M\\xc3\\xa1xima ao N\\xc3\\xadvel da Esta\\xc3\\xa7\\xc3\\xa3o",
                    "units": "mb",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "precipitacao_max": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "precipitacao_max",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Precipita\\xc3\\xa7\\xc3\\xa3o M\\xc3\\xa1xima",
                    "missing_value": "-999.0",
                    "units": "unitless",
                    "pointwidth": "1.0"
                },
                "precipitacao": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "precipitacao",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "Precipita\\xc3\\xa7\\xc3\\xa3o Total Di\\xc3\\xa1ria",
                    "units": "mm",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "-34.0",
                    "long_name": "Longitude",
                    "units": "degree_east",
                    "scale_min": "-74.0",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "6.0",
                    "long_name": "Latitude",
                    "units": "degree_north",
                    "scale_min": "-34.0",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                },
                "elev": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "elev",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "long_name": "elevation",
                    "units": "m",
                    "missing_value": "-999.0",
                    "pointwidth": "1.0"
                }
            }
        },
        "gid": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "gid",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "1.0"
        },
        "T_04": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_04",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "standard_name": "time",
            "long_name": "Forecast Time",
            "pointwidth": "3"
        },
        "T_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "long_name": "Time",
            "standard_name": "time",
            "pointwidth": "1.0",
            "poinwidth": "1"
        },
        "L": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "L",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months",
            "gridtype": "0",
            "pointwidth": "1"
        },
        "S": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "S",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "months since 1960-01-01",
            "gridtype": "0",
            "calendar": "360",
            "long_name": "Forecast Start Time",
            "pointwidth": "0"
        },
        "WMOID_03": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "WMOID_03",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2"
        },
        "T_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1960-01-01",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "T_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1960-01-01",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "WMOID_02": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "WMOID_02",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2"
        },
        "WMOID_01": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "WMOID_01",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2"
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1960-01-01",
            "gridtype": "0",
            "calendar": "standard",
            "standard_name": "time",
            "pointwidth": "1.0"
        },
        "WMOID": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "WMOID",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "ids",
            "gridtype": "2"
        },
        "dir": "SOURCES/INMET"
    },
    "INPE": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/INPE",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "INPE",
        "restriction": "Public",
        "CPTEC": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/INPE/CPTEC",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "CPTEC",
            "restriction": "Public",
            "latam": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/INPE/CPTEC/latam",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "latam",
                "restriction": "Public",
                "CoSch": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/INPE/CPTEC/latam/CoSch",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "CoSch",
                    "restriction": "Public",
                    "daily": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "daily",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NC_GLOBAL": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NC_GLOBAL",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Conventions": "IRIDL"
                        },
                        "rainfall": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "rainfall",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "0.0",
                            "CS": "0",
                            "maxncolor": "254",
                            "colorscalename": "precip_colors",
                            "colormap": "290304",
                            "ncolor": "254",
                            "missing_value": "-9999.0",
                            "long_name": "Rainfall",
                            "units": "mm/day",
                            "pointwidth": "1.0"
                        },
                        "Y": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Y",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_north",
                            "gridtype": "0",
                            "standard_name": "latitude",
                            "long_name": "Latitude",
                            "pointwidth": "0.25"
                        },
                        "T": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "T",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "days since 1960-01-01",
                            "gridtype": "0",
                            "calendar": "standard",
                            "standard_name": "time",
                            "pointwidth": "1.0"
                        },
                        "X": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "X",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_east",
                            "gridtype": "0",
                            "standard_name": "longitude",
                            "long_name": "Longitude",
                            "pointwidth": "0.25"
                        },
                        "dir": "SOURCES/INPE/CPTEC/latam/CoSch/daily"
                    },
                    "monthly": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "monthly",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NC_GLOBAL": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NC_GLOBAL",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Conventions": "IRIDL"
                        },
                        "rainfall": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "rainfall",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "0.0",
                            "CS": "0",
                            "long_name": "Rainfall",
                            "missing_value": "NaN",
                            "units": "mm/month",
                            "history": "Boxes with less than 0.0% dropped",
                            "file_missing_value": "-9999.0",
                            "maxncolor": "254",
                            "colorscalename": "precip_colors",
                            "colormap": "290304",
                            "ncolor": "254",
                            "pointwidth": "1.0"
                        },
                        "Y": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Y",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_north",
                            "gridtype": "0",
                            "standard_name": "latitude",
                            "long_name": "Latitude",
                            "pointwidth": "0.25"
                        },
                        "T": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "T",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "months since 1960-01-01",
                            "gridtype": "0",
                            "calendar": "360"
                        },
                        "X": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "X",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_east",
                            "gridtype": "0",
                            "standard_name": "longitude",
                            "long_name": "Longitude",
                            "pointwidth": "0.25"
                        },
                        "dir": "SOURCES/INPE/CPTEC/latam/CoSch/monthly"
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "daily",
                        "monthly"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "CoSch"
                ]
            },
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type",
                "latam"
            ]
        },
        "banned_long": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type",
            "CPTEC"
        ]
    },
    "IPB": {
        "iridl_type": "DataSet",
        "iridl_ds_name": "IPB",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "NC_GLOBAL": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "NC_GLOBAL",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "CCROMASEAN_Compendiumtitle": "Indonesia Station Rainfall Observations (from ASEAN Compedium)",
            "CCROMASEAN_CompendiumDescription": "Compilation of station rainfall data over Indonesia 1975--1999 , from ASEAN Compedium database.Compiled by A. Faqih (akhmadfaqih@gmail.com).",
            "description": "Institut Pertanian Bogor",
            "Conventions": "IRIDL"
        },
        "CCROM": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "CCROM",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "ASEAN_Compendium": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ASEAN_Compendium",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "prec": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "prec",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.0",
                    "units": "mm",
                    "long_name": "precipitation_amount"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.0",
                    "scale_max": "141.0",
                    "units": "degree_east",
                    "long_name": "longitude",
                    "scale_min": "95.0"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.0",
                    "scale_min": "-11.0",
                    "units": "degree_north",
                    "long_name": "latitude",
                    "scale_max": "6.0"
                },
                "elev": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "elev",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "-999.0",
                    "units": "m",
                    "long_name": "elevation"
                }
            }
        },
        "T": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "T",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "days since 1974-12-31 12:00",
            "gridtype": "0",
            "calendar": "standard",
            "long_name": "time",
            "pointwidth": "1.0"
        },
        "ISTA": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "ISTA",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "units": "unitless",
            "gridtype": "0",
            "pointwidth": "1.0"
        },
        "dir": "SOURCES/IPB"
    },
    "IPC": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/IPC",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "IPC",
        "restriction": "Public",
        "CurSit": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/IPC/CurSit",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "CurSit",
            "restriction": "Public",
            "EAF": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "EAF",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "eaf202010description": "October 2020",
                    "eaf202006description": "June 2020",
                    "eaf202002description": "February 2020",
                    "eaf201910description": "October 2019",
                    "eaf201906description": "June 2019",
                    "eaf201902description": "February 2019",
                    "eaf201810description": "October 2018",
                    "eaf201806description": "June 2018",
                    "eaf201802description": "February 2018",
                    "eaf201710description": "October 2017",
                    "eaf201706description": "June 2017",
                    "eaf201702description": "February 2017",
                    "eaf201610description": "October 2016",
                    "eaf201606description": "June 2016",
                    "eaf201602description": "February 2016",
                    "eaf201510description": "October 2015",
                    "eaf201507description": "July 2015",
                    "eaf201504description": "April 2015",
                    "eaf201501description": "January 2015",
                    "eaf201410description": "October 2014",
                    "eaf201407description": "July 2014",
                    "eaf201404description": "April 2014",
                    "eaf201401description": "January 2014",
                    "eaf201310description": "October 2013",
                    "eaf201307description": "July 2013",
                    "eaf201304description": "April 2013",
                    "eaf201301description": "January 2013",
                    "eaf201210description": "October 2012",
                    "eaf201207description": "July 2012",
                    "eaf201204description": "April 2012",
                    "eaf201201description": "January 2012",
                    "eaf201110description": "October 2011",
                    "eaf201107description": "July 2011",
                    "eaf201104description": "April 2011",
                    "eaf201101description": "January 2011",
                    "eaf201010description": "October 2010",
                    "eaf201007description": "July 2010",
                    "eaf201004description": "April 2010",
                    "eaf201001description": "January 2010",
                    "eaf200910description": "October 2009",
                    "eaf200907description": "July 2009",
                    "Conventions": "IRIDL",
                    "description": "East Africa - Acute Food Insecurity Phase"
                },
                "eaf202010": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf202010",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "PGtype": "float8"
                    }
                },
                "eaf202006": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf202006",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "PGtype": "float8"
                    }
                },
                "eaf202002": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf202002",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "PGtype": "float8"
                    }
                },
                "eaf201910": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201910",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "PGtype": "float8"
                    }
                },
                "eaf201906": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201906",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "PGtype": "float8"
                    }
                },
                "eaf201902": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201902",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "PGtype": "float8"
                    }
                },
                "eaf201810": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201810",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "PGtype": "float8"
                    }
                },
                "eaf201806": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201806",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "PGtype": "float8"
                    }
                },
                "eaf201802": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201802",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "PGtype": "float8"
                    }
                },
                "eaf201710": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201710",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "PGtype": "float8"
                    }
                },
                "eaf201706": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201706",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "PGtype": "float8"
                    }
                },
                "eaf201702": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201702",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "PGtype": "float8"
                    }
                },
                "eaf201610": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201610",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201606": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201606",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201602": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201602",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201510": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201510",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201507": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201507",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201504": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201504",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201501": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201501",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201410": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201410",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201407": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201407",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201404": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201404",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201401": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201401",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201310": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201310",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201307": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201307",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201304": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201304",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201301": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201301",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201210": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201210",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201207": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201207",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201204": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201204",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201201": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201201",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201110": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201110",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201107": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201107",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201104": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201104",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201101": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201101",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201010": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201010",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201007": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201007",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201004": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201004",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf201001": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf201001",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf200910": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf200910",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "eaf200907": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eaf200907",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "PGtype": "int4"
                    }
                },
                "gid_07": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_07",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/IPC/CurSit/EAF"
            },
            "EAF_gridded": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/IPC/CurSit/EAF_gridded",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "EAF_gridded",
                "restriction": "Public",
                "EAF_0p01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "EAF_0p01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "Conventions": "IRIDL"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Integrated Phase Classification Gridded",
                        "scale_min": "1.0",
                        "scale_max": "5.0",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "ncolor": "254",
                        "CS": "1",
                        "CE": "5",
                        "units": "unitless",
                        "history": "Boxes with less than 0.0% dropped",
                        "missing_value": "NaN",
                        "file_missing_value": "99",
                        "PGtype": "int4"
                    },
                    "T": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "T",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "1"
                    },
                    "Y": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Y",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_north",
                        "gridtype": "0",
                        "pointwidth": "0.01",
                        "long_name": "Latitude"
                    },
                    "X": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "X",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_east",
                        "gridtype": "0",
                        "pointwidth": "0.01",
                        "long_name": "Longitude"
                    },
                    "dir": "SOURCES/IPC/CurSit/EAF_gridded/EAF_0p01"
                },
                "EAF_0p1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "EAF_0p1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "Conventions": "IRIDL"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Integrated Phase Classification Gridded",
                        "scale_min": "1.0",
                        "scale_max": "5.0",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "ncolor": "254",
                        "CS": "1",
                        "CE": "5",
                        "units": "unitless",
                        "history": "Boxes with less than 0.0% dropped",
                        "missing_value": "NaN",
                        "file_missing_value": "99",
                        "PGtype": "int4"
                    },
                    "T": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "T",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "1"
                    },
                    "Y": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Y",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_north",
                        "gridtype": "0",
                        "pointwidth": "0.1",
                        "long_name": "Latitude"
                    },
                    "X": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "X",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_east",
                        "gridtype": "0",
                        "pointwidth": "0.1",
                        "long_name": "Longitude"
                    },
                    "dir": "SOURCES/IPC/CurSit/EAF_gridded/EAF_0p1"
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "EAF_0p01",
                    "EAF_0p1"
                ]
            },
            "SAF": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/IPC/CurSit/SAF",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "SAF",
                "restriction": "Public",
                "saf200907": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf200907",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "July 2009",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf200907"
                },
                "saf200910": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf200910",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "October 2009",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf200910"
                },
                "saf201001": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201001",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "January 2010",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201001"
                },
                "saf201004": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201004",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "April 2010",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201004"
                },
                "saf201007": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201007",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "July 2010",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201007"
                },
                "saf201010": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201010",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "October 2010",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201010"
                },
                "saf201101": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201101",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "January 2011",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201101"
                },
                "saf201104": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201104",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "April 2011",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201104"
                },
                "saf201107": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201107",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "July 2011",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201107"
                },
                "saf201110": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201110",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "October 2011",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201110"
                },
                "saf201201": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201201",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "January 2012",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201201"
                },
                "saf201204": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201204",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "April 2012",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201204"
                },
                "saf201207": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201207",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "July 2012",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201207"
                },
                "saf201210": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201210",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "October 2012",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201210"
                },
                "saf201301": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201301",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "January 2013",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201301"
                },
                "saf201304": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201304",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "April 2013",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201304"
                },
                "saf201307": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201307",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "July 2013",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201307"
                },
                "saf201310": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201310",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "October 2013",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201310"
                },
                "saf201401": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201401",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "January 2014",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201401"
                },
                "saf201404": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201404",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "April 2014",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201404"
                },
                "saf201407": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201407",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "July 2014",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201407"
                },
                "saf201410": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201410",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "October 2014",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201410"
                },
                "saf201501": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201501",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "January 2015",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201501"
                },
                "saf201504": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201504",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "April 2015",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201504"
                },
                "saf201507": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201507",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "July 2015",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201507"
                },
                "saf201510": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201510",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "October 2015",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201510"
                },
                "saf201602": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201602",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "February 2016",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201602"
                },
                "saf201606": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201606",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "June 2016",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201606"
                },
                "saf201610": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201610",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "October 2016",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201610"
                },
                "saf201702": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201702",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "February 2017",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201702"
                },
                "saf201706": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201706",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "June 2017",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201706"
                },
                "saf201710": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201710",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "October 2017",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201710"
                },
                "saf201802": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201802",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "February 2018",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201802"
                },
                "saf201806": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201806",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "June 2018",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201806"
                },
                "saf201810": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201810",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "October 2018",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201810"
                },
                "saf201902": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201902",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "February 2019",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201902"
                },
                "saf201906": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201906",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "June 2019",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201906"
                },
                "saf201910": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf201910",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "October 2019",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf201910"
                },
                "saf202002": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf202002",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "February 2020",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf202002"
                },
                "saf202006": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf202006",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "June 2020",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf202006"
                },
                "saf202010": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "saf202010",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "description": "October 2020",
                        "Conventions": "IRIDL"
                    },
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF/saf202010"
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "saf200907",
                    "saf200910",
                    "saf201001",
                    "saf201004",
                    "saf201007",
                    "saf201010",
                    "saf201101",
                    "saf201104",
                    "saf201107",
                    "saf201110",
                    "saf201201",
                    "saf201204",
                    "saf201207",
                    "saf201210",
                    "saf201301",
                    "saf201304",
                    "saf201307",
                    "saf201310",
                    "saf201401",
                    "saf201404",
                    "saf201407",
                    "saf201410",
                    "saf201501",
                    "saf201504",
                    "saf201507",
                    "saf201510",
                    "saf201602",
                    "saf201606",
                    "saf201610",
                    "saf201702",
                    "saf201706",
                    "saf201710",
                    "saf201802",
                    "saf201806",
                    "saf201810",
                    "saf201902",
                    "saf201906",
                    "saf201910",
                    "saf202002",
                    "saf202006",
                    "saf202010"
                ]
            },
            "SAF_gridded": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/IPC/CurSit/SAF_gridded",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "SAF_gridded",
                "restriction": "Public",
                "SAF_0p01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SAF_0p01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "Conventions": "IRIDL"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Integrated Phase Classification Gridded",
                        "scale_min": "1.0",
                        "scale_max": "5.0",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "ncolor": "254",
                        "CS": "1",
                        "CE": "5",
                        "units": "unitless",
                        "history": "Boxes with less than 0.0% dropped",
                        "missing_value": "NaN",
                        "file_missing_value": "99",
                        "PGtype": "int4"
                    },
                    "T": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "T",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "1"
                    },
                    "Y": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Y",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_north",
                        "gridtype": "0",
                        "pointwidth": "0.01",
                        "long_name": "Latitude"
                    },
                    "X": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "X",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_east",
                        "gridtype": "0",
                        "pointwidth": "0.01",
                        "long_name": "Longitude"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF_gridded/SAF_0p01"
                },
                "SAF_0p1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SAF_0p1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "Conventions": "IRIDL"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Integrated Phase Classification Gridded",
                        "scale_min": "1.0",
                        "scale_max": "5.0",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "ncolor": "254",
                        "CS": "1",
                        "CE": "5",
                        "units": "unitless",
                        "history": "Boxes with less than 0.0% dropped",
                        "missing_value": "NaN",
                        "file_missing_value": "99",
                        "PGtype": "int4"
                    },
                    "T": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "T",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "1"
                    },
                    "Y": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Y",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_north",
                        "gridtype": "0",
                        "pointwidth": "0.1",
                        "long_name": "Latitude"
                    },
                    "X": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "X",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_east",
                        "gridtype": "0",
                        "pointwidth": "0.1",
                        "long_name": "Longitude"
                    },
                    "dir": "SOURCES/IPC/CurSit/SAF_gridded/SAF_0p1"
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "SAF_0p01",
                    "SAF_0p1"
                ]
            },
            "WAF": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "WAF",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "waf202010description": "October 2020",
                    "waf202006description": "June 2020",
                    "waf202002description": "February 2020",
                    "waf201910description": "October 2019",
                    "waf201906description": "June 2019",
                    "waf201902description": "February 2019",
                    "waf201810description": "October 2018",
                    "waf201806description": "June 2018",
                    "waf201802description": "February 2018",
                    "waf201710description": "October 2017",
                    "waf201706description": "June 2017",
                    "waf201702description": "February 2017",
                    "waf201610description": "October 2016",
                    "waf201606description": "June 2016",
                    "waf201602description": "February 2016",
                    "waf201510description": "October 2015",
                    "waf201507description": "July 2015",
                    "waf201504description": "April 2015",
                    "waf201501description": "January 2015",
                    "waf201410description": "October 2014",
                    "waf201407description": "July 2014",
                    "waf201404description": "April 2014",
                    "waf201401description": "January 2014",
                    "waf201310description": "October 2013",
                    "waf201307description": "July 2013",
                    "waf201304description": "April 2013",
                    "waf201301description": "January 2013",
                    "waf201210description": "October 2012",
                    "waf201207description": "July 2012",
                    "waf201204description": "April 2012",
                    "waf201201description": "January 2012",
                    "waf201110description": "October 2011",
                    "waf201107description": "July 2011",
                    "waf201104description": "April 2011",
                    "waf201101description": "January 2011",
                    "waf201010description": "October 2010",
                    "waf201007description": "July 2010",
                    "waf201004description": "April 2010",
                    "waf201001description": "January 2010",
                    "waf200910description": "October 2009",
                    "waf200907description": "July 2009",
                    "description": "West Africa - Acute Food Insecurity Phase",
                    "Conventions": "IRIDL"
                },
                "waf202010": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf202010",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    }
                },
                "waf202006": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf202006",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    }
                },
                "waf202002": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf202002",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    }
                },
                "waf201910": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201910",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    }
                },
                "waf201906": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201906",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    }
                },
                "waf201902": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201902",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    }
                },
                "waf201810": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201810",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    }
                },
                "waf201806": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201806",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    }
                },
                "waf201802": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201802",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    }
                },
                "waf201710": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201710",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    }
                },
                "waf201706": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201706",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    }
                },
                "waf201702": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201702",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1.0",
                        "missing_value": "99.0",
                        "CLIST": "Famine",
                        "scale_max": "5.0",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "float8"
                    }
                },
                "waf201610": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201610",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201606": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201606",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201602": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201602",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201510": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201510",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201507": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201507",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201504": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201504",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201501": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201501",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201410": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201410",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201407": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201407",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201404": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201404",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201401": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201401",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201310": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201310",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201307": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201307",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201304": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201304",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201301": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201301",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201210": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201210",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201207": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201207",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201204": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201204",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201201": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201201",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201110": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201110",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201107": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201107",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201104": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201104",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Integrated Phase Classification",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201101": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201101",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201010": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201010",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201007": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201007",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201004": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201004",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf201001": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf201001",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf200910": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf200910",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "waf200907": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "waf200907",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "missing_value": "99",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "FEWS NET Food Insecurity Severity Scale",
                        "units": "ids",
                        "PGtype": "int4"
                    }
                },
                "gid_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/IPC/CurSit/WAF"
            },
            "WAF_gridded": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/IPC/CurSit/WAF_gridded",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "WAF_gridded",
                "restriction": "Public",
                "WAF_0p01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WAF_0p01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "Conventions": "IRIDL"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Integrated Phase Classification Gridded",
                        "scale_min": "1.0",
                        "scale_max": "5.0",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "ncolor": "254",
                        "CS": "1",
                        "CE": "5",
                        "units": "unitless",
                        "history": "Boxes with less than 0.0% dropped",
                        "missing_value": "NaN",
                        "file_missing_value": "99",
                        "PGtype": "int4"
                    },
                    "T": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "T",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "1"
                    },
                    "Y": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Y",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_north",
                        "gridtype": "0",
                        "pointwidth": "0.1",
                        "long_name": "Latitude"
                    },
                    "X": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "X",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_east",
                        "gridtype": "0",
                        "pointwidth": "0.1",
                        "long_name": "Longitude"
                    },
                    "dir": "SOURCES/IPC/CurSit/WAF_gridded/WAF_0p01"
                },
                "WAF_0p1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WAF_0p1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "Conventions": "IRIDL"
                    },
                    "ipc": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ipc",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Integrated Phase Classification Gridded",
                        "scale_min": "1.0",
                        "scale_max": "5.0",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "ncolor": "254",
                        "CS": "1",
                        "CE": "5",
                        "units": "unitless",
                        "history": "Boxes with less than 0.0% dropped",
                        "missing_value": "NaN",
                        "file_missing_value": "99",
                        "PGtype": "int4"
                    },
                    "T": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "T",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "1"
                    },
                    "Y": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Y",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_north",
                        "gridtype": "0",
                        "pointwidth": "0.1",
                        "long_name": "Latitude"
                    },
                    "X": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "X",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_east",
                        "gridtype": "0",
                        "pointwidth": "0.1",
                        "long_name": "Longitude"
                    },
                    "dir": "SOURCES/IPC/CurSit/WAF_gridded/WAF_0p1"
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "WAF_0p01",
                    "WAF_0p1"
                ]
            },
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type",
                "EAF",
                "EAF_gridded",
                "SAF",
                "SAF_gridded",
                "WAF",
                "WAF_gridded"
            ]
        },
        "EAF": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "EAF",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "eaflastML2description": "Medium Term",
                "eaflastML1description": "Near Term",
                "eaflastdescription": "January 2018",
                "eaf201801ML2description": "Medium Term",
                "eaf201801ML1description": "Near Term",
                "eaf201801description": "January 2018",
                "eaf201606ML2description": "Medium Term",
                "eaf201606ML1description": "Near Term",
                "eaf201606description": "June 2016",
                "description": "Eastern Africa",
                "Conventions": "IRIDL"
            },
            "eaflast": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "eaflast",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ML2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "pointwidth": "4",
                        "units": "months since 1960-01-01"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "units": "months since 1960-01-01",
                        "pointwidth": "1"
                    },
                    "ml2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "5",
                        "colormap": "0",
                        "maxncolor": "254",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                },
                "ML1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "units": "months since 1960-01-01",
                        "pointwidth": "1"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "units": "months since 1960-01-01",
                        "pointwidth": "1"
                    },
                    "ml1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "5",
                        "colormap": "0",
                        "maxncolor": "254",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                }
            },
            "eaf201801": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "eaf201801",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ML2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "pointwidth": "4",
                        "units": "months since 1960-01-01"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "units": "months since 1960-01-01",
                        "pointwidth": "1"
                    },
                    "ml2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "5",
                        "colormap": "0",
                        "maxncolor": "254",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                },
                "ML1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "units": "months since 1960-01-01",
                        "pointwidth": "1"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "units": "months since 1960-01-01",
                        "pointwidth": "1"
                    },
                    "ml1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "5",
                        "colormap": "0",
                        "maxncolor": "254",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                }
            },
            "eaf201606": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "eaf201606",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ML2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "units": "months since 1960-01-01",
                        "pointwidth": "4"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "units": "months since 1960-01-01",
                        "pointwidth": "1"
                    },
                    "ml2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "5",
                        "colormap": "0",
                        "maxncolor": "254",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    }
                },
                "ML1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "units": "months since 1960-01-01",
                        "pointwidth": "4"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "units": "months since 1960-01-01",
                        "pointwidth": "1"
                    },
                    "ml1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "8",
                        "colormap": "2763429",
                        "maxncolor": "254",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ncolor": "5",
                        "colormap": "0",
                        "maxncolor": "254",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    }
                }
            },
            "gid_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "dir": "SOURCES/IPC/EAF"
        },
        "WAF": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "WAF",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "waflastML2description": "Medium Term",
                "waflastML1description": "Near Term",
                "waflastdescription": "January 2018",
                "waf201801ML2description": "Medium Term",
                "waf201801ML1description": "Near Term",
                "waf201801description": "January 2018",
                "waf201702ML2description": "Medium Term",
                "waf201702ML1description": "Near Term",
                "waf201702description": "February 2017",
                "waf201610ML2description": "Medium Term",
                "waf201610ML1description": "Near Term",
                "waf201610description": "October 2016",
                "waf201606ML2description": "Medium Term",
                "waf201606ML1description": "Near Term",
                "waf201606description": "June 2016",
                "description": "Western Africa",
                "Conventions": "IRIDL"
            },
            "waflast": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "waflast",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ML2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "pointwidth": "4",
                        "long_name": "Target Date",
                        "units": "months since 1960-01-01"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "pointwidth": "1",
                        "units": "months since 1960-01-01"
                    },
                    "ml2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "5",
                        "colormap": "0",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                },
                "ML1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "pointwidth": "1",
                        "units": "months since 1960-01-01"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "pointwidth": "1",
                        "units": "months since 1960-01-01"
                    },
                    "ml1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "5",
                        "colormap": "0",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                }
            },
            "waf201801": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "waf201801",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ML2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "pointwidth": "4",
                        "long_name": "Target Date",
                        "units": "months since 1960-01-01"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "pointwidth": "1",
                        "units": "months since 1960-01-01"
                    },
                    "ml2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "5",
                        "colormap": "0",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                },
                "ML1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "pointwidth": "1",
                        "units": "months since 1960-01-01"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "pointwidth": "1",
                        "units": "months since 1960-01-01"
                    },
                    "ml1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "5",
                        "colormap": "0",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                }
            },
            "waf201702": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "waf201702",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ML2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "pointwidth": "4",
                        "units": "months since 1960-01-01"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "pointwidth": "1",
                        "units": "months since 1960-01-01"
                    },
                    "ml2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "5",
                        "colormap": "0",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                },
                "ML1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "pointwidth": "4",
                        "units": "months since 1960-01-01"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "pointwidth": "1",
                        "units": "months since 1960-01-01"
                    },
                    "ml1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "5",
                        "colormap": "0",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                }
            },
            "waf201610": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "waf201610",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ML2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "pointwidth": "4",
                        "units": "months since 1960-01-01"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "pointwidth": "1",
                        "units": "months since 1960-01-01"
                    },
                    "ml2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "5",
                        "colormap": "0",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                },
                "ML1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "pointwidth": "4",
                        "units": "months since 1960-01-01"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "pointwidth": "1",
                        "units": "months since 1960-01-01"
                    },
                    "ml1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "5",
                        "colormap": "0",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                }
            },
            "waf201606": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "waf201606",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "ML2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "pointwidth": "4",
                        "units": "months since 1960-01-01"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "pointwidth": "1",
                        "units": "months since 1960-01-01"
                    },
                    "ml2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "5",
                        "colormap": "0",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                },
                "ML1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ML1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "the_geom": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "the_geom",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Geometry",
                        "units": "unitless",
                        "PGtype": "bytea",
                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                        "SpatialReferenceSystemWKT": "]]"
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Target Date",
                        "pointwidth": "4",
                        "units": "months since 1960-01-01"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "calendar": "360",
                        "long_name": "Issue Date",
                        "pointwidth": "1",
                        "units": "months since 1960-01-01"
                    },
                    "ml1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ml1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "8",
                        "colormap": "2763429",
                        "scale_max": "5",
                        "long_name": "Acute Food Insecurity Phase",
                        "units": "ids",
                        "scale_min": "1",
                        "CLIST": "Famine",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "Label",
                        "units": "ids",
                        "PGtype": "text"
                    },
                    "ha1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ha1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "ncolor": "5",
                        "colormap": "0",
                        "scale_max": "1",
                        "long_name": "Humanitarian Assistance",
                        "units": "ids",
                        "scale_min": "0",
                        "CLIST": "would be 1 phase worse without HA",
                        "missing_value": "-2147483648",
                        "PGtype": "float8"
                    }
                }
            },
            "gid_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "gid": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "gid",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "unitless",
                "gridtype": "0",
                "pointwidth": "1.0"
            },
            "dir": "SOURCES/IPC/WAF"
        },
        "banned_long": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type",
            "CurSit",
            "EAF",
            "WAF"
        ]
    },
    "IRI": {
        "iridl_type": "Source",
        "invalid": [],
        "dir": "SOURCES/IRI",
        "banned": [
            "dir",
            "invalid",
            "parent",
            "name",
            "banned",
            "banned_long",
            "iridl_ds_name",
            "iridl_type"
        ],
        "iridl_ds_name": "IRI",
        "restriction": "Public",
        "Analyses": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/IRI/Analyses",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "Analyses",
            "restriction": "Public",
            "CSMT": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CSMT",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "Climatic Suitability for Malaria Transmission",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.Analyses/.CSMT/.dataset_documentation.html",
                    "iridlhasSemantics": "iridl:Malaria",
                    "Conventions": "IRIDL",
                    "references": "Grover-Kopec_etal2006"
                },
                "TempCondProb": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "TempCondProb",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "16777215",
                    "scale_max": "100.0",
                    "ncolor": "254",
                    "scale_min": "0.0",
                    "CE": "100.0",
                    "CS": "0.0",
                    "CI": "25.0",
                    "long_name": "Percent Occurrence of Temperature Condition in Historical Record",
                    "history": "Averaged over T2[1951, 2000] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "units": "unitless",
                    "fnname": "flagge",
                    "file_missing_value": "-99.900002"
                },
                "RHCondProb": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "RHCondProb",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "13882323",
                    "scale_max": "100.0",
                    "ncolor": "254",
                    "scale_min": "0.0",
                    "CE": "100.0",
                    "CS": "0.0",
                    "CI": "25.0",
                    "long_name": "Percent Occurrence of Relative Humidity Condition in Historical Record",
                    "history": "Averaged over T2[1951, 2000]",
                    "units": "unitless",
                    "fnname": "flagge",
                    "GRIBgridcode": "2",
                    "gribparam": "51",
                    "grib_name": "SPFH",
                    "center": "US Weather Service - National Met. Center",
                    "calendar": "standard",
                    "gribfield": "1",
                    "subcenter": "NCEP Ensemble Products",
                    "PTVersion": "2",
                    "process": " run",
                    "gribNumBits": "15",
                    "PDS_TimeRange": "113",
                    "gribvariable": "51",
                    "gribleveltype": "100",
                    "pointwidth": "1.0"
                },
                "PcpnCondProb": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "PcpnCondProb",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "16777215",
                    "scale_max": "100.0",
                    "ncolor": "254",
                    "scale_min": "0.0",
                    "CE": "100.0",
                    "CS": "0.0",
                    "CI": "25.0",
                    "long_name": "Percent Occurrence of Precipitation Condition in Historical Record",
                    "history": "Averaged over T2[1951, 2000] minimum 0.0% data present",
                    "units": "unitless",
                    "fnname": "flagge",
                    "missing_value": "NaN",
                    "file_missing_value": "-99.900002"
                },
                "Annual_Sum": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Annual_Sum",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "long_name": "Number of Months Suitable for Malaria Transmission",
                    "colormap": "0",
                    "scale_max": "12.5",
                    "ncolor": "254",
                    "scale_min": "0.0",
                    "CE": "12.5",
                    "CS": "0.0",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "units": "unitless",
                    "fnname": "flagge",
                    "file_missing_value": "-99.900002"
                },
                "AllCondProb": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "AllCondProb",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "13882323",
                    "scale_max": "100.0",
                    "ncolor": "254",
                    "scale_min": "0.0",
                    "CE": "100.0",
                    "CS": "0.0",
                    "CI": "25.0",
                    "long_name": "Percent Occurrence of All Three Climate Conditions in Historical Record",
                    "history": "Averaged over T2[1951, 2000] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "units": "unitless",
                    "fnname": "flagge",
                    "file_missing_value": "-99.900002"
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.5"
                },
                "X_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "0.5"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "0.5"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.5"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulo": "12.0",
                    "modulus": "12.0",
                    "calendar": "360",
                    "long_name": "Month",
                    "expires": "1617408000",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/IRI/Analyses/CSMT"
            },
            "ENSORP": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "ENSO-RP",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "ver19502002description": "Probabilistic precipitation anomalies associated with ENSO (1950-2002)",
                    "ver19501996description": "Probabilistic precipitation anomalies associated with ENSO (1950-1996)",
                    "references": "Mason_Goddard2001",
                    "description": "Probabilistic precipitation anomalies associated with ENSO",
                    "Conventions": "IRIDL"
                },
                "ver19502002": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ver1950-2002",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "p5deg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "0p5deg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "prob": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "prob",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_max": "1.0",
                            "CE": "1.0",
                            "CS": "0.0",
                            "scale_min": "0.0",
                            "maxncolor": "254",
                            "colorscalename": "tercileclassesscale",
                            "colormap": "6303920",
                            "ncolor": "254",
                            "missing_value": "-9999.0",
                            "long_name": "probability"
                        },
                        "maskedprob": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "maskedprob",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_max": "1.0",
                            "CE": "1.0",
                            "CS": "0.0",
                            "scale_min": "0.0",
                            "maxncolor": "254",
                            "colorscalename": "tercileclassesscale",
                            "colormap": "6303920",
                            "ncolor": "254",
                            "missing_value": "-9999.0",
                            "long_name": "probability masked below 90% significance"
                        }
                    }
                },
                "ver19501996": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ver1950-1996",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "p5deg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "0p5deg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "prob": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "prob",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_max": "1.0",
                            "CE": "1.0",
                            "CS": "0.0",
                            "scale_min": "0.0",
                            "maxncolor": "254",
                            "colorscalename": "tercileclassesscale",
                            "colormap": "6303920",
                            "ncolor": "254",
                            "missing_value": "-9999.0",
                            "long_name": "probability"
                        },
                        "maskedprob": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "maskedprob",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_max": "1.0",
                            "CE": "1.0",
                            "CS": "0.0",
                            "scale_min": "0.0",
                            "maxncolor": "254",
                            "colorscalename": "tercileclassesscale",
                            "colormap": "6303920",
                            "ncolor": "254",
                            "missing_value": "-9999.0",
                            "long_name": "probability masked below 90% significance"
                        }
                    }
                },
                "X_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "standard_name": "longitude",
                    "pointwidth": "2.5"
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "2.5"
                },
                "prcp": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "prcp",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "gridtype": "2"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "standard_name": "longitude",
                    "pointwidth": "0.5"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.5"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulo": "12.0",
                    "modulus": "12.0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "3.0"
                },
                "ENSO": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ENSO",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "gridtype": "2"
                },
                "dir": "SOURCES/IRI/Analyses/ENSO-RP"
            },
            "Fire": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Fire",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "IndonesiaKapuasCMAdescription": "Three-class model of fire vulnerability in Kapuas district determined from Composite Mapping Analysis (CMA)",
                    "IndonesiaKapuasdescription": "Fire risk data for Kapuas",
                    "AmazonFiresAmFires025long_name": "AmazonFires025",
                    "AmazonFirePredictionMayLead2long_name": "MayFCST_JAS_T2m",
                    "AmazonFirePredictionMayLead1long_name": "MayFCST_JJA_T2m",
                    "AmazonFirePredictionMay18Lead2long_name": "May18FCST_JAS",
                    "AmazonFirePredictionMay18Lead1long_name": "May18FCST_JJA",
                    "AmazonFirePredictionMarLead2long_name": "MarFCST_MJJ_T2m",
                    "AmazonFirePredictionMarLead1long_name": "MarFCST_AMJ_T2m",
                    "AmazonFirePredictionJunLead1long_name": "JunFCST_JAS_T2m",
                    "AmazonFirePredictionJun18Lead1long_name": "Jun18FCST_JAS",
                    "AmazonFirePredictionJun17Lead1long_name": "Jun17FCST_JAS",
                    "AmazonFirePredictionAprLead2long_name": "AprFCST_JJA_T2m",
                    "AmazonFirePredictionAprLead1long_name": "AprFCST_MJJ_T2m",
                    "AmazonFirePredictionApr18Lead2long_name": "Apr18FCST_JJA",
                    "AmazonFirePredictionApr18Lead1long_name": "Apr18FCST_MJJ",
                    "description": "Fire maproom analyses",
                    "Conventions": "IRIDL"
                },
                "Indonesia": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Indonesia",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Kapuas": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Kapuas",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "risk": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "risk",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "maxncolor": "6",
                            "CLIST": "high",
                            "colormap": "16777215",
                            "scale_max": "3.0",
                            "ncolor": "6",
                            "scale_min": "1.0",
                            "CE": "3",
                            "CS": "1",
                            "missing_value": "-9",
                            "long_name": "Fire Risk",
                            "units": "ids"
                        },
                        "CMA": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "CMA",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "vulnerability": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "vulnerability",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "maxncolor": "6",
                                "CLIST": "High",
                                "colormap": "16777215",
                                "scale_max": "3.0",
                                "ncolor": "6",
                                "scale_min": "1.0",
                                "CE": "3",
                                "CS": "1",
                                "missing_value": "127",
                                "valid_max": "3",
                                "valid_min": "1",
                                "long_name": "fire vulnerability",
                                "units": "ids"
                            }
                        }
                    },
                    "Kalimantan": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Kalimantan",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "the_geom": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "the_geom",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Province Geometry",
                            "units": "unitless",
                            "PGtype": "bytea",
                            "OpenGISSimpleFeature": "MULTIPOLYGON",
                            "SpatialReferenceSystemWKT": "]]"
                        },
                        "numberOfFires": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "numberOfFires",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "unitless",
                            "missing_value": "-9.0",
                            "long_name": "Number of fires"
                        },
                        "name1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "name1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Province Name",
                            "units": "ids",
                            "PGtype": "varchar"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Label",
                            "units": "ids",
                            "PGtype": "varchar"
                        }
                    }
                },
                "CMORPH": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "CMORPH",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "dekadal": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dekadal",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "avg": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "avg",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Dekadal CMORPH 2003-14 average",
                            "history": "Averaged over T2[0.5, 432.5] minimum 0.0% data present",
                            "missing_value": "NaN",
                            "maxncolor": "254",
                            "colorscalename": "cmorph_dekad_colors",
                            "colormap": "2237106",
                            "ncolor": "254",
                            "units": "mm",
                            "file_missing_value": "-9999.0",
                            "pointwidth": "0"
                        }
                    }
                },
                "Amazon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Amazon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Fires": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Fires",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "AmFires025": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "AmFires025",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "AmazonFires025": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "AmazonFires025",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "NaN",
                                "file_missing_value": "-999.0",
                                "units": "unitless",
                                "history": "[([(home katia Fires AmFires AmazonFires) [(X regridded on home katia Fires AmFires AmazonFires) (Y regridded on home katia Fires AmFires AmazonFires) (Boxes with less than 0.0% dropped)] (Averaged over T[Jul-Sep 2000, Jul-Sep 2015] minimum 0% data present)]) (T:  Jul-Sep 2016 to Jul-Sep 2016 appended from maskrange [ ( home katia Fires AmFires025 AmazonFires025 ) , -20 , 20 ])]"
                            }
                        }
                    },
                    "FirePrediction": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "FirePrediction",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "MayLead2": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "MayLead2",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "MayFCST_JAS_T2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MayFCST_JAS_T2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Standard Deviation"
                            }
                        },
                        "MayLead1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "MayLead1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "MayFCST_JJA_T2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MayFCST_JJA_T2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Standard Deviation"
                            }
                        },
                        "May18Lead2": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "May18Lead2",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "May18FCST_JAS_SST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "May18FCST_JAS_SST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Standard Deviation"
                            }
                        },
                        "May18Lead1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "May18Lead1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "May18FCST_JJA_SST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "May18FCST_JJA_SST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Standard Deviation"
                            }
                        },
                        "MarLead2": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "MarLead2",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "MarFCST_MJJ_T2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MarFCST_MJJ_T2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Standard Deviation"
                            }
                        },
                        "MarLead1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "MarLead1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "MarFCST_AMJ_T2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MarFCST_AMJ_T2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Standard Deviation"
                            }
                        },
                        "JunLead1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "JunLead1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "JunFCST_JAS_T2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "JunFCST_JAS_T2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Standard Deviation"
                            }
                        },
                        "Jun18Lead1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Jun18Lead1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Jun18FCST_JAS_SST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Jun18FCST_JAS_SST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Standard Deviation"
                            }
                        },
                        "Jun17Lead1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Jun17Lead1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Jun17FCST_JAS_SST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Jun17FCST_JAS_SST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Standard Deviation"
                            }
                        },
                        "AprLead2": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "AprLead2",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "AprFCST_JJA_T2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "AprFCST_JJA_T2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Standard Deviation"
                            }
                        },
                        "AprLead1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "AprLead1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "AprFCST_MJJ_T2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "AprFCST_MJJ_T2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Standard Deviation"
                            }
                        },
                        "Apr18Lead2": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Apr18Lead2",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Apr18FCST_JJA_SST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Apr18FCST_JJA_SST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Standard Deviation"
                            }
                        },
                        "Apr18Lead1": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Apr18Lead1",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Apr18FCST_MJJ_SST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Apr18FCST_MJJ_SST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Standard Deviation"
                            }
                        }
                    }
                },
                "Y_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "2.70945049E-04"
                },
                "X_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "2.70978169E-04"
                },
                "Y_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "1.26170009E-04"
                },
                "X_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "1.26169922E-04"
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "T_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "T_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "days since 2003-01-01",
                    "gridtype": "1",
                    "modulo": "365.0",
                    "modulus": "365.0",
                    "calendar": "365"
                },
                "X_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "standard_name": "longitude",
                    "pointwidth": "0.25"
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.25"
                },
                "T_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "3.0"
                },
                "T_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "Year",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "T_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "Year",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "pointwidth": "0.25"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "Year",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "pointwidth": "0.25"
                },
                "dir": "SOURCES/IRI/Analyses/Fire"
            },
            "ICPAC": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/IRI/Analyses/ICPAC",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "ICPAC",
                "restriction": "Public",
                "Models": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Models",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "WashingtonNCEPCFSv2HINDCASTPENTAD_SAMPLESSEASONALGHCN_CAMSdescription": "Seasonal (3-month) anomaly correlation between ensemble mean NCEP-CFSv2 hindcast temperature and GHCN-CAMS temperature during 1982-2010",
                        "WashingtonNCEPCFSv2HINDCASTPENTAD_SAMPLESSEASONALERSSTv5description": "Seasonal (3-month) anomaly correlation between ensemble mean NCEP-CFSv2 hindcast sst and ERSSTv5 sst during 1982-2010",
                        "WashingtonNCEPCFSv2HINDCASTPENTAD_SAMPLESSEASONALERSSTv4description": "Seasonal (3-month) anomaly correlation between ensemble mean NCEP-CFSv2 hindcast sst and ERSSTv4 sst during 1982-2010",
                        "WashingtonNCEPCFSv2HINDCASTPENTAD_SAMPLESSEASONALCAMSOPIdescription": "Seasonal (3-month) anomaly correlation between ensemble mean NCEP-CFSv2 hindcast precipitation and CAMS-OPI precipitation during 1982-2010",
                        "WashingtonNCEPCFSv2HINDCASTPENTAD_SAMPLESMONTHLYSamplingTable": "http://iridl.ldeo.columbia.edu/SOURCES/.NOAA/.NCEP/.EMC/.CFSv2/.ENSEMBLE/.FLXF/mark/sampleS/M/4/STEP/S/exch%5BM%5Dtable:/mark/:table/.html",
                        "WashingtonNCEPCFSv2HINDCASTPENTAD_SAMPLESMONTHLYACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "WashingtonNCEPCFSv2FORECASTPENTAD_SAMPLESMONTHLYSamplingTable": "http://iridl.ldeo.columbia.edu/SOURCES/.NOAA/.NCEP/.EMC/.CFSv2/.REALTIME_ENSEMBLE/.FLXF/mark/sampleS/M/4/STEP/S/exch%5BM%5Dtable:/mark/:table/.html",
                        "WashingtonNCEPCFSv2FORECASTPENTAD_SAMPLESMONTHLYACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "WashingtonNCEPCFSv2FORECASTPENTAD_SAMPLESdescription": "pentad realtime forecasts organized as monthly starts of 24-28 members, starting from Apr 2011, matching pattern of CFSv2 hindcast starts",
                        "NASANASAGMAO062012MONTHLYdataset_documentation": "geos5_model_basics.pptx",
                        "NASANASAGMAO062012MONTHLYIMPORTANT": "As of 2 November 2016 an error has been found and corrected in the IRI Data Library archive of the NMME NASA-GMAO-062012 January hindcast and forecast starts.  In the January starts (S grid) for ensemble members (M grid) 1-4 (corresponding to starts associated with dates Dec 12th, Dec 17th, Dec 22nd, and Dec 27th), for all variables, the data in these files were being wrongly associated with the January start of the previoius year.  For example, for the January 2014 start, data should be read from files named using the dates 12 Dec 2013 (ensemble member 1), 17 Dec 2013 (ensemble member 2), 22 Dec 2013 (ensemble member 3), 27 Dec 2013 (ensemble member 4), and 01 Jan 2014 (ensemble members 5-11).  However, continuing with this example, in the Data Library archive, the data from ensemble members 1-4 (dated Dec 12, 17, 22, and 27 2013) were being assigned to the January 2013 start, not the intended January 2014 start.  This means that in forecasts with a January monthly start time, ensemble members 1-4 would have been missing until the following January start, when these ensemble members 1-4 would have been filled with data intended for the next January monthly start, or remained missing in the case of the prec, sst, and tref variables from 2014 to 2016.  This error affected only ensemble members 1-4 of the January starts, but affected all variables and all hindcast and forecast years.  This error was the result of an archiving error in the Data Library, not any error in the original data files from NASA, and has been corrected as of 2 November 2016.  Send any questions to help@iri.columbia.edu .",
                        "NASANASAGMAO062012MONTHLYreferences": "Kirtman_etal2014",
                        "NASANASAGMAO062012MONTHLYdata_availability": "/mark/SOURCES/.Models/.NMME/.NASA-GMAO-062012/.MONTHLY/.fileavail/S2/exch%5BS1%5Dtable:/mark/:table/.html",
                        "NASANASAGMAO062012MONTHLYACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "NASANASAGMAO062012HINDCASTSEASONALGHCN_CAMSdescription": "Seasonal (3-month) anomaly correlation between ensemble mean NASA-GMAO hindcast temperature and GHCN-CAMS temperature during 1981-2010",
                        "NASANASAGMAO062012HINDCASTSEASONALERSSTv5description": "Seasonal (3-month) anomaly correlation between ensemble mean NASA-GMAO hindcast sst and ERSSTv5 sst during 1981-2010",
                        "NASANASAGMAO062012HINDCASTSEASONALERSSTv4description": "Seasonal (3-month) anomaly correlation between ensemble mean NASA-GMAO hindcast sst and ERSSTv4 sst during 1981-2010",
                        "NASANASAGMAO062012HINDCASTSEASONALCAMSOPIdescription": "Seasonal (3-month) anomaly correlation between ensemble mean NASA-GMAO hindcast precipitation and CAMS-OPI precipitation during 1981-2010",
                        "MontrealGEMNEMOHINDCASTSEASONALGHCN_CAMSdescription": "Seasonal (3-month) anomaly correlation between ensemble mean GEM-NEMO hindcast temperature and GHCN-CAMS temperature during 1981-2010",
                        "MontrealGEMNEMOHINDCASTSEASONALERSSTv5description": "Seasonal (3-month) anomaly correlation between ensemble mean GEM-NEMO hindcast sst and ERSSTv5 sst during 1981-2010",
                        "MontrealGEMNEMOHINDCASTSEASONALCAMSOPIdescription": "Seasonal (3-month) anomaly correlation between ensemble mean GEM-NEMO hindcast precipitation and CAMS-OPI precipitation during 1981-2010",
                        "MontrealGEMNEMOHINDCASTsc8110description": "1981-2010 Seasonal Climatology",
                        "MontrealGEMNEMOHINDCASTMONTHLYdataset_documentation": "https://iridl.ldeo.columbia.edu/documentation/Models/NMME/CanSIPSv2/technote_cansips-v2_20190703_e.pdf",
                        "MontrealGEMNEMOHINDCASTMONTHLYreferences": "Kirtman_etal2014",
                        "MontrealGEMNEMOHINDCASTMONTHLYACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "MontrealGEMNEMOHINDCASTmc8110description": "1981-2010 Monthly Climatology",
                        "MontrealGEMNEMOFORECASTMONTHLYdataset_documentation": "https://iridl.ldeo.columbia.edu/documentation/Models/NMME/CanSIPSv2/technote_cansips-v2_20190703_e.pdf",
                        "MontrealGEMNEMOFORECASTMONTHLYreferences": "Kirtman_etal2014",
                        "MontrealGEMNEMOFORECASTMONTHLYexpires": "1617260400",
                        "MontrealGEMNEMOFORECASTMONTHLYACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "MontrealGEMNEMOdataset_documentation": "https://iridl.ldeo.columbia.edu/documentation/Models/NMME/CanSIPSv2/technote_cansips-v2_20190703_e.pdf",
                        "MontrealCMC2CanCM4HINDCASTSEASONALGHCN_CAMSdescription": "Seasonal (3-month) anomaly correlation between ensemble mean CMC2-CanCM4 hindcast temperature and GHCN-CAMS temperature during 1981-2010",
                        "MontrealCMC2CanCM4HINDCASTSEASONALERSSTv5description": "Seasonal (3-month) anomaly correlation between ensemble mean CMC2-CanCM4 hindcast sst and ERSSTv5 sst during 1981-2010",
                        "MontrealCMC2CanCM4HINDCASTSEASONALERSSTv4description": "Seasonal (3-month) anomaly correlation between ensemble mean CMC2-CanCM4 hindcast sst and ERSSTv4 sst during 1981-2010",
                        "MontrealCMC2CanCM4HINDCASTSEASONALCAMSOPIdescription": "Seasonal (3-month) anomaly correlation between ensemble mean CMC2-CanCM4 hindcast precipitation and CAMS-OPI precipitation during 1981-2010",
                        "MontrealCMC2CanCM4HINDCASTMONTHLYreferences": "Kirtman_etal2014",
                        "MontrealCMC2CanCM4HINDCASTMONTHLYACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "MontrealCMC2CanCM4FORECASTMONTHLYorigreferences": "Kirtman_etal2014",
                        "MontrealCMC2CanCM4FORECASTMONTHLYorigdescription": "original entry",
                        "MontrealCMC2CanCM4FORECASTMONTHLYorigACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "MontrealCMC2CanCM4FORECASTMONTHLYreferences": "Kirtman_etal2014",
                        "MontrealCMC2CanCM4FORECASTMONTHLYACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "MontrealCMC1CanCM3HINDCASTSEASONALGHCN_CAMSdescription": "Seasonal (3-month) anomaly correlation between ensemble mean CMC1-CanCM3 hindcast temperature and GHCN-CAMS temperature during 1981-2010",
                        "MontrealCMC1CanCM3HINDCASTSEASONALERSSTv5description": "Seasonal (3-month) anomaly correlation between ensemble mean CMC1-CanCM3 hindcast sst and ERSSTv5 sst during 1981-2010",
                        "MontrealCMC1CanCM3HINDCASTSEASONALERSSTv4description": "Seasonal (3-month) anomaly correlation between ensemble mean CMC1-CanCM3 hindcast sst and ERSSTv4 sst during 1981-2010",
                        "MontrealCMC1CanCM3HINDCASTSEASONALCAMSOPIdescription": "Seasonal (3-month) anomaly correlation between ensemble mean CMC1-CanCM3 hindcast precipitation and CAMS-OPI precipitation during 1981-2010",
                        "MontrealCMC1CanCM3HINDCASTMONTHLYreferences": "Kirtman_etal2014",
                        "MontrealCMC1CanCM3HINDCASTMONTHLYACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "MontrealCMC1CanCM3FORECASTMONTHLYorigdescription": "original entry",
                        "MontrealCMC1CanCM3FORECASTMONTHLYorigACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "MontrealCMC1CanCM3FORECASTMONTHLYreferences": "Kirtman_etal2014",
                        "MontrealCMC1CanCM3FORECASTMONTHLYACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "MontrealCanCM4iHINDCASTSEASONALGHCN_CAMSdescription": "Seasonal (3-month) anomaly correlation between ensemble mean CanCM4i hindcast temperature and GHCN-CAMS temperature during 1981-2010",
                        "MontrealCanCM4iHINDCASTSEASONALERSSTv5description": "Seasonal (3-month) anomaly correlation between ensemble mean CanCM4i hindcast sst and ERSSTv5 sst during 1981-2010",
                        "MontrealCanCM4iHINDCASTSEASONALCAMSOPIdescription": "Seasonal (3-month) anomaly correlation between ensemble mean CanCM4i hindcast precipitation and CAMS-OPI precipitation during 1981-2010",
                        "MontrealCanCM4iHINDCASTsc8110description": "1981-2010 Seasonal Climatology",
                        "MontrealCanCM4iHINDCASTMONTHLYdataset_documentation": "https://iridl.ldeo.columbia.edu/documentation/Models/NMME/CanSIPSv2/technote_cansips-v2_20190703_e.pdf",
                        "MontrealCanCM4iHINDCASTMONTHLYreferences": "Kirtman_etal2014",
                        "MontrealCanCM4iHINDCASTMONTHLYACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "MontrealCanCM4iHINDCASTmc8110description": "1981-2010 Monthly Climatology",
                        "MontrealCanCM4iFORECASTMONTHLYdataset_documentation": "https://iridl.ldeo.columbia.edu/documentation/Models/NMME/CanSIPSv2/technote_cansips-v2_20190703_e.pdf",
                        "MontrealCanCM4iFORECASTMONTHLYreferences": "Kirtman_etal2014",
                        "MontrealCanCM4iFORECASTMONTHLYexpires": "1617260400",
                        "MontrealCanCM4iFORECASTMONTHLYACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "MontrealCanCM4idataset_documentation": "https://iridl.ldeo.columbia.edu/documentation/Models/NMME/CanSIPSv2/technote_cansips-v2_20190703_e.pdf",
                        "GFDLGFDLCM2p5FLORA06MONTHLYhistory": "FERRET V6.72   7-Jun-12",
                        "GFDLGFDLCM2p5FLORA06MONTHLYdataset_documentation": "http://www.gfdl.noaa.gov/cms-filesystem-action/user_files/gav/publications/jetal_14_flor_tsandpr.pdf",
                        "GFDLGFDLCM2p5FLORA06MONTHLYreferences": "Kirtman_etal2014",
                        "GFDLGFDLCM2p5FLORA06MONTHLYexpires": "1612162800",
                        "GFDLGFDLCM2p5FLORA06MONTHLYdata_availability": "fileavail/mark/exch/S2/exch[S1]table:/mark/:table/.html",
                        "GFDLGFDLCM2p5FLORA06MONTHLYConventions": "CF-1.0",
                        "GFDLGFDLCM2p5FLORA06MONTHLYACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "GFDLGFDLCM2p5FLORA06HINDCASTSEASONALGHCN_CAMSdescription": "Seasonal (3-month) anomaly correlation between ensemble mean GFDL-CM2p5-FLOR-A06 hindcast temperature and GHCN-CAMS temperature during 1981-2010",
                        "GFDLGFDLCM2p5FLORA06HINDCASTSEASONALERSSTv5description": "Seasonal (3-month) anomaly correlation between ensemble mean GFDL-CM2p5-FLOR-A06 hindcast sst and ERSSTv5 sst during 1981-2010",
                        "GFDLGFDLCM2p5FLORA06HINDCASTSEASONALERSSTv4description": "Seasonal (3-month) anomaly correlation between ensemble mean GFDL-CM2p5-FLOR-A06 hindcast sst and ERSSTv4 sst during 1981-2010",
                        "GFDLGFDLCM2p5FLORA06HINDCASTSEASONALCAMSOPIdescription": "Seasonal (3-month) anomaly correlation between ensemble mean GFDL-CM2p5-FLOR-A06 hindcast precipitation and CAMS-OPI precipitation during 1981-2010",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearum_version": "10.1",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearinitialization_description": "Atmos:ERA-I; Ocean & Sea-ice: GS5 OSIA NEMOVAR",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearforecast_type": "hindcast",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearmodel_id": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearsource": "model-generated, GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearmodeling_realm": "atmos",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearphysics_description": "See Williams et al, 2015 for GC2 description",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearinstitution": "Met Office",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyeartitle": "Operational seasonal forecast data from UK Met Office.",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearConventions": "CF-1.6",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearcontributor_name": "Met Office",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearinstitute_id": "UKMO",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearcontact": "Contact the Met Office Monthly to Decadal Prediction team",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearassociated_model": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28_multiyearassociated_experiment": "GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28um_version": "10.1",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28initialization_description": "Atmos:ERA-I; Ocean & Sea-ice: GS5 OSIA NEMOVAR",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28forecast_type": "hindcast",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28model_id": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28source": "model-generated, GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28modeling_realm": "atmos",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28physics_description": "See Williams et al, 2015 for GC2 description",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28institution": "Met Office",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28title": "Operational seasonal forecast data from UK Met Office.",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28Conventions": "CF-1.6",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28contributor_name": "Met Office",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28institute_id": "UKMO",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28contact": "Contact the Met Office Monthly to Decadal Prediction team",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28associated_model": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1shiftnchindcast_ens28associated_experiment": "GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1shiftncforecastum_version": "10.1",
                        "ExeterUKMOGloSea5d1x1shiftncforecastinitialization_description": "Atmos:Met Office NWP 4DVar; Ocean & Sea-ice: Met Office FOAM NEMOVAR",
                        "ExeterUKMOGloSea5d1x1shiftncforecastforecast_type": "forecast",
                        "ExeterUKMOGloSea5d1x1shiftncforecastmodel_id": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1shiftncforecastsource": "model-generated, GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1shiftncforecastmodeling_realm": "atmos",
                        "ExeterUKMOGloSea5d1x1shiftncforecastexpires": "1615420800",
                        "ExeterUKMOGloSea5d1x1shiftncforecastphysics_description": "See Williams et al, 2015 for GC2 description",
                        "ExeterUKMOGloSea5d1x1shiftncforecastinstitution": "Met Office",
                        "ExeterUKMOGloSea5d1x1shiftncforecasttitle": "Operational seasonal forecast data from UK Met Office.",
                        "ExeterUKMOGloSea5d1x1shiftncforecastConventions": "CF-1.6",
                        "ExeterUKMOGloSea5d1x1shiftncforecastcontributor_name": "Met Office",
                        "ExeterUKMOGloSea5d1x1shiftncforecastinstitute_id": "UKMO",
                        "ExeterUKMOGloSea5d1x1shiftncforecastcontact": "Contact the Met Office Monthly to Decadal Prediction team",
                        "ExeterUKMOGloSea5d1x1shiftncforecastassociated_model": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1shiftncforecastassociated_experiment": "GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1shiftncdescription": "GloSea5 hindcasts & forecasts for forecast start times starting from Apr 2019",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearassociated_model": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearum_version": "10.1",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearinstitute_id": "UKMO",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearinitialization_description": "Atmos:ERA-I; Ocean & Sea-ice: GS5 OSIA NEMOVAR",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearcontact": "Contact the Met Office Monthly to Decadal Prediction team",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearmodeling_realm": "atmos",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearsource": "model-generated, GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearassociated_experiment": "GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearinstitution": "Met Office",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearConventions": "CF-1.6",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyeartitle": "Operational seasonal forecast data from UK Met Office.",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearmodel_id": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearcontributor_name": "Met Office",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearforecast_type": "hindcast",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28_multiyearphysics_description": "See Williams et al, 2015 for GC2 description",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28um_version": "10.1",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28initialization_description": "Atmos:ERA-I; Ocean & Sea-ice: GS5 OSIA NEMOVAR",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28forecast_type": "hindcast",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28model_id": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28source": "model-generated, GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28modeling_realm": "atmos",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28physics_description": "See Williams et al, 2015 for GC2 description",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28institution": "Met Office",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28title": "Operational seasonal forecast data from UK Met Office.",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28Conventions": "CF-1.6",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28contributor_name": "Met Office",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28institute_id": "UKMO",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28contact": "Contact the Met Office Monthly to Decadal Prediction team",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28associated_model": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1nchindcast_ens28associated_experiment": "GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1nchindcastum_version": "10.1",
                        "ExeterUKMOGloSea5d1x1nchindcastinitialization_description": "Atmos:ERA-I; Ocean & Sea-ice: GS5 OSIA NEMOVAR",
                        "ExeterUKMOGloSea5d1x1nchindcastforecast_type": "hindcast",
                        "ExeterUKMOGloSea5d1x1nchindcastmodel_id": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1nchindcastsource": "model-generated, GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1nchindcastmodeling_realm": "atmos",
                        "ExeterUKMOGloSea5d1x1nchindcastphysics_description": "See Williams et al, 2015 for GC2 description",
                        "ExeterUKMOGloSea5d1x1nchindcastinstitution": "Met Office",
                        "ExeterUKMOGloSea5d1x1nchindcasttitle": "Operational seasonal forecast data from UK Met Office.",
                        "ExeterUKMOGloSea5d1x1nchindcastConventions": "CF-1.6",
                        "ExeterUKMOGloSea5d1x1nchindcastcontributor_name": "Met Office",
                        "ExeterUKMOGloSea5d1x1nchindcastinstitute_id": "UKMO",
                        "ExeterUKMOGloSea5d1x1nchindcastcontact": "Contact the Met Office Monthly to Decadal Prediction team",
                        "ExeterUKMOGloSea5d1x1nchindcastassociated_model": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1nchindcastassociated_experiment": "GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1ncforecastassociated_model": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1ncforecastum_version": "10.1",
                        "ExeterUKMOGloSea5d1x1ncforecastinstitute_id": "UKMO",
                        "ExeterUKMOGloSea5d1x1ncforecastinitialization_description": "Atmos:Met Office NWP 4DVar; Ocean & Sea-ice: Met Office FOAM NEMOVAR",
                        "ExeterUKMOGloSea5d1x1ncforecastcontact": "Contact the Met Office Monthly to Decadal Prediction team",
                        "ExeterUKMOGloSea5d1x1ncforecastmodeling_realm": "atmos",
                        "ExeterUKMOGloSea5d1x1ncforecastsource": "model-generated, GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1ncforecastassociated_experiment": "GloSea5-GC2",
                        "ExeterUKMOGloSea5d1x1ncforecastinstitution": "Met Office",
                        "ExeterUKMOGloSea5d1x1ncforecastConventions": "CF-1.6",
                        "ExeterUKMOGloSea5d1x1ncforecasttitle": "Operational seasonal forecast data from UK Met Office.",
                        "ExeterUKMOGloSea5d1x1ncforecastmodel_id": "HadGEM3-GC2.0",
                        "ExeterUKMOGloSea5d1x1ncforecastcontributor_name": "Met Office",
                        "ExeterUKMOGloSea5d1x1ncforecastforecast_type": "forecast",
                        "ExeterUKMOGloSea5d1x1ncforecastphysics_description": "See Williams et al, 2015 for GC2 description",
                        "ExeterUKMOGloSea5d1x1ncdescription": "GloSea5 hindcasts & forecasts for forecast start times from Dec 2016 to Mar 2019",
                        "ExeterGloSea": "UKMO",
                        "COLARSMASCOLARSMASCCSM4MONTHLYReferences": "Ben P. Kirtman, Dughong Min. (2009) Multimodel Ensemble ENSO Prediction with CCSM and CFS. Monthly Weather Review 137:9, 2908-2930",
                        "COLARSMASCOLARSMASCCSM4MONTHLYGenerator": "NCL v.5.0",
                        "COLARSMASCOLARSMASCCSM4MONTHLYComment": "Dughong Min (dmin@rsmas.miami.edu) and Ben Kirtman (bkirtman@rsmas.miami.edu)",
                        "COLARSMASCOLARSMASCCSM4MONTHLYTitle": "CCSM4.0 National Multi-Model Ensembles(NMME) project",
                        "COLARSMASCOLARSMASCCSM4MONTHLYCreated": "Wed May 7 20:32:28 EDT 2014",
                        "COLARSMASCOLARSMASCCSM4MONTHLYreferences": "Kirtman_etal2014",
                        "COLARSMASCOLARSMASCCSM4MONTHLYexpires": "1617237720",
                        "COLARSMASCOLARSMASCCSM4MONTHLYdata_availability": "fileavail/mark/exch/S2/exch[S1]table:/mark/:table/.html",
                        "COLARSMASCOLARSMASCCSM4MONTHLYConventions": "CF-1.0",
                        "COLARSMASCOLARSMASCCSM4MONTHLYACKNOWLEDGEMENTS": "  Besides the above acknowledgement, users should register any journal articles (or other scientific documents) that are based on NMME-Phase II results.",
                        "COLARSMASCOLARSMASCCSM4HINDCASTSEASONALGHCN_CAMSdescription": "Seasonal (3-month) anomaly correlation between ensemble mean COLA-RSMAS-CCSM4 hindcast temperature and GHCN-CAMS temperature during 1982-2010",
                        "COLARSMASCOLARSMASCCSM4HINDCASTSEASONALERSSTv5description": "Seasonal (3-month) anomaly correlation between ensemble mean COLA-RSMAS-CCSM4 hindcast sst and ERSSTv5 sst during 1982-2010",
                        "COLARSMASCOLARSMASCCSM4HINDCASTSEASONALERSSTv4description": "Seasonal (3-month) anomaly correlation between ensemble mean COLA-RSMAS-CCSM4 hindcast sst and ERSSTv4 sst during 1982-2010",
                        "COLARSMASCOLARSMASCCSM4HINDCASTSEASONALCAMSOPIdescription": "Seasonal (3-month) anomaly correlation between ensemble mean COLA-RSMAS-CCSM4 hindcast precipitation and CAMS-OPI precipitation during 1982-2010",
                        "Conventions": "IRIDL"
                    },
                    "Washington": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Washington",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NCEPCFSv2": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NCEP-CFSv2",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "HINDCAST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HINDCAST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PENTAD_SAMPLES": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PENTAD_SAMPLES",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "SEASONAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SEASONAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "GHCN_CAMS": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "GHCN_CAMS",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "correlation": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "correlation",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "cNZ": "0",
                                                "history": "[[(NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) [(NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1982, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) [(X regridded on anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) (Y regridded on anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                                "CS": "-1",
                                                "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                                "file_missing_value": "9.99900026E20",
                                                "long_name": "correlation",
                                                "missing_value": "NaN",
                                                "colorscalename": "correlationcolorscale",
                                                "pointwidth": "0",
                                                "scale_min": "-1.0",
                                                "standard_name": "air_temperature",
                                                "units": "unitless",
                                                "maxncolor": "254",
                                                "CE": "1",
                                                "gribfield": "1",
                                                "ncolor": "254",
                                                "scale_max": "1.0"
                                            }
                                        },
                                        "ERSSTv5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ERSSTv5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "correlation": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "correlation",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "cNZ": "7",
                                                "history": "[[(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCDC ERSST version5 sst ]) [(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1982, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCDC ERSST version5 sst ]) [(X regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Y regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                                "CS": "-1",
                                                "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                                "file_missing_value": "0.0",
                                                "long_name": "correlation",
                                                "missing_value": "NaN",
                                                "colorscalename": "correlationcolorscale",
                                                "pointwidth": "0",
                                                "scale_min": "-1.0",
                                                "standard_name": "sea_surface_temperature",
                                                "units": "unitless",
                                                "maxncolor": "254",
                                                "CE": "1",
                                                "gribfield": "1",
                                                "fnname": "maskge",
                                                "ncolor": "254",
                                                "scale_max": "1.0"
                                            }
                                        },
                                        "ERSSTv4": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ERSSTv4",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "correlation": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "correlation",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "cNZ": "7",
                                                "history": "[[(NOAA NCDC ERSST version4 sst) [(Version 4 based on Version 3b) (Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCDC ERSST version4 sst ]) [(NOAA NCDC ERSST version4 sst) [(Version 4 based on Version 3b) (Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1982, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCDC ERSST version4 sst ]) [(X regridded on anomaly [ NOAA NCDC ERSST version4 sst ]) (Y regridded on anomaly [ NOAA NCDC ERSST version4 sst ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                                "CS": "-1",
                                                "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                                "file_missing_value": "0.0",
                                                "long_name": "correlation",
                                                "missing_value": "NaN",
                                                "colorscalename": "correlationcolorscale",
                                                "pointwidth": "0",
                                                "scale_min": "-1.0",
                                                "standard_name": "sea_surface_temperature",
                                                "units": "unitless",
                                                "maxncolor": "254",
                                                "CE": "1",
                                                "gribfield": "1",
                                                "fnname": "maskge",
                                                "ncolor": "254",
                                                "scale_max": "1.0"
                                            }
                                        },
                                        "CAMSOPI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CAMS-OPI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "correlation": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "correlation",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "cNZ": "0",
                                                "history": "[[(NOAA NCEP CPC CAMS_OPI v0208 mean prcp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) [(NOAA NCEP CPC CAMS_OPI v0208 mean prcp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1982, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) [(X regridded on anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) (Y regridded on anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                                "CS": "-1",
                                                "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                                "file_missing_value": "9.99900026E20",
                                                "long_name": "correlation",
                                                "missing_value": "NaN",
                                                "colorscalename": "correlationcolorscale",
                                                "pointwidth": "0",
                                                "scale_min": "-1.0",
                                                "standard_name": "lwe_precipitation_rate",
                                                "units": "unitless",
                                                "maxncolor": "254",
                                                "CE": "1",
                                                "gribfield": "1",
                                                "ncolor": "254",
                                                "scale_max": "1.0"
                                            }
                                        }
                                    },
                                    "sc8210": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sc8210",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "tref": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tref",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Near-Surface Temperature",
                                            "units": "Celsius_scale",
                                            "history": "[(Averaged over M[0.5, 24.5]) (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010]) (Averaged in L with overlapping interval 3)]",
                                            "gribcenter": "7",
                                            "gribparam": "11",
                                            "center": "US Weather Service - National Met. Center",
                                            "PDS_TimeRange": "3",
                                            "missing_value": "NaN",
                                            "PTVersion": "2",
                                            "process": " run.",
                                            "pointwidth": "0",
                                            "standard_name": "air_temperature",
                                            "grib_name": "TMP",
                                            "GRIBgridcode": "3",
                                            "gribfield": "1",
                                            "gribNumBits": "21",
                                            "gribleveltype": "105"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "time",
                                            "long_name": "Time",
                                            "pointwidth": "3",
                                            "calendar": "360",
                                            "units": "months since 1960-01-01"
                                        },
                                        "sst": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sst",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "history": "[(Averaged over M[0.5, 24.5]) (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010]) (Averaged in L with overlapping interval 3)]",
                                            "gribcenter": "7",
                                            "gribparam": "11",
                                            "center": "US Weather Service - National Met. Center",
                                            "PDS_TimeRange": "3",
                                            "long_name": "Sea Surface Temperature",
                                            "missing_value": "NaN",
                                            "PTVersion": "2",
                                            "process": " run.",
                                            "pointwidth": "0",
                                            "standard_name": "sea_surface_temperature",
                                            "units": "Celsius_scale",
                                            "grib_name": "TMP",
                                            "GRIBgridcode": "3",
                                            "gribfield": "1",
                                            "gribNumBits": "21",
                                            "gribleveltype": "1"
                                        },
                                        "prec": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prec",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "history": "[(Averaged over M[0.5, 24.5]) (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010]) (Averaged in L with overlapping interval 3)]",
                                            "gribcenter": "7",
                                            "gribparam": "59",
                                            "center": "US Weather Service - National Met. Center",
                                            "PDS_TimeRange": "3",
                                            "long_name": "Total Precipitation",
                                            "missing_value": "NaN",
                                            "PTVersion": "2",
                                            "process": " run.",
                                            "pointwidth": "0",
                                            "standard_name": "precipitation_rate",
                                            "units": "mm/day",
                                            "grib_name": "PRATE",
                                            "GRIBgridcode": "3",
                                            "gribfield": "1",
                                            "gribNumBits": "13",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "MONTHLY": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "MONTHLY",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "tref": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tref",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "air_temperature",
                                            "long_name": "Reference Temperature",
                                            "missing_value": "NaN",
                                            "units": "Kelvin_scale",
                                            "history": "Boxes with less than 0.0% dropped",
                                            "file_missing_value": "9.99900026E20",
                                            "cNZ": "0",
                                            "gribfield": "1",
                                            "pointwidth": "0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "calendar": "360",
                                            "long_name": "Forecast Time",
                                            "pointwidth": "1.0",
                                            "units": " months since 1960-01-01"
                                        },
                                        "sst": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sst",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Celsius_scale",
                                            "missing_value": "NaN",
                                            "fnname": "maskge",
                                            "long_name": "Sea Surface Temperature",
                                            "file_missing_value": "0.0",
                                            "standard_name": "sea_surface_temperature",
                                            "cNZ": "7",
                                            "gribfield": "1",
                                            "pointwidth": "0"
                                        },
                                        "prec": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prec",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "lwe_precipitation_rate",
                                            "long_name": "Total Precipitation",
                                            "missing_value": "NaN",
                                            "units": "mm/day",
                                            "history": "Boxes with less than 0.0% dropped",
                                            "file_missing_value": "9.99900026E20",
                                            "cNZ": "0",
                                            "gribfield": "1",
                                            "pointwidth": "0"
                                        }
                                    },
                                    "mc8210": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mc8210",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "tref": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tref",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Near-Surface Temperature",
                                            "units": "Celsius_scale",
                                            "history": "[(Averaged over M[0.5, 24.5]) (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010])]",
                                            "gribcenter": "7",
                                            "gribparam": "11",
                                            "center": "US Weather Service - National Met. Center",
                                            "PDS_TimeRange": "3",
                                            "PTVersion": "2",
                                            "process": " run.",
                                            "pointwidth": "0",
                                            "standard_name": "air_temperature",
                                            "grib_name": "TMP",
                                            "GRIBgridcode": "3",
                                            "gribfield": "1",
                                            "gribNumBits": "21",
                                            "gribleveltype": "105"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "time",
                                            "long_name": "Time",
                                            "pointwidth": "1",
                                            "calendar": "360",
                                            "units": "months since 1960-01-01"
                                        },
                                        "sst": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sst",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "history": "[(Averaged over M[0.5, 24.5]) (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010])]",
                                            "gribcenter": "7",
                                            "gribparam": "11",
                                            "center": "US Weather Service - National Met. Center",
                                            "PDS_TimeRange": "3",
                                            "long_name": "Sea Surface Temperature",
                                            "PTVersion": "2",
                                            "process": " run.",
                                            "pointwidth": "0",
                                            "standard_name": "sea_surface_temperature",
                                            "units": "Celsius_scale",
                                            "grib_name": "TMP",
                                            "GRIBgridcode": "3",
                                            "gribfield": "1",
                                            "gribNumBits": "21",
                                            "gribleveltype": "1"
                                        },
                                        "prec": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prec",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "history": "[(Averaged over M[0.5, 24.5]) (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010])]",
                                            "gribcenter": "7",
                                            "gribparam": "59",
                                            "center": "US Weather Service - National Met. Center",
                                            "PDS_TimeRange": "3",
                                            "long_name": "Total Precipitation",
                                            "PTVersion": "2",
                                            "process": " run.",
                                            "pointwidth": "0",
                                            "standard_name": "precipitation_rate",
                                            "units": "mm/day",
                                            "grib_name": "PRATE",
                                            "GRIBgridcode": "3",
                                            "gribfield": "1",
                                            "gribNumBits": "13",
                                            "gribleveltype": "1"
                                        }
                                    }
                                }
                            },
                            "FORECAST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "FORECAST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PENTAD_SAMPLES": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PENTAD_SAMPLES",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "MONTHLY": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "MONTHLY",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "tref": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tref",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "air_temperature",
                                            "long_name": "Reference Temperature",
                                            "missing_value": "NaN",
                                            "units": "Kelvin_scale",
                                            "history": "Boxes with less than 0.0% dropped",
                                            "file_missing_value": "9.99900026E20",
                                            "cNZ": "0",
                                            "gribfield": "1",
                                            "pointwidth": "0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "time",
                                            "pointwidth": "1",
                                            "calendar": "360",
                                            "long_name": "Forecast Time",
                                            "units": "months since 1960-01-01"
                                        },
                                        "sst": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sst",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Celsius_scale",
                                            "missing_value": "NaN",
                                            "fnname": "maskge",
                                            "long_name": "Sea Surface Temperature",
                                            "standard_name": "sea_surface_temperature",
                                            "file_missing_value": "0.0",
                                            "cNZ": "7",
                                            "gribfield": "1",
                                            "pointwidth": "0"
                                        },
                                        "prec": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prec",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "lwe_precipitation_rate",
                                            "long_name": "Total Precipitation",
                                            "missing_value": "NaN",
                                            "units": "mm/day",
                                            "history": "Boxes with less than 0.0% dropped",
                                            "file_missing_value": "9.99900026E20",
                                            "cNZ": "0",
                                            "gribfield": "1",
                                            "pointwidth": "0"
                                        }
                                    }
                                }
                            }
                        }
                    },
                    "NASA": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NASA",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NASAGMAO062012": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NASA-GMAO-062012",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "MONTHLY": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MONTHLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tref": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tref",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Reference Temperature",
                                    "standard_name": "air_temperature",
                                    "units": "Kelvin_scale",
                                    "missing_value": "9.99999987E14",
                                    "pointwidth": "0"
                                },
                                "t2mmin": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmin",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "file_missing_value": "9.99999987E14",
                                    "units": "Celsius_scale",
                                    "long_name": "Minimum Temperature",
                                    "standard_name": "air_temperature",
                                    "pointwidth": "0"
                                },
                                "t2mmax": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmax",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "file_missing_value": "9.99999987E14",
                                    "units": "Celsius_scale",
                                    "long_name": "Maximum Temperature",
                                    "standard_name": "air_temperature",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "file_missing_value": "9.99999987E14",
                                    "units": "Celsius_scale",
                                    "long_name": "Sea Surface Temperature",
                                    "standard_name": "sea_surface_temperature",
                                    "pointwidth": "0"
                                },
                                "runoff": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "runoff",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "mm/s",
                                    "long_name": "Runoff",
                                    "standard_name": "runoff_flux",
                                    "missing_value": "9.99999987E14",
                                    "pointwidth": "0"
                                },
                                "prec": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prec",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "mm/day",
                                    "missing_value": "NaN",
                                    "file_missing_value": "9.99999987E14",
                                    "long_name": "Total Precipitation",
                                    "standard_name": "lwe_precipitation_rate",
                                    "pointwidth": "0"
                                },
                                "mmdd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mmdd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "evap": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "evap",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "W m-2",
                                    "long_name": "Evaporation",
                                    "missing_value": "9.99999987E14",
                                    "pointwidth": "0"
                                }
                            },
                            "HINDCAST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HINDCAST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "SEASONAL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SEASONAL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "GHCN_CAMS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "GHCN_CAMS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[[(NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) [(NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) [(X regridded on anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) (Y regridded on anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "defaultvalue": "695.0",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "9.99999987E14",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "pointwidth": "0",
                                            "scale_min": "-1.0",
                                            "standard_name": "air_temperature",
                                            "units": "unitless",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    },
                                    "ERSSTv5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ERSSTv5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[[(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCDC ERSST version5 sst ]) [(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCDC ERSST version5 sst ]) [(X regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Y regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "defaultvalue": "696.0",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "9.99999987E14",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "pointwidth": "0",
                                            "scale_min": "-1.0",
                                            "standard_name": "sea_surface_temperature",
                                            "units": "unitless",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    },
                                    "ERSSTv4": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ERSSTv4",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[[(NOAA NCDC ERSST version4 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCDC ERSST version4 sst ]) [(NOAA NCDC ERSST version4 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCDC ERSST version4 sst ]) [(X regridded on anomaly [ NOAA NCDC ERSST version4 sst ]) (Y regridded on anomaly [ NOAA NCDC ERSST version4 sst ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "defaultvalue": "695.0",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "9.99999987E14",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "pointwidth": "0",
                                            "scale_min": "-1.0",
                                            "standard_name": "sea_surface_temperature",
                                            "units": "unitless",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    },
                                    "CAMSOPI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CAMS-OPI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[[(NOAA NCEP CPC CAMS_OPI v0208 mean prcp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) [(NOAA NCEP CPC CAMS_OPI v0208 mean prcp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) [(X regridded on anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) (Y regridded on anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "defaultvalue": "695.0",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "9.99999987E14",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "pointwidth": "0",
                                            "scale_min": "-1.0",
                                            "standard_name": "lwe_precipitation_rate",
                                            "units": "unitless",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    }
                                }
                            }
                        }
                    },
                    "Montreal": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Montreal",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "GEMNEMO": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "GEM-NEMO",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "HINDCAST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HINDCAST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "SEASONAL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SEASONAL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "GHCN_CAMS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "GHCN_CAMS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[([[(NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) [(NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) [(X regridded on anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) (Y regridded on anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]) (S:  0000 1 Jul to 0000 1 Dec 1960 appended from GEM-NEMO_tref_anomcorr_s8110_Jul-Dec.nc correlation)]",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "9.99900026E20",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "scale_min": "-1.0",
                                            "pointwidth": "0",
                                            "gribPDSpattern": "04XXXX",
                                            "standard_name": "air_temperature",
                                            "units": "unitless",
                                            "grib_name": "TMP",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    },
                                    "ERSSTv5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ERSSTv5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[([[(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCDC ERSST version5 sst ]) [(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCDC ERSST version5 sst ]) [(X regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Y regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]) (S:  0000 1 Jul to 0000 1 Dec 1960 appended from GEM-NEMO_ERSSTv5_anomcorr_s8110_Jul-Dec.nc correlation)]",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "9.99900026E20",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "scale_min": "-1.0",
                                            "pointwidth": "0",
                                            "gribPDSpattern": "04XXXX",
                                            "standard_name": "sea_surface_temperature",
                                            "units": "unitless",
                                            "grib_name": "WTMP",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    },
                                    "CAMSOPI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CAMS-OPI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[([[(NOAA NCEP CPC CAMS_OPI v0208 mean prcp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) [(NOAA NCEP CPC CAMS_OPI v0208 mean prcp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) [(X regridded on anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) (Y regridded on anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]) (S:  0000 1 Jul to 0000 1 Dec 1960 appended from GEM-NEMO_prcp_anomcorr_s8110_Jul-Dec.nc correlation)]",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "9.99900026E20",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "scale_min": "-1.0",
                                            "pointwidth": "0",
                                            "gribPDSpattern": "04XXXX",
                                            "standard_name": "lwe_pecipitation_rate",
                                            "units": "unitless",
                                            "grib_name": "PRATE",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    }
                                },
                                "sc8110": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sc8110",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Near-Surface Temperature",
                                        "units": "Celsius_scale",
                                        "grib_name": "TMP",
                                        "history": "[(mean [ Models NMME GEM-NEMO HINDCAST MONTHLY tref ]) [(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "standard_name": "air_temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "gribPDSpattern": "04XXXX",
                                        "missing_value": "NaN",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "pointwidth": "1",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "41.850006",
                                        "scale_min": "-8.1499939",
                                        "units": "Celsius_scale",
                                        "grib_name": "WTMP",
                                        "history": "[(mean [ Models NMME GEM-NEMO HINDCAST MONTHLY sst ]) [(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "standard_name": "sea_surface_temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Sea Surface Temperature",
                                        "gribPDSpattern": "04XXXX",
                                        "missing_value": "NaN",
                                        "pointwidth": "0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mm/day",
                                        "grib_name": "PRATE",
                                        "history": "[(mean [ Models NMME GEM-NEMO HINDCAST MONTHLY prec ]) [(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "standard_name": "lwe_pecipitation_rate",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Total Precipitation",
                                        "gribPDSpattern": "04XXXX",
                                        "missing_value": "NaN",
                                        "pointwidth": "0"
                                    }
                                },
                                "MONTHLY": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "MONTHLY",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "vgrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vgrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Meridional Wind",
                                        "units": "m s-1",
                                        "grib_name": "VGRD",
                                        "standard_name": "northward_wind",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "650.0"
                                    },
                                    "ugrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ugrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Zonal Wind",
                                        "units": "m s-1",
                                        "grib_name": "UGRD",
                                        "standard_name": "eastward_wind",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "650.0"
                                    },
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Reference Temperature",
                                        "units": "K",
                                        "grib_name": "TMP",
                                        "standard_name": "air_temperature",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "0"
                                    },
                                    "tmp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "850 hPa Temperature",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TMP",
                                        "standard_name": "air_temperature",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Sea Surface Temperature",
                                        "units": "K",
                                        "grib_name": "WTMP",
                                        "standard_name": "sea_surface_temperature",
                                        "scale_min": "260.0",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "0"
                                    },
                                    "prmsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prmsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Pressure Reduced to Mean Sea Level",
                                        "units": "Pa",
                                        "grib_name": "PRMSL",
                                        "standard_name": "air_pressure_at_sea_level",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "PRATE",
                                        "standard_name": "lwe_pecipitation_rate",
                                        "units": "mm/day",
                                        "file_missing_value": "9.99900026E20",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "0"
                                    },
                                    "hgt": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hgt",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Geopotential Height",
                                        "units": "gpm",
                                        "grib_name": "HGT",
                                        "standard_name": "geopotential_height",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "300.0"
                                    }
                                },
                                "mc8110": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mc8110",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Near-Surface Temperature",
                                        "units": "Celsius_scale",
                                        "grib_name": "TMP",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "standard_name": "air_temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "gribPDSpattern": "04XXXX",
                                        "missing_value": "NaN",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "pointwidth": "1",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "41.850006",
                                        "scale_min": "-8.1499939",
                                        "units": "Celsius_scale",
                                        "grib_name": "WTMP",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "standard_name": "sea_surface_temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Sea Surface Temperature",
                                        "gribPDSpattern": "04XXXX",
                                        "missing_value": "NaN",
                                        "pointwidth": "0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mm/day",
                                        "grib_name": "PRATE",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "standard_name": "lwe_pecipitation_rate",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Total Precipitation",
                                        "gribPDSpattern": "04XXXX",
                                        "missing_value": "NaN",
                                        "pointwidth": "0"
                                    }
                                }
                            },
                            "FORECAST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "FORECAST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "MONTHLY": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "MONTHLY",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "vgrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vgrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Meridional Wind",
                                        "units": "m s-1",
                                        "grib_name": "VGRD",
                                        "standard_name": "northward_wind",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "650.0"
                                    },
                                    "ugrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ugrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Zonal Wind",
                                        "units": "m s-1",
                                        "grib_name": "UGRD",
                                        "standard_name": "eastward_wind",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "650.0"
                                    },
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Reference Temperature",
                                        "units": "K",
                                        "grib_name": "TMP",
                                        "standard_name": "air_temperature",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "tmp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "850 hPa Temperature",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TMP",
                                        "standard_name": "air_temperature",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "tmin": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmin",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Minimum Temperature",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TMIN",
                                        "standard_name": "air_temperature",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "tmax": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmax",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Maximum Temperature",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TMAX",
                                        "standard_name": "air_temperature",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "expires": "1617260400",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0",
                                        "defaultvalue": "734.0",
                                        "bounds": "S"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Sea Surface Temperature",
                                        "units": "K",
                                        "grib_name": "WTMP",
                                        "standard_name": "sea_surface_temperature",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "prmsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prmsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Pressure Reduced to Mean Sea Level",
                                        "units": "Pa",
                                        "grib_name": "PRMSL",
                                        "standard_name": "air_pressure_at_sea_level",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "PRATE",
                                        "standard_name": "lwe_pecipitation_rate",
                                        "expires": "1617260400",
                                        "units": "mm/day",
                                        "file_missing_value": "9.99900026E20",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "hgt": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hgt",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Geopotential Height",
                                        "units": "gpm",
                                        "grib_name": "HGT",
                                        "standard_name": "geopotential_height",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "300.0"
                                    }
                                }
                            }
                        },
                        "CMC2CanCM4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "CMC2-CanCM4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "HINDCAST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HINDCAST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "SEASONAL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SEASONAL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "GHCN_CAMS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "GHCN_CAMS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "CE": "1",
                                            "CS": "-1",
                                            "long_name": "correlation",
                                            "pointwidth": "0",
                                            "gribparam": "11",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "maxncolor": "254",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "standard_name": "air_temperature",
                                            "history": "[[(NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) [(NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) [(X regridded on anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) (Y regridded on anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "gribleveltype": "105",
                                            "scale_min": "-1.0",
                                            "file_missing_value": "9.99900026E20",
                                            "units": "unitless",
                                            "colorscalename": "correlationcolorscale",
                                            "ncolor": "254",
                                            "missing_value": "NaN",
                                            "gribNumBits": "16",
                                            "gribfield": "1",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "TMP"
                                        }
                                    },
                                    "ERSSTv5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ERSSTv5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "CE": "1",
                                            "CS": "-1",
                                            "long_name": "correlation",
                                            "pointwidth": "0",
                                            "gribparam": "80",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "maxncolor": "254",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "standard_name": "sea_surface_temperature",
                                            "history": "[[(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCDC ERSST version5 sst ]) [(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCDC ERSST version5 sst ]) [(X regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Y regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "gribleveltype": "1",
                                            "scale_min": "-1.0",
                                            "file_missing_value": "9.99900026E20",
                                            "units": "unitless",
                                            "colorscalename": "correlationcolorscale",
                                            "ncolor": "254",
                                            "missing_value": "NaN",
                                            "gribNumBits": "16",
                                            "gribfield": "1",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "WTMP"
                                        }
                                    },
                                    "ERSSTv4": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ERSSTv4",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "CE": "1",
                                            "CS": "-1",
                                            "long_name": "correlation",
                                            "pointwidth": "0",
                                            "gribparam": "80",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "maxncolor": "254",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "standard_name": "sea_surface_temperature",
                                            "history": "[[(NOAA NCDC ERSST version4 sst) [(Version 4 based on Version 3b) (Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCDC ERSST version4 sst ]) [(NOAA NCDC ERSST version4 sst) [(Version 4 based on Version 3b) (Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCDC ERSST version4 sst ]) [(X regridded on anomaly [ NOAA NCDC ERSST version4 sst ]) (Y regridded on anomaly [ NOAA NCDC ERSST version4 sst ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "gribleveltype": "1",
                                            "scale_min": "-1.0",
                                            "file_missing_value": "9.99900026E20",
                                            "units": "unitless",
                                            "colorscalename": "correlationcolorscale",
                                            "ncolor": "254",
                                            "missing_value": "NaN",
                                            "gribNumBits": "16",
                                            "gribfield": "1",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "WTMP"
                                        }
                                    },
                                    "CAMSOPI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CAMS-OPI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "CE": "1",
                                            "CS": "-1",
                                            "long_name": "correlation",
                                            "pointwidth": "0",
                                            "gribparam": "59",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "maxncolor": "254",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "standard_name": "lwe_precipitation_rate",
                                            "history": "[[(NOAA NCEP CPC CAMS_OPI v0208 mean prcp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) [(NOAA NCEP CPC CAMS_OPI v0208 mean prcp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) [(X regridded on anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) (Y regridded on anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "gribleveltype": "1",
                                            "scale_min": "-1.0",
                                            "file_missing_value": "9.99900026E20",
                                            "units": "unitless",
                                            "colorscalename": "correlationcolorscale",
                                            "ncolor": "254",
                                            "missing_value": "NaN",
                                            "gribNumBits": "16",
                                            "gribfield": "1",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "PRATE"
                                        }
                                    }
                                },
                                "sc8110": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sc8110",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Near-Surface Temperature",
                                        "units": "Celsius_scale",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)]",
                                        "gribcenter": "54",
                                        "gribparam": "11",
                                        "center": "Montreal (RSMC)",
                                        "PDS_TimeRange": "10",
                                        "file_missing_value": "9.99900026E20",
                                        "missing_value": "NaN",
                                        "pointwidth": "0",
                                        "standard_name": "air_temperature",
                                        "grib_name": "TMP",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribleveltype": "105"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "pointwidth": "3",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Celsius_scale",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)]",
                                        "gribcenter": "54",
                                        "gribparam": "80",
                                        "center": "Montreal (RSMC)",
                                        "PDS_TimeRange": "10",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Sea Surface Temperature",
                                        "missing_value": "NaN",
                                        "pointwidth": "0",
                                        "standard_name": "sea_surface_temperature",
                                        "grib_name": "WTMP",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)]",
                                        "gribcenter": "54",
                                        "gribparam": "59",
                                        "center": "Montreal (RSMC)",
                                        "PDS_TimeRange": "10",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Total Precipitation",
                                        "missing_value": "NaN",
                                        "pointwidth": "0",
                                        "standard_name": "lwe_precipitation_rate",
                                        "units": "mm/day",
                                        "grib_name": "PRATE",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1"
                                    }
                                },
                                "MONTHLY": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "MONTHLY",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "vrgd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vrgd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "34",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "VGRD",
                                        "gribfield": "1",
                                        "units": "m/s",
                                        "PDS_TimeRange": "10",
                                        "gribcenter": "54",
                                        "long_name": "Meridional Wind",
                                        "standard_name": "northward_wind",
                                        "gribvariable": "34",
                                        "gribleveltype": "100",
                                        "pointwidth": "0"
                                    },
                                    "vgrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vgrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "34",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "VGRD",
                                        "gribfield": "1",
                                        "units": "m/s",
                                        "PDS_TimeRange": "10",
                                        "gribcenter": "54",
                                        "long_name": "Meridional Wind",
                                        "standard_name": "northward_wind",
                                        "gribvariable": "34",
                                        "gribleveltype": "100",
                                        "pointwidth": "0"
                                    },
                                    "ugrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ugrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "33",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "UGRD",
                                        "gribfield": "1",
                                        "units": "m/s",
                                        "PDS_TimeRange": "10",
                                        "gribcenter": "54",
                                        "long_name": "Zonal Wind",
                                        "standard_name": "eastward_wind",
                                        "gribvariable": "33",
                                        "gribleveltype": "100",
                                        "pointwidth": "0"
                                    },
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "11",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMP",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Reference Temperature at 2 Meters",
                                        "gribcenter": "54",
                                        "standard_name": "air_temperature",
                                        "gribleveltype": "105",
                                        "pointwidth": "0"
                                    },
                                    "tmp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribvariable": "11",
                                        "gribfield": "1",
                                        "gribleveltype": "100",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "11",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMP",
                                        "PDS_TimeRange": "10",
                                        "long_name": "850 hPa Temperature",
                                        "gribcenter": "54",
                                        "standard_name": "air_temperature",
                                        "pointwidth": "0"
                                    },
                                    "tmin": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmin",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "16",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMIN",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Minimum Temperature at 2 Meters",
                                        "gribcenter": "54",
                                        "standard_name": "air_temperature",
                                        "gribleveltype": "105",
                                        "pointwidth": "0"
                                    },
                                    "tmax": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmax",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "15",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMAX",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Maximum Temperature at 2 Meters",
                                        "gribcenter": "54",
                                        "standard_name": "air_temperature",
                                        "gribleveltype": "105",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "80",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "WTMP",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Sea Surface Temperature",
                                        "gribcenter": "54",
                                        "standard_name": "sea_surface_temperature",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "soilw": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilw",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "kg/m2",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "127",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "IMGD",
                                        "PDS_TimeRange": "0",
                                        "long_name": "Soil Moisture Content 0-10cm Below Surface",
                                        "gribcenter": "54",
                                        "standard_name": "soil_moisture_content",
                                        "gribleveltype": "119",
                                        "pointwidth": "0"
                                    },
                                    "prmsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prmsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "2",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "PRMSL",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Pressure Reduced to Mean Sea Level",
                                        "gribcenter": "54",
                                        "standard_name": "air_pressure_at_sea_level",
                                        "gribleveltype": "102",
                                        "pointwidth": "0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "units": "mm/day",
                                        "file_missing_value": "9.99900026E20",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribparam": "59",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "PRATE",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Total Precipitation",
                                        "gribcenter": "54",
                                        "standard_name": "lwe_precipitation_rate",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    }
                                },
                                "mc8110": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mc8110",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Near-Surface Temperature",
                                        "units": "Celsius_scale",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "gribcenter": "54",
                                        "gribparam": "11",
                                        "center": "Montreal (RSMC)",
                                        "PDS_TimeRange": "10",
                                        "file_missing_value": "9.99900026E20",
                                        "missing_value": "NaN",
                                        "pointwidth": "0",
                                        "standard_name": "air_temperature",
                                        "grib_name": "TMP",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribleveltype": "105"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "pointwidth": "1",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Celsius_scale",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "gribcenter": "54",
                                        "gribparam": "80",
                                        "center": "Montreal (RSMC)",
                                        "PDS_TimeRange": "10",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Sea Surface Temperature",
                                        "missing_value": "NaN",
                                        "pointwidth": "0",
                                        "standard_name": "sea_surface_temperature",
                                        "grib_name": "WTMP",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "gribcenter": "54",
                                        "gribparam": "59",
                                        "center": "Montreal (RSMC)",
                                        "PDS_TimeRange": "10",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Total Precipitation",
                                        "missing_value": "NaN",
                                        "pointwidth": "0",
                                        "standard_name": "lwe_precipitation_rate",
                                        "units": "mm/day",
                                        "grib_name": "PRATE",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1"
                                    }
                                }
                            },
                            "FORECAST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "FORECAST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "MONTHLY": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "MONTHLY",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "vgrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vgrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY vgrd",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "34",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "VGRD",
                                        "gribfield": "1",
                                        "units": "m/s",
                                        "PDS_TimeRange": "10",
                                        "gribcenter": "54",
                                        "long_name": "Meridional Wind",
                                        "standard_name": "northward_wind",
                                        "gribvariable": "34",
                                        "gribleveltype": "100",
                                        "pointwidth": "0"
                                    },
                                    "ugrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ugrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY ugrd",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "33",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "UGRD",
                                        "gribfield": "1",
                                        "units": "m/s",
                                        "PDS_TimeRange": "10",
                                        "gribcenter": "54",
                                        "long_name": "Zonal Wind",
                                        "standard_name": "eastward_wind",
                                        "gribvariable": "33",
                                        "gribleveltype": "100",
                                        "pointwidth": "0"
                                    },
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY tref",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "11",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMP",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Reference Temperature at 2 Meters",
                                        "gribcenter": "54",
                                        "standard_name": "air_temperature",
                                        "gribleveltype": "105",
                                        "pointwidth": "0"
                                    },
                                    "tmp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY tmp",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "11",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMP",
                                        "gribfield": "1",
                                        "units": "Kelvin_scale",
                                        "PDS_TimeRange": "10",
                                        "gribcenter": "54",
                                        "long_name": "850 hPa Temperature",
                                        "standard_name": "air_temperature",
                                        "gribvariable": "11",
                                        "gribleveltype": "100",
                                        "pointwidth": "0"
                                    },
                                    "tmin": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmin",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Minimum Temperature",
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY tmin",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "16",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMIN",
                                        "PDS_TimeRange": "2",
                                        "gribcenter": "54",
                                        "standard_name": "air_temperature",
                                        "gribleveltype": "119",
                                        "pointwidth": "0"
                                    },
                                    "tmax": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmax",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Maximum Temperature",
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY tmax",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "15",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMAX",
                                        "PDS_TimeRange": "2",
                                        "gribcenter": "54",
                                        "standard_name": "air_temperature",
                                        "gribleveltype": "119",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY sst",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "80",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "WTMP",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Sea Surface Temperature",
                                        "gribcenter": "54",
                                        "standard_name": "sea_surface_temperature",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "soilw": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilw",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY soilw",
                                        "units": "kg/m2",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "127",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "IMGD",
                                        "PDS_TimeRange": "0",
                                        "long_name": "Soil Moisture Content 0-10cm Below Surface",
                                        "gribcenter": "54",
                                        "standard_name": "soil_moisture_content",
                                        "gribleveltype": "119",
                                        "pointwidth": "0"
                                    },
                                    "prmsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prmsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY prmsl",
                                        "units": "Pa",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "2",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "PRMSL",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Pressure Reduced to Mean Sea Level",
                                        "gribcenter": "54",
                                        "standard_name": "air_pressure_at_sea_level",
                                        "gribleveltype": "102",
                                        "pointwidth": "0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY prec",
                                        "missing_value": "NaN",
                                        "units": "mm/day",
                                        "file_missing_value": "9.99900026E20",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribparam": "59",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "PRATE",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Total Precipitation",
                                        "gribcenter": "54",
                                        "standard_name": "lwe_precipitation_rate",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "orig": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "orig",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "vgrd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vgrd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "34",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "VGRD",
                                            "gribfield": "1",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "long_name": "Meridional Wind",
                                            "standard_name": "northward_wind",
                                            "gribvariable": "34",
                                            "gribleveltype": "100",
                                            "pointwidth": "0"
                                        },
                                        "ugrd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ugrd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "33",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "UGRD",
                                            "gribfield": "1",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "long_name": "Zonal Wind",
                                            "standard_name": "eastward_wind",
                                            "gribvariable": "33",
                                            "gribleveltype": "100",
                                            "pointwidth": "0"
                                        },
                                        "tref": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tref",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribfield": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "11",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "TMP",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Reference Temperature",
                                            "gribcenter": "54",
                                            "standard_name": "air_temperature",
                                            "gribleveltype": "105",
                                            "pointwidth": "0"
                                        },
                                        "tmp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tmp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "11",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "TMP",
                                            "gribfield": "1",
                                            "units": "Kelvin_scale",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "long_name": "850 hPa Temperature",
                                            "standard_name": "air_temperature",
                                            "gribvariable": "11",
                                            "gribleveltype": "100",
                                            "pointwidth": "0"
                                        },
                                        "tmin": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tmin",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribfield": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "16",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "TMIN",
                                            "PDS_TimeRange": "2",
                                            "long_name": "Minimum Temperature",
                                            "gribcenter": "54",
                                            "standard_name": "air_temperature",
                                            "gribleveltype": "119",
                                            "pointwidth": "0"
                                        },
                                        "tmax": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tmax",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribfield": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "15",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "TMAX",
                                            "PDS_TimeRange": "2",
                                            "long_name": "Maximum Temperature",
                                            "gribcenter": "54",
                                            "standard_name": "air_temperature",
                                            "gribleveltype": "119",
                                            "pointwidth": "0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "time",
                                            "long_name": "Time",
                                            "calendar": "360",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "1.0"
                                        },
                                        "sst": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sst",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribfield": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "80",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "WTMP",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Sea Surface Temperature",
                                            "gribcenter": "54",
                                            "standard_name": "sea_surface_temperature",
                                            "gribleveltype": "1",
                                            "pointwidth": "0"
                                        },
                                        "soilw": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilw",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "kg/m2",
                                            "gribfield": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "127",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "IMGD",
                                            "PDS_TimeRange": "0",
                                            "long_name": "Soil Moisture Content 0-10cm Below Surface",
                                            "gribcenter": "54",
                                            "standard_name": "soil_moisture_content",
                                            "gribleveltype": "119",
                                            "pointwidth": "0"
                                        },
                                        "prmsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prmsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa",
                                            "gribfield": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "2",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "PRMSL",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Pressure Reduced to Mean Sea Level",
                                            "gribcenter": "54",
                                            "standard_name": "air_pressure_at_sea_level",
                                            "gribleveltype": "102",
                                            "pointwidth": "0"
                                        },
                                        "prec": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prec",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "NaN",
                                            "units": "mm/day",
                                            "file_missing_value": "9.99900026E20",
                                            "gribfield": "1",
                                            "gribNumBits": "16",
                                            "gribparam": "59",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "PRATE",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Total Precipitation",
                                            "gribcenter": "54",
                                            "standard_name": "lwe_precipitation_rate",
                                            "gribleveltype": "1",
                                            "pointwidth": "0"
                                        }
                                    }
                                }
                            }
                        },
                        "CMC1CanCM3": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "CMC1-CanCM3",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "HINDCAST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HINDCAST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "SEASONAL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SEASONAL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "GHCN_CAMS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "GHCN_CAMS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "CE": "1",
                                            "CS": "-1",
                                            "long_name": "correlation",
                                            "pointwidth": "0",
                                            "gribparam": "11",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "maxncolor": "254",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "standard_name": "air_temperature",
                                            "history": "[[(NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) [(NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) [(X regridded on anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) (Y regridded on anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "gribleveltype": "105",
                                            "scale_min": "-1.0",
                                            "file_missing_value": "9.99900026E20",
                                            "units": "unitless",
                                            "colorscalename": "correlationcolorscale",
                                            "ncolor": "254",
                                            "missing_value": "NaN",
                                            "gribNumBits": "16",
                                            "gribfield": "1",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "TMP"
                                        }
                                    },
                                    "ERSSTv5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ERSSTv5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "CE": "1",
                                            "CS": "-1",
                                            "long_name": "correlation",
                                            "pointwidth": "0",
                                            "gribparam": "80",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "maxncolor": "254",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "standard_name": "sea_surface_temperature",
                                            "history": "[[(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCDC ERSST version5 sst ]) [(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCDC ERSST version5 sst ]) [(X regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Y regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "gribleveltype": "1",
                                            "scale_min": "-1.0",
                                            "file_missing_value": "9.99900026E20",
                                            "units": "unitless",
                                            "colorscalename": "correlationcolorscale",
                                            "ncolor": "254",
                                            "missing_value": "NaN",
                                            "gribNumBits": "16",
                                            "gribfield": "1",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "WTMP"
                                        }
                                    },
                                    "ERSSTv4": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ERSSTv4",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "CE": "1",
                                            "CS": "-1",
                                            "long_name": "correlation",
                                            "pointwidth": "0",
                                            "gribparam": "80",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "maxncolor": "254",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "standard_name": "sea_surface_temperature",
                                            "history": "[[(NOAA NCDC ERSST version4 sst) [(Version 4 based on Version 3b) (Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCDC ERSST version4 sst ]) [(NOAA NCDC ERSST version4 sst) [(Version 4 based on Version 3b) (Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCDC ERSST version4 sst ]) [(X regridded on anomaly [ NOAA NCDC ERSST version4 sst ]) (Y regridded on anomaly [ NOAA NCDC ERSST version4 sst ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "gribleveltype": "1",
                                            "scale_min": "-1.0",
                                            "file_missing_value": "9.99900026E20",
                                            "units": "unitless",
                                            "colorscalename": "correlationcolorscale",
                                            "ncolor": "254",
                                            "missing_value": "NaN",
                                            "gribNumBits": "16",
                                            "gribfield": "1",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "WTMP"
                                        }
                                    },
                                    "CAMSOPI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CAMS-OPI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "CE": "1",
                                            "CS": "-1",
                                            "long_name": "correlation",
                                            "pointwidth": "0",
                                            "gribparam": "59",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "maxncolor": "254",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "standard_name": "lwe_precipitation_rate",
                                            "history": "[[(NOAA NCEP CPC CAMS_OPI v0208 mean prcp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) [(NOAA NCEP CPC CAMS_OPI v0208 mean prcp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) [(X regridded on anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) (Y regridded on anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "gribleveltype": "1",
                                            "scale_min": "-1.0",
                                            "file_missing_value": "9.99900026E20",
                                            "units": "unitless",
                                            "colorscalename": "correlationcolorscale",
                                            "ncolor": "254",
                                            "missing_value": "NaN",
                                            "gribNumBits": "16",
                                            "gribfield": "1",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "PRATE"
                                        }
                                    }
                                },
                                "sc8110": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sc8110",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Near-Surface Temperature",
                                        "units": "Celsius_scale",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)]",
                                        "gribcenter": "54",
                                        "gribparam": "11",
                                        "center": "Montreal (RSMC)",
                                        "PDS_TimeRange": "10",
                                        "file_missing_value": "9.99900026E20",
                                        "missing_value": "NaN",
                                        "pointwidth": "0",
                                        "standard_name": "air_temperature",
                                        "grib_name": "TMP",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribleveltype": "105"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "pointwidth": "3",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Celsius_scale",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)]",
                                        "gribcenter": "54",
                                        "gribparam": "80",
                                        "center": "Montreal (RSMC)",
                                        "PDS_TimeRange": "10",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Sea Surface Temperature",
                                        "missing_value": "NaN",
                                        "pointwidth": "0",
                                        "standard_name": "sea_surface_temperature",
                                        "grib_name": "WTMP",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)]",
                                        "gribcenter": "54",
                                        "gribparam": "59",
                                        "center": "Montreal (RSMC)",
                                        "PDS_TimeRange": "10",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Total Precipitation",
                                        "missing_value": "NaN",
                                        "pointwidth": "0",
                                        "standard_name": "lwe_precipitation_rate",
                                        "units": "mm/day",
                                        "grib_name": "PRATE",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1"
                                    }
                                },
                                "MONTHLY": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "MONTHLY",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "vrgd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vrgd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "34",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "VGRD",
                                        "gribfield": "1",
                                        "units": "m/s",
                                        "PDS_TimeRange": "10",
                                        "gribcenter": "54",
                                        "long_name": "Meridional Wind",
                                        "standard_name": "northward_wind",
                                        "gribvariable": "34",
                                        "gribleveltype": "100",
                                        "pointwidth": "0"
                                    },
                                    "ugrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ugrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "33",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "UGRD",
                                        "gribfield": "1",
                                        "units": "m/s",
                                        "PDS_TimeRange": "10",
                                        "gribcenter": "54",
                                        "long_name": "Zonal Wind",
                                        "standard_name": "eastward_wind",
                                        "gribvariable": "33",
                                        "gribleveltype": "100",
                                        "pointwidth": "0"
                                    },
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "11",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMP",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Reference Temperature at 2 Meters",
                                        "gribcenter": "54",
                                        "standard_name": "air_temperature",
                                        "gribleveltype": "105",
                                        "pointwidth": "0"
                                    },
                                    "tmp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribvariable": "11",
                                        "gribfield": "1",
                                        "gribleveltype": "100",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "11",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMP",
                                        "PDS_TimeRange": "10",
                                        "long_name": "850 hPa Temperature",
                                        "gribcenter": "54",
                                        "standard_name": "air_temperature",
                                        "pointwidth": "0"
                                    },
                                    "tmin": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmin",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "16",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMIN",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Minimum Temperature at 2 Meters",
                                        "gribcenter": "54",
                                        "standard_name": "air_temperature",
                                        "gribleveltype": "105",
                                        "pointwidth": "0"
                                    },
                                    "tmax": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmax",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "15",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMAX",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Maximum Temperature at 2 Meters",
                                        "gribcenter": "54",
                                        "standard_name": "air_temperature",
                                        "gribleveltype": "105",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "80",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "WTMP",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Sea Surface Temperature",
                                        "gribcenter": "54",
                                        "standard_name": "sea_surface_temperature",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "soilw": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilw",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "kg/m2",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "127",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "IMGD",
                                        "PDS_TimeRange": "0",
                                        "long_name": "Soil Moisture Content 0-10cm Below Surface",
                                        "gribcenter": "54",
                                        "standard_name": "soil_moisture_content",
                                        "gribleveltype": "119",
                                        "pointwidth": "0"
                                    },
                                    "prmsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prmsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "2",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "PRMSL",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Pressure Reduced to Mean Sea Level",
                                        "gribcenter": "54",
                                        "standard_name": "air_pressure_at_sea_level",
                                        "gribleveltype": "102",
                                        "pointwidth": "0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "units": "mm/day",
                                        "file_missing_value": "9.99900026E20",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribparam": "59",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "PRATE",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Total Precipitation",
                                        "gribcenter": "54",
                                        "standard_name": "lwe_precipitation_rate",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    }
                                },
                                "mc8110": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mc8110",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Near-Surface Temperature",
                                        "units": "Celsius_scale",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "gribcenter": "54",
                                        "gribparam": "11",
                                        "center": "Montreal (RSMC)",
                                        "PDS_TimeRange": "10",
                                        "file_missing_value": "9.99900026E20",
                                        "missing_value": "NaN",
                                        "pointwidth": "0",
                                        "standard_name": "air_temperature",
                                        "grib_name": "TMP",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribleveltype": "105"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "pointwidth": "1",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Celsius_scale",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "gribcenter": "54",
                                        "gribparam": "80",
                                        "center": "Montreal (RSMC)",
                                        "PDS_TimeRange": "10",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Sea Surface Temperature",
                                        "missing_value": "NaN",
                                        "pointwidth": "0",
                                        "standard_name": "sea_surface_temperature",
                                        "grib_name": "WTMP",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "gribcenter": "54",
                                        "gribparam": "59",
                                        "center": "Montreal (RSMC)",
                                        "PDS_TimeRange": "10",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Total Precipitation",
                                        "missing_value": "NaN",
                                        "pointwidth": "0",
                                        "standard_name": "lwe_precipitation_rate",
                                        "units": "mm/day",
                                        "grib_name": "PRATE",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1"
                                    }
                                }
                            },
                            "FORECAST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "FORECAST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "MONTHLY": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "MONTHLY",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "vgrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vgrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY vgrd",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "34",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "VGRD",
                                        "gribfield": "1",
                                        "units": "m/s",
                                        "PDS_TimeRange": "10",
                                        "gribcenter": "54",
                                        "long_name": "Meridional Wind",
                                        "standard_name": "northward_wind",
                                        "gribvariable": "34",
                                        "gribleveltype": "100",
                                        "pointwidth": "0"
                                    },
                                    "ugrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ugrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY ugrd",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "33",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "UGRD",
                                        "gribfield": "1",
                                        "units": "m/s",
                                        "PDS_TimeRange": "10",
                                        "gribcenter": "54",
                                        "long_name": "Zonal Wind",
                                        "standard_name": "eastward_wind",
                                        "gribvariable": "33",
                                        "gribleveltype": "100",
                                        "pointwidth": "0"
                                    },
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY tref",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "11",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMP",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Reference Temperature at 2 Meters",
                                        "gribcenter": "54",
                                        "standard_name": "air_temperature",
                                        "gribleveltype": "105",
                                        "pointwidth": "0"
                                    },
                                    "tmp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY tmp",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "11",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMP",
                                        "gribfield": "1",
                                        "units": "Kelvin_scale",
                                        "PDS_TimeRange": "10",
                                        "gribcenter": "54",
                                        "long_name": "850 hPa Temperature",
                                        "standard_name": "air_temperature",
                                        "gribvariable": "11",
                                        "gribleveltype": "100",
                                        "pointwidth": "0"
                                    },
                                    "tmin": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmin",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Minimum Temperature",
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY tmin",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "16",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMIN",
                                        "PDS_TimeRange": "2",
                                        "gribcenter": "54",
                                        "standard_name": "air_temperature",
                                        "gribleveltype": "119",
                                        "pointwidth": "0"
                                    },
                                    "tmax": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmax",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Maximum Temperature",
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY tmax",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "15",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "TMAX",
                                        "PDS_TimeRange": "2",
                                        "gribcenter": "54",
                                        "standard_name": "air temperature",
                                        "gribleveltype": "119",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY sst",
                                        "units": "Kelvin_scale",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "80",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "WTMP",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Sea Surface Temperature",
                                        "gribcenter": "54",
                                        "standard_name": "sea_surface_temperature",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "soilw": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilw",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY soilw",
                                        "units": "kg/m2",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "127",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "IMGD",
                                        "PDS_TimeRange": "0",
                                        "long_name": "Soil Moisture Content 0-10cm Below Surface",
                                        "gribcenter": "54",
                                        "standard_name": "soil_moisture_content",
                                        "gribleveltype": "119",
                                        "pointwidth": "0"
                                    },
                                    "prmsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prmsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY prmsl",
                                        "units": "Pa",
                                        "gribfield": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "16",
                                        "gribparam": "2",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "PRMSL",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Pressure Reduced to Mean Sea Level",
                                        "gribcenter": "54",
                                        "standard_name": "air_pressure_at_sea_level",
                                        "gribleveltype": "102",
                                        "pointwidth": "0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "S:  0000 1 Dec 2015 to 0000 1 Jul 2019 appended from Models NMME Cansips FORECAST MONTHLY prec",
                                        "missing_value": "NaN",
                                        "units": "mm/day",
                                        "file_missing_value": "9.99900026E20",
                                        "gribfield": "1",
                                        "gribNumBits": "16",
                                        "gribparam": "59",
                                        "center": "Montreal (RSMC)",
                                        "grib_name": "PRATE",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Total Precipitation",
                                        "gribcenter": "54",
                                        "standard_name": "lwe_precipitation_rate",
                                        "gribleveltype": "1",
                                        "pointwidth": "0"
                                    },
                                    "orig": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "orig",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "vgrd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vgrd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "34",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "VGRD",
                                            "gribfield": "1",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "long_name": "Meridional Wind",
                                            "standard_name": "northward_wind",
                                            "gribvariable": "34",
                                            "gribleveltype": "100",
                                            "pointwidth": "0"
                                        },
                                        "ugrd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ugrd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "33",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "UGRD",
                                            "gribfield": "1",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "long_name": "Zonal Wind",
                                            "standard_name": "eastward_wind",
                                            "gribvariable": "33",
                                            "gribleveltype": "100",
                                            "pointwidth": "0"
                                        },
                                        "tref": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tref",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribfield": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "11",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "TMP",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Reference Temperature",
                                            "gribcenter": "54",
                                            "standard_name": "air_temperature",
                                            "gribleveltype": "105",
                                            "pointwidth": "0"
                                        },
                                        "tmp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tmp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "11",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "TMP",
                                            "gribfield": "1",
                                            "units": "Kelvin_scale",
                                            "PDS_TimeRange": "10",
                                            "gribcenter": "54",
                                            "long_name": "850 hPa Temperature",
                                            "standard_name": "air_temperature",
                                            "gribvariable": "11",
                                            "gribleveltype": "100",
                                            "pointwidth": "0"
                                        },
                                        "tmin": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tmin",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribfield": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "16",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "TMIN",
                                            "PDS_TimeRange": "2",
                                            "long_name": "Minimum Temperature",
                                            "gribcenter": "54",
                                            "standard_name": "air_temperature",
                                            "gribleveltype": "119",
                                            "pointwidth": "0"
                                        },
                                        "tmax": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tmax",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribfield": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "15",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "TMAX",
                                            "PDS_TimeRange": "2",
                                            "long_name": "Maximum Temperature",
                                            "gribcenter": "54",
                                            "standard_name": "air temperature",
                                            "gribleveltype": "119",
                                            "pointwidth": "0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "time",
                                            "long_name": "Time",
                                            "calendar": "360",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "1.0"
                                        },
                                        "sst": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sst",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribfield": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "80",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "WTMP",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Sea Surface Temperature",
                                            "gribcenter": "54",
                                            "standard_name": "sea_surface_temperature",
                                            "gribleveltype": "1",
                                            "pointwidth": "0"
                                        },
                                        "soilw": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilw",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "kg/m2",
                                            "gribfield": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "127",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "IMGD",
                                            "PDS_TimeRange": "0",
                                            "long_name": "Soil Moisture Content 0-10cm Below Surface",
                                            "gribcenter": "54",
                                            "standard_name": "soil_moisture_content",
                                            "gribleveltype": "119",
                                            "pointwidth": "0"
                                        },
                                        "prmsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prmsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa",
                                            "gribfield": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "16",
                                            "gribparam": "2",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "PRMSL",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Pressure Reduced to Mean Sea Level",
                                            "gribcenter": "54",
                                            "standard_name": "air_pressure_at_sea_level",
                                            "gribleveltype": "102",
                                            "pointwidth": "0"
                                        },
                                        "prec": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prec",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "missing_value": "NaN",
                                            "units": "mm/day",
                                            "file_missing_value": "9.99900026E20",
                                            "gribfield": "1",
                                            "gribNumBits": "16",
                                            "gribparam": "59",
                                            "center": "Montreal (RSMC)",
                                            "grib_name": "PRATE",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Total Precipitation",
                                            "gribcenter": "54",
                                            "standard_name": "lwe_precipitation_rate",
                                            "gribleveltype": "1",
                                            "pointwidth": "0"
                                        }
                                    }
                                }
                            }
                        },
                        "CanCM4i": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "CanCM4i",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "HINDCAST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HINDCAST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "SEASONAL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SEASONAL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "GHCN_CAMS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "GHCN_CAMS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[([[(NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) [(NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) [(X regridded on anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) (Y regridded on anomaly [ NOAA NCEP CPC GHCN_CAMS gridded deg0p5 temp ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]) (S:  0000 1 Jul to 0000 1 Dec 1960 appended from CanCM4i_tref_anomcorr_s8110_Jul-Dec.nc correlation)]",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "9.99900026E20",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "scale_min": "-1.0",
                                            "pointwidth": "0",
                                            "gribPDSpattern": "04XXXX",
                                            "standard_name": "air_temperature",
                                            "units": "unitless",
                                            "grib_name": "TMP",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    },
                                    "ERSSTv5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ERSSTv5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[([[(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCDC ERSST version5 sst ]) [(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCDC ERSST version5 sst ]) [(X regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Y regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]) (S:  0000 1 Jul to 0000 1 Dec 1960 appended from CanCM4i_ERSSTv5_anomcorr_s8110_Jul-Dec.nc correlation)]",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "9.99900026E20",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "scale_min": "-1.0",
                                            "pointwidth": "0",
                                            "gribPDSpattern": "04XXXX",
                                            "standard_name": "sea_surface_temperature",
                                            "units": "unitless",
                                            "grib_name": "WTMP",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    },
                                    "CAMSOPI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CAMS-OPI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "history": "[([[(NOAA NCEP CPC CAMS_OPI v0208 mean prcp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) [(NOAA NCEP CPC CAMS_OPI v0208 mean prcp) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) [(X regridded on anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) (Y regridded on anomaly [ NOAA NCEP CPC CAMS_OPI v0208 mean prcp ]) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]) (S:  0000 1 Jul to 0000 1 Dec 1960 appended from CanCM4i_prcp_anomcorr_s8110_Jul-Dec.nc correlation)]",
                                            "scale_max": "1.0",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "9.99900026E20",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "scale_min": "-1.0",
                                            "pointwidth": "0",
                                            "gribPDSpattern": "04XXXX",
                                            "standard_name": "lwe_pecipitation_rate",
                                            "units": "unitless",
                                            "grib_name": "PRATE",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    }
                                },
                                "sc8110": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sc8110",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Near-Surface Temperature",
                                        "units": "Celsius_scale",
                                        "grib_name": "TMP",
                                        "history": "[(mean [ Models NMME CanCM4i HINDCAST MONTHLY tref ]) [(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "standard_name": "air_temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "gribPDSpattern": "04XXXX",
                                        "missing_value": "NaN",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "pointwidth": "1",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "41.850006",
                                        "scale_min": "-8.1499939",
                                        "units": "Celsius_scale",
                                        "grib_name": "WTMP",
                                        "history": "[(mean [ Models NMME CanCM4i HINDCAST MONTHLY sst ]) [(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "standard_name": "sea_surface_temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Sea Surface Temperature",
                                        "gribPDSpattern": "04XXXX",
                                        "missing_value": "NaN",
                                        "pointwidth": "0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mm/day",
                                        "grib_name": "PRATE",
                                        "history": "[(mean [ Models NMME CanCM4i HINDCAST MONTHLY prec ]) [(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "standard_name": "lwe_pecipitation_rate",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Total Precipitation",
                                        "gribPDSpattern": "04XXXX",
                                        "missing_value": "NaN",
                                        "pointwidth": "0"
                                    }
                                },
                                "MONTHLY": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "MONTHLY",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "vgrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vgrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Meridional Wind",
                                        "units": "m s-1",
                                        "grib_name": "VGRD",
                                        "standard_name": "northward_wind",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "650.0"
                                    },
                                    "ugrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ugrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Zonal Wind",
                                        "units": "m s-1",
                                        "grib_name": "UGRD",
                                        "standard_name": "eastward_wind",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "650.0"
                                    },
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Reference Temperature",
                                        "units": "K",
                                        "grib_name": "TMP",
                                        "standard_name": "air_temperature",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "0"
                                    },
                                    "tmp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "850 hPa Temperature",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TMP",
                                        "standard_name": "air_temperature",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Sea Surface Temperature",
                                        "units": "K",
                                        "grib_name": "WTMP",
                                        "standard_name": "sea_surface_temperature",
                                        "scale_min": "260.0",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "0"
                                    },
                                    "prmsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prmsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Pressure Reduced to Mean Sea Level",
                                        "units": "Pa",
                                        "grib_name": "PRMSL",
                                        "standard_name": "air_pressure_at_sea_level",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "PRATE",
                                        "standard_name": "lwe_pecipitation_rate",
                                        "units": "mm/day",
                                        "file_missing_value": "9.99900026E20",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "0"
                                    },
                                    "hgt": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hgt",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Geopotential Height",
                                        "units": "gpm",
                                        "grib_name": "HGT",
                                        "standard_name": "geopotential_height",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "300.0"
                                    }
                                },
                                "mc8110": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mc8110",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Near-Surface Temperature",
                                        "units": "Celsius_scale",
                                        "grib_name": "TMP",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "standard_name": "air_temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "gribPDSpattern": "04XXXX",
                                        "missing_value": "NaN",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "pointwidth": "1",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "41.850006",
                                        "scale_min": "-8.1499939",
                                        "units": "Celsius_scale",
                                        "grib_name": "WTMP",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "standard_name": "sea_surface_temperature",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Sea Surface Temperature",
                                        "gribPDSpattern": "04XXXX",
                                        "missing_value": "NaN",
                                        "pointwidth": "0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mm/day",
                                        "grib_name": "PRATE",
                                        "history": "[(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)]",
                                        "standard_name": "lwe_pecipitation_rate",
                                        "file_missing_value": "9.99900026E20",
                                        "long_name": "Total Precipitation",
                                        "gribPDSpattern": "04XXXX",
                                        "missing_value": "NaN",
                                        "pointwidth": "0"
                                    }
                                }
                            },
                            "FORECAST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "FORECAST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "MONTHLY": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "MONTHLY",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "vgrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vgrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Meridional Wind",
                                        "units": "m s-1",
                                        "grib_name": "VGRD",
                                        "standard_name": "northward_wind",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "650.0"
                                    },
                                    "ugrd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ugrd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Zonal Wind",
                                        "units": "m s-1",
                                        "grib_name": "UGRD",
                                        "standard_name": "eastward_wind",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "650.0"
                                    },
                                    "tref": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tref",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Reference Temperature",
                                        "units": "K",
                                        "grib_name": "TMP",
                                        "standard_name": "air_temperature",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "tmp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "850 hPa Temperature",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TMP",
                                        "standard_name": "air_temperature",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "tmin": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmin",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Minimum Temperature",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TMIN",
                                        "standard_name": "air_temperature",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "tmax": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmax",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Maximum Temperature",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TMAX",
                                        "standard_name": "air_temperature",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Time",
                                        "expires": "1617260400",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0",
                                        "defaultvalue": "734.0",
                                        "bounds": "S"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Sea Surface Temperature",
                                        "units": "K",
                                        "grib_name": "WTMP",
                                        "standard_name": "sea_surface_temperature",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "prmsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prmsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Pressure Reduced to Mean Sea Level",
                                        "units": "Pa",
                                        "grib_name": "PRMSL",
                                        "standard_name": "air_pressure_at_sea_level",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "PRATE",
                                        "standard_name": "lwe_pecipitation_rate",
                                        "expires": "1617260400",
                                        "units": "mm/day",
                                        "file_missing_value": "9.99900026E20",
                                        "gribPDSpattern": "04XXXX",
                                        "defaultvalue": "734.0",
                                        "pointwidth": "0"
                                    },
                                    "hgt": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hgt",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "9.99900026E20",
                                        "long_name": "Geopotential Height",
                                        "units": "gpm",
                                        "grib_name": "HGT",
                                        "standard_name": "geopotential_height",
                                        "expires": "1617260400",
                                        "gribPDSpattern": "04XXXX",
                                        "pointwidth": "300.0"
                                    }
                                }
                            }
                        }
                    },
                    "GFDL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "GFDL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "GFDLCM2p5FLORA06": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "GFDL-CM2p5-FLOR-A06",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "MONTHLY": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MONTHLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tref": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tref",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1612162800",
                                    "missing_value": "-9.99999979E33",
                                    "long_name": "Reference Temperature",
                                    "units": "Kelvin_scale",
                                    "standard_name": "air_temperature",
                                    "defaultvalue": "732.0",
                                    "pointwidth": "0"
                                },
                                "t_ref_min": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t_ref_min",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1612162800",
                                    "missing_value": "-9.99999979E33",
                                    "long_name": "Minimum Temperature",
                                    "units": "Kelvin_scale",
                                    "standard_name": "air_temperature",
                                    "defaultvalue": "732.0",
                                    "pointwidth": "0"
                                },
                                "t_ref_max": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t_ref_max",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1612162800",
                                    "missing_value": "-9.99999979E33",
                                    "long_name": "Maximum Temperature",
                                    "units": "Kelvin_scale",
                                    "standard_name": "air_temperature",
                                    "defaultvalue": "732.0",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "expires": "1612162800",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0",
                                    "defaultvalue": "732.0",
                                    "bounds": "S"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1612162800",
                                    "missing_value": "-9.99999979E33",
                                    "long_name": "Sea Surface Temperature",
                                    "units": "Celsius_scale",
                                    "standard_name": "sea_surface_temperature",
                                    "defaultvalue": "732.0",
                                    "pointwidth": "0"
                                },
                                "prec": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prec",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "mm/day",
                                    "missing_value": "NaN",
                                    "file_missing_value": "-9.99999979E33",
                                    "expires": "1612162800",
                                    "long_name": "Total Precipitation",
                                    "standard_name": "lwe_precipitation_rate",
                                    "defaultvalue": "732.0",
                                    "pointwidth": "0"
                                },
                                "hght": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hght",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1612162800",
                                    "missing_value": "-9.99999979E33",
                                    "long_name": "Geopotential Height at 200 hPa",
                                    "units": "m",
                                    "standard_name": "geopotential_height",
                                    "defaultvalue": "732.0",
                                    "pointwidth": "0"
                                }
                            },
                            "HINDCAST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HINDCAST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "SEASONAL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SEASONAL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "GHCN_CAMS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "GHCN_CAMS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[([[(mean [ Models NMME GFDL-CM2p5-FLOR-A06 MONTHLY tref ]) [(FERRET V6.72   7-Jun-12) (Averaged over M[0.5, 12.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(Models NMME GFDL-CM2p5-FLOR-A06 sc8110 tref) ([(mean [ Models NMME GFDL-CM2p5-FLOR-A06 MONTHLY tref ]) [(FERRET V6.72   7-Jun-12) (Averaged over M[0.5, 12.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)])]]) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "9.99900026E20",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "units": "unitless",
                                            "scale_min": "-1.0",
                                            "standard_name": "air_temperature",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "gribfield": "1",
                                            "ncolor": "254"
                                        }
                                    },
                                    "ERSSTv5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ERSSTv5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[([[(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCDC ERSST version5 sst ]) [(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1981, 2010] minimum 0.0% data present)]] (X regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Y regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Boxes with less than 0.0% dropped)]) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "defaultvalue": "711.0",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "-9.99999979E33",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "pointwidth": "0",
                                            "scale_min": "-1.0",
                                            "standard_name": "sea_surface_temperature",
                                            "units": "unitless",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    },
                                    "ERSSTv4": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ERSSTv4",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[([([[(mean [ Models NMME GFDL-CM2p5-FLOR-A06 MONTHLY sst ]) [(FERRET V6.72   7-Jun-12) (Averaged over M[0.5, 12.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(Models NMME GFDL-CM2p5-FLOR-A06 sc8110 sst) ([(mean [ Models NMME GFDL-CM2p5-FLOR-A06 MONTHLY sst ]) [(FERRET V6.72   7-Jun-12) (Averaged over M[0.5, 12.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)])]]) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]) (S:  0000 1 Jul to 0000 1 Dec 1960 appended from GFDL_FLORA06_sst_anomcorr_s8110_Jul_Dec.nc correlation)]",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "-999.0",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "pointwidth": "1.0",
                                            "standard_name": "sea_surface_temperature",
                                            "scale_min": "-1.0",
                                            "units": "unitless",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    },
                                    "CAMSOPI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CAMS-OPI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[([([[(mean [ Models NMME GFDL-CM2p5-FLOR-A06 MONTHLY prec ]) [(FERRET V6.72   7-Jun-12) (Averaged over M[0.5, 12.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(Models NMME GFDL-CM2p5-FLOR-A06 sc8110 prec) ([(mean [ Models NMME GFDL-CM2p5-FLOR-A06 MONTHLY prec ]) [(FERRET V6.72   7-Jun-12) (Averaged over M[0.5, 12.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 1999 - 15 Dec 2000] minimum 0.0% data present)])]]) (Averaged over S2[16 Dec 1980 - 15 Dec 1981, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]) (S:  0000 1 Jul to 0000 1 Dec 1960 appended from GFDL_FLORA06_prcp_anomcorr_s8110_Jul-Dec.nc correlation)]",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "-999.0",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "bounds": "T",
                                            "colorscalename": "correlationcolorscale",
                                            "pointwidth": "1.0",
                                            "standard_name": "time",
                                            "scale_min": "-1.0",
                                            "units": "unitless",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    }
                                }
                            }
                        }
                    },
                    "Exeter": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Exeter",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "UKMO": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "UKMO",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "GloSea5": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "GloSea5",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "d2p5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "d2p5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "hindcast": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hindcast",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s",
                                            "gribvariable": "132",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "132",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Meridional Velocity",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s",
                                            "gribvariable": "131",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "131",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Zonal Velocity",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "tmp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tmp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribvariable": "130",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "0.0",
                                            "gribNumBits": "12",
                                            "gribparam": "130",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "t1p5m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t1p5m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribvariable": "167",
                                            "gribfield": "1",
                                            "gribleveltype": "105",
                                            "scale_max": "307.56787",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "scale_min": "218.74658",
                                            "gribparam": "167",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "1.5m Air Temperature",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "calendar": "360",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "1.0"
                                        },
                                        "sst": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sst",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribvariable": "34",
                                            "gribfield": "1",
                                            "gribleveltype": "1",
                                            "missing_value": "0.0",
                                            "gribNumBits": "12",
                                            "gribparam": "34",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Sea Surface Temperature",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "kg/m2/s",
                                            "gribvariable": "228",
                                            "gribfield": "1",
                                            "gribleveltype": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "228",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "precipitation",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "mslp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "mslp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa",
                                            "gribvariable": "151",
                                            "gribfield": "1",
                                            "gribleveltype": "102",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "151",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Mean Sea Level Pressure",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "gz": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gz",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m",
                                            "gribvariable": "129",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "129",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Geopotential Height",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        }
                                    },
                                    "forecast": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "forecast",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s",
                                            "gribvariable": "132",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "132",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Meridional velocity",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s",
                                            "gribvariable": "131",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "131",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Zonal velocity",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "tmp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tmp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribvariable": "130",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "0.0",
                                            "gribNumBits": "12",
                                            "gribparam": "130",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "t1p5m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t1p5m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribvariable": "167",
                                            "gribfield": "1",
                                            "gribleveltype": "105",
                                            "scale_max": "307.56787",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "scale_min": "218.74658",
                                            "gribparam": "167",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "1.5m Air Temperature",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "calendar": "360",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "1.0"
                                        },
                                        "sst": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sst",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribvariable": "34",
                                            "gribfield": "1",
                                            "gribleveltype": "1",
                                            "missing_value": "0.0",
                                            "gribNumBits": "12",
                                            "gribparam": "34",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Sea Surface Temperature",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "kg/m2/s",
                                            "gribvariable": "228",
                                            "gribfield": "1",
                                            "gribleveltype": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "228",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "precipitation",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "mslp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "mslp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa",
                                            "gribvariable": "151",
                                            "gribfield": "1",
                                            "gribleveltype": "102",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "151",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Mean Sea Level Pressure",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "gz": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gz",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m",
                                            "gribvariable": "129",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "129",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Geopotential Height",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        }
                                    }
                                },
                                "d1x1shiftnc": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "d1x1shiftnc",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "hindcast_ens28_multiyear": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hindcast_ens28_multiyear",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "y_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Meridional Velocity on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "northward_wind",
                                            "units": "m/s",
                                            "defaultvalue": "733.0",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i201",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Zonal Velocity on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "eastward_wind",
                                            "units": "m/s",
                                            "defaultvalue": "733.0",
                                            "pointwidth": "0.0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "time",
                                            "long_name": "Time",
                                            "calendar": "360",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "1.0",
                                            "defaultvalue": "733.0",
                                            "bounds": "S"
                                        },
                                        "surface_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "surface_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s00i024",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Surface Temperature",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "surface_temperature",
                                            "units": "Kelvin_scale",
                                            "defaultvalue": "733.0",
                                            "pointwidth": "0.0"
                                        },
                                        "Sp5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Sp5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "Sp1": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Sp1",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "sea_ice_area_fraction": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sea_ice_area_fraction",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s00i031",
                                            "missing_value": "-1.07374182E09",
                                            "long_name": "Sea Ice Area Fraction",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "sea_ice_area_fraction",
                                            "units": "unitless",
                                            "defaultvalue": "733.0",
                                            "pointwidth": "0.0"
                                        },
                                        "precipitation_flux": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "precipitation_flux",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s05i216",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Precipitation Flux",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "precipitation_flux",
                                            "units": "kg/m2/s",
                                            "defaultvalue": "733.0",
                                            "pointwidth": "0.0"
                                        },
                                        "geopotential_height": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "geopotential_height",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Geopotential Height",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "geopotential_height",
                                            "units": "m",
                                            "defaultvalue": "733.0",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i204",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Air Temperature on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "defaultvalue": "733.0",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s03i236",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Near-Surface Air Temperature",
                                            "coordinates": "forecast_period forecast_reference_time height realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "defaultvalue": "733.0",
                                            "pointwidth": "0.0"
                                        },
                                        "air_pressure_at_sea_level": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_pressure_at_sea_level",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i222",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Mean Sea Level Pressure",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_pressure_at_mean_sea_level",
                                            "units": "Pa",
                                            "defaultvalue": "733.0",
                                            "pointwidth": "0.0"
                                        }
                                    },
                                    "hindcast_ens28": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hindcast_ens28",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "y_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Meridional Velocity on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "northward_wind",
                                            "units": "m/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i201",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Zonal Velocity on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "eastward_wind",
                                            "units": "m/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "time",
                                            "long_name": "Time",
                                            "calendar": "360",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "1.0"
                                        },
                                        "surface_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "surface_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s00i024",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Surface Temperature",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "surface_temperature",
                                            "units": "Kelvin_scale",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "sea_ice_area_fraction": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sea_ice_area_fraction",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s00i031",
                                            "missing_value": "-1.07374182E09",
                                            "long_name": "Sea Ice Area Fraction",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "sea_ice_area_fraction",
                                            "units": "unitless",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "precipitation_flux": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "precipitation_flux",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s05i216",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Precipitation Flux",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "precipitation_flux",
                                            "units": "kg/m2/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "geopotential_height": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "geopotential_height",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Geopotential Height",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "geopotential_height",
                                            "units": "m",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i204",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Air Temperature on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s03i236",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Near-Surface Air Temperature",
                                            "coordinates": "forecast_period forecast_reference_time height realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "air_pressure_at_sea_level": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_pressure_at_sea_level",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i222",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Mean Sea Level Pressure",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_pressure_at_mean_sea_level",
                                            "units": "Pa",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        }
                                    },
                                    "forecast": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "forecast",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "y_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "expires": "1615420800",
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "missing_value": "1.00000002E20",
                                            "um_stash_source": "m01s15i202",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "long_name": "Meridional Velocity on Pressure Levels",
                                            "units": "m/s",
                                            "standard_name": "northward_wind",
                                            "grid_mapping": "latitude_longitude",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "expires": "1615420800",
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "missing_value": "1.00000002E20",
                                            "um_stash_source": "m01s15i201",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "long_name": "Zonal Velocity on Pressure Levels",
                                            "units": "m/s",
                                            "standard_name": "eastward_wind",
                                            "grid_mapping": "latitude_longitude",
                                            "pointwidth": "0.0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "time",
                                            "long_name": "Time",
                                            "expires": "1615420800",
                                            "calendar": "360",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "1.0",
                                            "bounds": "S"
                                        },
                                        "surface_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "surface_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "expires": "1615420800",
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s00i024",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Surface Temperature",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "surface_temperature",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "0.0"
                                        },
                                        "sea_ice_area_fraction": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sea_ice_area_fraction",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "expires": "1615420800",
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s00i031",
                                            "missing_value": "-1.07374182E09",
                                            "long_name": "Sea Ice Area Fraction",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "sea_ice_area_fraction",
                                            "units": "unitless",
                                            "pointwidth": "0.0"
                                        },
                                        "precipitation_flux": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "precipitation_flux",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "expires": "1615420800",
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s05i216",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Precipitation Flux",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "precipitation_flux",
                                            "units": "kg/m2/s",
                                            "pointwidth": "0.0"
                                        },
                                        "geopotential_height": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "geopotential_height",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "expires": "1615420800",
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Geopotential Height",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "geopotential_height",
                                            "units": "m",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "expires": "1615420800",
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i204",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Air Temperature on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "expires": "1615420800",
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s03i236",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Near-Surface Air Temperature",
                                            "coordinates": "forecast_period forecast_reference_time height realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "0.0"
                                        },
                                        "air_pressure_at_sea_level": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_pressure_at_sea_level",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "expires": "1615420800",
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i222",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Mean Sea Level Pressure",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_pressure_at_mean_sea_level",
                                            "units": "Pa",
                                            "pointwidth": "0.0"
                                        }
                                    }
                                },
                                "d1x1nc": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "d1x1nc",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "hindcast_ens28_multiyear": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hindcast_ens28_multiyear",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "y_wind_old": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind_old",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s15i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Meridional Velocity, Through Aug 2017",
                                            "coordinates": "forecast_period forecast_reference_time pressure_1 realization",
                                            "standard_name": "northward_wind",
                                            "units": "m/s",
                                            "defaultvalue": "710.0",
                                            "pointwidth": "0.0"
                                        },
                                        "y_wind_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Meridional Velocity on Pressure Levels, Through Aug 2017",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "northward_wind",
                                            "units": "m/s",
                                            "defaultvalue": "710.0",
                                            "pointwidth": "0.0"
                                        },
                                        "y_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Meridional Velocity on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "northward_wind",
                                            "units": "m/s",
                                            "defaultvalue": "710.0",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind_old": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind_old",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s15i201",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Zonal Velocity, Through Aug 2017",
                                            "coordinates": "forecast_period forecast_reference_time pressure_1 realization",
                                            "standard_name": "eastward_wind",
                                            "units": "m/s",
                                            "defaultvalue": "710.0",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i201",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Zonal Velocity on Pressure Levels, Through Aug 2017",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "eastward_wind",
                                            "units": "m/s",
                                            "defaultvalue": "710.0",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i201",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Zonal Velocity on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "eastward_wind",
                                            "units": "m/s",
                                            "defaultvalue": "710.0",
                                            "pointwidth": "0.0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "time",
                                            "long_name": "Time",
                                            "calendar": "360",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "1.0",
                                            "defaultvalue": "710.0",
                                            "bounds": "S"
                                        },
                                        "surface_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "surface_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s00i024",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Surface Temperature",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "surface_temperature",
                                            "units": "Kelvin_scale",
                                            "defaultvalue": "710.0",
                                            "pointwidth": "0.0"
                                        },
                                        "Sp5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Sp5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "Sp1": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Sp1",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "sea_ice_area_fraction": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sea_ice_area_fraction",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s00i031",
                                            "missing_value": "-1.07374182E09",
                                            "long_name": "Sea Ice Area Fraction",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "sea_ice_area_fraction",
                                            "units": "unitless",
                                            "defaultvalue": "710.0",
                                            "pointwidth": "0.0"
                                        },
                                        "precipitation_flux": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "precipitation_flux",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s05i216",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Precipitation Flux",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "precipitation_flux",
                                            "units": "kg/m2/s",
                                            "defaultvalue": "710.0",
                                            "pointwidth": "0.0"
                                        },
                                        "geopotential_height": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "geopotential_height",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Geopotential Height",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "geopotential_height",
                                            "units": "m",
                                            "defaultvalue": "710.0",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i204",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Air Temperature on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "defaultvalue": "710.0",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s03i236",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Near-Surface Air Temperature",
                                            "coordinates": "forecast_period forecast_reference_time height realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "defaultvalue": "710.0",
                                            "pointwidth": "0.0"
                                        },
                                        "air_pressure_at_sea_level": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_pressure_at_sea_level",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i222",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Mean Sea Level Pressure",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_pressure_at_mean_sea_level",
                                            "units": "Pa",
                                            "defaultvalue": "710.0",
                                            "pointwidth": "0.0"
                                        }
                                    },
                                    "hindcast_ens28": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hindcast_ens28",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "y_wind_old": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind_old",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s15i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Meridional Velocity, Through Aug 2017",
                                            "coordinates": "forecast_period forecast_reference_time pressure_1 realization",
                                            "standard_name": "northward_wind",
                                            "units": "m/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "y_wind_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Meridional Velocity on Pressure Levels, Through Aug 2017",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "northward_wind",
                                            "units": "m/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "y_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Meridional Velocity on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "northward_wind",
                                            "units": "m/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind_old": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind_old",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s15i201",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Zonal Velocity, Through Aug 2017",
                                            "coordinates": "forecast_period forecast_reference_time pressure_1 realization",
                                            "standard_name": "eastward_wind",
                                            "units": "m/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i201",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Zonal Velocity on Pressure Levels, Through Aug 2017",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "eastward_wind",
                                            "units": "m/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i201",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Zonal Velocity on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "eastward_wind",
                                            "units": "m/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "time",
                                            "long_name": "Time",
                                            "calendar": "360",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "1.0"
                                        },
                                        "surface_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "surface_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s00i024",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Surface Temperature",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "surface_temperature",
                                            "units": "Kelvin_scale",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "sea_ice_area_fraction": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sea_ice_area_fraction",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s00i031",
                                            "missing_value": "-1.07374182E09",
                                            "long_name": "Sea Ice Area Fraction",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "sea_ice_area_fraction",
                                            "units": "unitless",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "precipitation_flux": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "precipitation_flux",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s05i216",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Precipitation Flux",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "precipitation_flux",
                                            "units": "kg/m2/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "geopotential_height": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "geopotential_height",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Geopotential Height",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "geopotential_height",
                                            "units": "m",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i204",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Air Temperature on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s03i236",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Near-Surface Air Temperature",
                                            "coordinates": "forecast_period forecast_reference_time height realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "air_pressure_at_sea_level": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_pressure_at_sea_level",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i222",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Mean Sea Level Pressure",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_pressure_at_mean_sea_level",
                                            "units": "Pa",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        }
                                    },
                                    "hindcast": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hindcast",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "y_wind_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Meridional Velocity on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "y_wind",
                                            "units": "m/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "y_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s15i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Meridional Velocity",
                                            "coordinates": "forecast_period forecast_reference_time pressure_1 realization",
                                            "standard_name": "y_wind",
                                            "units": "m/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i201",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Zonal Velocity on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "x_wind",
                                            "units": "m/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s15i201",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Zonal Velocity",
                                            "coordinates": "forecast_period forecast_reference_time pressure_1 realization",
                                            "standard_name": "x_wind",
                                            "units": "m/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "time",
                                            "long_name": "Time",
                                            "calendar": "360",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "1.0"
                                        },
                                        "surface_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "surface_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s00i024",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Surface Temperature",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "surface_temperature",
                                            "units": "Kelvin_scale",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "precipitation_flux": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "precipitation_flux",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s05i216",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Precipitation Flux",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "precipitation_flux",
                                            "units": "kg/m2/s",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "geopotential_height": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "geopotential_height",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Geopotential Height",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "geopotential_height",
                                            "units": "m",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i204",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Air Temperature on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s03i236",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Near-Surface Air Temperature",
                                            "coordinates": "forecast_period forecast_reference_time height realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "air_pressure_at_sea_level": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_pressure_at_sea_level",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i222",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Mean Sea Level Pressure",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_pressure_at_sea_level",
                                            "units": "Pa",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        }
                                    },
                                    "forecast": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "forecast",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "y_wind_old": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind_old",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s15i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Meridional Velocity, Through Aug 2017",
                                            "coordinates": "forecast_period forecast_reference_time pressure_1 realization",
                                            "standard_name": "northward_wind",
                                            "units": "m/s",
                                            "pointwidth": "0.0"
                                        },
                                        "y_wind_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Meridional Velocity on Pressure Levels, Through Aug 2017",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "northward_wind",
                                            "units": "m/s",
                                            "pointwidth": "0.0"
                                        },
                                        "y_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "y_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "missing_value": "1.00000002E20",
                                            "um_stash_source": "m01s15i202",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "long_name": "Meridional Velocity on Pressure Levels",
                                            "units": "m/s",
                                            "standard_name": "northward_wind",
                                            "grid_mapping": "latitude_longitude",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind_old": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind_old",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s15i201",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Zonal Velocity, Through Aug 2017",
                                            "coordinates": "forecast_period forecast_reference_time pressure_1 realization",
                                            "standard_name": "eastward_wind",
                                            "units": "m/s",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i201",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Zonal Velocity on Pressure Levels, Through Aug 2017",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "eastward_wind",
                                            "units": "m/s",
                                            "pointwidth": "0.0"
                                        },
                                        "x_wind": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "x_wind",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "missing_value": "1.00000002E20",
                                            "um_stash_source": "m01s15i201",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "long_name": "Zonal Velocity on Pressure Levels",
                                            "units": "m/s",
                                            "standard_name": "eastward_wind",
                                            "grid_mapping": "latitude_longitude",
                                            "pointwidth": "0.0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "standard_name": "time",
                                            "long_name": "Time",
                                            "calendar": "360",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "1.0",
                                            "bounds": "S"
                                        },
                                        "surface_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "surface_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s00i024",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Surface Temperature",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "surface_temperature",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "0.0"
                                        },
                                        "sea_ice_area_fraction": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sea_ice_area_fraction",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s00i031",
                                            "missing_value": "-1.07374182E09",
                                            "long_name": "Sea Ice Area Fraction",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "sea_ice_area_fraction",
                                            "units": "unitless",
                                            "pointwidth": "0.0"
                                        },
                                        "precipitation_flux": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "precipitation_flux",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s05i216",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Precipitation Flux",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "precipitation_flux",
                                            "units": "kg/m2/s",
                                            "pointwidth": "0.0"
                                        },
                                        "geopotential_height": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "geopotential_height",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i202",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Geopotential Height",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "geopotential_height",
                                            "units": "m",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature_0_old": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature_0_old",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i204",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Air Temperature on Pressure Levels, Through Feb 2017",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature_0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature_0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s30i204",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Air Temperature on Pressure Levels",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "0.0"
                                        },
                                        "air_temperature": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_temperature",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s03i236",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Near-Surface Air Temperature",
                                            "coordinates": "forecast_period forecast_reference_time height realization",
                                            "standard_name": "air_temperature",
                                            "units": "Kelvin_scale",
                                            "pointwidth": "0.0"
                                        },
                                        "air_pressure_at_sea_level": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "air_pressure_at_sea_level",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "cell_methods": "time: mean (interval: 1 hour)",
                                            "grid_mapping": "latitude_longitude",
                                            "um_stash_source": "m01s16i222",
                                            "missing_value": "1.00000002E20",
                                            "long_name": "Mean Sea Level Pressure",
                                            "coordinates": "forecast_period forecast_reference_time realization",
                                            "standard_name": "air_pressure_at_mean_sea_level",
                                            "units": "Pa",
                                            "pointwidth": "0.0"
                                        }
                                    }
                                },
                                "d1x1": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "d1x1",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "hindcast": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hindcast",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s",
                                            "gribvariable": "132",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "132",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Meridional Velocity",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s",
                                            "gribvariable": "131",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "131",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Zonal Velocity",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "tmp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tmp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribvariable": "130",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "0.0",
                                            "gribNumBits": "12",
                                            "gribparam": "130",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "t1p5m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t1p5m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribvariable": "167",
                                            "gribfield": "1",
                                            "gribleveltype": "105",
                                            "scale_max": "307.56787",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "scale_min": "218.74658",
                                            "gribparam": "167",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "1.5m Air Temperature",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "calendar": "360",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "1.0"
                                        },
                                        "sst": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sst",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribvariable": "34",
                                            "gribfield": "1",
                                            "gribleveltype": "1",
                                            "missing_value": "0.0",
                                            "gribNumBits": "12",
                                            "gribparam": "34",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Sea Surface Temperature",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "kg/m2/s",
                                            "gribvariable": "228",
                                            "gribfield": "1",
                                            "gribleveltype": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "228",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "precipitation",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "mslp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "mslp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa",
                                            "gribvariable": "151",
                                            "gribfield": "1",
                                            "gribleveltype": "102",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "151",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Mean Sea Level Pressure",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        },
                                        "gz": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gz",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m",
                                            "gribvariable": "129",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "129",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Geopotential Height",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "fnname": "flagrange",
                                            "pointwidth": "0.0"
                                        }
                                    },
                                    "forecast": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "forecast",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s",
                                            "gribvariable": "132",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "132",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Meridional velocity",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s",
                                            "gribvariable": "131",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "131",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Zonal velocity",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "tmp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tmp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribvariable": "130",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "0.0",
                                            "gribNumBits": "12",
                                            "gribparam": "130",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "t1p5m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t1p5m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribvariable": "167",
                                            "gribfield": "1",
                                            "gribleveltype": "105",
                                            "scale_max": "307.56787",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "scale_min": "218.74658",
                                            "gribparam": "167",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "1.5m Air Temperature",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "T": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "T",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "calendar": "360",
                                            "units": "months since 1960-01-01",
                                            "pointwidth": "1.0"
                                        },
                                        "sst": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sst",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Kelvin_scale",
                                            "gribvariable": "34",
                                            "gribfield": "1",
                                            "gribleveltype": "1",
                                            "missing_value": "0.0",
                                            "gribNumBits": "12",
                                            "gribparam": "34",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Sea Surface Temperature",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "kg/m2/s",
                                            "gribvariable": "228",
                                            "gribfield": "1",
                                            "gribleveltype": "1",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "228",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "precipitation",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "mslp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "mslp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa",
                                            "gribvariable": "151",
                                            "gribfield": "1",
                                            "gribleveltype": "102",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "151",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Mean Sea Level Pressure",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        },
                                        "gz": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gz",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m",
                                            "gribvariable": "129",
                                            "gribfield": "1",
                                            "gribleveltype": "100",
                                            "missing_value": "9.99900026E20",
                                            "gribNumBits": "12",
                                            "gribparam": "129",
                                            "PTVersion": "1",
                                            "process": "1",
                                            "center": "U.K. Met Office - Exeter",
                                            "calendar": "standard",
                                            "long_name": "Geopotential Height",
                                            "PDS_TimeRange": "3",
                                            "gribcenter": "74",
                                            "pointwidth": "0.0"
                                        }
                                    }
                                }
                            },
                            "GloSea4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "GloSea4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "hindcast": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hindcast",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "gribvariable": "132",
                                        "gribfield": "1",
                                        "gribleveltype": "100",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "12",
                                        "gribparam": "132",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "Meridional Velocity",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "fnname": "flagge",
                                        "pointwidth": "0.0"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "gribvariable": "131",
                                        "gribfield": "1",
                                        "gribleveltype": "100",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "12",
                                        "gribparam": "131",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "Zonal Velocity",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "fnname": "flagge",
                                        "pointwidth": "0.0"
                                    },
                                    "tmp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribvariable": "130",
                                        "gribfield": "1",
                                        "gribleveltype": "100",
                                        "missing_value": "0.0",
                                        "gribNumBits": "12",
                                        "gribparam": "130",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "Temperature",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "fnname": "flagge",
                                        "pointwidth": "0.0"
                                    },
                                    "t1p5m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t1p5m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribvariable": "167",
                                        "gribfield": "1",
                                        "gribleveltype": "105",
                                        "scale_max": "307.56787",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "12",
                                        "scale_min": "218.74658",
                                        "gribparam": "167",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "1.5m Air Temperature",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "fnname": "flagge",
                                        "pointwidth": "0.0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribvariable": "34",
                                        "gribfield": "1",
                                        "gribleveltype": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "12",
                                        "gribparam": "34",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "Sea Surface Temperature",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "fnname": "flagge",
                                        "pointwidth": "0.0"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "kg/m2/s",
                                        "gribvariable": "228",
                                        "gribfield": "1",
                                        "gribleveltype": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "12",
                                        "gribparam": "228",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "precipitation",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "fnname": "flagge",
                                        "pointwidth": "0.0"
                                    },
                                    "mslp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mslp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa",
                                        "gribvariable": "151",
                                        "gribfield": "1",
                                        "gribleveltype": "102",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "12",
                                        "gribparam": "151",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "Mean Sea Level Pressure",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74"
                                    },
                                    "gz": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gz",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m",
                                        "gribvariable": "129",
                                        "gribfield": "1",
                                        "gribleveltype": "100",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "12",
                                        "gribparam": "129",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "Geopotential Height",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "fnname": "flagge",
                                        "pointwidth": "0.0"
                                    },
                                    "dirname": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dirname",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless"
                                    }
                                },
                                "forecast": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "forecast",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "gribvariable": "132",
                                        "gribfield": "1",
                                        "gribleveltype": "100",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "12",
                                        "gribparam": "132",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "Meridional velocity",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "pointwidth": "0.0"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "gribvariable": "131",
                                        "gribfield": "1",
                                        "gribleveltype": "100",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "12",
                                        "gribparam": "131",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "Zonal velocity",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "pointwidth": "0.0"
                                    },
                                    "tmp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tmp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribvariable": "130",
                                        "gribfield": "1",
                                        "gribleveltype": "100",
                                        "missing_value": "0.0",
                                        "gribNumBits": "12",
                                        "gribparam": "130",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "Temperature",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "pointwidth": "0.0"
                                    },
                                    "t1p5m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t1p5m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribvariable": "167",
                                        "gribfield": "1",
                                        "gribleveltype": "105",
                                        "scale_max": "307.56787",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "12",
                                        "scale_min": "218.74658",
                                        "gribparam": "167",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "1.5m Air Temperature",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "pointwidth": "0.0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "calendar": "360",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0"
                                    },
                                    "sst": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sst",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Kelvin_scale",
                                        "gribvariable": "34",
                                        "gribfield": "1",
                                        "gribleveltype": "1",
                                        "missing_value": "0.0",
                                        "gribNumBits": "12",
                                        "gribparam": "34",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "Sea Surface Temperature",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "pointwidth": "0.0"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "kg/m2/s",
                                        "gribvariable": "228",
                                        "gribfield": "1",
                                        "gribleveltype": "1",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "12",
                                        "gribparam": "228",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "precipitation",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "pointwidth": "0.0"
                                    },
                                    "mslp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mslp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa",
                                        "gribvariable": "151",
                                        "gribfield": "1",
                                        "gribleveltype": "102",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "12",
                                        "gribparam": "151",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "Mean Sea Level Pressure",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "pointwidth": "0.0"
                                    },
                                    "gz": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gz",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m",
                                        "gribvariable": "129",
                                        "gribfield": "1",
                                        "gribleveltype": "100",
                                        "missing_value": "9.99900026E20",
                                        "gribNumBits": "12",
                                        "gribparam": "129",
                                        "PTVersion": "1",
                                        "process": "1",
                                        "center": "U.K. Met Office - Exeter",
                                        "calendar": "standard",
                                        "long_name": "Geopotential Height",
                                        "PDS_TimeRange": "3",
                                        "gribcenter": "74",
                                        "pointwidth": "0.0"
                                    }
                                }
                            }
                        }
                    },
                    "COLARSMAS": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "COLA-RSMAS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "COLARSMASCCSM4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "COLA-RSMAS-CCSM4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "MONTHLY": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MONTHLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tsmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tsmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1617237720",
                                    "lat": "90.0",
                                    "missing_value": "9.96920997E36",
                                    "cell_method": "time: maximum",
                                    "long_name": "Maximum surface temperature over output period",
                                    "units": "Kelvin_scale",
                                    "lon": "358.75",
                                    "standard_name": "air_temperature",
                                    "defaultvalue": "734.0",
                                    "pointwidth": "0"
                                },
                                "tsmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tsmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1617237720",
                                    "lat": "90.0",
                                    "missing_value": "9.96920997E36",
                                    "cell_method": "time: minimum",
                                    "long_name": "Minimum surface temperature over output period",
                                    "units": "Kelvin_scale",
                                    "lon": "358.75",
                                    "standard_name": "air_temperature",
                                    "defaultvalue": "734.0",
                                    "pointwidth": "0"
                                },
                                "tref": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tref",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1617237720",
                                    "lat": "90.0",
                                    "missing_value": "9.96920997E36",
                                    "cell_method": "time: mean",
                                    "units": "Kelvin_scale",
                                    "long_name": "Reference Temperature",
                                    "standard_name": "air_temperature",
                                    "lon": "358.75",
                                    "defaultvalue": "734.0",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "expires": "1617237720",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0",
                                    "defaultvalue": "734.0",
                                    "bounds": "S"
                                },
                                "sst": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sst",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1617237720",
                                    "lat": "89.5",
                                    "missing_value": "9.96920997E36",
                                    "spatial_op": "Conservative remapping: 1st order: destarea: NCL: /homes/min/bin/ncl/POP_REMAP/map_gx1v3_to_1x1d_aave_da-010821.nc",
                                    "long_name": "Sea Surface Temperature",
                                    "units": "Celsius_scale",
                                    "standard_name": "sea_surface_temperature",
                                    "cell_methods": "time: mean",
                                    "defaultvalue": "734.0",
                                    "pointwidth": "0"
                                },
                                "soilw": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soilw",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1617237720",
                                    "lat": "90.0",
                                    "missing_value": "9.99999962E35",
                                    "sum_op_ncl": "dim_sum over dimension(s): levgrnd",
                                    "cell_method": "time: mean",
                                    "lon": "358.75",
                                    "long_name": " merely sum of soil liquid water over levels",
                                    "units": "kg/m2",
                                    "standard_name": "soil_moisture_content",
                                    "defaultvalue": "734.0",
                                    "pointwidth": "0"
                                },
                                "runoff": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "runoff",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1617237720",
                                    "lat": "90.0",
                                    "missing_value": "9.99999962E35",
                                    "long_name": "surface runoff + sub-surface drainage + surface runoff at glaciers, wetlands, lakes",
                                    "units": "mm/s",
                                    "lon": "358.75",
                                    "standard_name": "runoff_flux",
                                    "defaultvalue": "734.0",
                                    "pointwidth": "0"
                                },
                                "prec": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prec",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "file_missing_value": "9.96920997E36",
                                    "units": "mm/day",
                                    "expires": "1617237720",
                                    "lat": "90.0",
                                    "long_name": "Total Precipitation",
                                    "lon": "358.75",
                                    "standard_name": "lwe_precipitation_rate",
                                    "defaultvalue": "734.0",
                                    "pointwidth": "0"
                                },
                                "gz": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "gz",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1617237720",
                                    "lat": "90.0",
                                    "missing_value": "9.96920997E36",
                                    "units": "m",
                                    "long_name": "Geopotential Height (above sea level)",
                                    "lon": "358.75",
                                    "standard_name": "geopotential_height",
                                    "defaultvalue": "734.0",
                                    "pointwidth": "0"
                                },
                                "evap": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "evap",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1617237720",
                                    "lat": "90.0",
                                    "missing_value": "9.99999962E35",
                                    "cell_method": "time: mean",
                                    "long_name": "canopy evaporation",
                                    "units": "W/m2",
                                    "lon": "358.75",
                                    "defaultvalue": "734.0",
                                    "pointwidth": "0"
                                }
                            },
                            "HINDCAST": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HINDCAST",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "SEASONAL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SEASONAL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "GHCN_CAMS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "GHCN_CAMS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[([[(mean [ Models NMME COLA-RSMAS-CCSM4 MONTHLY tref ]) [(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(Models NMME COLA-RSMAS-CCSM4 sc8210 tref) ([(mean [ Models NMME COLA-RSMAS-CCSM4 MONTHLY tref ]) [(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)])]]) (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "9.99900026E20",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "units": "unitless",
                                            "scale_min": "-1.0",
                                            "standard_name": "air_temperature",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "gribfield": "1",
                                            "ncolor": "254"
                                        }
                                    },
                                    "ERSSTv5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ERSSTv5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "defaultvalue": "711.0",
                                            "scale_max": "1.0",
                                            "CE": "1",
                                            "CS": "-1",
                                            "pointwidth": "0",
                                            "long_name": "correlation",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "cell_methods": "time: mean",
                                            "maxncolor": "254",
                                            "lat": "89.5",
                                            "standard_name": "sea_surface_temperature",
                                            "history": "[([[(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(mean [ NOAA NCDC ERSST version5 sst ]) [(NOAA NCDC ERSST version5 sst) [(Averaged in T with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over T2[1982, 2010] minimum 0.0% data present)]] (X regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Y regridded on anomaly [ NOAA NCDC ERSST version5 sst ]) (Boxes with less than 0.0% dropped)]) (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]",
                                            "file_missing_value": "9.96920997E36",
                                            "units": "unitless",
                                            "scale_min": "-1.0",
                                            "colorscalename": "correlationcolorscale",
                                            "ncolor": "254",
                                            "missing_value": "NaN",
                                            "spatial_op": "Conservative remapping: 1st order: destarea: NCL: /homes/min/bin/ncl/POP_REMAP/map_gx1v3_to_1x1d_aave_da-010821.nc"
                                        }
                                    },
                                    "ERSSTv4": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ERSSTv4",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[([([[(mean [ Models NMME COLA-RSMAS-CCSM4 MONTHLY sst ]) [(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(Models NMME COLA-RSMAS-CCSM4 sc8210 sst) ([(mean [ Models NMME COLA-RSMAS-CCSM4 MONTHLY sst ]) [(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)])]]) (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]) (S:  0000 1 Jul to 0000 1 Dec 1960 appended from RSMAS_CCSM4_sst_anomcorr_s8210_Jul-Dec.nc correlation)]",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "-999.0",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "colorscalename": "correlationcolorscale",
                                            "pointwidth": "1.0",
                                            "standard_name": "sea_surface_temperature",
                                            "scale_min": "-1.0",
                                            "units": "unitless",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    },
                                    "CAMSOPI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CAMS-OPI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "correlation": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "correlation",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "history": "[([([[(mean [ Models NMME COLA-RSMAS-CCSM4 MONTHLY prec ]) [(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)]] [(Models NMME COLA-RSMAS-CCSM4 sc8210 prec) ([(mean [ Models NMME COLA-RSMAS-CCSM4 MONTHLY prec ]) [(Averaged over M[0.5, 10.5] minimum 0.0% data present) (Averaged in L with overlapping interval 3) (Boxes with less than 0.0% dropped)] (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0.0% data present)])]]) (Averaged over S2[16 Dec 1981 - 15 Dec 1982, 16 Dec 2009 - 15 Dec 2010] minimum 0% data present)]) (S:  0000 1 Jul to 0000 1 Dec 1960 appended from RSMAS_CCSM4_prcp_anomcorr_s8210_Jul-Dec.nc correlation)]",
                                            "CS": "-1",
                                            "colormap": "[None 0 8388608 [16711680 25] [16760576 26] [13959039 39] [10025880 26] 11920639 [11920639 26] 65535 [36095 38] [255 38] [128 39] 2763429]",
                                            "file_missing_value": "-999.0",
                                            "long_name": "correlation",
                                            "missing_value": "NaN",
                                            "bounds": "T",
                                            "colorscalename": "correlationcolorscale",
                                            "pointwidth": "1.0",
                                            "standard_name": "time",
                                            "scale_min": "-1.0",
                                            "units": "unitless",
                                            "maxncolor": "254",
                                            "CE": "1",
                                            "ncolor": "254"
                                        }
                                    }
                                }
                            }
                        }
                    },
                    "S_25": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_25",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "0",
                        "standard_name": "forecast_reference_time"
                    },
                    "S_24": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_24",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "0",
                        "standard_name": "forecast_reference_time"
                    },
                    "L_07": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "L_07",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months",
                        "gridtype": "0",
                        "standard_name": "forecast_period",
                        "pointwidth": "1.0"
                    },
                    "S_23": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_23",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "standard_name": "forecast_reference_time",
                        "calendar": "360",
                        "pointwidth": "0"
                    },
                    "L_06": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "L_06",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "3.0",
                        "standard_name": "forecast_period"
                    },
                    "L_05": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "L_05",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "3.0",
                        "standard_name": "forecast_period"
                    },
                    "S_22": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_22",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "long_name": "Forecast Start Time",
                        "pointwidth": "0"
                    },
                    "L_04": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "L_04",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months",
                        "gridtype": "0",
                        "pointwidth": "1.0",
                        "long_name": "Lead",
                        "standard_name": "forecast_period"
                    },
                    "S_21": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_21",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "long_name": "Forecast Start Time",
                        "pointwidth": "0"
                    },
                    "S_20": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_20",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "0",
                        "defaultvalue": "714.0"
                    },
                    "S_19": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_19",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "long_name": "Forecast Start Time",
                        "pointwidth": "0"
                    },
                    "zlev": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "zlev",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "m",
                        "gridtype": "0",
                        "pointwidth": "0"
                    },
                    "P_06": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "P_06",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "standard_name": "air_pressure",
                        "long_name": "Pressure Level",
                        "pointwidth": "650.0"
                    },
                    "S_18": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_18",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "long_name": "Forecast Start Time",
                        "pointwidth": "0"
                    },
                    "P_05": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "P_05",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "standard_name": "air_pressure",
                        "long_name": "Pressure Level",
                        "pointwidth": "650.0"
                    },
                    "P2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "P2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "standard_name": "air_pressure",
                        "long_name": "Pressure Level",
                        "pointwidth": "300.0"
                    },
                    "S_17": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_17",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "expires": "1617260400",
                        "defaultvalue": "734.0",
                        "calendar": "360",
                        "pointwidth": "0",
                        "long_name": "Forecast Start Time",
                        "standard_name": "forecast_reference_time"
                    },
                    "S_16": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_16",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "expires": "1612162800",
                        "defaultvalue": "732.0",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "pointwidth": "0"
                    },
                    "S_15": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_15",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "0.0"
                    },
                    "hdate_01": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "hdate_01",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "12.0"
                    },
                    "S_14": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_14",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "long_name": "Forecast Start Time",
                        "pointwidth": "0.0"
                    },
                    "Y_04": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Y_04",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_north",
                        "gridtype": "0",
                        "standard_name": "latitude",
                        "pointwidth": "1.0"
                    },
                    "X_02": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "X_02",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_east",
                        "gridtype": "1",
                        "standard_name": "longitude",
                        "pointwidth": "1.0"
                    },
                    "S_13": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_13",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "expires": "1615420800",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "long_name": "Forecast Start Time",
                        "pointwidth": "0.0"
                    },
                    "S_12": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_12",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "defaultvalue": "710.0",
                        "standard_name": "forecast_reference_time",
                        "long_name": "Forecast Start Time",
                        "pointwidth": "0.0"
                    },
                    "hdate": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "hdate",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "12.0"
                    },
                    "pressure_0_01": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pressure_0_01",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "standard_name": "air_pressure",
                        "pointwidth": "300.0"
                    },
                    "M_05": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "M_05",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "standard_name": "realization",
                        "long_name": "Ensemble Member",
                        "pointwidth": "1.0"
                    },
                    "pressure_01": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pressure_01",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "standard_name": "air_pressure"
                    },
                    "S_11": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_11",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "long_name": "Forecast Start Time",
                        "pointwidth": "0.0"
                    },
                    "pressure_2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pressure_2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "standard_name": "air_pressure"
                    },
                    "S_10": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_10",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "long_name": "Forecast Start Time",
                        "pointwidth": "0.0"
                    },
                    "pressure_1": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pressure_1",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "standard_name": "air_pressure"
                    },
                    "pressure_0": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pressure_0",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "standard_name": "air_pressure",
                        "pointwidth": "300.0"
                    },
                    "S_09": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_09",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "long_name": "Forecast Start Time",
                        "pointwidth": "0.0"
                    },
                    "pressure_3": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pressure_3",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "standard_name": "air_pressure"
                    },
                    "S_08": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_08",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "long_name": "Forecast Start Time",
                        "pointwidth": "0.0"
                    },
                    "pressure": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "pressure",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "standard_name": "air_pressure"
                    },
                    "Y_03": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Y_03",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_north",
                        "gridtype": "0",
                        "standard_name": "latitude",
                        "pointwidth": "1.0"
                    },
                    "S_07": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_07",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "long_name": "Forecast Start Time",
                        "pointwidth": "0.0"
                    },
                    "M_04": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "M_04",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "S_06": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_06",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "0.0"
                    },
                    "Y_02": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Y_02",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_north",
                        "gridtype": "0",
                        "standard_name": "latitude",
                        "pointwidth": "1.0"
                    },
                    "L_03": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "L_03",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "M_03": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "M_03",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "S_05": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_05",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "0.0"
                    },
                    "M_02": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "M_02",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "P_04": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "P_04",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "pointwidth": "0"
                    },
                    "S_04": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_04",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "0.0"
                    },
                    "P_03": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "P_03",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "pointwidth": "0"
                    },
                    "P_02": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "P_02",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "pointwidth": "0"
                    },
                    "Z_02": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Z_02",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "m",
                        "gridtype": "0",
                        "pointwidth": "0"
                    },
                    "Y_01": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Y_01",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_north",
                        "gridtype": "0",
                        "standard_name": "latitude",
                        "pointwidth": "2.5"
                    },
                    "L_02": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "L_02",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "X_01": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "X_01",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_east",
                        "gridtype": "1",
                        "standard_name": "longitude",
                        "pointwidth": "2.5"
                    },
                    "M_01": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "M_01",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "S_03": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_03",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "0.0"
                    },
                    "P_01": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "P_01",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "pointwidth": "350.0"
                    },
                    "Z_01": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Z_01",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "m",
                        "gridtype": "0",
                        "standard_name": "height",
                        "long_name": "Height",
                        "pointwidth": "0"
                    },
                    "P": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "P",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "hPa",
                        "gridtype": "0",
                        "standard_name": "air_pressure",
                        "long_name": "Pressure Level",
                        "pointwidth": "0"
                    },
                    "L_01": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "L_01",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months",
                        "gridtype": "0",
                        "standard_name": "forecast_period",
                        "pointwidth": "1.0"
                    },
                    "M": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "M",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0",
                        "standard_name": "realization"
                    },
                    "S_02": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_02",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "defaultvalue": "734.0",
                        "expires": "1617237720",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "pointwidth": "0"
                    },
                    "Z": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Z",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "m",
                        "gridtype": "0",
                        "long_name": "Height",
                        "pointwidth": "0",
                        "standard_name": "height"
                    },
                    "S_01": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S_01",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "1",
                        "modulo": "12.0",
                        "modulus": "12.0",
                        "calendar": "360",
                        "standard_name": "forecast_reference_time",
                        "pointwidth": "0",
                        "defaultvalue": "677.0"
                    },
                    "L": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "L",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months",
                        "gridtype": "0",
                        "shiftlag": "0.0",
                        "long_name": "Lead",
                        "pointwidth": "1.0",
                        "standard_name": "forecast_period"
                    },
                    "X": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "X",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_east",
                        "gridtype": "1",
                        "modulus": "360.0",
                        "pointwidth": "1.0",
                        "standard_name": "longitude"
                    },
                    "S": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "S",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "months since 1960-01-01",
                        "gridtype": "0",
                        "calendar": "360",
                        "pointwidth": "0"
                    },
                    "Y": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Y",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_north",
                        "gridtype": "0",
                        "pointwidth": "1.0",
                        "standard_name": "latitude"
                    },
                    "dir": "SOURCES/IRI/Analyses/ICPAC/Models"
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "Models"
                ]
            },
            "LandDAAC": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "LandDAAC",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "MODISversion_005SSAUruguaymonthlyclimlong_name": "2005-2014 monthly climatology",
                    "MODISversion_005SSAlong_name": "Southern South America",
                    "MODISversion_005NSAlong_name": "Northern South America",
                    "MODIS1km8dayversion_005TerraSSAUruguay_Daymonthlyclimlong_name": "2005-2014 monthly climatology",
                    "Conventions": "IRIDL"
                },
                "MODIS": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "MODIS",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "version_005": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "version_005",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "SSA": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "SSA",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Uruguay": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Uruguay",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "monthlyclim": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlyclim",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDWI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDWI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "history": "Averaged over T2[2005, 2014] minimum 0.0% data present",
                                        "missing_value": "NaN",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    }
                                },
                                "monthlyavg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlyavg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDWI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDWI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "units": "unitless",
                                        "history": "Boxes with less than 90.0% dropped",
                                        "pointwidth": "0"
                                    }
                                }
                            },
                            "Chile": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Chile",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "monthlystdanomcoarse": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlystdanomcoarse",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "units": "unitless",
                                        "history": "[(Boxes with less than 0.0% dropped) (Averaged over T[Dec 2001, Dec 2012] minimum 0.0% data present)]",
                                        "iridlhasSemantics": "iridl:NDVI",
                                        "maxncolor": "254",
                                        "colorscalename": "ndvi_colorsMODIS",
                                        "colormap": "2304",
                                        "ncolor": "254",
                                        "pointwidth": "0"
                                    }
                                },
                                "monthlysdcoarse": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlysdcoarse",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "valid_min": "0.0",
                                        "missing_value": "NaN",
                                        "ncolor": "254",
                                        "colorscalename": "ndvi_colorsMODIS",
                                        "valid_max": "1.0",
                                        "maxncolor": "254",
                                        "pointwidth": "0",
                                        "units": "unitless",
                                        "colormap": "[None 16711680 [16776960 22] [16777215 22] 12446186 [12446186 11] 9753559 [9753559 10] 7847370 [7847370 10] 5091247 [5091247 11] 371072 [371072 21] 32524 [32524 20] 24064 [24064 21] 80640 [80640 21] 2304 [2304 83] 2304 2304]",
                                        "long_name": "NDVI"
                                    }
                                },
                                "monthlysd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlysd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "valid_min": "0.0",
                                        "missing_value": "NaN",
                                        "ncolor": "254",
                                        "colorscalename": "ndvi_colorsMODIS",
                                        "valid_max": "1.0",
                                        "maxncolor": "254",
                                        "pointwidth": "0",
                                        "units": "unitless",
                                        "colormap": "[None 16711680 [16776960 22] [16777215 22] 12446186 [12446186 11] 9753559 [9753559 10] 7847370 [7847370 10] 5091247 [5091247 11] 371072 [371072 21] 32524 [32524 20] 24064 [24064 21] 80640 [80640 21] 2304 [2304 83] 2304 2304]",
                                        "long_name": "NDVI"
                                    }
                                },
                                "monthlypctavgcoarse": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlypctavgcoarse",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_min": "0.0",
                                        "scale_max": "400.0",
                                        "CE": "400",
                                        "CS": "0",
                                        "long_name": "NDVI Percent of Normal",
                                        "missing_value": "NaN",
                                        "units": "percent",
                                        "history": "[(Boxes with less than 0.0% dropped) (Averaged over T[Dec 2001, Dec 2012] minimum 0.0% data present)]",
                                        "iridlhasSemantics": "iridl:NDVI",
                                        "maxncolor": "254",
                                        "colorscalename": "ndvi_colorsMODIS",
                                        "colormap": "2304",
                                        "ncolor": "254",
                                        "pointwidth": "0"
                                    }
                                },
                                "monthlyclimcoarse": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlyclimcoarse",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "valid_min": "-0.2",
                                        "missing_value": "NaN",
                                        "ncolor": "254",
                                        "colorscalename": "ndvi_colorsMODIS",
                                        "valid_max": "1.0",
                                        "maxncolor": "254",
                                        "pointwidth": "0",
                                        "units": "unitless",
                                        "colormap": "[None 16711680 [16776960 22] [16777215 22] 12446186 [12446186 11] 9753559 [9753559 10] 7847370 [7847370 10] 5091247 [5091247 11] 371072 [371072 21] 32524 [32524 20] 24064 [24064 21] 80640 [80640 21] 2304 [2304 83] 2304 2304]",
                                        "long_name": "NDVI",
                                        "history": "[(Boxes with less than 0.0% dropped) (Averaged over T[Dec 2001, Dec 2012] minimum 0.0% data present)]"
                                    }
                                },
                                "monthlyclim": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlyclim",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "valid_min": "-0.2",
                                        "missing_value": "NaN",
                                        "ncolor": "254",
                                        "colorscalename": "ndvi_colorsMODIS",
                                        "valid_max": "1.0",
                                        "maxncolor": "254",
                                        "pointwidth": "0",
                                        "units": "unitless",
                                        "colormap": "[None 16711680 [16776960 22] [16777215 22] 12446186 [12446186 11] 9753559 [9753559 10] 7847370 [7847370 10] 5091247 [5091247 11] 371072 [371072 21] 32524 [32524 20] 24064 [24064 21] 80640 [80640 21] 2304 [2304 83] 2304 2304]",
                                        "long_name": "NDVI",
                                        "history": "[(Boxes with less than 0.0% dropped) (Averaged over T[Dec 2001, Dec 2012] minimum 0.0% data present)]"
                                    }
                                },
                                "monthlyavg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlyavg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "units": "unitless",
                                        "history": "Boxes with less than 0.0% dropped",
                                        "iridlhasSemantics": "iridl:NDVI",
                                        "maxncolor": "254",
                                        "colorscalename": "ndvi_colorsMODIS",
                                        "colormap": "2304",
                                        "ncolor": "254",
                                        "CE": "1.0",
                                        "CS": "-0.2",
                                        "pointwidth": "0"
                                    }
                                },
                                "Countrymask": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Countrymask",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "mask_coarse": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mask_coarse",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Chile mask coarse monthly",
                                        "missing_value": "NaN",
                                        "fnname": "maskle",
                                        "history": "Averaged over objectid=243 minimum 0.0% data present",
                                        "scale_max": "1.0",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "ncolor": "254",
                                        "colorscalename": "halfgreyscale",
                                        "maxncolor": "254",
                                        "colormap": "253",
                                        "PGtype": "bytea",
                                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                                        "SpatialReferenceSystemWKT": "]]"
                                    }
                                }
                            }
                        },
                        "NSA": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NSA",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Peru": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Peru",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "monthlystdanomcoarse": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlystdanomcoarse",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "units": "unitless",
                                        "history": "[([(Boxes with less than 0.0% dropped) (Averaged over T minimum 90.0% data present)]) (Boxes with less than 80.0% dropped) (Boxes with less than 80.0% dropped)]",
                                        "iridlhasSemantics": "iridl:NDVI",
                                        "maxncolor": "254",
                                        "colorscalename": "ndvi_colorsMODIS",
                                        "colormap": "2304",
                                        "ncolor": "254",
                                        "pointwidth": "0"
                                    }
                                },
                                "monthlysdcoarse": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlysdcoarse",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "maxncolor": "254",
                                        "missing_value": "NaN",
                                        "ncolor": "254",
                                        "pointwidth": "0",
                                        "units": "unitless",
                                        "colormap": "[None 16711680 [16776960 22] [16777215 22] 12446186 [12446186 11] 9753559 [9753559 10] 7847370 [7847370 10] 5091247 [5091247 11] 371072 [371072 21] 32524 [32524 20] 24064 [24064 21] 80640 [80640 21] 2304 [2304 83] 2304 2304]",
                                        "colorscalename": "ndvi_colorsMODIS"
                                    }
                                },
                                "monthlyclimcoarse": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlyclimcoarse",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "ncolor": "254",
                                        "modulus": "12.0",
                                        "colorscalename": "ndvi_colorsMODIS",
                                        "modulo": "12.0",
                                        "maxncolor": "254",
                                        "pointwidth": "0",
                                        "units": "unitless",
                                        "colormap": "[None 16711680 [16776960 22] [16777215 22] 12446186 [12446186 11] 9753559 [9753559 10] 7847370 [7847370 10] 5091247 [5091247 11] 371072 [371072 21] 32524 [32524 20] 24064 [24064 21] 80640 [80640 21] 2304 [2304 83] 2304 2304]",
                                        "long_name": "NDVI",
                                        "history": "[([(Boxes with less than 0.0% dropped) (Averaged over T minimum 90.0% data present)]) (Boxes with less than 80.0% dropped) (Boxes with less than 80.0% dropped)]"
                                    }
                                },
                                "monthlyclim": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlyclim",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "valid_min": "-0.2",
                                        "missing_value": "NaN",
                                        "ncolor": "254",
                                        "colorscalename": "ndvi_colorsMODIS",
                                        "valid_max": "1.0",
                                        "maxncolor": "254",
                                        "pointwidth": "0",
                                        "units": "unitless",
                                        "colormap": "[None 16711680 [16776960 22] [16777215 22] 12446186 [12446186 11] 9753559 [9753559 10] 7847370 [7847370 10] 5091247 [5091247 11] 371072 [371072 21] 32524 [32524 20] 24064 [24064 21] 80640 [80640 21] 2304 [2304 83] 2304 2304]",
                                        "long_name": "NDVI",
                                        "history": "[(Boxes with less than 0.0% dropped) (Averaged over T minimum 90.0% data present)]"
                                    }
                                },
                                "monthlyavg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthlyavg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NDVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NDVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "units": "unitless",
                                        "history": "Boxes with less than 0.0% dropped",
                                        "iridlhasSemantics": "iridl:NDVI",
                                        "maxncolor": "254",
                                        "colorscalename": "ndvi_colorsMODIS",
                                        "colormap": "2304",
                                        "ncolor": "254",
                                        "CE": "1.0",
                                        "CS": "-0.2",
                                        "pointwidth": "0"
                                    }
                                },
                                "Countrymask": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Countrymask",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "mask_coarse": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mask_coarse",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "Peru mask coarse",
                                        "missing_value": "NaN",
                                        "fnname": "maskle",
                                        "history": "Averaged over objectid=121 minimum 0.0% data present",
                                        "scale_max": "1.0",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "ncolor": "254",
                                        "colorscalename": "halfgreyscale",
                                        "maxncolor": "254",
                                        "colormap": "253",
                                        "PGtype": "bytea",
                                        "OpenGISSimpleFeature": "MULTIPOLYGON",
                                        "SpatialReferenceSystemWKT": "]]"
                                    }
                                }
                            }
                        }
                    },
                    "km": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "1km",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "day": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "8day",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "version_005": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "version_005",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "Terra": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Terra",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "SSA": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SSA",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "Uruguay_Day": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Uruguay_Day",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "monthlyclim": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "monthlyclim",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "LST": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "LST",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "history": "Averaged over T2[2005, 2014] minimum 0.0% data present",
                                                    "missing_value": "NaN",
                                                    "units": "Kelvin_scale",
                                                    "maxncolor": "254",
                                                    "colormap": "255",
                                                    "ncolor": "254",
                                                    "iridlhasSemantics": "iridl:LandSurfaceTemperature",
                                                    "pointwidth": "0"
                                                }
                                            },
                                            "monthlyavg": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "monthlyavg",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "LST": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "LST",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "missing_value": "NaN",
                                                    "units": "Kelvin_scale",
                                                    "history": "Boxes with less than 90.0% dropped",
                                                    "CE": "330",
                                                    "CS": "255",
                                                    "maxncolor": "254",
                                                    "colormap": "255",
                                                    "ncolor": "254",
                                                    "iridlhasSemantics": "iridl:LandSurfaceTemperature",
                                                    "pointwidth": "0"
                                                }
                                            }
                                        }
                                    }
                                },
                                "Aqua_night": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Aqua_night",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "WAF": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "WAF",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_min": "-10.0",
                                        "scale_max": "50.0",
                                        "CE": "50",
                                        "CS": "-10",
                                        "valid_max": "1037.5499",
                                        "valid_min": "-123.14999",
                                        "units": "Celsius_scale",
                                        "history": "Y regridded on USGS LandDAAC MODIS 1km 8day version_005 Aqua WAF Night LST",
                                        "missing_value": "NaN",
                                        "maxncolor": "254",
                                        "colormap": "255",
                                        "ncolor": "254",
                                        "iridlhasSemantics": "iridl:LandSurfaceTemperature",
                                        "pointwidth": "0"
                                    },
                                    "SAF": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SAF",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_min": "-10.0",
                                        "scale_max": "50.0",
                                        "CE": "50",
                                        "CS": "-10",
                                        "valid_max": "1037.5499",
                                        "valid_min": "-123.14999",
                                        "units": "Celsius_scale",
                                        "history": "Y regridded on USGS LandDAAC MODIS 1km 8day version_005 Aqua SAF Night LST",
                                        "missing_value": "NaN",
                                        "maxncolor": "254",
                                        "colormap": "255",
                                        "ncolor": "254",
                                        "iridlhasSemantics": "iridl:LandSurfaceTemperature",
                                        "pointwidth": "0"
                                    },
                                    "EAF": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "EAF",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_min": "-10.0",
                                        "scale_max": "50.0",
                                        "CE": "50",
                                        "CS": "-10",
                                        "valid_max": "1037.5499",
                                        "valid_min": "-123.14999",
                                        "units": "Celsius_scale",
                                        "history": "Y regridded on USGS LandDAAC MODIS 1km 8day version_005 Aqua EAF Night LST",
                                        "missing_value": "NaN",
                                        "maxncolor": "254",
                                        "colormap": "255",
                                        "ncolor": "254",
                                        "iridlhasSemantics": "iridl:LandSurfaceTemperature",
                                        "pointwidth": "0"
                                    }
                                },
                                "Aqua": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Aqua",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "WAF": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "WAF",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_min": "-10.0",
                                        "scale_max": "50.0",
                                        "CE": "50",
                                        "CS": "-10",
                                        "history": "Y regridded on USGS LandDAAC MODIS 1km 8day version_005 Aqua_reconstructed WAF tmax_rec",
                                        "missing_value": "NaN",
                                        "long_name": "reconstructed tmax",
                                        "units": "Celsius_scale",
                                        "maxncolor": "254",
                                        "colormap": "255",
                                        "ncolor": "254",
                                        "iridlhasSemantics": "iridl:LandSurfaceTemperature",
                                        "pointwidth": "0"
                                    },
                                    "SAF": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SAF",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_min": "-10.0",
                                        "scale_max": "50.0",
                                        "CE": "50",
                                        "CS": "-10",
                                        "history": "Y regridded on USGS LandDAAC MODIS 1km 8day version_005 Aqua_reconstructed SAF tmax_rec",
                                        "missing_value": "NaN",
                                        "long_name": "reconstructed tmax",
                                        "units": "Celsius_scale",
                                        "maxncolor": "254",
                                        "colormap": "255",
                                        "ncolor": "254",
                                        "iridlhasSemantics": "iridl:LandSurfaceTemperature",
                                        "pointwidth": "0"
                                    },
                                    "EAF": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "EAF",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_min": "-10.0",
                                        "scale_max": "50.0",
                                        "CE": "50",
                                        "CS": "-10",
                                        "history": "Y regridded on USGS LandDAAC MODIS 1km 8day version_005 Aqua_reconstructed EAF tmax_rec",
                                        "missing_value": "NaN",
                                        "long_name": "reconstructed tmax",
                                        "units": "Celsius_scale",
                                        "maxncolor": "254",
                                        "colormap": "255",
                                        "ncolor": "254",
                                        "iridlhasSemantics": "iridl:LandSurfaceTemperature",
                                        "pointwidth": "0"
                                    }
                                }
                            }
                        }
                    }
                },
                "Y_07": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_07",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.002662043"
                },
                "X_08": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_08",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "0.002662043"
                },
                "T_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "Y_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.002662043"
                },
                "T_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "1.0"
                },
                "X_07": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_07",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "0.002662043"
                },
                "Y_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.01"
                },
                "X_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "0.01000001"
                },
                "T_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "Y_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.00208723"
                },
                "T_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "1.0"
                },
                "X_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "0.00208723"
                },
                "Y_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.01"
                },
                "X_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "0.01"
                },
                "T_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulo": "12.0",
                    "modulus": "12.0",
                    "calendar": "360",
                    "pointwidth": "1.0"
                },
                "Y_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.01064817"
                },
                "T_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "1.0"
                },
                "X_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "0.01064817"
                },
                "X_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "long_name": "Longitude",
                    "pointwidth": "0.1"
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "long_name": "Latitude",
                    "pointwidth": "0.1"
                },
                "X_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "long_name": "Longitude",
                    "pointwidth": "0.1"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "long_name": "Latitude",
                    "pointwidth": "0.1"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "long_name": "Longitude",
                    "pointwidth": "0.1"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "days since 2003-01-01",
                    "gridtype": "0",
                    "calendar": "standard",
                    "standard_name": "time"
                },
                "dir": "SOURCES/IRI/Analyses/LandDAAC"
            },
            "Locust": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Locust",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Conventions": "IRIDL"
                },
                "CMORPH": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "CMORPH",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "monthlysum": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "monthlysum",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm/month",
                        "missing_value": "NaN",
                        "history": "Boxes with less than 100.0% dropped",
                        "file_missing_value": "-9999.0",
                        "long_name": "Estimated precipitation",
                        "pointwidth": "0"
                    },
                    "monthlyavg": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "monthlyavg",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "history": "Boxes with less than 90.0% dropped",
                        "units": "mm/hr",
                        "file_missing_value": "-9999.0",
                        "long_name": "Estimated precipitation",
                        "pointwidth": "0"
                    },
                    "dekadsum": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dekadsum",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "cmorph_dekad_colors",
                        "colormap": "2237106",
                        "scale_max": "300.0",
                        "ncolor": "254",
                        "scale_min": "0.0",
                        "CE": "300",
                        "CS": "0",
                        "long_name": "Estimated Dekadal Precipitation",
                        "missing_value": "NaN",
                        "units": "mm",
                        "history": "Boxes with less than 100.0% dropped",
                        "file_missing_value": "-9999.0",
                        "pointwidth": "0"
                    }
                },
                "T_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "1.0"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.25"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "days since 2002-12-07 00:00:00",
                    "gridtype": "0",
                    "calendar": "standard"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "standard_name": "longitude",
                    "pointwidth": "0.25"
                },
                "dir": "SOURCES/IRI/Analyses/Locust"
            },
            "MDG": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "MDG",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Conventions": "IRIDL"
                },
                "Africa": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Africa",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "queriesCMAPlatest": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "queriesCMAPlatest",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "cabaseline_full": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "cabaseline_full",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Country-Average CMAP 12-Month WASP Baseline",
                            "missing_value": "NaN",
                            "units": "unitless",
                            "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                            "ncolor": "254",
                            "colorscalename": "std_wasp_colors",
                            "maxncolor": "254",
                            "colormap": "360960",
                            "file_missing_value": "-999.0",
                            "standard_name": "lwe_precipitation_rate"
                        }
                    }
                },
                "BaseYears": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "BaseYears",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "standard_name": "time",
                    "calendar": "360",
                    "pointwidth": "12.0"
                },
                "Baseline": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Baseline",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulo": "12.0",
                    "modulus": "12.0",
                    "long_name": "Month of the year baseline starts",
                    "calendar": "360",
                    "pointwidth": "1.0",
                    "standard_name": "time"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "12.0",
                    "standard_name": "time"
                },
                "country": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "country",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "gridtype": "2",
                    "units": "ids"
                },
                "dir": "SOURCES/IRI/Analyses/MDG"
            },
            "NOAA": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NOAA",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NCEPCPCGOBV0pxNMME_droughtmonthlyNMME_deg1p0totaldescription": "CPC GOB monthly precipitation regridded to 1.0 deg. lat/lon resolution to match NMME",
                    "NCEPCPCGOBV0pxNMME_droughtmonthlyNMME_deg1p0resampledseasonality_retainedSPIcorreldescription": "In this dataset the Start Time designates the latest month with real observations, NOT a forecast start time at 0000 1 Jan, for example.  So, for SPI3, with a Jan start time and lead of 1, the forecast is for Feb, and there are 2 months of overlap (Dec and Jan) between SPI3 and SPI2.  For SPI3 with a Jan start time and a lead of 2, the forecast is for Mar, and there is 1 month of overlap (Jan) between SPI3 and SPI1",
                    "NCEPCPCGOBV0pxNMME_droughtmonthlyNMME_deg1p0correl_diffNMME_MME_prcphind_obs_OptPersistSPI9description": "In this dataset SPI values calculated on merged NMME_MME_prcp hindcast data and observed monthly GOB data over Jan 1982-Dec 2010 are correlated with SPI calculated from GOB alone, and this correlation is compared to the equivalent correlation from the optimal persistence calculation to flag which is larger.  This flag will be used to make a skill mask for the MME/Optimal Persistence drought forecast tool.  In this dataset the start time corresponds to the last calendar month of observations before forecast data are appended, NOT a 0000 1 Jan forecast start, for example.",
                    "NCEPCPCGOBV0pxNMME_droughtmonthlyNMME_deg1p0correl_diffNMME_MME_prcphind_obs_OptPersistSPI6description": "In this dataset SPI values calculated on merged NMME_MME_prcp hindcast data and observed monthly GOB data over Jan 1982-Dec 2010 are correlated with SPI calculated from GOB alone, and this correlation is compared to the equivalent correlation from the optimal persistence calculation to flag which is larger.  This flag will be used to make a skill mask for the MME/Optimal Persistence drought forecast tool.  In this dataset the start time corresponds to the last calendar month of observations before forecast data are appended, NOT a 0000 1 Jan forecast start, for example.",
                    "NCEPCPCGOBV0pxNMME_droughtmonthlyNMME_deg1p0correl_diffNMME_MME_prcphind_obs_OptPersistSPI3description": "In this dataset SPI values calculated on merged NMME_MME_prcp hindcast data and observed monthly GOB data over Jan 1982-Dec 2010 are correlated with SPI calculated from GOB alone, and this correlation is compared to the equivalent correlation from the optimal persistence calculation to flag which is larger.  This flag will be used to make a skill mask for the MME/Optimal Persistence drought forecast tool.  In this dataset the start time corresponds to the last calendar month of observations before forecast data are appended, NOT a 0000 1 Jan forecast start, for example.",
                    "NCEPCPCGOBV0pxNMME_droughtmonthlyNMME_deg1p0correl_diffNMME_MME_prcphind_obs_OptPersistSPI12description": "In this dataset SPI values calculated on merged NMME_MME_prcp hindcast data and observed monthly GOB data over Jan 1982-Dec 2010 are correlated with SPI calculated from GOB alone, and this correlation is compared to the equivalent correlation from the optimal persistence calculation to flag which is larger.  This flag will be used to make a skill mask for the MME/Optimal Persistence drought forecast tool.  In this dataset the start time corresponds to the last calendar month of observations before forecast data are appended, NOT a 0000 1 Jan forecast start, for example.",
                    "Conventions": "IRIDL"
                },
                "NCEP": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NCEP",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "CPC": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "CPC",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "GOB": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "GOB",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "V0px": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "V0px",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "NMME_drought": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "NMME_drought",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "monthly": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "monthly",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "NMME_deg1p0": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "NMME_deg1p0",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "total": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "total",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "precipitation": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "precipitation",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "long_name": "precipitation",
                                                    "missing_value": "NaN",
                                                    "history": "Boxes with less than 25.0% dropped",
                                                    "units": "mm/month",
                                                    "file_missing_value": "-999.0",
                                                    "pointwidth": "1.0"
                                                }
                                            },
                                            "resampled": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "resampled",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "seasonality_retained": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "seasonality_retained",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "SPIcorrel": {
                                                        "iridl_type": "DataSet",
                                                        "iridl_ds_name": "SPIcorrel",
                                                        "banned": [
                                                            "dir",
                                                            "invalid",
                                                            "parent",
                                                            "name",
                                                            "banned",
                                                            "banned_long",
                                                            "iridl_ds_name",
                                                            "iridl_type"
                                                        ],
                                                        "spi9": {
                                                            "iridl_type": "DataSet",
                                                            "iridl_ds_name": "spi9",
                                                            "banned": [
                                                                "dir",
                                                                "invalid",
                                                                "parent",
                                                                "name",
                                                                "banned",
                                                                "banned_long",
                                                                "iridl_ds_name",
                                                                "iridl_type"
                                                            ],
                                                            "corrSPI9": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "corrSPI9",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "units": "unitless",
                                                                "pointwidth": "1.0"
                                                            }
                                                        },
                                                        "spi6": {
                                                            "iridl_type": "DataSet",
                                                            "iridl_ds_name": "spi6",
                                                            "banned": [
                                                                "dir",
                                                                "invalid",
                                                                "parent",
                                                                "name",
                                                                "banned",
                                                                "banned_long",
                                                                "iridl_ds_name",
                                                                "iridl_type"
                                                            ],
                                                            "corrSPI6": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "corrSPI6",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "units": "unitless",
                                                                "pointwidth": "1.0"
                                                            }
                                                        },
                                                        "spi3": {
                                                            "iridl_type": "DataSet",
                                                            "iridl_ds_name": "spi3",
                                                            "banned": [
                                                                "dir",
                                                                "invalid",
                                                                "parent",
                                                                "name",
                                                                "banned",
                                                                "banned_long",
                                                                "iridl_ds_name",
                                                                "iridl_type"
                                                            ],
                                                            "corrSPI3": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "corrSPI3",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "units": "unitless",
                                                                "pointwidth": "1.0"
                                                            }
                                                        },
                                                        "spi12": {
                                                            "iridl_type": "DataSet",
                                                            "iridl_ds_name": "spi12",
                                                            "banned": [
                                                                "dir",
                                                                "invalid",
                                                                "parent",
                                                                "name",
                                                                "banned",
                                                                "banned_long",
                                                                "iridl_ds_name",
                                                                "iridl_type"
                                                            ],
                                                            "corrSPI12": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "corrSPI12",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "units": "unitless",
                                                                "modulo": "12.0",
                                                                "modulus": "12.0",
                                                                "pointwidth": "1.0"
                                                            }
                                                        }
                                                    },
                                                    "forecast": {
                                                        "iridl_type": "DataSet",
                                                        "iridl_ds_name": "forecast",
                                                        "banned": [
                                                            "dir",
                                                            "invalid",
                                                            "parent",
                                                            "name",
                                                            "banned",
                                                            "banned_long",
                                                            "iridl_ds_name",
                                                            "iridl_type"
                                                        ],
                                                        "spi9": {
                                                            "iridl_type": "DataSet",
                                                            "iridl_ds_name": "spi9",
                                                            "banned": [
                                                                "dir",
                                                                "invalid",
                                                                "parent",
                                                                "name",
                                                                "banned",
                                                                "banned_long",
                                                                "iridl_ds_name",
                                                                "iridl_type"
                                                            ],
                                                            "sigma": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "sigma",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "long_name": "sigma",
                                                                "fnname": "sqrt",
                                                                "units": "unitless",
                                                                "pointwidth": "1.0"
                                                            },
                                                            "mean": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "mean",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "history": "L:  8.0 months to 8.0 months appended from   spi   prob   pcpn_accum [ IRI Analyses NOAA NCEP CPC GOB V0px NMME_drought monthly NMME_deg1p0 total precipitation ]       * [ IRI Analyses NOAA NCEP CPC GOB V0px NMME_drought monthly NMME_deg1p0 resampled seasonality_retained SPIcorrel spi9 corrSPI9 ]",
                                                                "long_name": "mean",
                                                                "missing_value": "NaN",
                                                                "units": "unitless",
                                                                "maxncolor": "254",
                                                                "colormap": "45",
                                                                "ncolor": "253",
                                                                "file_missing_value": "-9.9899998",
                                                                "pointwidth": "1.0"
                                                            },
                                                            "forecasttime": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "forecasttime",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "standard_name": "time",
                                                                "long_name": "Forecast Time",
                                                                "calendar": "360",
                                                                "units": "months since 1960-01-01",
                                                                "pointwidth": "1.0"
                                                            }
                                                        },
                                                        "spi6": {
                                                            "iridl_type": "DataSet",
                                                            "iridl_ds_name": "spi6",
                                                            "banned": [
                                                                "dir",
                                                                "invalid",
                                                                "parent",
                                                                "name",
                                                                "banned",
                                                                "banned_long",
                                                                "iridl_ds_name",
                                                                "iridl_type"
                                                            ],
                                                            "sigma": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "sigma",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "long_name": "sigma",
                                                                "fnname": "sqrt",
                                                                "units": "unitless",
                                                                "pointwidth": "1.0"
                                                            },
                                                            "mean": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "mean",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "history": "L:  5.0 months to 5.0 months appended from   spi   prob   pcpn_accum [ IRI Analyses NOAA NCEP CPC GOB V0px NMME_drought monthly NMME_deg1p0 total precipitation ]       * [ IRI Analyses NOAA NCEP CPC GOB V0px NMME_drought monthly NMME_deg1p0 resampled seasonality_retained SPIcorrel spi6 corrSPI6 ]",
                                                                "long_name": "mean",
                                                                "missing_value": "NaN",
                                                                "units": "unitless",
                                                                "maxncolor": "254",
                                                                "colormap": "45",
                                                                "ncolor": "253",
                                                                "file_missing_value": "-9.9899998",
                                                                "pointwidth": "1.0"
                                                            },
                                                            "forecasttime": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "forecasttime",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "standard_name": "time",
                                                                "long_name": "Forecast Time",
                                                                "calendar": "360",
                                                                "units": "months since 1960-01-01",
                                                                "pointwidth": "1.0"
                                                            }
                                                        },
                                                        "spi3": {
                                                            "iridl_type": "DataSet",
                                                            "iridl_ds_name": "spi3",
                                                            "banned": [
                                                                "dir",
                                                                "invalid",
                                                                "parent",
                                                                "name",
                                                                "banned",
                                                                "banned_long",
                                                                "iridl_ds_name",
                                                                "iridl_type"
                                                            ],
                                                            "sigma": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "sigma",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "long_name": "sigma",
                                                                "fnname": "sqrt",
                                                                "units": "unitless",
                                                                "pointwidth": "1.0"
                                                            },
                                                            "mean": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "mean",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "history": "L:  2.0 months to 2.0 months appended from   spi   prob   pcpn_accum [ IRI Analyses NOAA NCEP CPC GOB V0px NMME_drought monthly NMME_deg1p0 total precipitation ]       * [ IRI Analyses NOAA NCEP CPC GOB V0px NMME_drought monthly NMME_deg1p0 resampled seasonality_retained SPIcorrel spi3 corrSPI3 ]",
                                                                "long_name": "mean",
                                                                "missing_value": "NaN",
                                                                "units": "unitless",
                                                                "maxncolor": "254",
                                                                "colormap": "45",
                                                                "ncolor": "253",
                                                                "file_missing_value": "-9.9899998",
                                                                "pointwidth": "1.0"
                                                            },
                                                            "forecasttime": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "forecasttime",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "standard_name": "time",
                                                                "long_name": "Forecast Time",
                                                                "calendar": "360",
                                                                "units": "months since 1960-01-01",
                                                                "pointwidth": "1.0"
                                                            }
                                                        },
                                                        "spi12": {
                                                            "iridl_type": "DataSet",
                                                            "iridl_ds_name": "spi12",
                                                            "banned": [
                                                                "dir",
                                                                "invalid",
                                                                "parent",
                                                                "name",
                                                                "banned",
                                                                "banned_long",
                                                                "iridl_ds_name",
                                                                "iridl_type"
                                                            ],
                                                            "sigma": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "sigma",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "long_name": "sigma",
                                                                "fnname": "sqrt",
                                                                "units": "unitless",
                                                                "modulo": "12.0",
                                                                "modulus": "12.0",
                                                                "pointwidth": "1.0"
                                                            },
                                                            "mean": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "mean",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "history": "L:  11.0 months to 11.0 months appended from   spi   prob   pcpn_accum [ IRI Analyses NOAA NCEP CPC GOB V0px NMME_drought monthly NMME_deg1p0 total precipitation ]       * [ IRI Analyses NOAA NCEP CPC GOB V0px NMME_drought monthly NMME_deg1p0 resampled seasonality_retained SPIcorrel spi12 corrSPI12 ]",
                                                                "long_name": "mean",
                                                                "missing_value": "NaN",
                                                                "units": "unitless",
                                                                "maxncolor": "254",
                                                                "colormap": "45",
                                                                "ncolor": "253",
                                                                "file_missing_value": "-9.9899998",
                                                                "pointwidth": "1.0"
                                                            },
                                                            "forecasttime": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "forecasttime",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "standard_name": "time",
                                                                "long_name": "Forecast Time",
                                                                "calendar": "360",
                                                                "units": "months since 1960-01-01",
                                                                "pointwidth": "1.0"
                                                            }
                                                        }
                                                    }
                                                }
                                            },
                                            "correl_diff": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "correl_diff",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "NMME_MME_prcp": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "NMME_MME_prcp",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "hind_obs_OptPersist": {
                                                        "iridl_type": "DataSet",
                                                        "iridl_ds_name": "hind_obs_OptPersist",
                                                        "banned": [
                                                            "dir",
                                                            "invalid",
                                                            "parent",
                                                            "name",
                                                            "banned",
                                                            "banned_long",
                                                            "iridl_ds_name",
                                                            "iridl_type"
                                                        ],
                                                        "SPI9": {
                                                            "iridl_type": "DataSet",
                                                            "iridl_ds_name": "SPI9",
                                                            "banned": [
                                                                "dir",
                                                                "invalid",
                                                                "parent",
                                                                "name",
                                                                "banned",
                                                                "banned_long",
                                                                "iridl_ds_name",
                                                                "iridl_type"
                                                            ],
                                                            "sep": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "sep",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "oct": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "oct",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "nov": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "nov",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "may": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "may",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "mar": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "mar",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "jun": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "jun",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "jul": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "jul",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "jan": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "jan",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "feb": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "feb",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "dec": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "dec",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "aug": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "aug",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "apr": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "apr",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            }
                                                        },
                                                        "SPI6": {
                                                            "iridl_type": "DataSet",
                                                            "iridl_ds_name": "SPI6",
                                                            "banned": [
                                                                "dir",
                                                                "invalid",
                                                                "parent",
                                                                "name",
                                                                "banned",
                                                                "banned_long",
                                                                "iridl_ds_name",
                                                                "iridl_type"
                                                            ],
                                                            "sep": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "sep",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "oct": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "oct",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "nov": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "nov",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "may": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "may",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "mar": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "mar",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "jun": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "jun",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "jul": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "jul",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "jan": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "jan",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "feb": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "feb",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "dec": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "dec",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "aug": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "aug",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "apr": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "apr",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            }
                                                        },
                                                        "SPI3": {
                                                            "iridl_type": "DataSet",
                                                            "iridl_ds_name": "SPI3",
                                                            "banned": [
                                                                "dir",
                                                                "invalid",
                                                                "parent",
                                                                "name",
                                                                "banned",
                                                                "banned_long",
                                                                "iridl_ds_name",
                                                                "iridl_type"
                                                            ],
                                                            "sep": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "sep",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "oct": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "oct",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "nov": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "nov",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "may": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "may",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "mar": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "mar",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "jun": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "jun",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "jul": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "jul",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "jan": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "jan",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "feb": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "feb",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "dec": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "dec",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "aug": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "aug",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "apr": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "apr",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            }
                                                        },
                                                        "SPI12": {
                                                            "iridl_type": "DataSet",
                                                            "iridl_ds_name": "SPI12",
                                                            "banned": [
                                                                "dir",
                                                                "invalid",
                                                                "parent",
                                                                "name",
                                                                "banned",
                                                                "banned_long",
                                                                "iridl_ds_name",
                                                                "iridl_type"
                                                            ],
                                                            "sep": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "sep",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "oct": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "oct",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "nov": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "nov",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "may": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "may",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "mar": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "mar",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "jun": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "jun",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "jul": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "jul",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "jan": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "jan",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "feb": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "feb",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "dec": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "dec",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "aug": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "aug",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            },
                                                            "apr": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "apr",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "flag": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "flag",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "units": "unitless",
                                                                    "pointwidth": "1.0"
                                                                }
                                                            }
                                                        }
                                                    }
                                                }
                                            },
                                            "amplitudebiasfactor": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "amplitudebiasfactor",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "NMME_MMprcp": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "NMME_MMprcp",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "c8210": {
                                                        "iridl_type": "DataSet",
                                                        "iridl_ds_name": "c8210",
                                                        "banned": [
                                                            "dir",
                                                            "invalid",
                                                            "parent",
                                                            "name",
                                                            "banned",
                                                            "banned_long",
                                                            "iridl_ds_name",
                                                            "iridl_type"
                                                        ],
                                                        "_global": {
                                                            "iridl_type": "DataSet",
                                                            "iridl_ds_name": "global",
                                                            "banned": [
                                                                "dir",
                                                                "invalid",
                                                                "parent",
                                                                "name",
                                                                "banned",
                                                                "banned_long",
                                                                "iridl_ds_name",
                                                                "iridl_type"
                                                            ],
                                                            "lead_0month": {
                                                                "iridl_type": "DataSet",
                                                                "iridl_ds_name": "lead_0month",
                                                                "banned": [
                                                                    "dir",
                                                                    "invalid",
                                                                    "parent",
                                                                    "name",
                                                                    "banned",
                                                                    "banned_long",
                                                                    "iridl_ds_name",
                                                                    "iridl_type"
                                                                ],
                                                                "sep": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "sep",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "correction_factor": {
                                                                        "iridl_type": "DataSet",
                                                                        "iridl_ds_name": "correction_factor",
                                                                        "banned": [
                                                                            "dir",
                                                                            "invalid",
                                                                            "parent",
                                                                            "name",
                                                                            "banned",
                                                                            "banned_long",
                                                                            "iridl_ds_name",
                                                                            "iridl_type"
                                                                        ],
                                                                        "units": "unitless",
                                                                        "missing_value": "-9999.0"
                                                                    }
                                                                },
                                                                "oct": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "oct",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "correction_factor": {
                                                                        "iridl_type": "DataSet",
                                                                        "iridl_ds_name": "correction_factor",
                                                                        "banned": [
                                                                            "dir",
                                                                            "invalid",
                                                                            "parent",
                                                                            "name",
                                                                            "banned",
                                                                            "banned_long",
                                                                            "iridl_ds_name",
                                                                            "iridl_type"
                                                                        ],
                                                                        "units": "unitless",
                                                                        "missing_value": "-9999.0"
                                                                    }
                                                                },
                                                                "nov": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "nov",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "correction_factor": {
                                                                        "iridl_type": "DataSet",
                                                                        "iridl_ds_name": "correction_factor",
                                                                        "banned": [
                                                                            "dir",
                                                                            "invalid",
                                                                            "parent",
                                                                            "name",
                                                                            "banned",
                                                                            "banned_long",
                                                                            "iridl_ds_name",
                                                                            "iridl_type"
                                                                        ],
                                                                        "units": "unitless",
                                                                        "missing_value": "-9999.0"
                                                                    }
                                                                },
                                                                "may": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "may",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "correction_factor": {
                                                                        "iridl_type": "DataSet",
                                                                        "iridl_ds_name": "correction_factor",
                                                                        "banned": [
                                                                            "dir",
                                                                            "invalid",
                                                                            "parent",
                                                                            "name",
                                                                            "banned",
                                                                            "banned_long",
                                                                            "iridl_ds_name",
                                                                            "iridl_type"
                                                                        ],
                                                                        "units": "unitless",
                                                                        "missing_value": "-9999.0"
                                                                    }
                                                                },
                                                                "mar": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "mar",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "correction_factor": {
                                                                        "iridl_type": "DataSet",
                                                                        "iridl_ds_name": "correction_factor",
                                                                        "banned": [
                                                                            "dir",
                                                                            "invalid",
                                                                            "parent",
                                                                            "name",
                                                                            "banned",
                                                                            "banned_long",
                                                                            "iridl_ds_name",
                                                                            "iridl_type"
                                                                        ],
                                                                        "units": "unitless",
                                                                        "missing_value": "-9999.0"
                                                                    }
                                                                },
                                                                "jun": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "jun",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "correction_factor": {
                                                                        "iridl_type": "DataSet",
                                                                        "iridl_ds_name": "correction_factor",
                                                                        "banned": [
                                                                            "dir",
                                                                            "invalid",
                                                                            "parent",
                                                                            "name",
                                                                            "banned",
                                                                            "banned_long",
                                                                            "iridl_ds_name",
                                                                            "iridl_type"
                                                                        ],
                                                                        "units": "unitless",
                                                                        "missing_value": "-9999.0"
                                                                    }
                                                                },
                                                                "jul": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "jul",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "correction_factor": {
                                                                        "iridl_type": "DataSet",
                                                                        "iridl_ds_name": "correction_factor",
                                                                        "banned": [
                                                                            "dir",
                                                                            "invalid",
                                                                            "parent",
                                                                            "name",
                                                                            "banned",
                                                                            "banned_long",
                                                                            "iridl_ds_name",
                                                                            "iridl_type"
                                                                        ],
                                                                        "units": "unitless",
                                                                        "missing_value": "-9999.0"
                                                                    }
                                                                },
                                                                "jan": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "jan",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "correction_factor": {
                                                                        "iridl_type": "DataSet",
                                                                        "iridl_ds_name": "correction_factor",
                                                                        "banned": [
                                                                            "dir",
                                                                            "invalid",
                                                                            "parent",
                                                                            "name",
                                                                            "banned",
                                                                            "banned_long",
                                                                            "iridl_ds_name",
                                                                            "iridl_type"
                                                                        ],
                                                                        "units": "unitless",
                                                                        "missing_value": "-9999.0"
                                                                    }
                                                                },
                                                                "feb": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "feb",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "correction_factor": {
                                                                        "iridl_type": "DataSet",
                                                                        "iridl_ds_name": "correction_factor",
                                                                        "banned": [
                                                                            "dir",
                                                                            "invalid",
                                                                            "parent",
                                                                            "name",
                                                                            "banned",
                                                                            "banned_long",
                                                                            "iridl_ds_name",
                                                                            "iridl_type"
                                                                        ],
                                                                        "units": "unitless",
                                                                        "missing_value": "-9999.0"
                                                                    }
                                                                },
                                                                "dec": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "dec",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "correction_factor": {
                                                                        "iridl_type": "DataSet",
                                                                        "iridl_ds_name": "correction_factor",
                                                                        "banned": [
                                                                            "dir",
                                                                            "invalid",
                                                                            "parent",
                                                                            "name",
                                                                            "banned",
                                                                            "banned_long",
                                                                            "iridl_ds_name",
                                                                            "iridl_type"
                                                                        ],
                                                                        "units": "unitless",
                                                                        "missing_value": "-9999.0"
                                                                    }
                                                                },
                                                                "aug": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "aug",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "correction_factor": {
                                                                        "iridl_type": "DataSet",
                                                                        "iridl_ds_name": "correction_factor",
                                                                        "banned": [
                                                                            "dir",
                                                                            "invalid",
                                                                            "parent",
                                                                            "name",
                                                                            "banned",
                                                                            "banned_long",
                                                                            "iridl_ds_name",
                                                                            "iridl_type"
                                                                        ],
                                                                        "units": "unitless",
                                                                        "missing_value": "-9999.0"
                                                                    }
                                                                },
                                                                "apr": {
                                                                    "iridl_type": "DataSet",
                                                                    "iridl_ds_name": "apr",
                                                                    "banned": [
                                                                        "dir",
                                                                        "invalid",
                                                                        "parent",
                                                                        "name",
                                                                        "banned",
                                                                        "banned_long",
                                                                        "iridl_ds_name",
                                                                        "iridl_type"
                                                                    ],
                                                                    "correction_factor": {
                                                                        "iridl_type": "DataSet",
                                                                        "iridl_ds_name": "correction_factor",
                                                                        "banned": [
                                                                            "dir",
                                                                            "invalid",
                                                                            "parent",
                                                                            "name",
                                                                            "banned",
                                                                            "banned_long",
                                                                            "iridl_ds_name",
                                                                            "iridl_type"
                                                                        ],
                                                                        "units": "unitless",
                                                                        "missing_value": "-9999.0"
                                                                    }
                                                                }
                                                            }
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                },
                                "monthly": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthly",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mm/month",
                                        "missing_value": "NaN",
                                        "history": "T:  Nov 2014 to Feb 2021 appended from NOAA NCEP CPC GOB V0px daily REALTIME prcp",
                                        "file_missing_value": "-999.0",
                                        "long_name": "blended daily precipitation",
                                        "pointwidth": "1.0"
                                    }
                                }
                            }
                        }
                    }
                },
                "NCDC": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NCDC",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "USHCN": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "USHCN",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "daily": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "daily",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "MinpctilAT2": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MinpctilAT2",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "percentile": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "percentile",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "maxncolor": "8",
                                    "colormap": "2763429",
                                    "scale_max": "4.0",
                                    "ncolor": "8",
                                    "scale_min": "0.0",
                                    "CE": "4",
                                    "CS": "0",
                                    "missing_value": "9.0",
                                    "units": "ids",
                                    "long_name": "Min Apparent Temperature Percentile Category",
                                    "CLIST": "\\xe2\\x89\\xa5 95th"
                                }
                            },
                            "Minpctil2mt": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Minpctil2mt",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "percentile": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "percentile",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "maxncolor": "8",
                                    "colormap": "2763429",
                                    "scale_max": "4.0",
                                    "ncolor": "8",
                                    "scale_min": "0.0",
                                    "CE": "4",
                                    "CS": "0",
                                    "missing_value": "9.0",
                                    "units": "ids",
                                    "long_name": "MinT Heat Percentile Category",
                                    "CLIST": "\\xe2\\x89\\xa5 95th"
                                }
                            },
                            "MaxpctilAT2": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MaxpctilAT2",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "percentile": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "percentile",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "maxncolor": "8",
                                    "colormap": "2763429",
                                    "scale_max": "4.0",
                                    "ncolor": "8",
                                    "scale_min": "0.0",
                                    "CE": "4",
                                    "CS": "0",
                                    "missing_value": "9.0",
                                    "units": "ids",
                                    "long_name": "Max Apparent Temperature Percentile Category",
                                    "CLIST": "\\xe2\\x89\\xa5 95th"
                                }
                            },
                            "Maxpctil2mt": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Maxpctil2mt",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "percentile": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "percentile",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "maxncolor": "8",
                                    "colormap": "2763429",
                                    "scale_max": "4.0",
                                    "ncolor": "8",
                                    "scale_min": "0.0",
                                    "CE": "4",
                                    "CS": "0",
                                    "missing_value": "9.0",
                                    "units": "ids",
                                    "long_name": "MaxT Heat Percentile Category",
                                    "CLIST": "\\xe2\\x89\\xa5 95th"
                                }
                            },
                            "HWlength_2mtmin": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HWlength_2mtmin",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "heatwave_length": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "heatwave_length",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "maxncolor": "11",
                                    "colormap": "6303920",
                                    "scale_max": "7.0",
                                    "ncolor": "11",
                                    "scale_min": "0.0",
                                    "CE": "7",
                                    "CS": "0",
                                    "missing_value": "9.0",
                                    "units": "days",
                                    "long_name": "MinT Heatwave Length in Consecutive Days",
                                    "CLIST": "\\xe2\\x89\\xa5 9 dy"
                                }
                            },
                            "HWlength_2mtmax": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HWlength_2mtmax",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "heatwave_length": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "heatwave_length",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "maxncolor": "11",
                                    "colormap": "6303920",
                                    "scale_max": "7.0",
                                    "ncolor": "11",
                                    "scale_min": "0.0",
                                    "CE": "7",
                                    "CS": "0",
                                    "missing_value": "9.0",
                                    "units": "days",
                                    "long_name": "MaxT Heatwave Length in Consecutive Days",
                                    "CLIST": "\\xe2\\x89\\xa5 9 dy"
                                }
                            },
                            "HWlength_2mATmin": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HWlength_2mATmin",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "heatwave_length": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "heatwave_length",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "maxncolor": "11",
                                    "colormap": "6303920",
                                    "scale_max": "7.0",
                                    "ncolor": "11",
                                    "scale_min": "0.0",
                                    "CE": "7",
                                    "CS": "0",
                                    "missing_value": "9.0",
                                    "units": "days",
                                    "long_name": "Min Apparent Temperature Heatwave Length in Consecutive Days",
                                    "CLIST": "\\xe2\\x89\\xa5 9 dy"
                                }
                            },
                            "HWlength_2mATmax": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "HWlength_2mATmax",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "heatwave_length": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "heatwave_length",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "maxncolor": "11",
                                    "colormap": "6303920",
                                    "scale_max": "7.0",
                                    "ncolor": "11",
                                    "scale_min": "0.0",
                                    "CE": "7",
                                    "CS": "0",
                                    "missing_value": "9.0",
                                    "units": "days",
                                    "long_name": "Max Apparent Temperature Heatwave Length in Consecutive Days",
                                    "CLIST": "\\xe2\\x89\\xa5 9 dy"
                                }
                            }
                        }
                    }
                },
                "L_08": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_08",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "0"
                },
                "L_07": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_07",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "0"
                },
                "L_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "0"
                },
                "S_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulo": "12.0",
                    "modulus": "12.0",
                    "calendar": "360",
                    "long_name": "Start Time",
                    "pointwidth": "1.0"
                },
                "L_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "0"
                },
                "S_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Start Time",
                    "pointwidth": "1.0"
                },
                "L_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "long_name": "lead",
                    "pointwidth": "1.0"
                },
                "S": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360"
                },
                "L_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "long_name": "Lead",
                    "pointwidth": "1.0"
                },
                "L_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "long_name": "Lead",
                    "pointwidth": "1.0"
                },
                "L_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "long_name": "Lead",
                    "pointwidth": "1.0"
                },
                "Y_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "latitude",
                    "pointwidth": "1.0"
                },
                "L": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "long_name": "Lead",
                    "pointwidth": "1.0"
                },
                "T_13": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_13",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "T_12": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_12",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "T_11": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_11",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "T_10": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_10",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "T_09": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_09",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "T_08": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_08",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "T_07": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_07",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "T_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "T_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "T_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "T_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "X_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "standard_name": "longitude",
                    "pointwidth": "1.0"
                },
                "Y_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "1.0"
                },
                "T_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "T_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360"
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "0.25"
                },
                "X_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "standard_name": "longitude",
                    "long_name": "Longitude",
                    "pointwidth": "0.25"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.5"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "julian_day",
                    "gridtype": "0",
                    "calendar": "standard",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "0.5"
                },
                "dir": "SOURCES/IRI/Analyses/NOAA"
            },
            "SPI": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "SPI",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Conventions": "IRIDL"
                },
                "SPIUEA_9Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-UEA_9-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-UEA_9-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPIUEA_6Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-UEA_6-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-UEA_6-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPIUEA_3Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-UEA_3-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-UEA_3-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPIUEA_12Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-UEA_12-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-UEA_12-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPIUEA_1Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-UEA_1-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-UEA_1-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPITS2p1_9Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-TS2p1_9-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-TS2p1_9-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPITS2p1_6Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-TS2p1_6-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-TS2p1_6-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPITS2p1_3Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-TS2p1_3-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-TS2p1_3-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPITS2p1_12Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-TS2p1_12-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-TS2p1_12-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPITS2p1_1Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-TS2p1_1-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-TS2p1_1-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPIPRECL0p5_9Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-PRECL0p5_9-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-PRECL0p5_9-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "standard_name": "lwe_precipitation_rate",
                    "expires": "1617235200",
                    "pointwidth": "0"
                },
                "SPIPRECL0p5_6Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-PRECL0p5_6-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-PRECL0p5_6-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "standard_name": "lwe_precipitation_rate",
                    "expires": "1617235200",
                    "pointwidth": "0"
                },
                "SPIPRECL0p5_3Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-PRECL0p5_3-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-PRECL0p5_3-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "standard_name": "lwe_precipitation_rate",
                    "expires": "1617235200",
                    "pointwidth": "0"
                },
                "SPIPRECL0p5_12Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-PRECL0p5_12-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-PRECL0p5_12-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "standard_name": "lwe_precipitation_rate",
                    "expires": "1617235200",
                    "pointwidth": "0"
                },
                "SPIPRECL0p5_1Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-PRECL0p5_1-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-PRECL0p5_1-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "standard_name": "lwe_precipitation_rate",
                    "expires": "1617235200",
                    "pointwidth": "0"
                },
                "SPIGPCPv2OPI_9Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-GPCPv2OPI_9-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-GPCPv2OPI_9-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "technique": "OPI",
                    "pointwidth": "0"
                },
                "SPIGPCPv2OPI_6Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-GPCPv2OPI_6-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-GPCPv2OPI_6-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "technique": "OPI",
                    "pointwidth": "0"
                },
                "SPIGPCPv2OPI_3Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-GPCPv2OPI_3-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-GPCPv2OPI_3-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "technique": "OPI",
                    "pointwidth": "0"
                },
                "SPIGPCPv2OPI_12Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-GPCPv2OPI_12-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-GPCPv2OPI_12-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "technique": "OPI",
                    "pointwidth": "0"
                },
                "SPIGPCPv2OPI_1Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-GPCPv2OPI_1-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-GPCPv2OPI_1-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "technique": "OPI",
                    "pointwidth": "0"
                },
                "SPIGOBv0px1deg_9Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-GOBv0px1deg_9-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "17920",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "drought_monitor_colors1",
                    "CE": "3.5",
                    "long_name": "9-Month Standardized Precipitation Index",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "history": "Boxes with less than 25.0% dropped",
                    "pointwidth": "1.0"
                },
                "SPIGOBv0px1deg_6Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-GOBv0px1deg_6-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "17920",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "drought_monitor_colors1",
                    "CE": "3.5",
                    "long_name": "6-Month Standardized Precipitation Index",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "history": "Boxes with less than 25.0% dropped",
                    "pointwidth": "1.0"
                },
                "SPIGOBv0px1deg_3Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-GOBv0px1deg_3-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "17920",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "drought_monitor_colors1",
                    "CE": "3.5",
                    "long_name": "3-Month Standardized Precipitation Index",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "history": "Boxes with less than 25.0% dropped",
                    "pointwidth": "1.0"
                },
                "SPIGOBv0px1deg_12Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-GOBv0px1deg_12-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "17920",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "drought_monitor_colors1",
                    "CE": "3.5",
                    "long_name": "12-Month Standardized Precipitation Index",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "history": "Boxes with less than 25.0% dropped",
                    "pointwidth": "1.0"
                },
                "SPIGOBv0px1deg_1Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-GOBv0px1deg_1-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "17920",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "drought_monitor_colors1",
                    "CE": "3.5",
                    "long_name": "1-Month Standardized Precipitation Index",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "history": "Boxes with less than 25.0% dropped",
                    "pointwidth": "1.0"
                },
                "SPICMAP0407v1_9Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-CMAP0407v1_9-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-CMAP0407v1_9-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPICMAP0407v1_6Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-CMAP0407v1_6-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-CMAP0407v1_6-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPICMAP0407v1_3Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-CMAP0407v1_3-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-CMAP0407v1_3-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPICMAP0407v1_12Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-CMAP0407v1_12-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-CMAP0407v1_12-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPICMAP0407v1_1Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-CMAP0407v1_1-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-CMAP0407v1_1-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998"
                },
                "SPICAMSOPI_9Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-CAMSOPI_9-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-CAMS_OPI_9-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "expires": "1617235200",
                    "pointwidth": "9",
                    "standard_name": "time",
                    "calendar": "360",
                    "bounds": "T"
                },
                "SPICAMSOPI_6Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-CAMSOPI_6-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-CAMS_OPI_6-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "expires": "1617235200",
                    "pointwidth": "9",
                    "standard_name": "time",
                    "calendar": "360",
                    "bounds": "T"
                },
                "SPICAMSOPI_3Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-CAMSOPI_3-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-CAMS_OPI_3-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "expires": "1617235200",
                    "pointwidth": "9",
                    "standard_name": "time",
                    "calendar": "360",
                    "bounds": "T"
                },
                "SPICAMSOPI_12Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-CAMSOPI_12-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-CAMS_OPI_12-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "expires": "1617235200",
                    "pointwidth": "9",
                    "standard_name": "time",
                    "calendar": "360",
                    "bounds": "T"
                },
                "SPICAMSOPI_1Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SPI-CAMSOPI_1-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "scale_max": "3.0999999",
                    "maxncolor": "254",
                    "ncolor": "254",
                    "scale_min": "-3.0999999",
                    "CS": "-3.0999999",
                    "CE": "3.0999999",
                    "colormap": "360960",
                    "long_name": "SPI-CAMS_OPI_1-month",
                    "units": "unitless",
                    "missing_value": "NaN",
                    "file_missing_value": "-9.9899998",
                    "expires": "1617235200",
                    "pointwidth": "9",
                    "standard_name": "time",
                    "calendar": "360",
                    "bounds": "T"
                },
                "T_29": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_29",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "9",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_28": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_28",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "6",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_27": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_27",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "3",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_26": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_26",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "12",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_25": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_25",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "1.0",
                    "standard_name": "time"
                },
                "T_24": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_24",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "9",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_23": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_23",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "6",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_22": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_22",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "3",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_21": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_21",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "12",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_20": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_20",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "1.0",
                    "standard_name": "time"
                },
                "X_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "pointwidth": "0.5",
                    "standard_name": "longitude"
                },
                "T_19": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_19",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "9",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_18": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_18",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "6",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_17": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_17",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "3",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_16": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_16",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "12",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "Y_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "pointwidth": "0.5",
                    "standard_name": "latitude",
                    "long_name": "Latitude"
                },
                "T_15": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_15",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "expires": "1617235200",
                    "pointwidth": "1.0",
                    "long_name": "Time",
                    "standard_name": "time"
                },
                "X_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "pointwidth": "0.5",
                    "standard_name": "longitude",
                    "long_name": "Longitude"
                },
                "T_14": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_14",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "9",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_13": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_13",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "6",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_12": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_12",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "3",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_11": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_11",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "12",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "Y_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "pointwidth": "2.5",
                    "standard_name": "latitude"
                },
                "T_10": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_10",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "1.0",
                    "standard_name": "time"
                },
                "X_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "pointwidth": "1.0"
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "T_09": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_09",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "9",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_08": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_08",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "6",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_07": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_07",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "3",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "12",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "1",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "9",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "6",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "3",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "12",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "pointwidth": "2.5",
                    "standard_name": "latitude"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "1.0",
                    "standard_name": "time",
                    "calendar": "360",
                    "expires": "1617235200"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "pointwidth": "2.5",
                    "standard_name": "longitude"
                },
                "dir": "SOURCES/IRI/Analyses/SPI"
            },
            "TS": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "TS",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "AR4history": " (20C3M) experiment are used. To obtain an estimate of the forced response, we average together the 20th-century global mean temperature records from the members of this ensemble, which here includes 23 (nearly all) of the IPCC GCMs. The multimodel mean signal is further processed, by lowpass filtering.",
                    "description": "Time Scales",
                    "Conventions": "IRIDL"
                },
                "AR4": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "AR4",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "tas": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "tas",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "Kelvin_scale",
                        "long_name": "temperature at surface"
                    }
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "12"
                },
                "dir": "SOURCES/IRI/Analyses/TS"
            },
            "Tailored": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/IRI/Analyses/Tailored",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "Tailored",
                "restriction": "Public",
                "Bangladesh": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/IRI/Analyses/Tailored/Bangladesh",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "Bangladesh",
                    "restriction": "Public",
                    "precipitation": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "precipitation",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NC_GLOBAL": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NC_GLOBAL",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Conventions": "IRIDL"
                        },
                        "historical": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "historical",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "0.0",
                            "CS": "0",
                            "maxncolor": "254",
                            "colorscalename": "precip_colors",
                            "colormap": "290304",
                            "ncolor": "254",
                            "long_name": "Precipitation",
                            "units": "mm",
                            "history": "Averaged over T[Jan 1951, 2400 31 Jan 2007] minimum 0.0% data present",
                            "missing_value": "NaN",
                            "file_missing_value": "-99.900002",
                            "pointwidth": "0"
                        },
                        "X": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "X",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_east",
                            "gridtype": "0",
                            "standard_name": "longitude",
                            "pointwidth": "0.25"
                        },
                        "Y": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Y",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_north",
                            "gridtype": "0",
                            "standard_name": "latitude",
                            "pointwidth": "0.25"
                        },
                        "dir": "SOURCES/IRI/Analyses/Tailored/Bangladesh/precipitation"
                    },
                    "temperature": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "temperature",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NC_GLOBAL": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NC_GLOBAL",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Conventions": "IRIDL"
                        },
                        "lon": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lon",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "88.0",
                            "scale_max": "93.0",
                            "units": "degree_east",
                            "missing_value": "999.0"
                        },
                        "location": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "location",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "OpenGISSimpleFeature": "Point",
                            "long_name": "location",
                            "SpatialReferenceSystemWKT": "]]",
                            "scale_min": "88",
                            "scale_max": "93",
                            "units": "degree_east"
                        },
                        "lat": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lat",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "20.0",
                            "scale_max": "27.0",
                            "units": "degree_north",
                            "missing_value": "999.0"
                        },
                        "historical": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "historical",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "ncolor": "254",
                            "colorscalename": "temp_colors",
                            "maxncolor": "254",
                            "colormap": "255",
                            "long_name": "Minimum Temperature",
                            "history": "Averaged over T[Jan 1979, 2400 31 Jan 2011] minimum 0.0% data present",
                            "missing_value": "NaN",
                            "units": "Celsius_scale",
                            "file_missing_value": "999.0"
                        },
                        "elev": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "elev",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "999.0",
                            "units": "m"
                        },
                        "IWMO": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "IWMO",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "gridtype": "0"
                        },
                        "dir": "SOURCES/IRI/Analyses/Tailored/Bangladesh/temperature"
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "precipitation",
                        "temperature"
                    ]
                },
                "Ethiopia": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Ethiopia",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "Conventions": "IRIDL"
                    },
                    "precipitation": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "precipitation",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "historical": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "historical",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "0.0",
                            "CS": "0",
                            "maxncolor": "254",
                            "colorscalename": "precip_colors",
                            "colormap": "290304",
                            "ncolor": "254",
                            "long_name": "Precipitation",
                            "units": "mm",
                            "history": "Averaged over T[11-31 Jan 1983, 2400 31 Jan 2010]",
                            "pointwidth": "1.0"
                        }
                    },
                    "X": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "X",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_east",
                        "gridtype": "0",
                        "standard_name": "longitude",
                        "pointwidth": "0.1"
                    },
                    "Y": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Y",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_north",
                        "gridtype": "0",
                        "standard_name": "latitude",
                        "pointwidth": "0.09999999"
                    },
                    "dir": "SOURCES/IRI/Analyses/Tailored/Ethiopia"
                },
                "Lao": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/IRI/Analyses/Tailored/Lao",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "Lao",
                    "restriction": "Public",
                    "CCROMASEAN": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/IRI/Analyses/Tailored/Lao/CCROM-ASEAN",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "CCROM-ASEAN",
                        "restriction": "Public",
                        "precipitation": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "precipitation",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "Conventions": "IRIDL"
                            },
                            "lon": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lon",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "108.0",
                                "scale_min": "100.0",
                                "units": "degree_east",
                                "long_name": "Longitude"
                            },
                            "location": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "location",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "OpenGISSimpleFeature": "Point",
                                "SpatialReferenceSystemWKT": "]]",
                                "long_name": "location",
                                "scale_max": "108.0",
                                "scale_min": "100.0",
                                "units": "degree_east"
                            },
                            "lat": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lat",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "23.0",
                                "scale_min": "13.5",
                                "units": "degree_north",
                                "long_name": "Latitude"
                            },
                            "label": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "label",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "label"
                            },
                            "historical": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "historical",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "CS": "0",
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "ncolor": "254",
                                "long_name": "Precipitation",
                                "units": "mm",
                                "history": "Averaged over T[Jan 1980, 2400 31 Jan 2010] minimum 0.0% data present",
                                "missing_value": "NaN",
                                "file_missing_value": "-999.0"
                            },
                            "Station": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Station",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2"
                            },
                            "dir": "SOURCES/IRI/Analyses/Tailored/Lao/CCROM-ASEAN/precipitation"
                        },
                        "temperature": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "temperature",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "Conventions": "IRIDL"
                            },
                            "lon": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lon",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "108.0",
                                "scale_min": "100.0",
                                "units": "degree_east",
                                "long_name": "Longitude"
                            },
                            "location": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "location",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "OpenGISSimpleFeature": "Point",
                                "SpatialReferenceSystemWKT": "]]",
                                "long_name": "location",
                                "scale_max": "108.0",
                                "scale_min": "100.0",
                                "units": "degree_east"
                            },
                            "lat": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lat",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "23.0",
                                "scale_min": "13.5",
                                "units": "degree_north",
                                "long_name": "Latitude"
                            },
                            "label": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "label",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "label"
                            },
                            "historical": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "historical",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "ncolor": "254",
                                "colorscalename": "temp_colors",
                                "maxncolor": "254",
                                "colormap": "255",
                                "long_name": "Minimum Temperature",
                                "history": "Averaged over T[Jan 1980, 2400 31 Jan 2010] minimum 0.0% data present",
                                "missing_value": "NaN",
                                "units": "Celsius_scale",
                                "file_missing_value": "-999.0"
                            },
                            "Station": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Station",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2"
                            },
                            "dir": "SOURCES/IRI/Analyses/Tailored/Lao/CCROM-ASEAN/temperature"
                        },
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type",
                            "precipitation",
                            "temperature"
                        ]
                    },
                    "aphroditeV1101": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "aphroditeV1101",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NC_GLOBAL": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NC_GLOBAL",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Conventions": "IRIDL"
                        },
                        "precipitation": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "precipitation",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "historical": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "historical",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "CS": "0",
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "ncolor": "254",
                                "long_name": "Precipitation",
                                "units": "mm",
                                "history": "Averaged over T[Jan 1951, 2400 31 Jan 2007] minimum 0.0% data present",
                                "missing_value": "NaN",
                                "file_missing_value": "-99.900002",
                                "pointwidth": "0"
                            }
                        },
                        "X": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "X",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_east",
                            "gridtype": "0",
                            "standard_name": "longitude",
                            "pointwidth": "0.25"
                        },
                        "Y": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Y",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_north",
                            "gridtype": "0",
                            "standard_name": "latitude",
                            "pointwidth": "0.25"
                        },
                        "dir": "SOURCES/IRI/Analyses/Tailored/Lao/aphroditeV1101"
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "CCROMASEAN",
                        "aphroditeV1101"
                    ]
                },
                "Monsoon_Asia": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/IRI/Analyses/Tailored/Monsoon_Asia",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "Monsoon_Asia",
                    "restriction": "Public",
                    "precipitation": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "precipitation",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NC_GLOBAL": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NC_GLOBAL",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Conventions": "IRIDL"
                        },
                        "historical": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "historical",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "0.0",
                            "CS": "0",
                            "maxncolor": "254",
                            "colorscalename": "precip_colors",
                            "colormap": "290304",
                            "ncolor": "254",
                            "long_name": "Precipitation",
                            "units": "mm",
                            "history": "Averaged over T[Jan 1951, 2400 31 Jan 2007] minimum 0.0% data present",
                            "missing_value": "NaN",
                            "file_missing_value": "-99.900002",
                            "pointwidth": "0"
                        },
                        "X": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "X",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_east",
                            "gridtype": "0",
                            "standard_name": "longitude",
                            "pointwidth": "0.25"
                        },
                        "Y": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Y",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_north",
                            "gridtype": "0",
                            "standard_name": "latitude",
                            "pointwidth": "0.25"
                        },
                        "dir": "SOURCES/IRI/Analyses/Tailored/Monsoon_Asia/precipitation"
                    },
                    "temperature": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "temperature",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NC_GLOBAL": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NC_GLOBAL",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Conventions": "IRIDL"
                        },
                        "historical": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "historical",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Chilling Degree Days",
                            "history": "Averaged over T[Jan 1961, 2400 31 Jan 2007] minimum 0.0% data present",
                            "missing_value": "NaN",
                            "units": "86400 (degree_Kelvin above 273.15) second",
                            "fnname": "abs",
                            "file_missing_value": "-99.900002",
                            "maxncolor": "254",
                            "colorscalename": "temp_colors",
                            "colormap": "255",
                            "ncolor": "254",
                            "pointwidth": "0"
                        },
                        "X": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "X",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_east",
                            "gridtype": "0",
                            "standard_name": "longitude",
                            "pointwidth": "0.25"
                        },
                        "Y": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Y",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_north",
                            "gridtype": "0",
                            "standard_name": "latitude",
                            "pointwidth": "0.25"
                        },
                        "dir": "SOURCES/IRI/Analyses/Tailored/Monsoon_Asia/temperature"
                    },
                    "temperature2": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "temperature2",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NC_GLOBAL": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NC_GLOBAL",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Conventions": "IRIDL"
                        },
                        "historical": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "historical",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Mean Temperature",
                            "history": "Averaged over T[Jan 1961, 2400 31 Jan 2007] minimum 0.0% data present",
                            "missing_value": "NaN",
                            "units": "Celsius_scale",
                            "file_missing_value": "-99.900002",
                            "maxncolor": "254",
                            "colorscalename": "temp_colors",
                            "colormap": "255",
                            "ncolor": "254",
                            "pointwidth": "0"
                        },
                        "X": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "X",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_east",
                            "gridtype": "0",
                            "standard_name": "longitude",
                            "pointwidth": "0.25"
                        },
                        "Y": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Y",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_north",
                            "gridtype": "0",
                            "standard_name": "latitude",
                            "pointwidth": "0.25"
                        },
                        "dir": "SOURCES/IRI/Analyses/Tailored/Monsoon_Asia/temperature2"
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "precipitation",
                        "temperature",
                        "temperature2"
                    ]
                },
                "NE_Brazil": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NE_Brazil",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "Conventions": "IRIDL"
                    },
                    "precipitation": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "precipitation",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "lon": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lon",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "-42.0",
                            "scale_max": "-37.5",
                            "units": "degree_east",
                            "long_name": "longitude"
                        },
                        "location": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "location",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "OpenGISSimpleFeature": "Point",
                            "long_name": "location",
                            "SpatialReferenceSystemWKT": "]]",
                            "scale_min": "-42.0",
                            "scale_max": "-37.5",
                            "units": "degree_east"
                        },
                        "lat": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lat",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "-8.0",
                            "scale_max": "-2.5",
                            "units": "degree_north",
                            "long_name": "latitude"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids"
                        },
                        "historical": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "historical",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "0.0",
                            "CS": "0",
                            "maxncolor": "254",
                            "colorscalename": "precip_colors",
                            "colormap": "290304",
                            "ncolor": "254",
                            "long_name": "Precipitation",
                            "units": "mm",
                            "history": "Averaged over T[Jan 1973, 2400 31 Jan 2002] minimum 0.0% data present",
                            "missing_value": "NaN",
                            "file_missing_value": "-1.0"
                        },
                        "elev": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "elev",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "-999.0",
                            "units": "m",
                            "long_name": "Elevation"
                        }
                    },
                    "STNID": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "STNID",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "gridtype": "0",
                        "long_name": "Station"
                    },
                    "dir": "SOURCES/IRI/Analyses/Tailored/NE_Brazil"
                },
                "Nepal": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/IRI/Analyses/Tailored/Nepal",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "Nepal",
                    "restriction": "Public",
                    "precipitation": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "precipitation",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NC_GLOBAL": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NC_GLOBAL",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Conventions": "IRIDL"
                        },
                        "historical": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "historical",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "0.0",
                            "CS": "0",
                            "maxncolor": "254",
                            "colorscalename": "precip_colors",
                            "colormap": "290304",
                            "ncolor": "254",
                            "long_name": "Precipitation",
                            "units": "mm",
                            "history": "Averaged over T[Jan 1951, 2400 31 Jan 2007] minimum 0.0% data present",
                            "missing_value": "NaN",
                            "file_missing_value": "-99.900002",
                            "pointwidth": "0"
                        },
                        "X": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "X",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_east",
                            "gridtype": "0",
                            "standard_name": "longitude",
                            "pointwidth": "0.25"
                        },
                        "Y": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Y",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_north",
                            "gridtype": "0",
                            "standard_name": "latitude",
                            "pointwidth": "0.25"
                        },
                        "dir": "SOURCES/IRI/Analyses/Tailored/Nepal/precipitation"
                    },
                    "temperature": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "temperature",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NC_GLOBAL": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NC_GLOBAL",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Conventions": "IRIDL"
                        },
                        "lon": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lon",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "79.5",
                            "scale_max": "88.5",
                            "units": "degree_east",
                            "missing_value": "999.0"
                        },
                        "location": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "location",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "OpenGISSimpleFeature": "Point",
                            "long_name": "location",
                            "SpatialReferenceSystemWKT": "]]",
                            "scale_min": "79.5",
                            "scale_max": "88.5",
                            "units": "degree_east"
                        },
                        "lat": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lat",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "26.0",
                            "scale_max": "31.0",
                            "units": "degree_north",
                            "missing_value": "999.0"
                        },
                        "historical": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "historical",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "ncolor": "254",
                            "colorscalename": "temp_colors",
                            "maxncolor": "254",
                            "colormap": "255",
                            "long_name": "Minimum Temperature",
                            "history": "Averaged over T[Jan 1979, 2400 31 Jan 2011] minimum 0.0% data present",
                            "missing_value": "NaN",
                            "units": "Celsius_scale",
                            "file_missing_value": "999.0"
                        },
                        "elev": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "elev",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "999.0",
                            "units": "m"
                        },
                        "IWMO": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "IWMO",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "gridtype": "0"
                        },
                        "dir": "SOURCES/IRI/Analyses/Tailored/Nepal/temperature"
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "precipitation",
                        "temperature"
                    ]
                },
                "Northern_India": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/IRI/Analyses/Tailored/Northern_India",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "Northern_India",
                    "restriction": "Public",
                    "precipitation": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "precipitation",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NC_GLOBAL": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NC_GLOBAL",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Conventions": "IRIDL"
                        },
                        "historical": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "historical",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "0.0",
                            "CS": "0",
                            "maxncolor": "254",
                            "colorscalename": "precip_colors",
                            "colormap": "290304",
                            "ncolor": "254",
                            "long_name": "Precipitation",
                            "units": "mm",
                            "history": "Averaged over T[Jan 1951, 2400 31 Jan 2007] minimum 0.0% data present",
                            "missing_value": "NaN",
                            "file_missing_value": "-99.900002",
                            "pointwidth": "0"
                        },
                        "X": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "X",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_east",
                            "gridtype": "0",
                            "standard_name": "longitude",
                            "pointwidth": "0.25"
                        },
                        "Y": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Y",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_north",
                            "gridtype": "0",
                            "standard_name": "latitude",
                            "pointwidth": "0.25"
                        },
                        "dir": "SOURCES/IRI/Analyses/Tailored/Northern_India/precipitation"
                    },
                    "temperature": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "temperature",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NC_GLOBAL": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NC_GLOBAL",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "Conventions": "IRIDL"
                        },
                        "IMD_temperature": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "IMD_temperature",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "historical": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "historical",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "ncolor": "254",
                                "colorscalename": "temp_colors",
                                "maxncolor": "254",
                                "colormap": "255",
                                "long_name": "Minimum Temperature",
                                "history": "Averaged over T[Jan 1979, 2400 31 Jan 2005] minimum 0.0% data present",
                                "missing_value": "NaN",
                                "units": "Celsius_scale",
                                "file_missing_value": "99.900002",
                                "calendar": "standard",
                                "pointwidth": "1.0",
                                "standard_name": "air_temperature",
                                "step": "1.0"
                            }
                        },
                        "historical": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "historical",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "ncolor": "254",
                            "colorscalename": "temp_colors",
                            "maxncolor": "254",
                            "colormap": "255",
                            "long_name": "Minimum Temperature",
                            "history": "Averaged over T[Jan 1979, 2400 31 Jan 2005] minimum 0.0% data present",
                            "missing_value": "NaN",
                            "units": "Celsius_scale",
                            "file_missing_value": "99.900002",
                            "calendar": "standard",
                            "pointwidth": "1.0",
                            "standard_name": "air_temperature",
                            "step": "1.0"
                        },
                        "GSOD_temperature": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "GSOD_temperature",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "lon": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lon",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "73.0",
                                "scale_max": "89.0",
                                "units": "degree_east",
                                "missing_value": "999.0"
                            },
                            "location": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "location",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "OpenGISSimpleFeature": "Point",
                                "long_name": "location",
                                "SpatialReferenceSystemWKT": "]]",
                                "scale_min": "73",
                                "scale_max": "89",
                                "units": "degree_east"
                            },
                            "lat": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lat",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "24.0",
                                "scale_max": "33.0",
                                "units": "degree_north",
                                "missing_value": "999.0"
                            },
                            "historical": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "historical",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "ncolor": "254",
                                "colorscalename": "temp_colors",
                                "maxncolor": "254",
                                "colormap": "255",
                                "long_name": "Minimum Temperature",
                                "history": "Averaged over T[Jan 1979, 2400 31 Jan 2011] minimum 0.0% data present",
                                "missing_value": "NaN",
                                "units": "Celsius_scale",
                                "file_missing_value": "999.0"
                            },
                            "elev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "elev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "999.0",
                                "units": "m"
                            }
                        },
                        "X": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "X",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_east",
                            "gridtype": "0",
                            "standard_name": "longitude",
                            "pointwidth": "1.0"
                        },
                        "Y": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Y",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_north",
                            "gridtype": "0",
                            "standard_name": "latitude",
                            "pointwidth": "1.0"
                        },
                        "IWMO_01": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "IWMO_01",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "gridtype": "0"
                        },
                        "IWMO": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "IWMO",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids",
                            "gridtype": "0"
                        },
                        "dir": "SOURCES/IRI/Analyses/Tailored/Northern_India/temperature"
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "precipitation",
                        "temperature"
                    ]
                },
                "Philippines": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Philippines",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NC_GLOBAL": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NC_GLOBAL",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "Conventions": "IRIDL"
                    },
                    "precipitation": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "precipitation",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "PAGASA_precipitation": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "PAGASA_precipitation",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "lon": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lon",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "114.0",
                                "scale_max": "132.0",
                                "units": "degree_east",
                                "long_name": "Longitude"
                            },
                            "location": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "location",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "OpenGISSimpleFeature": "Point",
                                "long_name": "location",
                                "SpatialReferenceSystemWKT": "]]",
                                "scale_min": "114.0",
                                "scale_max": "132.0",
                                "units": "degree_east"
                            },
                            "lat": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lat",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "3.0",
                                "scale_max": "22.0",
                                "units": "degree_north",
                                "long_name": "Latitude"
                            },
                            "label": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "label",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            },
                            "historical": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "historical",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "CS": "0",
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "ncolor": "254",
                                "long_name": "Precipitation",
                                "units": "mm",
                                "history": "Averaged over T[Jan-Apr 1977, 2400 30 Apr 2007] minimum 0.0% data present",
                                "missing_value": "NaN",
                                "file_missing_value": "-9.8999996"
                            },
                            "elev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "elev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Elevation",
                                "missing_value": "-999.90002",
                                "units": "m"
                            }
                        },
                        "lon": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lon",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "114.0",
                            "scale_max": "132.0",
                            "units": "degree_east",
                            "long_name": "Longitude"
                        },
                        "location": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "location",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "OpenGISSimpleFeature": "Point",
                            "long_name": "location",
                            "SpatialReferenceSystemWKT": "]]",
                            "scale_min": "114.0",
                            "scale_max": "132.0",
                            "units": "degree_east"
                        },
                        "lat": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lat",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "3.0",
                            "scale_max": "22.0",
                            "units": "degree_north",
                            "long_name": "Latitude"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids"
                        },
                        "historical": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "historical",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "0.0",
                            "CS": "0",
                            "maxncolor": "254",
                            "colorscalename": "precip_colors",
                            "colormap": "290304",
                            "ncolor": "254",
                            "long_name": "Precipitation",
                            "units": "mm",
                            "history": "Averaged over T[Jan-Apr 1977, 2400 30 Apr 2007] minimum 0.0% data present",
                            "missing_value": "NaN",
                            "file_missing_value": "-9.8999996"
                        },
                        "elev": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "elev",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Elevation",
                            "missing_value": "-999.90002",
                            "units": "m"
                        },
                        "APHRODITE_precipitation": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "APHRODITE_precipitation",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "historical": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "historical",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "CS": "0",
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "ncolor": "254",
                                "long_name": "Precipitation",
                                "units": "mm",
                                "history": "Averaged over T[Jan-Apr 1951, 2400 30 Apr 2007] minimum 0.0% data present",
                                "missing_value": "NaN",
                                "file_missing_value": "-99.900002",
                                "pointwidth": "0"
                            }
                        }
                    },
                    "precip_prov": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "precip_prov",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "PAGASA_precipitation": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "PAGASA_precipitation",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "lon": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lon",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "114.0",
                                "scale_max": "132.0",
                                "units": "degree_east",
                                "long_name": "Longitude"
                            },
                            "location": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "location",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "OpenGISSimpleFeature": "Point",
                                "long_name": "location",
                                "SpatialReferenceSystemWKT": "]]",
                                "scale_min": "114.0",
                                "scale_max": "132.0",
                                "units": "degree_east"
                            },
                            "lat": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lat",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "3.0",
                                "scale_max": "22.0",
                                "units": "degree_north",
                                "long_name": "Latitude"
                            },
                            "label": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "label",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids"
                            },
                            "historical": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "historical",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "CS": "0",
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "ncolor": "254",
                                "long_name": "Precipitation",
                                "units": "mm",
                                "history": "Averaged over T[Jan-Apr 1977, 2400 30 Apr 2007] minimum 0.0% data present",
                                "missing_value": "NaN",
                                "file_missing_value": "-9.8999996"
                            },
                            "elev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "elev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Elevation",
                                "missing_value": "-999.90002",
                                "units": "m"
                            }
                        },
                        "lon": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lon",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "114.0",
                            "scale_max": "132.0",
                            "units": "degree_east",
                            "long_name": "Longitude"
                        },
                        "location": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "location",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "OpenGISSimpleFeature": "Point",
                            "long_name": "location",
                            "SpatialReferenceSystemWKT": "]]",
                            "scale_min": "114.0",
                            "scale_max": "132.0",
                            "units": "degree_east"
                        },
                        "lat": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lat",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "3.0",
                            "scale_max": "22.0",
                            "units": "degree_north",
                            "long_name": "Latitude"
                        },
                        "label": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "label",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "ids"
                        },
                        "historical": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "historical",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_min": "0.0",
                            "CS": "0",
                            "maxncolor": "254",
                            "colorscalename": "precip_colors",
                            "colormap": "290304",
                            "ncolor": "254",
                            "long_name": "Precipitation",
                            "units": "mm",
                            "history": "Averaged over T[Jan-Apr 1977, 2400 30 Apr 2007] minimum 0.0% data present",
                            "missing_value": "NaN",
                            "file_missing_value": "-9.8999996"
                        },
                        "elev": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "elev",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "Elevation",
                            "missing_value": "-999.90002",
                            "units": "m"
                        },
                        "APHRODITE_precipitation": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "APHRODITE_precipitation",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "the_geom": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "the_geom",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Provinces Geometry",
                                "units": "unitless",
                                "PGtype": "bytea",
                                "OpenGISSimpleFeature": "MULTIPOLYGON",
                                "SpatialReferenceSystemWKT": "]]"
                            },
                            "historical": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "historical",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "CS": "0",
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "ncolor": "254",
                                "long_name": "Precipitation",
                                "units": "mm",
                                "history": "Averaged over T[Jan-Apr 1951, 2400 30 Apr 2007] minimum 0.0% data present",
                                "missing_value": "NaN",
                                "file_missing_value": "-99.900002",
                                "pointwidth": "0"
                            }
                        }
                    },
                    "X": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "X",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_east",
                        "gridtype": "0",
                        "standard_name": "longitude",
                        "pointwidth": "0.25"
                    },
                    "Y": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Y",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "degree_north",
                        "gridtype": "0",
                        "standard_name": "latitude",
                        "pointwidth": "0.25"
                    },
                    "STNID": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "STNID",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids",
                        "gridtype": "0",
                        "long_name": "Station",
                        "pointwidth": "1.0"
                    },
                    "gid": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "gid",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "unitless",
                        "gridtype": "0",
                        "pointwidth": "1.0"
                    },
                    "dir": "SOURCES/IRI/Analyses/Tailored/Philippines"
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "Bangladesh",
                    "Ethiopia",
                    "Lao",
                    "Monsoon_Asia",
                    "NE_Brazil",
                    "Nepal",
                    "Northern_India",
                    "Philippines"
                ]
            },
            "USGS": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "USGS",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "ADDSNDVINDVIgdeg0p1monthlysd8204description": "1982-2004 standard deviation of monthly maximum NDVIg data",
                    "ADDSNDVINDVIgdeg0p1monthlysd8204long_name": "1982-2004 standard deviation",
                    "ADDSNDVINDVIgdeg0p1monthlyc8204description": "1982-2004 climatology of monthly NDVIg data",
                    "ADDSNDVINDVIgdeg0p1monthlyc8204long_name": "1982-2004 climatology",
                    "Conventions": "IRIDL"
                },
                "VCAP": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "VCAP",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "eightday": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "eight-day",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "v200906": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "v200906",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "vcap_coarse": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "vcap_coarse",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "maxncolor": "254",
                                "colormap": "8388608",
                                "scale_max": "50.0",
                                "ncolor": "254",
                                "scale_min": "0.0",
                                "CE": "50.0",
                                "CS": "0.0",
                                "long_name": "Vectorial Capacity",
                                "history": "Y regridded on USGS VCAP eight-day v200906 vcap",
                                "missing_value": "NaN",
                                "file_missing_value": "-9999.0",
                                "units": "unitless",
                                "iridlhasSemantics": "iridl:Malaria",
                                "pointwidth": "0"
                            }
                        }
                    }
                },
                "ADDS": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ADDS",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "NDVI": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "NDVI",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NDVIg": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NDVIg",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "deg0p1": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "deg0p1",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "monthly": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthly",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "sd8204": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sd8204",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "sdNDVImonmax": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sdNDVImonmax",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "1982-2004 SD of Monthly Maximum NDVI",
                                            "missing_value": "99999.0",
                                            "history": "Averaged over T2[1982, 2004] minimum 0.0% data present",
                                            "maxncolor": "254",
                                            "colormap": "2304",
                                            "ncolor": "254",
                                            "grid_mapping": "Projection",
                                            "standard_name": "normalized_difference_vegetation_index",
                                            "iridlhasSemantics": "iridl:NDVI",
                                            "units": "unitless"
                                        },
                                        "sdNDVImonavg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sdNDVImonavg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "1982-2004 SD of Monthly Average NDVI",
                                            "missing_value": "99999.0",
                                            "history": "Averaged over T2[1982, 2004] minimum 0.0% data present",
                                            "units": "unitless",
                                            "maxncolor": "254",
                                            "colormap": "2304",
                                            "ncolor": "254",
                                            "grid_mapping": "Projection",
                                            "standard_name": "normalized_difference_vegetation_index",
                                            "iridlhasSemantics": "iridl:NDVI"
                                        }
                                    },
                                    "maximum": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "maximum",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "NDVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "NDVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Monthly Maximum NDVIg",
                                            "history": "max over T[1.0, 3.0]",
                                            "missing_value": "NaN",
                                            "file_missing_value": "99999.0",
                                            "maxncolor": "254",
                                            "colormap": "2304",
                                            "scale_max": "1.0",
                                            "ncolor": "254",
                                            "scale_min": "0.0",
                                            "CE": "1.0",
                                            "CS": "0.0",
                                            "valid_max": "0.999984",
                                            "valid_min": "0.0",
                                            "grid_mapping": "Projection",
                                            "standard_name": "normalized_difference_vegetation_index",
                                            "iridlhasSemantics": "iridl:NDVI",
                                            "units": "unitless"
                                        }
                                    },
                                    "c8204": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "c8204",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "avgNDVImonmax": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "avgNDVImonmax",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "1982-2004 Avg. of Monthly Maximum NDVI",
                                            "missing_value": "99999.0",
                                            "history": "Averaged over T2[1982, 2004] minimum 0.0% data present",
                                            "maxncolor": "254",
                                            "colormap": "2304",
                                            "ncolor": "254",
                                            "grid_mapping": "Projection",
                                            "standard_name": "normalized_difference_vegetation_index",
                                            "iridlhasSemantics": "iridl:NDVI",
                                            "units": "unitless"
                                        },
                                        "avgNDVImonavg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "avgNDVImonavg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "1982-2004 Avg. of Monthly Average NDVI",
                                            "missing_value": "99999.0",
                                            "history": "Averaged over T2[1982, 2004] minimum 0.0% data present",
                                            "units": "unitless",
                                            "maxncolor": "254",
                                            "colormap": "2304",
                                            "ncolor": "254",
                                            "grid_mapping": "Projection",
                                            "standard_name": "normalized_difference_vegetation_index",
                                            "iridlhasSemantics": "iridl:NDVI"
                                        }
                                    }
                                }
                            }
                        }
                    }
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "long_name": "Latitude",
                    "pointwidth": "0.1"
                },
                "X_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "long_name": "Longitude",
                    "pointwidth": "0.1"
                },
                "T_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "days since 2004-01-01",
                    "gridtype": "0",
                    "calendar": "standard",
                    "standard_name": "time"
                },
                "T_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "defaultvalue": "539.5",
                    "bounds": "T2",
                    "pointwidth": "1.0"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "pointwidth": "0.1"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulo": "12.0",
                    "modulus": "12.0",
                    "calendar": "360",
                    "pointwidth": "1.0"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "pointwidth": "0.1"
                },
                "dir": "SOURCES/IRI/Analyses/USGS"
            },
            "WASP": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "WASP",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "references": "Lyon2004 Lyon_Barnston2005",
                    "description": "Weighted Anomaly of Standardized Precipitation Index analyses of multiple global precipitation data sets",
                    "Conventions": "IRIDL",
                    "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.Analyses/.WASP/.dataset_documentation.html"
                },
                "WASPUEATS2p1_9Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-UEA-TS2p1_9-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "UEA-TS2p1_WASP9",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-99.900002"
                },
                "WASPUEATS2p1_6Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-UEA-TS2p1_6-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "UEA-TS2p1_WASP6",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-99.900002"
                },
                "WASPUEATS2p1_3Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-UEA-TS2p1_3-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "UEA-TS2p1_WASP3",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-99.900002"
                },
                "WASPUEATS2p1_12Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-UEA-TS2p1_12-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "UEA-TS2p1_WASP12",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-99.900002"
                },
                "WASPUEATS2p1_1Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-UEA-TS2p1_1-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "UEA-TS2p1_WASP1",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-99.900002"
                },
                "WASPGPCPv2SatGauge_9Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-GPCPv2Sat-Gauge_9-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "GPCPv2Sat-Gauge_WASP9",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-99999.0",
                    "technique": "Satellite-Gauge",
                    "pointwidth": "0"
                },
                "WASPGPCPv2SatGauge_6Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-GPCPv2Sat-Gauge_6-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "GPCPv2Sat-Gauge_WASP6",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-99999.0",
                    "technique": "Satellite-Gauge",
                    "pointwidth": "0"
                },
                "WASPGPCPv2SatGauge_3Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-GPCPv2Sat-Gauge_3-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "GPCPv2Sat-Gauge_WASP3",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-99999.0",
                    "technique": "Satellite-Gauge",
                    "pointwidth": "0"
                },
                "WASPGPCPv2SatGauge_12Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-GPCPv2Sat-Gauge_12-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "GPCPv2Sat-Gauge_WASP12",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-99999.0",
                    "technique": "Satellite-Gauge",
                    "pointwidth": "0"
                },
                "WASPGPCPv2SatGauge_1Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-GPCPv2Sat-Gauge_1-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "GPCPv2Sat-Gauge_WASP1",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-99999.0",
                    "technique": "Satellite-Gauge",
                    "pointwidth": "0"
                },
                "WASPCMAPlatestv2_9Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-CMAPlatestv2_9-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "CMAP-latest_WASP9",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-999.0",
                    "standard_name": "lwe_precipitation_rate"
                },
                "WASPCMAPlatestv2_6Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-CMAPlatestv2_6-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "CMAP-latest_WASP6",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-999.0",
                    "standard_name": "lwe_precipitation_rate"
                },
                "WASPCMAPlatestv2_3Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-CMAPlatestv2_3-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "CMAP-latest_WASP3",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-999.0",
                    "standard_name": "lwe_precipitation_rate"
                },
                "WASPCMAPlatestv2_12Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-CMAPlatestv2_12-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "CMAP-latest_WASP12",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-999.0",
                    "standard_name": "lwe_precipitation_rate"
                },
                "WASPCMAPlatestv2_1Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-CMAPlatestv2_1-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "CMAP-latest_WASP1",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "file_missing_value": "-999.0",
                    "standard_name": "lwe_precipitation_rate"
                },
                "WASPCAMSOPIv0208_9Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-CAMS-OPI-v0208_9-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "CAMS-OPI-v0208_WASP9",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "expires": "1617235200",
                    "file_missing_value": "-999.0",
                    "pointwidth": "1.0",
                    "standard_name": "time",
                    "bounds": "T"
                },
                "WASPCAMSOPIv0208_6Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-CAMS-OPI-v0208_6-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "CAMS-OPI-v0208_WASP6",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "expires": "1617235200",
                    "file_missing_value": "-999.0",
                    "pointwidth": "1.0",
                    "standard_name": "time",
                    "bounds": "T"
                },
                "WASPCAMSOPIv0208_3Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-CAMS-OPI-v0208_3-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "CAMS-OPI-v0208_WASP3",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "expires": "1617235200",
                    "file_missing_value": "-999.0",
                    "pointwidth": "1.0",
                    "standard_name": "time",
                    "bounds": "T"
                },
                "WASPCAMSOPIv0208_12Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-CAMS-OPI-v0208_12-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "CAMS-OPI-v0208_WASP12",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "expires": "1617235200",
                    "file_missing_value": "-999.0",
                    "pointwidth": "1.0",
                    "standard_name": "time",
                    "bounds": "T"
                },
                "WASPCAMSOPIv0208_1Month": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WASP-CAMS-OPI-v0208_1-Month",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "maxncolor": "254",
                    "colormap": "360960",
                    "scale_max": "3.5",
                    "ncolor": "254",
                    "scale_min": "-3.5",
                    "CS": "-3.5",
                    "colorscalename": "std_wasp_colors",
                    "CE": "3.5",
                    "long_name": "CAMS-OPI-v0208_WASP1",
                    "units": "unitless",
                    "history": "Averaged over T[Jan, Dec] minimum 0.0% data present",
                    "missing_value": "NaN",
                    "expires": "1617235200",
                    "file_missing_value": "-999.0",
                    "pointwidth": "1.0",
                    "standard_name": "time",
                    "bounds": "T"
                },
                "T_19": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_19",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "9.0",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_18": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_18",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "6.0",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_17": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_17",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "3.0",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_16": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_16",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "12.0",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "Y_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "pointwidth": "0.5",
                    "standard_name": "latitude"
                },
                "T_15": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_15",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "1.0",
                    "standard_name": "time"
                },
                "X_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "pointwidth": "0.5",
                    "standard_name": "longitude"
                },
                "T_14": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_14",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "9.0",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_13": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_13",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "6.0",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_12": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_12",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "3.0",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "T_11": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_11",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "pointwidth": "12.0",
                    "standard_name": "time",
                    "calendar": "360"
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "pointwidth": "2.5",
                    "standard_name": "latitude"
                },
                "T_10": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_10",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "1.0",
                    "standard_name": "time"
                },
                "T_09": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_09",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "9.0",
                    "standard_name": "time"
                },
                "T_08": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_08",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "6.0",
                    "standard_name": "time"
                },
                "T_07": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_07",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "3.0",
                    "standard_name": "time"
                },
                "T_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "12.0",
                    "standard_name": "time"
                },
                "T_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "1",
                    "standard_name": "time"
                },
                "T_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "9.0",
                    "standard_name": "time"
                },
                "T_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "6.0",
                    "standard_name": "time"
                },
                "T_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "3.0",
                    "standard_name": "time"
                },
                "T_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "12.0",
                    "standard_name": "time"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "pointwidth": "2.5",
                    "standard_name": "latitude"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "1.0",
                    "standard_name": "time",
                    "expires": "1617235200"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "pointwidth": "2.5",
                    "standard_name": "longitude"
                },
                "dir": "SOURCES/IRI/Analyses/WASP"
            },
            "WFP": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "WFP",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "FooDSECuREPhilippinesClim_Typesc7807Clusterdescription": "Cluster analysis of 1978-2007 APHRODITE by Province",
                    "FooDSECuREPhilippinesClim_Typesc7807Clusterhistory": "",
                    "Conventions": "IRIDL"
                },
                "FooDSECuRE": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "FooDSECuRE",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Philippines": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Philippines",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "Clim_Types": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Clim_Types",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "c7807Cluster": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "c7807Cluster",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "vartot": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vartot",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "0.000144 meter2 year-2",
                                    "long_name": "precipitation"
                                },
                                "var_misfit": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "var_misfit",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "fraction"
                                },
                                "var_fit": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "var_fit",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "fraction",
                                    "long_name": "precipitation"
                                },
                                "Ts": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Ts",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "mm/month",
                                    "long_name": "precipitation"
                                },
                                "the_geom": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "the_geom",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Provinces Geometry",
                                    "units": "unitless",
                                    "PGtype": "bytea",
                                    "OpenGISSimpleFeature": "MULTIPOLYGON",
                                    "SpatialReferenceSystemWKT": "]]"
                                },
                                "NC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "NC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "label": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "label",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "ids",
                                    "PGtype": "text"
                                },
                                "clusters": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clusters",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "ncolor": "7",
                                    "colormap": "65535",
                                    "maxncolor": "254",
                                    "units": "ids",
                                    "long_name": "k_mean clusters"
                                }
                            }
                        }
                    }
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulo": "12.0",
                    "modulus": "12.0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "cluster": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "cluster",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/IRI/Analyses/WFP"
            },
            "WORLDCLIM": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/IRI/Analyses/WORLDCLIM",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "WORLDCLIM",
                "restriction": "Public",
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ]
            },
            "Water_Balance": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/IRI/Analyses/Water_Balance",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "Water_Balance",
                "restriction": "Public",
                "Brazil": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/IRI/Analyses/Water_Balance/Brazil",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "Brazil",
                    "restriction": "Public",
                    "Rio_Grande_do_Sul": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/IRI/Analyses/Water_Balance/Brazil/Rio_Grande_do_Sul",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "Rio_Grande_do_Sul",
                        "restriction": "Public",
                        "Crop_Cultivar": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Crop_Cultivar",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "Conventions": "IRIDL"
                            },
                            "Kc": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Kc",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "crop coefficient",
                                "history": "Crop:  Soybean to Soybean appended from   mean [ ( IRI Analyses Water_Balance Brazil Rio_Grande_do_Sul Crop_Cultivar myvar 2.0 ) ]   + [   maskgt ( { int_dI + 0. } , 150.0 )   * 0. ]",
                                "units": "unitless",
                                "pointwidth": "1.0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "gridtype": "0",
                                "long_name": "days since planting",
                                "units": "days",
                                "pointwidth": "1.0"
                            },
                            "Crop": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Crop",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "calendar": "standard",
                                "pointwidth": "1.0"
                            },
                            "dir": "SOURCES/IRI/Analyses/Water_Balance/Brazil/Rio_Grande_do_Sul/Crop_Cultivar"
                        },
                        "TAW": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/IRI/Analyses/Water_Balance/Brazil/Rio_Grande_do_Sul/TAW",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "TAW",
                            "restriction": "Public",
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ]
                        },
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type",
                            "Crop_Cultivar",
                            "TAW"
                        ]
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "Rio_Grande_do_Sul"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "Brazil"
                ]
            },
            "banned_long": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type",
                "CSMT",
                "ENSORP",
                "Fire",
                "ICPAC",
                "LandDAAC",
                "Locust",
                "MDG",
                "NOAA",
                "SPI",
                "TS",
                "Tailored",
                "USGS",
                "WASP",
                "WFP",
                "WORLDCLIM",
                "Water_Balance"
            ]
        },
        "EPPF": {
            "iridl_type": "DataSet",
            "iridl_ds_name": "EPPF",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "NC_GLOBAL": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "NC_GLOBAL",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "weekly_fishingdefinitions_and_explanationshtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.EPPF/.weekly_fishing.definitions_and_explanations.html",
                "weekly_fishingdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.EPPF/.weekly_fishing.dataset_documentation.html",
                "environmentdefinitions_and_explanationshtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.EPPF/.environment.definitions_and_explanations.html",
                "environmentdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.EPPF/.environment.dataset_documentation.html",
                "economicsdefinitions_and_explanationshtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.EPPF/.economics.definitions_and_explanations.html",
                "economicsdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.EPPF/.economics.dataset_documentation.html",
                "catchdefinitions_and_explanationshtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.EPPF/.catch.definitions_and_explanations.html",
                "catchdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.EPPF/.catch.dataset_documentation.html",
                "anchovetadefinitions_and_explanationshtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.EPPF/.anchoveta.definitions_and_explanations.html",
                "anchovetadataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.EPPF/.anchoveta.dataset_documentation.html",
                "definitions_and_explanationshtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.EPPF/.definitions_and_explanations.html",
                "long_name": "Eastern Pacific Pelagic Fisheries",
                "references": "Csirke_etal1996",
                "description": "Fisheries data from the Pacific Coast of South America",
                "Conventions": "IRIDL",
                "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.EPPF/.dataset_documentation.html"
            },
            "weekly_fishing": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "weekly_fishing",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "Peru": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Peru",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "total": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "total",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne",
                        "long_name": "total Peru fishing: w1 1993 - w21 1998"
                    },
                    "Privates": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Privates",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne",
                        "long_name": "Privates Peru fishing: w1 1993 - w21 1998"
                    },
                    "ports": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ports",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "total": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "total",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne",
                            "long_name": "total Peru fishing: w1 1993 - w21 1998"
                        },
                        "Privates": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Privates",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne",
                            "long_name": "Privates Peru fishing: w1 1993 - w21 1998"
                        },
                        "Pesca": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Pesca",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne",
                            "long_name": "Pesca Peru fishing: w1 1993 - w21 1998"
                        }
                    },
                    "Pesca": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Pesca",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne",
                        "long_name": "Pesca Peru fishing: w1 1993 - w21 1998"
                    }
                },
                "Chile": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Chile",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "total": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "total",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne",
                        "long_name": "Chile fishing total: w1 1993 - w21 1998"
                    },
                    "south": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "south",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne",
                        "long_name": "Chile fishing south: w1 1993 - w21 1998"
                    },
                    "north": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "north",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne",
                        "long_name": "Chile fishing north: w1 1993 - w21 1998"
                    }
                }
            },
            "Steve_filter": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "Steve_filter",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "anchoveta": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "anchoveta",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "PeruII": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PeruII",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "total": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "total",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "biomass": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "biomass",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "NaN",
                                "units": "tonne",
                                "long_name": "biomass (5 year filter): 1953-1985"
                            }
                        },
                        "recruits": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "recruits",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "number*10^9",
                            "long_name": "recruits (5 year filter): 1953-1985"
                        },
                        "egg_production": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "egg_production",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "number*10^9",
                            "long_name": "egg production (5 year filter): 1953-1985"
                        }
                    },
                    "catch": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "catch",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "nominal_catch": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "nominal_catch",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne/month",
                            "long_name": "nominal catch (5 year filter): 1953-1987"
                        },
                        "condition_factor": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "condition_factor",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "unitless",
                            "long_name": "condition factor (5 year filter): 1953-1987"
                        }
                    }
                }
            },
            "environment": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "environment",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "xbtpc2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "xbtpc2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "unitless",
                    "long_name": "XBTPC2: 1960-1986"
                },
                "xbtpc1": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "xbtpc1",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "unitless",
                    "long_name": "XBTPC1: 1960-1986"
                },
                "wind_velocity": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "wind_velocity",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "meters/second",
                    "long_name": "wind velocity: 1953-1982"
                },
                "weekly": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "weekly",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "sst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "Celsius_scale",
                        "long_name": "NINO12 sea surface temperature: w1 1982 - w25 1998"
                    }
                },
                "velocity": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "velocity",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "meters/second",
                    "long_name": "velocity: 1953-1984"
                },
                "upwelling": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "upwelling",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "meter^3/second",
                    "long_name": "upwelling: 1953-1986"
                },
                "turbulence": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "turbulence",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "meters^3/seconds^3",
                    "long_name": "turbulence index: 1953-1984"
                },
                "thermocline_depth": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "thermocline_depth",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "meters",
                    "long_name": "thermocline depth: 1951-1984"
                },
                "sst": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sst",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "Celsius_scale",
                    "long_name": "sea surface temperature: 1953-1984"
                },
                "SOI": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SOI",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "milibar",
                    "long_name": "southern oscillation index: 1948-1985"
                },
                "sea_level": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "sea_level",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "999.0",
                    "units": "cm",
                    "long_name": "sea level anomalies: varies"
                },
                "rossby_radius": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "rossby_radius",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "kilometer",
                    "long_name": "rossby radius: 1953-1982"
                },
                "primary_production": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "primary_production",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "gC/meter/day",
                    "long_name": "primary production: 1953-1984"
                },
                "oceanic": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "oceanic",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "VDM": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "VDM",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "primary_production": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "primary_production",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "gC/meter/day",
                            "long_name": "primary production"
                        }
                    },
                    "flux_derived": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "flux_derived",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "VDM": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "VDM",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NO3": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NO3",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "NaN",
                                "units": "Mm/meter/day",
                                "long_name": "NO3: 1953-1982"
                            }
                        },
                        "ConcBakun_VDM": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Conc*Bakun_VDM",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NO3": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NO3",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "NaN",
                                "units": "Mm/meter/day",
                                "long_name": "NO3: 1953-1982"
                            }
                        },
                        "ConcBakun_CDM": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Conc*Bakun_CDM",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NO3": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NO3",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "NaN",
                                "units": "Mm/meter/day",
                                "long_name": "NO3: 1953-1982"
                            }
                        },
                        "CDM": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "CDM",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NO3": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NO3",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "NaN",
                                "units": "Mm/meter/day",
                                "long_name": "NO3: 1953-1982"
                            }
                        }
                    },
                    "CDM": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "CDM",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "primary_production": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "primary_production",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "gC/meter/day",
                            "long_name": "primary production: 1953-1982"
                        }
                    }
                },
                "NO3": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NO3",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "mM/meter^3",
                    "long_name": "NO3: 1953-1982"
                },
                "mean_relat_cld_cvr": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "mean_relat_cld_cvr",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "meters",
                    "long_name": "mean relative cloud cover: 1953-1984"
                },
                "lasker_events": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lasker_events",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "numbers",
                    "long_name": "lasker events: 1953-1985"
                },
                "coastal": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "coastal",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "VDM": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "VDM",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "primary_production": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "primary_production",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "gC/meter/day",
                            "long_name": "primary production: 1953-1982"
                        }
                    },
                    "flux_derived": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "flux_derived",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "VDM": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "VDM",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NO3": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NO3",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "NaN",
                                "units": "Mm/meter/day",
                                "long_name": "NO3: 1953-1982"
                            }
                        },
                        "ConcTrujUp_VDM": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Conc*TrujUp_VDM",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NO3": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NO3",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "NaN",
                                "units": "Mm/meter/day",
                                "long_name": "NO3: 1953-1982"
                            }
                        },
                        "ConcTrujUp_CDM": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Conc*TrujUp_CDM",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NO3": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NO3",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "NaN",
                                "units": "Mm/meter/day",
                                "long_name": "NO3: 1953-1982"
                            }
                        },
                        "CDM": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "CDM",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NO3": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NO3",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "NaN",
                                "units": "Mm/meter/day",
                                "long_name": "NO3: 1953-1982"
                            }
                        }
                    },
                    "CDM": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "CDM",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "primary_production": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "primary_production",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "gC/meter/day",
                            "long_name": "primary production: 1953-1982"
                        }
                    }
                },
                "absorbed_solar_radiation": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "absorbed_solar_radiation",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "missing_value": "NaN",
                    "units": "Watt/meter/day",
                    "long_name": "absorbed solar radiation: 1953-1984"
                }
            },
            "economics": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "economics",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "yearly": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "yearly",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "exports": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "exports",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "total": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "total",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "number",
                            "long_name": "Total Fish Flour and Oil Exports: 1968-1995"
                        }
                    },
                    "capacity": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "capacity",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "total_capacity": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "total_capacity",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne*10^3/hours",
                            "long_name": "total capacity: 1950-1996"
                        },
                        "ship_hold": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ship_hold",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne*10^3",
                            "long_name": "ship hold: 1950-1996"
                        },
                        "num_plants": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "num_plants",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "number",
                            "long_name": "number of plants: 1950-1996"
                        },
                        "num_boats": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "num_boats",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "number",
                            "long_name": "number of boats: 1950-1996"
                        }
                    }
                },
                "prices": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "prices",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "soyameal": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "soyameal",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "long_name": "soyameal prices: w49 1993 - w21 1998"
                    },
                    "fishmeal": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "fishmeal",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "long_name": "fishmeal prices: w49 1993 - w21 1998"
                    }
                },
                "FOB": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "FOB",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "soyomeal_Brasil": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "soyomeal_Brasil",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "long_name": "soyomeal FOB Brasil: w49 1993 - w21 1998"
                    },
                    "prices_Peru": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "prices_Peru",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "long_name": "FOB Peru: w49 1993 - w21 1998"
                    },
                    "ind": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ind",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "long_name": "FOB index: w49 1993 - w21 1998"
                    }
                }
            },
            "catch": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "catch",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "yearly": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "yearly",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "sardina": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sardina",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne",
                        "long_name": "yearly sardina catch: 1950-1996"
                    },
                    "jurel": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "jurel",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne",
                        "long_name": "yearly jurel catch: 1950-1996"
                    },
                    "human_consumption": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "human_consumption",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "total": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "total",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "number",
                            "long_name": "Catch for Indirect Human Consumption: 1968-1995"
                        },
                        "ports": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ports",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "number",
                            "long_name": "Catch for Indirect Human Consumption by Port: 1968-1995"
                        }
                    },
                    "caballa": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "caballa",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne",
                        "long_name": "yearly caballa catch: 1950-1996"
                    },
                    "anchoveta": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "anchoveta",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne",
                        "long_name": "yearly anchoveta catch: 1950-1996"
                    }
                }
            },
            "anchoveta": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "anchoveta",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "yearly": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "yearly",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "mean": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mean",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "recruits": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "recruits",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne",
                            "long_name": "recruits: 1962-1993"
                        },
                        "adult_stock": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "adult_stock",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne",
                            "long_name": "adult stock: 1962-1993"
                        }
                    }
                },
                "predators": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "predators",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "total_natural_mortality": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "total_natural_mortality",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "10^6",
                        "long_name": "total natural mortality: 1953-1982"
                    },
                    "species": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "species",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "total": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "total",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "consumption": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "consumption",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "NaN",
                                "units": "tonne",
                                "long_name": "consumption: 1953-1982"
                            }
                        },
                        "numbers": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "numbers",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "10^6",
                            "long_name": "numbers: 1953-1982"
                        },
                        "biomass": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "biomass",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne",
                            "long_name": "biomass: 1953-1982"
                        },
                        "anchovy": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "anchovy",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "consumption": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "consumption",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "NaN",
                                "units": "tonne",
                                "long_name": "consumption: 1953-1982"
                            }
                        },
                        "abundance": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "abundance",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne",
                            "long_name": "abundance: 1953-1982"
                        }
                    },
                    "PeruII": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PeruII",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "baseline_natural_mortality": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "baseline_natural_mortality",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "10^6",
                            "long_name": "baseline natural mortality: 1953-1982"
                        }
                    },
                    "PeruI": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PeruI",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "baseline_natural_mortality": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "baseline_natural_mortality",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "Mo",
                            "long_name": "baseline natural mortality: 1953-1982"
                        }
                    },
                    "nominal_catch": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nominal_catch",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne",
                        "long_name": "nominal catch: 1953-1982"
                    }
                },
                "PeruII": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "PeruII",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "total": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "total",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "biomass": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "biomass",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne",
                            "long_name": "biomass: 1953-1985"
                        }
                    },
                    "recruits": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "recruits",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "number*10^9",
                        "long_name": "recruits: 1953-1985"
                    },
                    "mature_male_female": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mature_male_female",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "biomass": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "biomass",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne",
                            "long_name": "biomass: 1953-1985"
                        }
                    },
                    "mature_female": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mature_female",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "biomass": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "biomass",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne",
                            "long_name": "biomass: 1953-1985"
                        }
                    },
                    "egg_production": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "egg_production",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "number*10^9",
                        "long_name": "egg production: 1953-1985"
                    },
                    "biomass": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "biomass",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "dist": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "dist",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "percent",
                            "long_name": "distribution by cm length class: 1953-1985"
                        }
                    }
                },
                "PeruI": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "PeruI",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "total": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "total",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "biomass": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "biomass",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne",
                            "long_name": "biomass: 1953-1982"
                        }
                    },
                    "recruits": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "recruits",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "number*10^9",
                        "long_name": "recruits: 1953-1982"
                    },
                    "mature_male_female": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mature_male_female",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "biomass": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "biomass",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne",
                            "long_name": "biomass: 1953-1982"
                        }
                    },
                    "mature_female": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mature_female",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "biomass": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "biomass",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "tonne",
                            "long_name": "biomass: 1953-1982"
                        }
                    },
                    "egg_production": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "egg_production",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "number*10^9",
                        "long_name": "egg production: 1953-1982"
                    },
                    "biomass": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "biomass",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "dist": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "dist",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "NaN",
                            "units": "percent",
                            "long_name": "distribution by cm length class: 1953-1982"
                        }
                    }
                },
                "eggs": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "eggs",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "sardine_biomass": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "sardine_biomass",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne*10^6",
                        "long_name": "sardine biomass: 1964-1986"
                    },
                    "parent_stock": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "parent_stock",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne*10^6",
                        "long_name": "Anchoveta parent stock: 1964-1986"
                    },
                    "mortality": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "mortality",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "day^-1",
                        "long_name": "mortality: 1964-1986"
                    },
                    "map_standing_stock": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "map_standing_stock",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "N*10^12",
                        "long_name": "map standing stock: 1964-1986"
                    },
                    "est_mortality": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "est_mortality",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "day^-1",
                        "long_name": "estimated mortality: 1964-1986"
                    },
                    "egg_dvlp_time": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "egg_dvlp_time",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "days",
                        "long_name": "egg developement time: 1964-1986"
                    },
                    "daily_reprod_output": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "daily_reprod_output",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne*10^12",
                        "long_name": "daily reproductive output: 1964-1986"
                    }
                },
                "catch": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "catch",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "nominal_catch": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "nominal_catch",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "tonne/month",
                        "long_name": "nominal catch: 1953-1987"
                    },
                    "dist": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "dist",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "percent: 1953-1987",
                        "long_name": "distribution by cm length class"
                    },
                    "condition_factor": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "condition_factor",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "missing_value": "NaN",
                        "units": "unitless",
                        "long_name": "condition factor: 1953-1987"
                    }
                }
            },
            "T_06": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T_06",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "long_name": "time",
                "pointwidth": "1.0"
            },
            "T_05": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T_05",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "julian_day",
                "gridtype": "0",
                "calendar": "standard",
                "pointwidth": "7.0",
                "long_name": "time",
                "add_offset": "2444976.0"
            },
            "T_04": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T_04",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "long_name": "time",
                "pointwidth": "1.0"
            },
            "loc": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "loc",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "gridtype": "2",
                "long_name": "port"
            },
            "T_03": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T_03",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "julian_day",
                "gridtype": "0",
                "calendar": "standard",
                "pointwidth": "7.0",
                "long_name": "time",
                "add_offset": "2449330.0"
            },
            "port": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "port",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "gridtype": "2",
                "long_name": "port"
            },
            "T_02": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T_02",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "long_name": "time",
                "pointwidth": "12.0"
            },
            "T_01": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T_01",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "long_name": "time",
                "pointwidth": "12.0"
            },
            "species": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "species",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "ids",
                "gridtype": "2",
                "long_name": "species"
            },
            "len": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "len",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "cm",
                "gridtype": "0",
                "long_name": "length",
                "pointwidth": "1.0"
            },
            "T": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "T",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "units": "months since 1960-01-01",
                "gridtype": "0",
                "calendar": "360",
                "long_name": "time",
                "pointwidth": "1.0"
            },
            "dir": "SOURCES/IRI/EPPF"
        },
        "FD": {
            "iridl_type": "Source",
            "invalid": [],
            "dir": "SOURCES/IRI/FD",
            "banned": [
                "dir",
                "invalid",
                "parent",
                "name",
                "banned",
                "banned_long",
                "iridl_ds_name",
                "iridl_type"
            ],
            "iridl_ds_name": "FD",
            "restriction": "Public",
            "AgMIP": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "AgMIP",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "WAmonthlysimall_JJAS_95_07053_WA_003nc4runNo": "003",
                    "WAmonthlysimall_JJAS_95_02649_WA_003nc4runNo": "003",
                    "WAmonthlysimall_JJAS_95_00747_WA_003nc4runNo": "003",
                    "WAmonthlysimall_JJAS_50_07053_WA_003nc4runNo": "003",
                    "WAmonthlysimall_JJAS_50_02649_WA_003nc4runNo": "003",
                    "WAmonthlysimall_JJAS_50_00747_WA_003nc4runNo": "003",
                    "WAmonthlysimall_JJAS_05_07053_WA_003nc4runNo": "003",
                    "WAmonthlysimall_JJAS_05_02649_WA_003nc4runNo": "003",
                    "WAmonthlysimall_JJAS_05_00747_WA_003nc4runNo": "003",
                    "WAdailysimall_JJAS_95_07053_WA_003nc4runNo": "003",
                    "WAdailysimall_JJAS_95_02649_WA_003nc4runNo": "003",
                    "WAdailysimall_JJAS_95_00747_WA_003nc4runNo": "003",
                    "WAdailysimall_JJAS_50_07053_WA_003nc4runNo": "003",
                    "WAdailysimall_JJAS_50_02649_WA_003nc4runNo": "003",
                    "WAdailysimall_JJAS_50_00747_WA_003nc4runNo": "003",
                    "WAdailysimall_JJAS_05_07053_WA_003nc4runNo": "003",
                    "WAdailysimall_JJAS_05_02649_WA_003nc4runNo": "003",
                    "WAdailysimall_JJAS_05_00747_WA_003nc4runNo": "003",
                    "WAdocumentation": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.AgMIP/.WA/Greene_AgMIP_WA.pdf",
                    "SIR3_MAMmonthlysimall_MAM_95_06728_SI_R3_001nc4runNo": "R3_001",
                    "SIR3_MAMmonthlysimall_MAM_95_01693_SI_R3_001nc4runNo": "R3_001",
                    "SIR3_MAMmonthlysimall_MAM_95_01359_SI_R3_001nc4runNo": "R3_001",
                    "SIR3_MAMmonthlysimall_MAM_50_06728_SI_R3_001nc4runNo": "R3_001",
                    "SIR3_MAMmonthlysimall_MAM_50_01693_SI_R3_001nc4runNo": "R3_001",
                    "SIR3_MAMmonthlysimall_MAM_50_01359_SI_R3_001nc4runNo": "R3_001",
                    "SIR3_MAMmonthlysimall_MAM_05_06728_SI_R3_001nc4runNo": "R3_001",
                    "SIR3_MAMmonthlysimall_MAM_05_01693_SI_R3_001nc4runNo": "R3_001",
                    "SIR3_MAMmonthlysimall_MAM_05_01359_SI_R3_001nc4runNo": "R3_001",
                    "SIR3_MAMdailysimall_MAM_95_06728_SI_R3_001dnc4runNo": "R3_001d",
                    "SIR3_MAMdailysimall_MAM_95_01693_SI_R3_001dnc4runNo": "R3_001d",
                    "SIR3_MAMdailysimall_MAM_95_01359_SI_R3_001dnc4runNo": "R3_001d",
                    "SIR3_MAMdailysimall_MAM_50_06728_SI_R3_001dnc4runNo": "R3_001d",
                    "SIR3_MAMdailysimall_MAM_50_01693_SI_R3_001dnc4runNo": "R3_001d",
                    "SIR3_MAMdailysimall_MAM_50_01359_SI_R3_001dnc4runNo": "R3_001d",
                    "SIR3_MAMdailysimall_MAM_05_06728_SI_R3_001dnc4runNo": "R3_001d",
                    "SIR3_MAMdailysimall_MAM_05_01693_SI_R3_001dnc4runNo": "R3_001d",
                    "SIR3_MAMdailysimall_MAM_05_01359_SI_R3_001dnc4runNo": "R3_001d",
                    "SIR2_ONDmonthlysimall_OND_95_09583_SI_R2_001nc4runNo": "R2_001",
                    "SIR2_ONDmonthlysimall_OND_95_06339_SI_R2_001nc4runNo": "R2_001",
                    "SIR2_ONDmonthlysimall_OND_95_02030_SI_R2_001nc4runNo": "R2_001",
                    "SIR2_ONDmonthlysimall_OND_50_09583_SI_R2_001nc4runNo": "R2_001",
                    "SIR2_ONDmonthlysimall_OND_50_06339_SI_R2_001nc4runNo": "R2_001",
                    "SIR2_ONDmonthlysimall_OND_50_02030_SI_R2_001nc4runNo": "R2_001",
                    "SIR2_ONDmonthlysimall_OND_05_09583_SI_R2_001nc4runNo": "R2_001",
                    "SIR2_ONDmonthlysimall_OND_05_06339_SI_R2_001nc4runNo": "R2_001",
                    "SIR2_ONDmonthlysimall_OND_05_02030_SI_R2_001nc4runNo": "R2_001",
                    "SIR2_ONDdailysimall_OND_95_09583_SI_R2_001dnc4runNo": "R2_001d",
                    "SIR2_ONDdailysimall_OND_95_06339_SI_R2_001dnc4runNo": "R2_001d",
                    "SIR2_ONDdailysimall_OND_95_02030_SI_R2_001dnc4runNo": "R2_001d",
                    "SIR2_ONDdailysimall_OND_50_09583_SI_R2_001dnc4runNo": "R2_001d",
                    "SIR2_ONDdailysimall_OND_50_06339_SI_R2_001dnc4runNo": "R2_001d",
                    "SIR2_ONDdailysimall_OND_50_02030_SI_R2_001dnc4runNo": "R2_001d",
                    "SIR2_ONDdailysimall_OND_05_09583_SI_R2_001dnc4runNo": "R2_001d",
                    "SIR2_ONDdailysimall_OND_05_06339_SI_R2_001dnc4runNo": "R2_001d",
                    "SIR2_ONDdailysimall_OND_05_02030_SI_R2_001dnc4runNo": "R2_001d",
                    "SIR1_JJASmonthlysimall_JJAS_95_04970_SI_R1_001nc4runNo": "R1_001",
                    "SIR1_JJASmonthlysimall_JJAS_95_03950_SI_R1_001nc4runNo": "R1_001",
                    "SIR1_JJASmonthlysimall_JJAS_95_00964_SI_R1_001nc4runNo": "R1_001",
                    "SIR1_JJASmonthlysimall_JJAS_50_04970_SI_R1_001nc4runNo": "R1_001",
                    "SIR1_JJASmonthlysimall_JJAS_50_03950_SI_R1_001nc4runNo": "R1_001",
                    "SIR1_JJASmonthlysimall_JJAS_50_00964_SI_R1_001nc4runNo": "R1_001",
                    "SIR1_JJASmonthlysimall_JJAS_05_04970_SI_R1_001nc4runNo": "R1_001",
                    "SIR1_JJASmonthlysimall_JJAS_05_03950_SI_R1_001nc4runNo": "R1_001",
                    "SIR1_JJASmonthlysimall_JJAS_05_00964_SI_R1_001nc4runNo": "R1_001",
                    "SIR1_JJASdailysimall_JJAS_95_04970_SI_R1_001dnc4runNo": "R1_001d",
                    "SIR1_JJASdailysimall_JJAS_95_03950_SI_R1_001dnc4runNo": "R1_001d",
                    "SIR1_JJASdailysimall_JJAS_95_00964_SI_R1_001dnc4runNo": "R1_001d",
                    "SIR1_JJASdailysimall_JJAS_50_04970_SI_R1_001dnc4runNo": "R1_001d",
                    "SIR1_JJASdailysimall_JJAS_50_03950_SI_R1_001dnc4runNo": "R1_001d",
                    "SIR1_JJASdailysimall_JJAS_50_00964_SI_R1_001dnc4runNo": "R1_001d",
                    "SIR1_JJASdailysimall_JJAS_05_04970_SI_R1_001dnc4runNo": "R1_001d",
                    "SIR1_JJASdailysimall_JJAS_05_03950_SI_R1_001dnc4runNo": "R1_001d",
                    "SIR1_JJASdailysimall_JJAS_05_00964_SI_R1_001dnc4runNo": "R1_001d",
                    "SIdocumentation": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.AgMIP/.SI/Greene_AgMIP_SI.pdf",
                    "Conventions": "IRIDL"
                },
                "WA": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "WA",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "monthly": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "monthly",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "simall_JJAS_95_07053_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_95_07053_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            }
                        },
                        "simall_JJAS_95_02649_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_95_02649_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            }
                        },
                        "simall_JJAS_95_00747_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_95_00747_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            }
                        },
                        "simall_JJAS_50_07053_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_50_07053_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            }
                        },
                        "simall_JJAS_50_02649_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_50_02649_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            }
                        },
                        "simall_JJAS_50_00747_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_50_00747_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            }
                        },
                        "simall_JJAS_05_07053_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_05_07053_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            }
                        },
                        "simall_JJAS_05_02649_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_05_02649_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            }
                        },
                        "simall_JJAS_05_00747_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_05_00747_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            }
                        }
                    },
                    "daily": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "daily",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "simall_JJAS_95_07053_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_95_07053_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "wind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "wind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "m s-1"
                            },
                            "vp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "vp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "hPa"
                            },
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "rsds": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "rsds",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "MJ m-2 day-1"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            },
                            "hur": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hur",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "percent"
                            },
                            "dewp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "dewp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            }
                        },
                        "simall_JJAS_95_02649_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_95_02649_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "wind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "wind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "m s-1"
                            },
                            "vp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "vp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "hPa"
                            },
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "rsds": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "rsds",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "MJ m-2 day-1"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            },
                            "hur": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hur",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "percent"
                            },
                            "dewp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "dewp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            }
                        },
                        "simall_JJAS_95_00747_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_95_00747_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "wind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "wind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "m s-1"
                            },
                            "vp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "vp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "hPa"
                            },
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "rsds": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "rsds",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "MJ m-2 day-1"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            },
                            "hur": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hur",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "percent"
                            },
                            "dewp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "dewp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            }
                        },
                        "simall_JJAS_50_07053_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_50_07053_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "wind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "wind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "m s-1"
                            },
                            "vp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "vp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "hPa"
                            },
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "rsds": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "rsds",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "MJ m-2 day-1"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            },
                            "hur": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hur",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "percent"
                            },
                            "dewp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "dewp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            }
                        },
                        "simall_JJAS_50_02649_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_50_02649_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "wind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "wind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "m s-1"
                            },
                            "vp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "vp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "hPa"
                            },
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "rsds": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "rsds",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "MJ m-2 day-1"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            },
                            "hur": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hur",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "percent"
                            },
                            "dewp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "dewp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            }
                        },
                        "simall_JJAS_50_00747_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_50_00747_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "wind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "wind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "m s-1"
                            },
                            "vp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "vp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "hPa"
                            },
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "rsds": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "rsds",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "MJ m-2 day-1"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            },
                            "hur": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hur",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "percent"
                            },
                            "dewp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "dewp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            }
                        },
                        "simall_JJAS_05_07053_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_05_07053_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "wind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "wind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "m s-1"
                            },
                            "vp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "vp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "hPa"
                            },
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "rsds": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "rsds",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "MJ m-2 day-1"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            },
                            "hur": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hur",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "percent"
                            },
                            "dewp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "dewp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            }
                        },
                        "simall_JJAS_05_02649_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_05_02649_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "wind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "wind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "m s-1"
                            },
                            "vp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "vp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "hPa"
                            },
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "rsds": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "rsds",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "MJ m-2 day-1"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            },
                            "hur": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hur",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "percent"
                            },
                            "dewp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "dewp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            }
                        },
                        "simall_JJAS_05_00747_WA_003nc4": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "simall_JJAS_05_00747_WA_003.nc4",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "wind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "wind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "m s-1"
                            },
                            "vp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "vp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "hPa"
                            },
                            "tmx": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmx",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "tmn": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "tmn",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            },
                            "rsds": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "rsds",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "MJ m-2 day-1"
                            },
                            "pre": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "pre",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "mm/day"
                            },
                            "hur": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hur",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "percent"
                            },
                            "dewp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "dewp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "1.00000002E20",
                                "units": "Celsius_scale"
                            }
                        }
                    }
                },
                "SI": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "SI",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "R3_MAM": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "R3_MAM",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "monthly": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "monthly",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "simall_MAM_95_06728_SI_R3_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_95_06728_SI_R3_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_MAM_95_01693_SI_R3_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_95_01693_SI_R3_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_MAM_95_01359_SI_R3_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_95_01359_SI_R3_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_MAM_50_06728_SI_R3_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_50_06728_SI_R3_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_MAM_50_01693_SI_R3_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_50_01693_SI_R3_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_MAM_50_01359_SI_R3_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_50_01359_SI_R3_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_MAM_05_06728_SI_R3_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_05_06728_SI_R3_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_MAM_05_01693_SI_R3_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_05_01693_SI_R3_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_MAM_05_01359_SI_R3_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_05_01359_SI_R3_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            }
                        },
                        "daily": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "daily",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "simall_MAM_95_06728_SI_R3_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_95_06728_SI_R3_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_MAM_95_01693_SI_R3_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_95_01693_SI_R3_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_MAM_95_01359_SI_R3_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_95_01359_SI_R3_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_MAM_50_06728_SI_R3_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_50_06728_SI_R3_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_MAM_50_01693_SI_R3_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_50_01693_SI_R3_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_MAM_50_01359_SI_R3_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_50_01359_SI_R3_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_MAM_05_06728_SI_R3_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_05_06728_SI_R3_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_MAM_05_01693_SI_R3_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_05_01693_SI_R3_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_MAM_05_01359_SI_R3_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_MAM_05_01359_SI_R3_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            }
                        }
                    },
                    "R2_OND": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "R2_OND",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "monthly": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "monthly",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "simall_OND_95_09583_SI_R2_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_95_09583_SI_R2_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_OND_95_06339_SI_R2_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_95_06339_SI_R2_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_OND_95_02030_SI_R2_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_95_02030_SI_R2_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_OND_50_09583_SI_R2_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_50_09583_SI_R2_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_OND_50_06339_SI_R2_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_50_06339_SI_R2_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_OND_50_02030_SI_R2_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_50_02030_SI_R2_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_OND_05_09583_SI_R2_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_05_09583_SI_R2_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_OND_05_06339_SI_R2_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_05_06339_SI_R2_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_OND_05_02030_SI_R2_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_05_02030_SI_R2_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            }
                        },
                        "daily": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "daily",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "simall_OND_95_09583_SI_R2_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_95_09583_SI_R2_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_OND_95_06339_SI_R2_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_95_06339_SI_R2_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_OND_95_02030_SI_R2_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_95_02030_SI_R2_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_OND_50_09583_SI_R2_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_50_09583_SI_R2_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_OND_50_06339_SI_R2_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_50_06339_SI_R2_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_OND_50_02030_SI_R2_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_50_02030_SI_R2_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_OND_05_09583_SI_R2_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_05_09583_SI_R2_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_OND_05_06339_SI_R2_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_05_06339_SI_R2_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_OND_05_02030_SI_R2_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_OND_05_02030_SI_R2_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            }
                        }
                    },
                    "R1_JJAS": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "R1_JJAS",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "monthly": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "monthly",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "simall_JJAS_95_04970_SI_R1_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_95_04970_SI_R1_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_JJAS_95_03950_SI_R1_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_95_03950_SI_R1_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_JJAS_95_00964_SI_R1_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_95_00964_SI_R1_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_JJAS_50_04970_SI_R1_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_50_04970_SI_R1_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_JJAS_50_03950_SI_R1_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_50_03950_SI_R1_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_JJAS_50_00964_SI_R1_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_50_00964_SI_R1_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_JJAS_05_04970_SI_R1_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_05_04970_SI_R1_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_JJAS_05_03950_SI_R1_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_05_03950_SI_R1_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            },
                            "simall_JJAS_05_00964_SI_R1_001nc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_05_00964_SI_R1_001.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                }
                            }
                        },
                        "daily": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "daily",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "simall_JJAS_95_04970_SI_R1_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_95_04970_SI_R1_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_JJAS_95_03950_SI_R1_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_95_03950_SI_R1_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_JJAS_95_00964_SI_R1_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_95_00964_SI_R1_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_JJAS_50_04970_SI_R1_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_50_04970_SI_R1_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_JJAS_50_03950_SI_R1_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_50_03950_SI_R1_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_JJAS_50_00964_SI_R1_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_50_00964_SI_R1_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_JJAS_05_04970_SI_R1_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_05_04970_SI_R1_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_JJAS_05_03950_SI_R1_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_05_03950_SI_R1_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            },
                            "simall_JJAS_05_00964_SI_R1_001dnc4": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "simall_JJAS_05_00964_SI_R1_001d.nc4",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "m s-1"
                                },
                                "vp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "hPa"
                                },
                                "tmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "tmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                },
                                "rsds": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rsds",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "MJ m-2 day-1"
                                },
                                "pre": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pre",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "mm/day"
                                },
                                "hur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "percent"
                                },
                                "dewp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dewp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "1.00000002E20",
                                    "units": "Celsius_scale"
                                }
                            }
                        }
                    }
                },
                "lon_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "pointwidth": "0.5"
                },
                "lat_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "pointwidth": "0.5"
                },
                "time_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "time_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1901-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "1.0"
                },
                "time": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "time",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "days since 1901-01-01",
                    "gridtype": "0",
                    "calendar": "standard",
                    "pointwidth": "1.0"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "pointwidth": "0.5"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "pointwidth": "0.5"
                },
                "dir": "SOURCES/IRI/FD/AgMIP"
            },
            "CCM3": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CCM3",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Historyclimatologyc6998iridlhasSemantics": "iridl:climatology",
                    "Historyclimatologyc6998long_name": "1968-1998",
                    "ForecastiridlhasSemantics": "iridl:forecast",
                    "description": "CCM3.2 ensemble forecasts and simulations of precipitation rate, 2m temperature, and 500mb heights",
                    "iridlhasSemantics": "iridl:NCAR",
                    "Conventions": "IRIDL",
                    "long_name": "ccm3.2",
                    "references": "Hack_etal1998 Hurrell_etal1998 Kiehl_etal1998"
                },
                "History": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "History",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "ensemble_mean": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ensemble_mean",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "monthly": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "monthly",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "z500": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "z500",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m",
                                "long_name": "500mb height"
                            },
                            "t2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "t2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Kelvin_scale",
                                "long_name": "temperature at 2m"
                            },
                            "prcp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "prcp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/day",
                                "long_name": "precipitation rate"
                            }
                        },
                        "anomaly": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "anomaly",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "z500": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "z500",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m",
                                "long_name": "500mb height"
                            },
                            "t2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "t2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Kelvin_scale",
                                "long_name": "temperature at 2m"
                            },
                            "prcp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "prcp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/day",
                                "long_name": "precipitation rate"
                            }
                        }
                    },
                    "ensemble": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ensemble",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "monthly": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "monthly",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "z500": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "z500",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m",
                                "long_name": "500mb height"
                            },
                            "t2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "t2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Kelvin_scale",
                                "long_name": "temperature at 2m"
                            },
                            "prcp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "prcp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/day",
                                "long_name": "precipitation rate"
                            }
                        },
                        "anomaly": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "anomaly",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "z500": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "z500",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m",
                                "long_name": "500mb height"
                            },
                            "t2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "t2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Kelvin_scale",
                                "long_name": "temperature at 2m"
                            },
                            "prcp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "prcp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/day",
                                "long_name": "precipitation rate"
                            }
                        }
                    },
                    "climatology": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "climatology",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "c6998": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "c6998",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "z500": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "z500",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m",
                                "long_name": "500mb height"
                            },
                            "t2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "t2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Kelvin_scale",
                                "long_name": "temperature at 2m"
                            },
                            "prcp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "prcp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/day",
                                "long_name": "precipitation rate"
                            }
                        }
                    }
                },
                "Forecast": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "psst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "psst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ensemble": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ensemble",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "monthly": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "monthly",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "Kelvin_scale",
                                    "long_name": "Temperature at 2m"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Forecast Time",
                                    "pointwidth": "1",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "long_name": "precipitation rate"
                                }
                            }
                        }
                    },
                    "asst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "asst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ensemble": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ensemble",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "monthly": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "monthly",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "Kelvin_scale",
                                    "long_name": "Temperature at 2m"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Forecast Time",
                                    "pointwidth": "1",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "long_name": "precipitation rate"
                                }
                            }
                        }
                    }
                },
                "T_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "M_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "M_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulo": "12.0",
                    "modulus": "12.0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "L_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0"
                },
                "L": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "standard_name": "longitude",
                    "pointwidth": "2.8125"
                },
                "M": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "M",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "gridtype": "0",
                    "long_name": "member",
                    "pointwidth": "1.0"
                },
                "S": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Forecast Started",
                    "pointwidth": "0"
                },
                "dir": "SOURCES/IRI/FD/CCM3"
            },
            "CCM3v6": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CCM3v6",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "HistoryensembleMONTHLYtotal_air_columnexpires": "1491350400",
                    "HistoryensembleMONTHLYtoaexpires": "1491350400",
                    "HistoryensembleMONTHLYtoalong_name": "top of atmosphere",
                    "HistoryensembleMONTHLYsurfaceexpires": "1491350400",
                    "HistoryensembleMONTHLYparametersexpires": "1491350400",
                    "HistoryensembleMONTHLYlsmparametersexpires": "1491350400",
                    "HistoryensembleMONTHLYlsmdescription": "land surface model",
                    "HistoryensembleMONTHLYlsmSource": "Land Surface Model: lsm1.1",
                    "HistoryensembleMONTHLYlsmhistory": "Data created 06/10/04 10:29:31 $",
                    "HistoryensembleMONTHLYlsmcase_title": "ccm3bld : ccm3bld",
                    "HistoryensembleMONTHLYhybrid_levexpires": "1491350400",
                    "HistoryensembleMONTHLYcase": "ccm3bld",
                    "HistoryensembleMONTHLYlogname": "daved",
                    "HistoryensembleMONTHLYsource": "CCM",
                    "HistoryensembleMONTHLYexpires": "1491350400",
                    "HistoryensembleMONTHLYtitle": "ccm3bld",
                    "HistoryensembleMONTHLYConventions": "NCAR-CSM",
                    "HistoryensembleMONTHLYhost": "mako1.ldgo.colum",
                    "HistoryensembleDAILYlogname": "daved",
                    "HistoryensembleDAILYsource": "CCM",
                    "HistoryensembleDAILYtitle": "ccm3bld",
                    "HistoryensembleDAILYConventions": "NCAR-CSM",
                    "HistoryensembleDAILYhost": "mako1.ldgo.colum",
                    "Historyclimatologyc7100long_name": "1971-2000",
                    "Historyclimatologyc6998iridlhasSemantics": "iridl:climatology",
                    "Historyclimatologyc6998long_name": "1969-1998",
                    "Forecastssstensemblemonthlyexpires": "1491307200",
                    "ForecastssstensembleMONTHLYtotal_air_columnexpires": "1491307200",
                    "ForecastssstensembleMONTHLYtoaexpires": "1491307200",
                    "ForecastssstensembleMONTHLYtoalong_name": "top of atmosphere",
                    "ForecastssstensembleMONTHLYsurfaceexpires": "1491307200",
                    "ForecastssstensembleMONTHLYPressureLevelexpires": "1491307200",
                    "ForecastssstensembleMONTHLYparametersexpires": "1491307200",
                    "ForecastssstensembleMONTHLYhybrid_levexpires": "1491307200",
                    "ForecastssstensembleMONTHLYcase": "ccm3bld_200410",
                    "ForecastssstensembleMONTHLYlogname": "forecast",
                    "ForecastssstensembleMONTHLYsource": "CCM",
                    "ForecastssstensembleMONTHLYexpires": "1491307200",
                    "ForecastssstensembleMONTHLYtitle": "ccm3bld",
                    "ForecastssstensembleMONTHLYConventions": "NCAR-CSM",
                    "ForecastssstensembleMONTHLYhost": "mako1.ldgo.colum",
                    "Forecastpsstensemblemonthlyexpires": "1491307200",
                    "ForecastpsstensembleMONTHLYtotal_air_columnexpires": "1491307200",
                    "ForecastpsstensembleMONTHLYtoaexpires": "1491307200",
                    "ForecastpsstensembleMONTHLYtoalong_name": "top of atmosphere",
                    "ForecastpsstensembleMONTHLYsurfaceexpires": "1491307200",
                    "ForecastpsstensembleMONTHLYPressureLevelexpires": "1491307200",
                    "ForecastpsstensembleMONTHLYparametersexpires": "1491307200",
                    "ForecastpsstensembleMONTHLYhybrid_levexpires": "1491307200",
                    "ForecastpsstensembleMONTHLYcase": "ccm3bld_200410",
                    "ForecastpsstensembleMONTHLYlogname": "forecast",
                    "ForecastpsstensembleMONTHLYsource": "CCM",
                    "ForecastpsstensembleMONTHLYexpires": "1491307200",
                    "ForecastpsstensembleMONTHLYtitle": "ccm3bld",
                    "ForecastpsstensembleMONTHLYConventions": "NCAR-CSM",
                    "ForecastpsstensembleMONTHLYhost": "mako1.ldgo.colum",
                    "Forecastca_sstensembleMONTHLYtotal_air_columnexpires": "1491004800",
                    "Forecastca_sstensembleMONTHLYtoaexpires": "1491004800",
                    "Forecastca_sstensembleMONTHLYtoalong_name": "top of atmosphere",
                    "Forecastca_sstensembleMONTHLYsurfaceexpires": "1491004800",
                    "Forecastca_sstensembleMONTHLYparametersexpires": "1491004800",
                    "Forecastca_sstensembleMONTHLYmean_sea_levelexpires": "1491004800",
                    "Forecastca_sstensembleMONTHLYhybrid_levexpires": "1491004800",
                    "Forecastca_sstensembleMONTHLYabove_groundexpires": "1491004800",
                    "Forecastca_sstensembleMONTHLYsource": "CCM",
                    "Forecastca_sstensembleMONTHLYexpires": "1491004800",
                    "Forecastca_sstensembleMONTHLYtitle": "ccm3bld",
                    "Forecastca_sstensembleMONTHLYConventions": "NCAR-CSM",
                    "Forecastca_sstdataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.CCM3v6/.Forecast.ca_sst.dataset_documentation.html",
                    "Forecastca_sstiridlhasSemantics": "iridl:NCAR",
                    "Forecastca_sstreferences": "vandenDool1994 vandenDool2007",
                    "ForecastiridlhasSemantics": "iridl:forecast",
                    "description": "CCM3.6 ensemble forecasts and simulations",
                    "iridlhasSemantics": "iridl:NCAR",
                    "Conventions": "IRIDL",
                    "CCM3v6guide": "http://www.cgd.ucar.edu/cms/ccm3/ccm3lsm_doc/ccm3_doc/cover.html",
                    "references": "Hack_etal1998 Hurrell_etal1998 Kiehl_etal1998"
                },
                "History": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "History",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "ensemble_mean": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ensemble_mean",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "monthly": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "monthly",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "t2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "t2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Kelvin_scale",
                                "long_name": "temperature at 2m"
                            },
                            "prcp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "prcp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/day",
                                "long_name": "precipitation rate"
                            }
                        }
                    },
                    "ensemble": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ensemble",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "monthly": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "monthly",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "t2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "t2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ]
                            },
                            "prcp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "prcp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ]
                            }
                        },
                        "MONTHLY": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "MONTHLY",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "total_air_column": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "total_air_column",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "CNVCLD": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CNVCLD",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Total convective cloud amount",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "CLDTOT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CLDTOT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Vertically-integrated total cloud",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "CLDMED": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CLDMED",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Vertically-integrated mid-level cloud",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "CLDLOW": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CLDLOW",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Vertically-integrated low cloud",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "CLDHGH": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CLDHGH",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Vertically-integrated high cloud",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                }
                            },
                            "toa": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "toa",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "FSNTC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSNTC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Clearsky net solar flux at top",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSNT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSNT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Net solar flux at top",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSNRTC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSNRTC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Clear-sky Flux Shortwave Near-IR Absorbed at toa",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSNIRTSQ": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSNIRTSQ",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Flux Shortwave Near-IR Absorbed at toa >= 0.7 microns",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSNIRT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSNIRT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Flux Shortwave Near-IR Absorbed at TOA",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                }
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "USTAR": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "USTAR",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Surface friction velocity",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "TS4": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TS4",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "TS4      subsoil temperature",
                                    "units": "Kelvin_scale",
                                    "pointwidth": "1.0"
                                },
                                "TS3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TS3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "TS3      subsoil temperature",
                                    "units": "Kelvin_scale",
                                    "pointwidth": "1.0"
                                },
                                "TS2": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TS2",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "TS2      subsoil temperature",
                                    "units": "Kelvin_scale",
                                    "pointwidth": "1.0"
                                },
                                "TS1": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TS1",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "TS1      subsoil temperature",
                                    "units": "Kelvin_scale",
                                    "pointwidth": "1.0"
                                },
                                "TS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Surface temperature",
                                    "units": "Kelvin_scale",
                                    "pointwidth": "1.0"
                                },
                                "TREFHT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TREFHT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Reference height temperature",
                                    "units": "Kelvin_scale",
                                    "pointwidth": "1.0"
                                },
                                "TAUY": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TAUY",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "meridional surface stress",
                                    "units": "Pa",
                                    "pointwidth": "1.0"
                                },
                                "TAUX": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TAUX",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "zonal surface stress",
                                    "units": "Pa",
                                    "pointwidth": "1.0"
                                },
                                "SRFRAD": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SRFRAD",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Net radiative flux at surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "SOLSD": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SOLSD",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Solar downward visible diffuse to surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "SOLS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SOLS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Solar downward visible direct  to surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "SOLLD": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SOLLD",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Solar downward near infrared diffuse to surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "SOLL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SOLL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Solar downward near infrared direct  to surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "SOLIN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SOLIN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Solar insolation",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "SNOWH": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SNOWH",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Water equivalent snow depth",
                                    "units": "m",
                                    "pointwidth": "1.0"
                                },
                                "SICTHK": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SICTHK",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "sea ice thickness",
                                    "units": "m",
                                    "pointwidth": "1.0"
                                },
                                "SHFLX": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SHFLX",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Surface sensible heat flux",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "QFLX": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QFLX",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Surface water flux",
                                    "units": "kg/m2/s",
                                    "pointwidth": "1.0"
                                },
                                "PSL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PSL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Sea level pressure",
                                    "units": "Pa",
                                    "pointwidth": "1.0"
                                },
                                "PS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "surface pressure",
                                    "units": "Pa",
                                    "pointwidth": "1.0"
                                },
                                "PRECSL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PRECSL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Large-scale (stable) snow rate (water equivalent)",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "PRECSC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PRECSC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Convective snow rate (water equivalent)",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "PRECL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PRECL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Large-scale (stable) precipitation rate",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "PRECC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PRECC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Convective precipitation rate",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "PHIS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PHIS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "instantaneous",
                                    "long_name": "surface geopotential",
                                    "units": "m2/s2",
                                    "pointwidth": "1.0"
                                },
                                "PBLH": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PBLH",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "PBL height",
                                    "units": "m",
                                    "pointwidth": "1.0"
                                },
                                "ORO": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ORO",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "instantaneous",
                                    "long_name": "ocean (0), land (1), sea ice (2) flag",
                                    "units": "FLAG",
                                    "pointwidth": "1.0"
                                },
                                "LWSH": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "LWSH",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Liquid water scale height",
                                    "units": "m",
                                    "pointwidth": "1.0"
                                },
                                "LHFLX": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "LHFLX",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Surface latent heat flux",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSNSC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSNSC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Clearsky net solar flux at surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSNS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSNS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Net solar flux at surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSDS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSDS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Flux Shortwave Downwelling Surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FLNTC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FLNTC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Clearsky net longwave flux at top",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FLNT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FLNT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Net longwave flux at top",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FLNSC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FLNSC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Clearsky net longwave flux at surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FLNS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FLNS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Net longwave flux at surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                }
                            },
                            "PressureLevel": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PressureLevel",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "Z3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Geopotential Height (above sea level)",
                                    "pointwidth": "1.0"
                                },
                                "V": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "V",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "meridional wind",
                                    "pointwidth": "1.0"
                                },
                                "U": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "U",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "zonal wind",
                                    "pointwidth": "1.0"
                                },
                                "temp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "temp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "Kelvin_scale",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "temperature",
                                    "pointwidth": "1.0"
                                },
                                "RELHUM": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "RELHUM",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Relative humidity",
                                    "pointwidth": "1.0"
                                }
                            },
                            "parameters": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "parameters",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "time_written": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "time_written",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "P0": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P0",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "reference pressure",
                                    "units": "Pa"
                                },
                                "ntrn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ntrn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "spectral truncation parameter N",
                                    "units": "unitless"
                                },
                                "ntrm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ntrm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "spectral truncation parameter M",
                                    "units": "unitless"
                                },
                                "ntrk": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ntrk",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "spectral truncation parameter K",
                                    "units": "unitless"
                                },
                                "nsteph": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "nsteph",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "long_name": "current timestep",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "nscur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "nscur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "long_name": "current seconds of current day",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "nsbase": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "nsbase",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "seconds of base day",
                                    "units": "unitless"
                                },
                                "ndcur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ndcur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "long_name": "current day (from base day)",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "ndbase": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ndbase",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "base day",
                                    "units": "unitless"
                                },
                                "nbsec": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "nbsec",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "seconds of base date",
                                    "units": "unitless"
                                },
                                "nbdate": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "nbdate",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "base date (YYYYMMDD)",
                                    "units": "unitless"
                                },
                                "mdt": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mdt",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "timestep",
                                    "units": "s"
                                },
                                "gw": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "gw",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "gauss weights",
                                    "units": "unitless"
                                },
                                "datesec": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "datesec",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "long_name": "current seconds of current date",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "date_written": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "date_written",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "date": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "date",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "long_name": "current date (YYYYMMDD)",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                }
                            },
                            "lsm": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lsm",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "surface_type": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface_type",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "surface type",
                                    "units": "unitless"
                                },
                                "S_DOWN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "S_DOWN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "incident solar radiation",
                                    "long_name": "incident solar radiation",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "RSSUN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "RSSUN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "minimum",
                                    "level_flag": "single_level",
                                    "Title": "sunlit leaf stomatal resistance",
                                    "long_name": "sunlit leaf stomatal resistance",
                                    "units": "s/m",
                                    "pointwidth": "1.0"
                                },
                                "RSSHA": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "RSSHA",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "minimum",
                                    "level_flag": "single_level",
                                    "Title": "shaded leaf stomatal resistance",
                                    "long_name": "shaded leaf stomatal resistance",
                                    "units": "s/m",
                                    "pointwidth": "1.0"
                                },
                                "QVEGT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QVEGT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "canopy transpiration",
                                    "long_name": "canopy transpiration",
                                    "units": "mm/s",
                                    "pointwidth": "1.0"
                                },
                                "QVEGE": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QVEGE",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "canopy evaporation",
                                    "long_name": "canopy evaporation",
                                    "units": "mm/s",
                                    "pointwidth": "1.0"
                                },
                                "QSOIL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QSOIL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "ground evaporation",
                                    "long_name": "ground evaporation",
                                    "units": "mm/s",
                                    "pointwidth": "1.0"
                                },
                                "QPRECL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QPRECL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "large-scale precipitation",
                                    "long_name": "large-scale precipitation",
                                    "units": "mm/s",
                                    "pointwidth": "1.0"
                                },
                                "QPRECC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QPRECC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "convective precipitation",
                                    "long_name": "convective precipitation",
                                    "units": "mm/s",
                                    "pointwidth": "1.0"
                                },
                                "QOVER": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QOVER",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "surface runoff",
                                    "long_name": "surface runoff",
                                    "units": "mm/s",
                                    "pointwidth": "1.0"
                                },
                                "QMELT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QMELT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "snow melt",
                                    "long_name": "snow melt",
                                    "units": "mm/s",
                                    "pointwidth": "1.0"
                                },
                                "QINTR": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QINTR",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "interception",
                                    "long_name": "interception",
                                    "units": "mm/s",
                                    "pointwidth": "1.0"
                                },
                                "QINFL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QINFL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "infiltration",
                                    "long_name": "infiltration",
                                    "units": "mm/s",
                                    "pointwidth": "1.0"
                                },
                                "QGCM": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QGCM",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "atmospheric specific humidity",
                                    "long_name": "atmospheric specific humidity",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "QDRIP": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QDRIP",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "throughfall",
                                    "long_name": "throughfall",
                                    "units": "mm/s",
                                    "pointwidth": "1.0"
                                },
                                "QDRAI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QDRAI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "sub-surface drainage",
                                    "long_name": "sub-surface drainage",
                                    "units": "mm/s",
                                    "pointwidth": "1.0"
                                },
                                "PGCM": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PGCM",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "atmospheric pressure",
                                    "long_name": "atmospheric pressure",
                                    "units": "Pa",
                                    "pointwidth": "1.0"
                                },
                                "parameters": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "parameters",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "nhtfrq": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nhtfrq",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "frequency of model writes (timesteps)",
                                        "units": "unitless"
                                    },
                                    "msbase": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "msbase",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "seconds to complete base day",
                                        "units": "s"
                                    },
                                    "mdbase": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mdbase",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "base day for this case",
                                        "units": "unitless"
                                    },
                                    "mbsec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mbsec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "seconds to complete base date",
                                        "units": "s"
                                    },
                                    "mbdate": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mbdate",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "base date as 6 digit integer (YYMMDD)",
                                        "units": "unitless"
                                    },
                                    "inifil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "inifil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "input initial data",
                                        "units": "unitless"
                                    },
                                    "flnfil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "flnfil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "fractional land data",
                                        "units": "unitless"
                                    },
                                    "dtlsm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dtlsm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491350400",
                                        "long_name": "model timestep",
                                        "units": "s",
                                        "pointwidth": "1.0"
                                    },
                                    "datesec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "datesec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491350400",
                                        "long_name": "seconds into current date",
                                        "units": "s",
                                        "pointwidth": "1.0"
                                    },
                                    "date": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "date",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491350400",
                                        "long_name": "current date as 6 digit integer (YYMMDD)",
                                        "units": "unitless",
                                        "pointwidth": "1.0"
                                    }
                                },
                                "NDVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "NDVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "surface ndvi",
                                    "long_name": "surface ndvi",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "mask2d": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mask2d",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "reduced grid 2d mask array",
                                    "units": "unitless"
                                },
                                "L_DOWN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "L_DOWN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "incident longwave radiation",
                                    "long_name": "incident longwave radiation",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "H2OSOI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "H2OSOI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "multi_level",
                                    "Title": "volumetric soil water",
                                    "long_name": "surface temperature at height z0h+d",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "H2OSNO": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "H2OSNO",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "snow depth (liquid water)",
                                    "long_name": "snow depth (liquid water)",
                                    "units": "mm",
                                    "pointwidth": "1.0"
                                },
                                "H2OCAN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "H2OCAN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "intercepted water",
                                    "long_name": "intercepted water",
                                    "units": "mm",
                                    "pointwidth": "1.0"
                                },
                                "FSR": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSR",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "reflected solar radiation",
                                    "long_name": "reflected solar radiation",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSM": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSM",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "snow melt heat flux",
                                    "long_name": "snow melt heat flux",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSH": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSH",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "sensible heat",
                                    "long_name": "sensible heat",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSA": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSA",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "absorbed solar radiation",
                                    "long_name": "absorbed solar radiation",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FRMS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FRMS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "stem maintenance respiration",
                                    "long_name": "stem maintenance respiration",
                                    "units": "micro mol/(m2 s)",
                                    "pointwidth": "1.0"
                                },
                                "FRMR": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FRMR",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "root maintenance respiration",
                                    "long_name": "root maintenance respiration",
                                    "units": "micro mol/(m2 s)",
                                    "pointwidth": "1.0"
                                },
                                "FRMF": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FRMF",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "foliage maintenance respiration",
                                    "long_name": "foliage maintenance respiration",
                                    "units": "micro mol/(m2 s)",
                                    "pointwidth": "1.0"
                                },
                                "FRG": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FRG",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "growth respiration",
                                    "long_name": "growth respiration",
                                    "units": "micro mol/(m2 s)",
                                    "pointwidth": "1.0"
                                },
                                "FPSN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FPSN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "photosynthesis",
                                    "long_name": "photosynthesis",
                                    "units": "micro mol/(m2 s)",
                                    "pointwidth": "1.0"
                                },
                                "FMICR": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FMICR",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "microbial respiration",
                                    "long_name": "microbial respiration",
                                    "units": "micro mol/(m2 s)",
                                    "pointwidth": "1.0"
                                },
                                "FLH": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FLH",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "latent heat",
                                    "long_name": "latent heat",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FIRE": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FIRE",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "emitted infrared (longwave) radiation",
                                    "long_name": "emitted infrared (longwave) radiation",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FIRA": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FIRA",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "net infrared (longwave) radiation",
                                    "long_name": "net infrared (longwave) radiation",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FGR": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FGR",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "heat flux into soil",
                                    "long_name": "heat flux into soil",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FGEV": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FGEV",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "ground evaporation",
                                    "long_name": "ground evaporation",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FCTR": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FCTR",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "canopy transpiration",
                                    "long_name": "canopy transpiration",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FCO2": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FCO2",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "net co2 flux",
                                    "long_name": "net co2 flux",
                                    "units": "micro mol/(m2 s)",
                                    "pointwidth": "1.0"
                                },
                                "FCEV": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FCEV",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "canopy evaporation",
                                    "long_name": "canopy evaporation",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "EVAP": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "EVAP",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "total evaporative flux",
                                    "long_name": "total evaporative flux",
                                    "units": "kg/m2/s",
                                    "pointwidth": "1.0"
                                },
                                "ESAI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ESAI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "exposed one-sided stem area index",
                                    "long_name": "exposed one-sided stem area index",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "ERRSOL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ERRSOL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "solar radiation conservation error",
                                    "long_name": "solar radiation conservation error",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "ERRSOI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ERRSOI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "soil/lake energy conservation error",
                                    "long_name": "soil/lake energy conservation error",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "ERRSEB": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ERRSEB",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "surface energy conservation error",
                                    "long_name": "surface energy conservation error",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "ERRH2O": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ERRH2O",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "total water conservation error",
                                    "long_name": "total water conservation error",
                                    "units": "mm",
                                    "pointwidth": "1.0"
                                },
                                "ELAI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ELAI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "exposed one-sided leaf area index",
                                    "long_name": "exposed one-sided leaf area index",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "DTV": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "DTV",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "change in tv last iteration",
                                    "long_name": "change in tv last iteration",
                                    "units": "Kelvin_scale",
                                    "pointwidth": "1.0"
                                },
                                "DTG": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "DTG",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "change in tg last iteration",
                                    "long_name": "change in tg last iteration",
                                    "units": "Kelvin_scale",
                                    "pointwidth": "1.0"
                                },
                                "DMI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "DMI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "net primary production",
                                    "long_name": "net primary production",
                                    "units": "micro g/(m2 s)",
                                    "pointwidth": "1.0"
                                },
                                "CN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "neutral momentum drag coefficient",
                                    "long_name": "neutral momentum drag coefficient",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "CM": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CM",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "momentum drag coefficient",
                                    "long_name": "momentum drag coefficient",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "BTRAN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "BTRAN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "transpiration beta factor",
                                    "long_name": "transpiration beta factor",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "BEVAP": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "BEVAP",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "ground evaporation beta factor",
                                    "long_name": "ground evaporation beta factor",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "BASIN_RUNOFF": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "BASIN_RUNOFF",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "long_name": "total runoff to various basins",
                                    "units": "kg/sec",
                                    "pointwidth": "1.0"
                                },
                                "basin_name": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "basin_name",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "expires": "1491350400"
                                },
                                "ASDIR": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ASDIR",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "albedo solar - direct",
                                    "long_name": "albedo solar - direct",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "ASDIF": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ASDIF",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "albedo - solar diffuse",
                                    "long_name": "albedo - solar diffuse",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "ALDIR": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALDIR",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "albedo longwave - direct",
                                    "long_name": "albedo longwave - direct",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "ALDIF": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALDIF",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "1.00000002E30",
                                    "field_type": "average",
                                    "level_flag": "single_level",
                                    "Title": "albedo - longwve diffuse",
                                    "long_name": "albedo - longwve diffuse",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                }
                            },
                            "hybrid_lev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hybrid_lev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "Z3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Geopotential Height (above sea level)",
                                    "units": "m",
                                    "pointwidth": "1.0"
                                },
                                "VT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Meridional heat transport",
                                    "units": "Km/s",
                                    "pointwidth": "1.0"
                                },
                                "VQ": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VQ",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Meridional water transport",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "V": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "V",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "meridional wind",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "U": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "U",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "zonal wind",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "temp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "temp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "temperature",
                                    "units": "Kelvin_scale",
                                    "pointwidth": "1.0"
                                },
                                "SETLWP": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SETLWP",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Specified liquid water path lengths",
                                    "units": "G/M2",
                                    "pointwidth": "1.0"
                                },
                                "RELHUM": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "RELHUM",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Relative humidity",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "QRS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QRS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Solar heating rate",
                                    "units": "degree_Kelvin/s",
                                    "pointwidth": "1.0"
                                },
                                "QRL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QRL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Longwave heating rate",
                                    "units": "degree_Kelvin/s",
                                    "pointwidth": "1.0"
                                },
                                "Q": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Q",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Q constituent tracer",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "OMEGA": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "OMEGA",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Vertical velocity (pressure)",
                                    "units": "Pa/s",
                                    "pointwidth": "1.0"
                                },
                                "MQ": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "MQ",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Water vapor mass in layer",
                                    "units": "kg/m2",
                                    "pointwidth": "1.0"
                                },
                                "hybm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "hybrid B coefficient at layer midpoints",
                                    "units": "unitless"
                                },
                                "hybi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "hybrid B coefficient at layer interfaces",
                                    "units": "unitless"
                                },
                                "hyam": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hyam",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "hybrid A coefficient at layer midpoints",
                                    "units": "unitless"
                                },
                                "hyai": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hyai",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "hybrid A coefficient at layer interfaces",
                                    "units": "unitless"
                                },
                                "ETADOT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ETADOT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "vertical (eta) velocity",
                                    "units": "1/S",
                                    "pointwidth": "1.0"
                                },
                                "EFFCLD": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "EFFCLD",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Effective cloud fraction",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "CLOUD": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CLOUD",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491350400",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Cloud fraction",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                }
                            }
                        },
                        "DAILY": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "DAILY",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "total_air_column": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "total_air_column",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "CLDTOT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CLDTOT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Vertically-integrated total cloud",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "CLDMED": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CLDMED",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Vertically-integrated mid-level cloud",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "CLDLOW": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CLDLOW",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Vertically-integrated low cloud",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "CLDHGH": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CLDHGH",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Vertically-integrated high cloud",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                }
                            },
                            "top": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "top",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "FSNTC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSNTC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Clearsky net solar flux at top",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSNT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSNT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Net solar flux at top",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FLNTC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FLNTC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Clearsky net longwave flux at top",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FLNT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FLNT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Net longwave flux at top",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                }
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "TS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Surface temperature",
                                    "units": "Kelvin_scale",
                                    "pointwidth": "1.0"
                                },
                                "TAUY": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TAUY",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "meridional surface stress",
                                    "units": "Pa",
                                    "pointwidth": "1.0"
                                },
                                "TAUX": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TAUX",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "zonal surface stress",
                                    "units": "Pa",
                                    "pointwidth": "1.0"
                                },
                                "SNOWH": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SNOWH",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Water equivalent snow depth",
                                    "units": "m",
                                    "pointwidth": "1.0"
                                },
                                "SHFLX": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SHFLX",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Surface sensible heat flux",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "PSL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PSL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Sea level pressure",
                                    "units": "Pa",
                                    "pointwidth": "1.0"
                                },
                                "PS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "surface pressure",
                                    "units": "Pa",
                                    "pointwidth": "1.0"
                                },
                                "PRECL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PRECL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Large-scale (stable) precipitation rate",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "PRECC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PRECC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Convective precipitation rate",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "total precipitation rate",
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "pointwidth": "1.0",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average"
                                },
                                "LHFLX": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "LHFLX",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Surface latent heat flux",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSNSC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSNSC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Clearsky net solar flux at surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSNS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSNS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Net solar flux at surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FSDS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FSDS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Flux Shortwave Downwelling Surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FLNSC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FLNSC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Clearsky net longwave flux at surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                },
                                "FLNS": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "FLNS",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Net longwave flux at surface",
                                    "units": "W/m2",
                                    "pointwidth": "1.0"
                                }
                            },
                            "PressureLevel": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PressureLevel",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "Z3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "history": "toS: regridded lev to IRI FD CCM3v6 History ensemble DAILY hybrid_lev P",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Geopotential Height (above sea level)",
                                    "units": "m",
                                    "pointwidth": "1.0"
                                },
                                "V": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "V",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "history": "toS: regridded lev to IRI FD CCM3v6 History ensemble DAILY hybrid_lev P",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "meridional wind",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "U": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "U",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "history": "toS: regridded lev to IRI FD CCM3v6 History ensemble DAILY hybrid_lev P",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "zonal wind",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "temp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "temp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "history": "toS: regridded lev to IRI FD CCM3v6 History ensemble DAILY hybrid_lev P",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "temperature",
                                    "units": "Kelvin_scale",
                                    "pointwidth": "1.0"
                                },
                                "RELHUM": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "RELHUM",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "history": "toS: regridded lev to IRI FD CCM3v6 History ensemble DAILY hybrid_lev P",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Relative humidity",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                }
                            },
                            "parameters": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "parameters",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "time_written": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "time_written",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "P0": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P0",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "reference pressure",
                                    "units": "Pa"
                                },
                                "ntrn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ntrn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "spectral truncation parameter N",
                                    "units": "unitless"
                                },
                                "ntrm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ntrm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "spectral truncation parameter M",
                                    "units": "unitless"
                                },
                                "ntrk": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ntrk",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "spectral truncation parameter K",
                                    "units": "unitless"
                                },
                                "nsteph": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "nsteph",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "current timestep",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "nscur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "nscur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "current seconds of current day",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "nsbase": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "nsbase",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "seconds of base day",
                                    "units": "unitless"
                                },
                                "ndcur": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ndcur",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "current day (from base day)",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "ndbase": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ndbase",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "base day",
                                    "units": "unitless"
                                },
                                "nbsec": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "nbsec",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "seconds of base date",
                                    "units": "unitless"
                                },
                                "nbdate": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "nbdate",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "base date (YYYYMMDD)",
                                    "units": "unitless"
                                },
                                "mdt": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mdt",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "timestep",
                                    "units": "s"
                                },
                                "gw": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "gw",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "gauss weights",
                                    "units": "unitless"
                                },
                                "datesec": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "datesec",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "current seconds of current date",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "date_written": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "date_written",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "date": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "date",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "current date (YYYYMMDD)",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                }
                            },
                            "hybrid_lev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hybrid_lev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "Z3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Geopotential Height (above sea level)",
                                    "units": "m",
                                    "pointwidth": "1.0"
                                },
                                "V": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "V",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "meridional wind",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "U": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "U",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "zonal wind",
                                    "units": "m/s",
                                    "pointwidth": "1.0"
                                },
                                "temp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "temp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "temperature",
                                    "units": "Kelvin_scale",
                                    "pointwidth": "1.0"
                                },
                                "RELHUM": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "RELHUM",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Relative humidity",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "Q": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Q",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Q constituent tracer",
                                    "units": "unitless",
                                    "pointwidth": "1.0"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Pressure",
                                    "units": "mb",
                                    "missing_value": "NaN",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "pointwidth": "1.0"
                                },
                                "OMEGA": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "OMEGA",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Vertical velocity (pressure)",
                                    "units": "Pa/s",
                                    "pointwidth": "1.0"
                                },
                                "hybm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "hybrid B coefficient at layer midpoints",
                                    "units": "unitless"
                                },
                                "hybi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "hybrid B coefficient at layer interfaces",
                                    "units": "unitless"
                                },
                                "hyam": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hyam",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "hybrid A coefficient at layer midpoints",
                                    "units": "unitless"
                                },
                                "hyai": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hyai",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "hybrid A coefficient at layer interfaces",
                                    "units": "unitless"
                                },
                                "ETADOT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ETADOT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "vertical (eta) velocity",
                                    "units": "1/s",
                                    "pointwidth": "1.0"
                                }
                            },
                            "above_ground": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "above_ground",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "TREFHT": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TREFHT",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "long_name": "Reference height temperature",
                                    "units": "Kelvin_scale",
                                    "pointwidth": "1.0"
                                }
                            }
                        }
                    },
                    "climatology": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "climatology",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "c7100": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "c7100",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "zg": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "zg",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "history": "Averaged over T2[1971, 2000] minimum 0.0% data present",
                                "missing_value": "NaN",
                                "units": "m",
                                "file_missing_value": "9.99999962E35",
                                "time_op": "average",
                                "long_name": "Geopotential Height (above sea level)",
                                "pointwidth": "1.0"
                            },
                            "t2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "t2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Kelvin_scale",
                                "long_name": "temperature at 2m"
                            },
                            "prcp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "prcp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/day",
                                "long_name": "precipitation rate"
                            }
                        },
                        "c6998": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "c6998",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "t2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "t2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Kelvin_scale",
                                "long_name": "temperature at 2m"
                            },
                            "prcp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "prcp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/day",
                                "long_name": "precipitation rate"
                            }
                        }
                    }
                },
                "Forecast": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "ssst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ssst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ensemble": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ensemble",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "monthly": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "monthly",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "zg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "zg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "geopotential height",
                                    "units": "m",
                                    "missing_value": "NaN",
                                    "history": "toS: regridded lev to IRI FD CCM3v6 Forecast ssst ensemble MONTHLY hybrid_lev P",
                                    "file_missing_value": "9.99999962E35",
                                    "expires": "1491307200",
                                    "time_op": "average",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Temperature at 2m",
                                    "units": "Kelvin_scale",
                                    "expires": "1491307200",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Forecast Time",
                                    "pointwidth": "1",
                                    "expires": "1491307200",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "precipitation rate",
                                    "units": "m/s",
                                    "missing_value": "NaN",
                                    "expires": "1491307200",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "pointwidth": "0"
                                }
                            },
                            "MONTHLY": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MONTHLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "CNVCLD": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CNVCLD",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Total convective cloud amount",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "CLDTOT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLDTOT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Vertically-integrated total cloud",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "CLDMED": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLDMED",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Vertically-integrated mid-level cloud",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "CLDLOW": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLDLOW",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Vertically-integrated low cloud",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "CLDHGH": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLDHGH",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Vertically-integrated high cloud",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    }
                                },
                                "toa": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "toa",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "FSNTC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNTC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Clearsky net solar flux at top",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSNT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net solar flux at top",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSNRTC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNRTC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Clear-sky Flux Shortwave Near-IR Absorbed at toa",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSNIRTSQ": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNIRTSQ",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Flux Shortwave Near-IR Absorbed at toa >= 0.7 microns",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSNIRT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNIRT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Flux Shortwave Near-IR Absorbed at TOA",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "USTAR": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "USTAR",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Surface friction velocity",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "TS4": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TS4",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "TS4      subsoil temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "TS3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TS3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "TS3      subsoil temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "TS2": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TS2",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "TS2      subsoil temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "TS1": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TS1",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "TS1      subsoil temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "TS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Surface temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "TREFHT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TREFHT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Reference height temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "TAUY": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TAUY",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "meridional surface stress",
                                        "units": "Pa",
                                        "pointwidth": "0"
                                    },
                                    "TAUX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TAUX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "zonal surface stress",
                                        "units": "Pa",
                                        "pointwidth": "0"
                                    },
                                    "SRFRAD": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRFRAD",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net radiative flux at surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "SOLSD": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SOLSD",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Solar downward visible diffuse to surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "SOLS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SOLS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Solar downward visible direct  to surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "SOLLD": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SOLLD",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Solar downward near infrared diffuse to surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "SOLL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SOLL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Solar downward near infrared direct  to surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "SOLIN": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SOLIN",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Solar insolation",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "SNOWH": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SNOWH",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Water equivalent snow depth",
                                        "units": "m",
                                        "pointwidth": "0"
                                    },
                                    "SICTHK": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SICTHK",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "sea ice thickness",
                                        "units": "m",
                                        "pointwidth": "0"
                                    },
                                    "SHFLX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SHFLX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Surface sensible heat flux",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "QFLX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QFLX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Surface water flux",
                                        "units": "kg/m2/s",
                                        "pointwidth": "0"
                                    },
                                    "PSL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PSL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Sea level pressure",
                                        "units": "Pa",
                                        "pointwidth": "0"
                                    },
                                    "PS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "surface pressure",
                                        "units": "Pa",
                                        "pointwidth": "0"
                                    },
                                    "PRECSL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PRECSL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Large-scale (stable) snow rate (water equivalent)",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "PRECSC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PRECSC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Convective snow rate (water equivalent)",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "PRECL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PRECL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Large-scale (stable) precipitation rate",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "PRECC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PRECC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Convective precipitation rate",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "PHIS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PHIS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "instantaneous",
                                        "long_name": "surface geopotential",
                                        "units": "m2/s2",
                                        "pointwidth": "0"
                                    },
                                    "PBLH": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PBLH",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "PBL height",
                                        "units": "m",
                                        "pointwidth": "0"
                                    },
                                    "ORO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ORO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "instantaneous",
                                        "long_name": "ocean (0), land (1), sea ice (2) flag",
                                        "units": "FLAG",
                                        "pointwidth": "0"
                                    },
                                    "LWSH": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "LWSH",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Liquid water scale height",
                                        "units": "m",
                                        "pointwidth": "0"
                                    },
                                    "LHFLX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "LHFLX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Surface latent heat flux",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSNSC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNSC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Clearsky net solar flux at surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSNS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net solar flux at surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSDS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSDS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Flux Shortwave Downwelling Surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "forecasttime": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "forecasttime",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "calendar": "360",
                                        "long_name": "Forecast Time",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0",
                                        "standard_name": "time"
                                    },
                                    "FLNTC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FLNTC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Clearsky net longwave flux at top",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FLNT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FLNT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net longwave flux at top",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FLNSC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FLNSC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Clearsky net longwave flux at surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FLNS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FLNS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net longwave flux at surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "Z3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "history": "toS: regridded lev to IRI FD CCM3v6 Forecast ssst ensemble MONTHLY hybrid_lev P",
                                        "file_missing_value": "9.99999962E35",
                                        "expires": "1491307200",
                                        "time_op": "average",
                                        "long_name": "Geopotential Height (above sea level)",
                                        "units": "m",
                                        "pointwidth": "0"
                                    }
                                },
                                "parameters": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "parameters",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "time_written": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "time_written",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "P0": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P0",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "reference pressure",
                                        "units": "Pa"
                                    },
                                    "ntrn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ntrn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "spectral truncation parameter N",
                                        "units": "unitless"
                                    },
                                    "ntrm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ntrm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "spectral truncation parameter M",
                                        "units": "unitless"
                                    },
                                    "ntrk": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ntrk",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "spectral truncation parameter K",
                                        "units": "unitless"
                                    },
                                    "nsteph": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nsteph",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "long_name": "current timestep",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "nscur": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nscur",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "long_name": "current seconds of current day",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "nsbase": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nsbase",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "seconds of base day",
                                        "units": "unitless"
                                    },
                                    "ndcur": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ndcur",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "long_name": "current day (from base day)",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "ndbase": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ndbase",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "base day",
                                        "units": "unitless"
                                    },
                                    "nbsec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nbsec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "seconds of base date",
                                        "units": "unitless"
                                    },
                                    "nbdate": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nbdate",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "base date (YYYYMMDD)",
                                        "units": "unitless"
                                    },
                                    "mdt": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mdt",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "timestep",
                                        "units": "s"
                                    },
                                    "gw": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gw",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "gauss weights",
                                        "units": "unitless"
                                    },
                                    "datesec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "datesec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "long_name": "current seconds of current date",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "date_written": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "date_written",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "date": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "date",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "long_name": "current date (YYYYMMDD)",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "Z3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Geopotential Height (above sea level)",
                                        "units": "m",
                                        "pointwidth": "0"
                                    },
                                    "VT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "VT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Meridional heat transport",
                                        "units": "Km/s",
                                        "pointwidth": "0"
                                    },
                                    "VQ": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "VQ",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Meridional water transport",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "V": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "V",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "meridional wind",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "zonal wind",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "temp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "temp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "SETLWP": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SETLWP",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Specified liquid water path lengths",
                                        "units": "G/M2",
                                        "pointwidth": "0"
                                    },
                                    "RELHUM": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "RELHUM",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Relative humidity",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "QRS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QRS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Solar heating rate",
                                        "units": "degree_Kelvin/s",
                                        "pointwidth": "0"
                                    },
                                    "QRL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QRL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Longwave heating rate",
                                        "units": "degree_Kelvin/s",
                                        "pointwidth": "0"
                                    },
                                    "Q": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Q",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Q constituent tracer",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "air_pressure",
                                        "long_name": "Pressure",
                                        "missing_value": "NaN",
                                        "expires": "1491307200",
                                        "units": "Pa",
                                        "file_missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "pointwidth": "0"
                                    },
                                    "OMEGA": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "OMEGA",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Vertical velocity (pressure)",
                                        "units": "Pa/s",
                                        "pointwidth": "0"
                                    },
                                    "MQ": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "MQ",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Water vapor mass in layer",
                                        "units": "kg/m2",
                                        "pointwidth": "0"
                                    },
                                    "hybm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "hybrid B coefficient at layer midpoints",
                                        "units": "unitless"
                                    },
                                    "hybi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "hybrid B coefficient at layer interfaces",
                                        "units": "unitless"
                                    },
                                    "hyam": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hyam",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "hybrid A coefficient at layer midpoints",
                                        "units": "unitless"
                                    },
                                    "hyai": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hyai",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "hybrid A coefficient at layer interfaces",
                                        "units": "unitless"
                                    },
                                    "ETADOT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ETADOT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "vertical (eta) velocity",
                                        "units": "1/S",
                                        "pointwidth": "0"
                                    },
                                    "EFFCLD": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "EFFCLD",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Effective cloud fraction",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "CLOUD": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLOUD",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Cloud fraction",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    }
                                },
                                "forecasttime": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "forecasttime",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491307200",
                                    "calendar": "360",
                                    "long_name": "Forecast Time",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0",
                                    "standard_name": "time"
                                }
                            }
                        }
                    },
                    "psst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "psst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ensemble": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ensemble",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "monthly": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "monthly",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "zg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "zg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "geopotential height",
                                    "units": "m",
                                    "missing_value": "NaN",
                                    "history": "toS: regridded lev to IRI FD CCM3v6 Forecast psst ensemble MONTHLY hybrid_lev P",
                                    "file_missing_value": "9.99999962E35",
                                    "expires": "1491307200",
                                    "time_op": "average",
                                    "pointwidth": "0"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Temperature at 2m",
                                    "units": "Kelvin_scale",
                                    "expires": "1491307200",
                                    "missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "pointwidth": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Forecast Time",
                                    "pointwidth": "1",
                                    "expires": "1491307200",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "precipitation rate",
                                    "units": "m/s",
                                    "missing_value": "NaN",
                                    "expires": "1491307200",
                                    "file_missing_value": "9.99999962E35",
                                    "time_op": "average",
                                    "pointwidth": "0"
                                }
                            },
                            "MONTHLY": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MONTHLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "CNVCLD": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CNVCLD",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Total convective cloud amount",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "CLDTOT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLDTOT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Vertically-integrated total cloud",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "CLDMED": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLDMED",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Vertically-integrated mid-level cloud",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "CLDLOW": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLDLOW",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Vertically-integrated low cloud",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "CLDHGH": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLDHGH",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Vertically-integrated high cloud",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    }
                                },
                                "toa": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "toa",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "FSNTC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNTC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Clearsky net solar flux at top",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSNT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net solar flux at top",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSNRTC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNRTC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Clear-sky Flux Shortwave Near-IR Absorbed at toa",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSNIRTSQ": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNIRTSQ",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Flux Shortwave Near-IR Absorbed at toa >= 0.7 microns",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSNIRT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNIRT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Flux Shortwave Near-IR Absorbed at TOA",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "USTAR": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "USTAR",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Surface friction velocity",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "TS4": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TS4",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "TS4      subsoil temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "TS3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TS3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "TS3      subsoil temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "TS2": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TS2",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "TS2      subsoil temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "TS1": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TS1",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "TS1      subsoil temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "TS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Surface temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "TREFHT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TREFHT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Reference height temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "TAUY": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TAUY",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "meridional surface stress",
                                        "units": "Pa",
                                        "pointwidth": "0"
                                    },
                                    "TAUX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TAUX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "zonal surface stress",
                                        "units": "Pa",
                                        "pointwidth": "0"
                                    },
                                    "SRFRAD": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRFRAD",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net radiative flux at surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "SOLSD": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SOLSD",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Solar downward visible diffuse to surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "SOLS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SOLS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Solar downward visible direct  to surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "SOLLD": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SOLLD",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Solar downward near infrared diffuse to surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "SOLL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SOLL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Solar downward near infrared direct  to surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "SOLIN": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SOLIN",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Solar insolation",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "SNOWH": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SNOWH",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Water equivalent snow depth",
                                        "units": "m",
                                        "pointwidth": "0"
                                    },
                                    "SICTHK": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SICTHK",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "sea ice thickness",
                                        "units": "m",
                                        "pointwidth": "0"
                                    },
                                    "SHFLX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SHFLX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Surface sensible heat flux",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "QFLX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QFLX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Surface water flux",
                                        "units": "kg/m2/s",
                                        "pointwidth": "0"
                                    },
                                    "PSL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PSL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Sea level pressure",
                                        "units": "Pa",
                                        "pointwidth": "0"
                                    },
                                    "PS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "surface pressure",
                                        "units": "Pa",
                                        "pointwidth": "0"
                                    },
                                    "PRECSL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PRECSL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Large-scale (stable) snow rate (water equivalent)",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "PRECSC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PRECSC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Convective snow rate (water equivalent)",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "PRECL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PRECL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Large-scale (stable) precipitation rate",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "PRECC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PRECC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Convective precipitation rate",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "PHIS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PHIS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "instantaneous",
                                        "long_name": "surface geopotential",
                                        "units": "m2/s2",
                                        "pointwidth": "0"
                                    },
                                    "PBLH": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PBLH",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "PBL height",
                                        "units": "m",
                                        "pointwidth": "0"
                                    },
                                    "ORO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ORO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "instantaneous",
                                        "long_name": "ocean (0), land (1), sea ice (2) flag",
                                        "units": "FLAG",
                                        "pointwidth": "0"
                                    },
                                    "LWSH": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "LWSH",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Liquid water scale height",
                                        "units": "m",
                                        "pointwidth": "0"
                                    },
                                    "LHFLX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "LHFLX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Surface latent heat flux",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSNSC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNSC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Clearsky net solar flux at surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSNS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net solar flux at surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FSDS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSDS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Flux Shortwave Downwelling Surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "forecasttime": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "forecasttime",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "calendar": "360",
                                        "long_name": "Forecast Time",
                                        "units": "months since 1960-01-01",
                                        "pointwidth": "1.0",
                                        "standard_name": "time"
                                    },
                                    "FLNTC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FLNTC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Clearsky net longwave flux at top",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FLNT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FLNT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net longwave flux at top",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FLNSC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FLNSC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Clearsky net longwave flux at surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    },
                                    "FLNS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FLNS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net longwave flux at surface",
                                        "units": "W/m2",
                                        "pointwidth": "0"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "Z3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "history": "toS: regridded lev to IRI FD CCM3v6 Forecast psst ensemble MONTHLY hybrid_lev P",
                                        "file_missing_value": "9.99999962E35",
                                        "expires": "1491307200",
                                        "time_op": "average",
                                        "long_name": "Geopotential Height (above sea level)",
                                        "units": "m",
                                        "pointwidth": "0"
                                    }
                                },
                                "parameters": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "parameters",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "time_written": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "time_written",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "P0": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P0",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "reference pressure",
                                        "units": "Pa"
                                    },
                                    "ntrn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ntrn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "spectral truncation parameter N",
                                        "units": "unitless"
                                    },
                                    "ntrm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ntrm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "spectral truncation parameter M",
                                        "units": "unitless"
                                    },
                                    "ntrk": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ntrk",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "spectral truncation parameter K",
                                        "units": "unitless"
                                    },
                                    "nsteph": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nsteph",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "long_name": "current timestep",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "nscur": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nscur",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "long_name": "current seconds of current day",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "nsbase": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nsbase",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "seconds of base day",
                                        "units": "unitless"
                                    },
                                    "ndcur": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ndcur",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "long_name": "current day (from base day)",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "ndbase": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ndbase",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "base day",
                                        "units": "unitless"
                                    },
                                    "nbsec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nbsec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "seconds of base date",
                                        "units": "unitless"
                                    },
                                    "nbdate": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nbdate",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "base date (YYYYMMDD)",
                                        "units": "unitless"
                                    },
                                    "mdt": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mdt",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "timestep",
                                        "units": "s"
                                    },
                                    "gw": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gw",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "gauss weights",
                                        "units": "unitless"
                                    },
                                    "datesec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "datesec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "long_name": "current seconds of current date",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "date_written": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "date_written",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "date": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "date",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "long_name": "current date (YYYYMMDD)",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "Z3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Geopotential Height (above sea level)",
                                        "units": "m",
                                        "pointwidth": "0"
                                    },
                                    "VT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "VT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Meridional heat transport",
                                        "units": "Km/s",
                                        "pointwidth": "0"
                                    },
                                    "VQ": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "VQ",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Meridional water transport",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "V": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "V",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "meridional wind",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "zonal wind",
                                        "units": "m/s",
                                        "pointwidth": "0"
                                    },
                                    "temp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "temp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "0"
                                    },
                                    "SETLWP": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SETLWP",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Specified liquid water path lengths",
                                        "units": "G/M2",
                                        "pointwidth": "0"
                                    },
                                    "RELHUM": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "RELHUM",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Relative humidity",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "QRS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QRS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Solar heating rate",
                                        "units": "degree_Kelvin/s",
                                        "pointwidth": "0"
                                    },
                                    "QRL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QRL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Longwave heating rate",
                                        "units": "degree_Kelvin/s",
                                        "pointwidth": "0"
                                    },
                                    "Q": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Q",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Q constituent tracer",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "P_i": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P_i",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "air_pressure",
                                        "long_name": "Pressure",
                                        "missing_value": "NaN",
                                        "expires": "1491307200",
                                        "units": "Pa",
                                        "file_missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "pointwidth": "0"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "air_pressure",
                                        "long_name": "Pressure",
                                        "missing_value": "NaN",
                                        "expires": "1491307200",
                                        "units": "Pa",
                                        "file_missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "pointwidth": "0"
                                    },
                                    "OMEGA": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "OMEGA",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Vertical velocity (pressure)",
                                        "units": "Pa/s",
                                        "pointwidth": "0"
                                    },
                                    "MQ": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "MQ",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Water vapor mass in layer",
                                        "units": "kg/m2",
                                        "pointwidth": "0"
                                    },
                                    "hybm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "hybrid B coefficient at layer midpoints",
                                        "units": "unitless"
                                    },
                                    "hybi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "hybrid B coefficient at layer interfaces",
                                        "units": "unitless"
                                    },
                                    "hyam": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hyam",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "hybrid A coefficient at layer midpoints",
                                        "units": "unitless"
                                    },
                                    "hyai": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hyai",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "hybrid A coefficient at layer interfaces",
                                        "units": "unitless"
                                    },
                                    "ETADOT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ETADOT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "vertical (eta) velocity",
                                        "units": "1/S",
                                        "pointwidth": "0"
                                    },
                                    "EFFCLD": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "EFFCLD",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Effective cloud fraction",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    },
                                    "CLOUD": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLOUD",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491307200",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Cloud fraction",
                                        "units": "unitless",
                                        "pointwidth": "0"
                                    }
                                },
                                "forecasttime": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "forecasttime",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "expires": "1491307200",
                                    "calendar": "360",
                                    "long_name": "Forecast Time",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0",
                                    "standard_name": "time"
                                }
                            }
                        }
                    },
                    "ca_sst": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ca_sst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ensemble": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ensemble",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "MONTHLY": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MONTHLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "CLDTOT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLDTOT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Vertically-integrated total cloud",
                                        "units": "unitless",
                                        "pointwidth": "1.0"
                                    }
                                },
                                "toa": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "toa",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "FSNT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net solar flux at top",
                                        "units": "W/m2",
                                        "pointwidth": "1.0"
                                    },
                                    "FLNT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FLNT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net longwave flux at top",
                                        "units": "W/m2",
                                        "pointwidth": "1.0"
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "TS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Surface temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "1.0"
                                    },
                                    "TAUY": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TAUY",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "meridional surface stress",
                                        "units": "Pa",
                                        "pointwidth": "1.0"
                                    },
                                    "TAUX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TAUX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "zonal surface stress",
                                        "units": "Pa",
                                        "pointwidth": "1.0"
                                    },
                                    "SHFLX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SHFLX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Surface sensible heat flux",
                                        "units": "W/m2",
                                        "pointwidth": "1.0"
                                    },
                                    "PRECL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PRECL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Large-scale (stable) precipitation rate",
                                        "units": "m/s",
                                        "pointwidth": "1.0"
                                    },
                                    "PRECC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PRECC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Convective precipitation rate",
                                        "units": "m/s",
                                        "pointwidth": "1.0"
                                    },
                                    "ORO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ORO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "instantaneous",
                                        "long_name": "ocean (0), land (1), sea ice (2) flag",
                                        "units": "FLAG",
                                        "pointwidth": "1.0"
                                    },
                                    "LHFLX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "LHFLX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Surface latent heat flux",
                                        "units": "W/m2",
                                        "pointwidth": "1.0"
                                    },
                                    "FSNS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FSNS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net solar flux at surface",
                                        "units": "W/m2",
                                        "pointwidth": "1.0"
                                    },
                                    "FLNS": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FLNS",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Net longwave flux at surface",
                                        "units": "W/m2",
                                        "pointwidth": "1.0"
                                    }
                                },
                                "parameters": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "parameters",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "time_written": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "time_written",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "units": "unitless",
                                        "pointwidth": "1.0"
                                    },
                                    "P0": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P0",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "reference pressure",
                                        "units": "Pa"
                                    },
                                    "ntrn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ntrn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "spectral truncation parameter N",
                                        "units": "unitless"
                                    },
                                    "ntrm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ntrm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "spectral truncation parameter M",
                                        "units": "unitless"
                                    },
                                    "ntrk": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ntrk",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "spectral truncation parameter K",
                                        "units": "unitless"
                                    },
                                    "nsteph": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nsteph",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "long_name": "current timestep",
                                        "units": "unitless",
                                        "pointwidth": "1.0"
                                    },
                                    "nscur": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nscur",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "long_name": "current seconds of current day",
                                        "units": "unitless",
                                        "pointwidth": "1.0"
                                    },
                                    "nsbase": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nsbase",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "seconds of base day",
                                        "units": "unitless"
                                    },
                                    "ndcur": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ndcur",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "long_name": "current day (from base day)",
                                        "units": "unitless",
                                        "pointwidth": "1.0"
                                    },
                                    "ndbase": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ndbase",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "base day",
                                        "units": "unitless"
                                    },
                                    "nbsec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nbsec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "seconds of base date",
                                        "units": "unitless"
                                    },
                                    "nbdate": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nbdate",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "base date (YYYYMMDD)",
                                        "units": "unitless"
                                    },
                                    "mdt": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "mdt",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "timestep",
                                        "units": "s"
                                    },
                                    "gw": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gw",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "gauss weights",
                                        "units": "unitless"
                                    },
                                    "datesec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "datesec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "long_name": "current seconds of current date",
                                        "units": "unitless",
                                        "pointwidth": "1.0"
                                    },
                                    "date_written": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "date_written",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "units": "unitless",
                                        "pointwidth": "1.0"
                                    },
                                    "date": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "date",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "long_name": "current date (YYYYMMDD)",
                                        "units": "unitless",
                                        "pointwidth": "1.0"
                                    }
                                },
                                "mean_sea_level": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mean_sea_level",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "PSL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PSL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Sea level pressure",
                                        "units": "Pa",
                                        "pointwidth": "1.0"
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "Z3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Geopotential Height (above sea level)",
                                        "units": "m",
                                        "pointwidth": "1.0"
                                    },
                                    "V": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "V",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "meridional wind",
                                        "units": "m/s",
                                        "pointwidth": "1.0"
                                    },
                                    "U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "zonal wind",
                                        "units": "m/s",
                                        "pointwidth": "1.0"
                                    },
                                    "temp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "temp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "1.0"
                                    },
                                    "RELHUM": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "RELHUM",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Relative humidity",
                                        "units": "unitless",
                                        "pointwidth": "1.0"
                                    },
                                    "Q": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Q",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Q constituent tracer",
                                        "units": "unitless",
                                        "pointwidth": "1.0"
                                    },
                                    "OMEGA": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "OMEGA",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Vertical velocity (pressure)",
                                        "units": "Pa/s",
                                        "pointwidth": "1.0"
                                    },
                                    "hybm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "hybrid B coefficient at layer midpoints",
                                        "units": "unitless"
                                    },
                                    "hybi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "hybrid B coefficient at layer interfaces",
                                        "units": "unitless"
                                    },
                                    "hyam": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hyam",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "hybrid A coefficient at layer midpoints",
                                        "units": "unitless"
                                    },
                                    "hyai": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hyai",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "hybrid A coefficient at layer interfaces",
                                        "units": "unitless"
                                    }
                                },
                                "forecasttime": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "forecasttime",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "standard_name": "time",
                                    "long_name": "Forecast Time",
                                    "expires": "1491004800",
                                    "calendar": "360",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "1.0"
                                },
                                "above_ground": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "above_ground",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "TREFHT": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TREFHT",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491004800",
                                        "missing_value": "9.99999962E35",
                                        "time_op": "average",
                                        "long_name": "Reference height temperature",
                                        "units": "Kelvin_scale",
                                        "pointwidth": "1.0"
                                    }
                                }
                            }
                        }
                    }
                },
                "T_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "time_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "time_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "1.0"
                },
                "lev_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lev_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "basins": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "basins",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "time_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "time_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1491350400",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "time": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "time",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "days since 1946-01-01 00:00:00",
                    "gridtype": "0",
                    "calendar": "365",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "P_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "P_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "mb",
                    "gridtype": "0",
                    "long_name": "Pressure"
                },
                "X_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "standard_name": "longitude",
                    "pointwidth": "2.8125"
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulo": "12.0",
                    "modulus": "12.0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "L_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "long_name": "lead time",
                    "standard_name": "forecast_period",
                    "pointwidth": "1.0"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "standard_name": "longitude",
                    "pointwidth": "2.8125"
                },
                "P": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "P",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "mb",
                    "gridtype": "0",
                    "long_name": "Pressure"
                },
                "L_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "long_name": "lead time",
                    "standard_name": "forecast_period",
                    "pointwidth": "1.0"
                },
                "S_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1491307200",
                    "calendar": "360",
                    "standard_name": "forecast_reference_time",
                    "long_name": "start time",
                    "pointwidth": "0"
                },
                "lev": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lev",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "hybrid_sigma_pressure",
                    "gridtype": "0"
                },
                "ilev": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ilev",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "hybrid_sigma_pressure",
                    "gridtype": "0"
                },
                "L": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "long_name": "lead time",
                    "standard_name": "forecast_period",
                    "pointwidth": "1.0"
                },
                "S": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1491004800",
                    "calendar": "360",
                    "standard_name": "forecast_reference_time",
                    "long_name": "start time",
                    "pointwidth": "0"
                },
                "M": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "M",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "lon": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lon",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "standard_name": "longitude",
                    "pointwidth": "2.8125"
                },
                "lat": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "lat",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude"
                },
                "dir": "SOURCES/IRI/FD/CCM3v6"
            },
            "COLA": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "COLA",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "T63Historyclimatologyc7100long_name": "1971-2000",
                    "T63Historyclimatologyc6998long_name": "1969-1998",
                    "T63HistoryclimatologyiridlhasSemantics": "iridl:climatology",
                    "T63Forecastssstensemblemonthlyexpires": "1491868800",
                    "T63Forecastssstensemblemonthlyrunoffset": "533.0",
                    "T63ForecastiridlhasSemantics": "iridl:forecast",
                    "description": "COLA C2.2 ensemble forecasts and simulations of precipitation rate and temperature at canapy air space",
                    "about_COLA": "http://www.iges.org/cola.html",
                    "iridlhasSemantics": "iridl:COLA",
                    "Conventions": "IRIDL",
                    "long_name": "COLA",
                    "references": "Kinter_etal1988 Dewitt1996 Schneider2002"
                },
                "T63": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T63",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "History": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "History",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ensemble_mean": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ensemble_mean",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "monthly": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "monthly",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Kelvin_scale",
                                    "missing_value": "-9999.0",
                                    "long_name": "temperature at canopy air space"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "mm/day",
                                    "long_name": "precipitation rate"
                                }
                            }
                        },
                        "ensemble": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ensemble",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "monthly": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "monthly",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "-9999.0",
                                    "units": "Kelvin_scale",
                                    "long_name": "temperature at canopy air space"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "mm/day",
                                    "long_name": "precipitation rate"
                                }
                            }
                        },
                        "climatology": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "climatology",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "c7100": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "c7100",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Kelvin_scale",
                                    "missing_value": "-9999.0",
                                    "long_name": "temperature at canopy air space"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "mm/day",
                                    "long_name": "precipitation rate"
                                }
                            },
                            "c6998": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "c6998",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Kelvin_scale",
                                    "missing_value": "-9999.0",
                                    "long_name": "temperature at canopy air space"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "mm/day",
                                    "long_name": "precipitation rate"
                                }
                            }
                        }
                    },
                    "Forecast": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Forecast",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "ssst": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ssst",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "ensemble": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "ensemble",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "monthly": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthly",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491868800",
                                        "units": "Kelvin_scale",
                                        "long_name": "Temperature at 2m",
                                        "pointwidth": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Forecast Time",
                                        "pointwidth": "1",
                                        "expires": "1491868800",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "expires": "1491868800",
                                        "units": "mm/day",
                                        "long_name": "precipitation rate",
                                        "missing_value": "-999.0",
                                        "pointwidth": "0"
                                    }
                                }
                            }
                        },
                        "asst": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "asst",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "ensemble": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "ensemble",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "monthly": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "monthly",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "units": "Kelvin_scale",
                                        "long_name": "Temperature at 2m"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "standard_name": "time",
                                        "long_name": "Forecast Time",
                                        "pointwidth": "1",
                                        "calendar": "360",
                                        "units": "months since 1960-01-01"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "missing_value": "NaN",
                                        "units": "mm/day",
                                        "long_name": "precipitation rate"
                                    }
                                }
                            }
                        }
                    }
                },
                "T_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "M_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "M_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "long_name": "member",
                    "pointwidth": "1.0"
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulo": "12.0",
                    "modulus": "12.0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "M_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "M_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "gridtype": "0",
                    "long_name": "member",
                    "pointwidth": "1.0"
                },
                "S_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1491868800",
                    "calendar": "360",
                    "standard_name": "forecast_reference_time",
                    "long_name": "Forecast Started",
                    "pointwidth": "0"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0"
                },
                "L": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "standard_name": "forecast_period",
                    "pointwidth": "1.0"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "standard_name": "longitude",
                    "pointwidth": "1.875"
                },
                "M": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "M",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "gridtype": "0",
                    "long_name": "member",
                    "pointwidth": "1.0"
                },
                "S": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "forecast_reference_time",
                    "long_name": "Forecast Started",
                    "pointwidth": "0"
                },
                "dir": "SOURCES/IRI/FD/COLA"
            },
            "COLA2p2p6": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "COLA2p2p6",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "description": "COLA AGCM V2.2.6",
                    "Conventions": "IRIDL",
                    "long_name": "COLA2.2.6"
                },
                "History": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "History",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "ensemble": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ensemble",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "monthly": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "monthly",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "t2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "t2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "Kelvin_scale",
                                "long_name": "temperature at canopy air space"
                            },
                            "prcp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "prcp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "units": "mm/day",
                                "long_name": "precipitation rate"
                            }
                        }
                    }
                },
                "M": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "M",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "1",
                    "standard_name": "longitude",
                    "pointwidth": "1.875"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "dir": "SOURCES/IRI/FD/COLA2p2p6"
            },
            "CPT": {
                "iridl_type": "DataSet",
                "iridl_ds_name": "CPT",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "NC_GLOBAL": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NC_GLOBAL",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "W_S_Americaexpires": "1552089600",
                    "W_S_Americahistory": "Output from CPT for 12 3-month running seasons for 1973-2001 between ECHAM4p5 GCM and CRU dataset, CPT recompiled on Mac 9.04 version",
                    "PAGASAhistory": "Output from CPT for 12 3-month running seasons for 1977-2003 between Echam4.5 CASST GCM and PAGASA stations dataset, CPT recompiled on Mac 9.04 version",
                    "PAGASAexpires": "1552089600",
                    "NEBrazilexpires": "1552089600",
                    "NEBrazilhistory": "Output from CPT for 12 3-month running seasons for 1973-2001 between ECHAM4p5 GCM and CRU dataset, CPT recompiled on Mac 9.04 version",
                    "Monsoon_Asiatemperatureminimumexpires": "1552089600",
                    "Monsoon_Asiatemperatureminimumhistory": "Output from CPT for 12 3-month running seasons for 1979-2008 with UEA CRU TS3p1 monthly dataset, CPT v10",
                    "Monsoon_Asiatemperaturemaximumexpires": "1552089600",
                    "Monsoon_Asiatemperaturemaximumhistory": "Output from CPT for 12 3-month running seasons for 1979-2008 with UEA CRU TS3p1 monthly dataset, CPT v10",
                    "Monsoon_Asiatemperatureaverageexpires": "1552089600",
                    "Monsoon_Asiatemperatureaveragehistory": "Output from CPT for 12 3-month running seasons for 1979-2008 with UEA CRU TS3p1 monthly dataset, CPT v10",
                    "Monsoon_Asiaprecipitationexpires": "1552089600",
                    "Monsoon_Asiaprecipitationhistory": "Output from CPT for 12 3-month running seasons for 1972-2007 between ECHAM4p5 GCM and RIHN aphrodite V1003R1 Monsoon Asia gridded daily precipitation dataset, CPT v10",
                    "Indonesiaunknown_obsexpires": "1552089600",
                    "IndonesiaGPCC_obsHistorydescription": "Predicand, Hindcast and Skill",
                    "IndonesiaGPCC_obsHistoryexpires": "1552089600",
                    "IndonesiaGPCC_obsForecastdescription": "Forecast and Error",
                    "IndonesiaGPCC_obsForecastexpires": "1552089600",
                    "IndonesiaGPCC_obsexpires": "1552089600",
                    "IndonesiaCMAP_obsHistorydescription": "Predicand, Hindcast and Skill",
                    "IndonesiaCMAP_obsHistoryexpires": "1552089600",
                    "IndonesiaCMAP_obsForecastdescription": "Forecast and Error",
                    "IndonesiaCMAP_obsForecastexpires": "1552089600",
                    "IndonesiaCMAP_obsexpires": "1552089600",
                    "IndonesiaCHIRPS_obsHistorydescription": "Predicand, Hindcast and Skill",
                    "IndonesiaCHIRPS_obsHistoryexpires": "1552089600",
                    "IndonesiaCHIRPS_obsForecastdescription": "Forecast and Error",
                    "IndonesiaCHIRPS_obsForecastexpires": "1552089600",
                    "IndonesiaCHIRPS_obsexpires": "1552089600",
                    "IndonesiaAPHR_obsHistorydescription": "Predicand, Hindcast and Skill",
                    "IndonesiaAPHR_obsHistoryexpires": "1552089600",
                    "IndonesiaAPHR_obsForecastdescription": "Forecast and Error",
                    "IndonesiaAPHR_obsForecastexpires": "1552089600",
                    "IndonesiaAPHR_obsexpires": "1552089600",
                    "Indonesiaexpires": "1552089600",
                    "GHAGPCCHistorydescription": "Predictand, Hindcast and Skill",
                    "GHAGPCCForecastdescription": "Forecast and Error",
                    "GHAGPCCForecastexpires": "1552089600",
                    "FooDSECuRESudanJJASHistorydescription": "Predicand, Hindcast and Skill",
                    "FooDSECuRESudanJJASForecastdescription": "Forecast and Error",
                    "FooDSECuRESudanJJASForecastexpires": "1586131200",
                    "FooDSECuRESudanJJASdescription": "JJAS Forecasts",
                    "FooDSECuREPhilippinesJFMAForecastexpires": "1617667200",
                    "FooDSECuREPhilippinesAMJJAForecastexpires": "1617667200",
                    "FooDSECuRENigerJJASHistorydescription": "Predicand, Hindcast and Skill",
                    "FooDSECuRENigerJJASForecastdescription": "Forecast and Error",
                    "FooDSECuRENigerJJASForecastexpires": "1586131200",
                    "FooDSECuRENigerJJASdescription": "JJAS Forecasts",
                    "ChileIVStreamflowobshistory": "Output from CPT http://iri.columbia.edu/CPT/v10/",
                    "ChileIVStreamflowobsexpires": "1552089600",
                    "ChileIVStreamflowCFShistory": "Output from CPT http://iri.columbia.edu/CPT/v10/",
                    "ChileIVStreamflowCFSexpires": "1585785600",
                    "ChileIVPrecipitationhistory": "Output from CPT http://iri.columbia.edu/CPT/v10/",
                    "ChileIVPrecipitationexpires": "1585785600",
                    "description": "Climate Prediction Tool",
                    "Conventions": "IRIDL"
                },
                "W_S_America": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "W_S_America",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "forecast time",
                        "pointwidth": "3",
                        "expires": "1552089600",
                        "calendar": "360",
                        "units": "months since 1960-01-01",
                        "standard_name": "forecast_reference_time"
                    },
                    "PredErrorVars": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PredErrorVars",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "expires": "1552089600",
                        "units": "mm/month",
                        "long_name": "prediction error variance",
                        "scale_min": "0.0",
                        "missing_value": "-999.0",
                        "pointwidth": "0"
                    },
                    "PearsonR": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PearsonR",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_max": "1.0",
                        "scale_min": "-1.0",
                        "ncolor": "254",
                        "CS": "-0.9960159",
                        "colorscalename": "correlationcolorscale",
                        "CE": "0.9960159",
                        "maxncolor": "254",
                        "colormap": "2763429",
                        "units": "unitless",
                        "long_name": "Pearson correlation skill values",
                        "missing_value": "-999.0",
                        "pointwidth": "1.0"
                    },
                    "InputObs": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "InputObs",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm/month",
                        "long_name": "input observations",
                        "missing_value": "-999.0",
                        "pointwidth": "1.0"
                    },
                    "hindcast_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "hindcast_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "hindcast time",
                        "pointwidth": "3",
                        "calendar": "360",
                        "units": "months since 1960-01-01"
                    },
                    "Forecast": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Forecast",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "prcp_0to500_colors",
                        "colormap": "341760",
                        "scale_max": "500.0",
                        "ncolor": "254",
                        "scale_min": "0.0",
                        "CE": "500",
                        "CS": "0",
                        "expires": "1552089600",
                        "units": "mm/month",
                        "long_name": "current forecast",
                        "missing_value": "-999.0",
                        "pointwidth": "0"
                    },
                    "CrossValHind": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "CrossValHind",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm/month",
                        "long_name": "cross-validated hindcasts",
                        "missing_value": "-999.0",
                        "pointwidth": "1.0"
                    }
                },
                "PAGASA": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "PAGASA",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "forecast time",
                        "pointwidth": "3",
                        "expires": "1552089600",
                        "calendar": "360",
                        "units": "months since 1960-01-01",
                        "bounds": "S",
                        "standard_name": "forecast_reference_time"
                    },
                    "PredErrorVars": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PredErrorVars",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "expires": "1552089600",
                        "units": "mm/day",
                        "long_name": "prediction error variance",
                        "scale_min": "0.0",
                        "missing_value": "-999.0",
                        "pointwidth": "0"
                    },
                    "PearsonR": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PearsonR",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_max": "1.0",
                        "scale_min": "-1.0",
                        "ncolor": "254",
                        "CS": "-0.9960159",
                        "colorscalename": "correlationcolorscale",
                        "CE": "0.9960159",
                        "maxncolor": "254",
                        "colormap": "2763429",
                        "units": "unitless",
                        "long_name": "Pearson correlation skill values",
                        "missing_value": "-999.0",
                        "pointwidth": "1.0"
                    },
                    "lon": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lon",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "114.0",
                        "units": "degree_east",
                        "long_name": "longitude",
                        "scale_max": "132.0"
                    },
                    "location": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "location",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "OpenGISSimpleFeature": "Point",
                        "long_name": "location",
                        "SpatialReferenceSystemWKT": "]]",
                        "scale_min": "114.0",
                        "units": "degree_east",
                        "scale_max": "132.0"
                    },
                    "lat": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "lat",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_min": "3.0",
                        "units": "degree_north",
                        "long_name": "latitude",
                        "scale_max": "22.0"
                    },
                    "label": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "label",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "ids"
                    },
                    "InputObs": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "InputObs",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm/day",
                        "long_name": "input observations",
                        "missing_value": "-999.0",
                        "pointwidth": "1.0"
                    },
                    "hindcast_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "hindcast_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "hindcast time",
                        "pointwidth": "3",
                        "calendar": "360",
                        "units": "months since 1960-01-01"
                    },
                    "Forecast": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Forecast",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "prcp_0to500_colors",
                        "colormap": "341760",
                        "scale_max": "500.0",
                        "ncolor": "254",
                        "scale_min": "0.0",
                        "CE": "500",
                        "CS": "0",
                        "expires": "1552089600",
                        "units": "mm/day",
                        "long_name": "current forecast",
                        "missing_value": "-999.0",
                        "pointwidth": "0"
                    },
                    "CrossValHind": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "CrossValHind",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm/day",
                        "long_name": "cross-validated hindcasts",
                        "missing_value": "-999.0",
                        "pointwidth": "1.0"
                    }
                },
                "NEBrazil": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "NEBrazil",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "forecast time",
                        "expires": "1552089600",
                        "calendar": "360",
                        "units": "months since 1960-01-01",
                        "pointwidth": "3.0"
                    },
                    "PredErrorVars": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PredErrorVars",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "expires": "1552089600",
                        "units": "mm/month",
                        "long_name": "prediction error variance",
                        "scale_min": "0.0",
                        "missing_value": "-999.0",
                        "pointwidth": "0"
                    },
                    "PearsonR": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PearsonR",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_max": "1.0",
                        "scale_min": "-1.0",
                        "ncolor": "254",
                        "CS": "-0.9960159",
                        "colorscalename": "correlationcolorscale",
                        "CE": "0.9960159",
                        "maxncolor": "254",
                        "colormap": "2763429",
                        "units": "unitless",
                        "long_name": "Pearson correlation skill values",
                        "missing_value": "-999.0",
                        "pointwidth": "1.0"
                    },
                    "InputObs": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "InputObs",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm/month",
                        "long_name": "input observations",
                        "missing_value": "-999.0",
                        "pointwidth": "1.0"
                    },
                    "hindcast_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "hindcast_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "hindcast time",
                        "pointwidth": "3",
                        "calendar": "360",
                        "units": "months since 1960-01-01"
                    },
                    "Forecast": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Forecast",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "prcp_0to500_colors",
                        "colormap": "341760",
                        "scale_max": "500.0",
                        "ncolor": "254",
                        "scale_min": "0.0",
                        "CE": "500",
                        "CS": "0",
                        "expires": "1552089600",
                        "units": "mm/month",
                        "long_name": "current forecast",
                        "missing_value": "-999.0",
                        "pointwidth": "0"
                    },
                    "CrossValHind": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "CrossValHind",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm/month",
                        "long_name": "cross-validated hindcasts",
                        "missing_value": "-999.0",
                        "pointwidth": "1.0"
                    }
                },
                "Monsoon_Asia": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Monsoon_Asia",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "temperature": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "temperature",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "minimum": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "minimum",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "target_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "target_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "forecast time",
                                "expires": "1552089600",
                                "calendar": "360",
                                "units": "months since 1960-01-01",
                                "pointwidth": "3.0"
                            },
                            "PredErrorVars": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PredErrorVars",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "expires": "1552089600",
                                "units": "Celsius_scale",
                                "long_name": "prediction error variance",
                                "scale_min": "0.0",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "PearsonR": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PearsonR",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "1.0",
                                "scale_min": "-1.0",
                                "ncolor": "254",
                                "CS": "-0.9960159",
                                "colorscalename": "correlationcolorscale",
                                "CE": "0.9960159",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "units": "unitless",
                                "long_name": "Pearson correlation skill values",
                                "missing_value": "-999.0",
                                "pointwidth": "1.0"
                            },
                            "InputObs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "InputObs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Celsius_scale",
                                "long_name": "input observations",
                                "missing_value": "-999.0",
                                "pointwidth": "1.0"
                            },
                            "hindcast_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "hindcast time",
                                "pointwidth": "3",
                                "calendar": "360",
                                "units": "months since 1960-01-01"
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "40.0",
                                "ncolor": "254",
                                "scale_min": "-40.0",
                                "CS": "-40",
                                "colorscalename": "temp_colors",
                                "CE": "40",
                                "maxncolor": "254",
                                "colormap": "255",
                                "expires": "1552089600",
                                "units": "Celsius_scale",
                                "long_name": "current forecast",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "CrossValHind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "CrossValHind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Celsius_scale",
                                "long_name": "cross-validated hindcasts",
                                "missing_value": "-999.0",
                                "pointwidth": "1.0"
                            }
                        },
                        "maximum": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "maximum",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "target_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "target_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "forecast time",
                                "expires": "1552089600",
                                "calendar": "360",
                                "units": "months since 1960-01-01",
                                "pointwidth": "3.0"
                            },
                            "PredErrorVars": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PredErrorVars",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "expires": "1552089600",
                                "units": "Celsius_scale",
                                "long_name": "prediction error variance",
                                "scale_min": "0.0",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "PearsonR": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PearsonR",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "1.0",
                                "scale_min": "-1.0",
                                "ncolor": "254",
                                "CS": "-0.9960159",
                                "colorscalename": "correlationcolorscale",
                                "CE": "0.9960159",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "units": "unitless",
                                "long_name": "Pearson correlation skill values",
                                "missing_value": "-999.0",
                                "pointwidth": "1.0"
                            },
                            "InputObs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "InputObs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Celsius_scale",
                                "long_name": "input observations",
                                "missing_value": "-999.0",
                                "pointwidth": "1.0"
                            },
                            "hindcast_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "hindcast time",
                                "pointwidth": "3",
                                "calendar": "360",
                                "units": "months since 1960-01-01"
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "40.0",
                                "ncolor": "254",
                                "scale_min": "-40.0",
                                "CS": "-40",
                                "colorscalename": "temp_colors",
                                "CE": "40",
                                "maxncolor": "254",
                                "colormap": "255",
                                "expires": "1552089600",
                                "units": "Celsius_scale",
                                "long_name": "current forecast",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "CrossValHind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "CrossValHind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Celsius_scale",
                                "long_name": "cross-validated hindcasts",
                                "missing_value": "-999.0",
                                "pointwidth": "1.0"
                            }
                        },
                        "average": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "average",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "target_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "target_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "forecast time",
                                "expires": "1552089600",
                                "calendar": "360",
                                "units": "months since 1960-01-01",
                                "pointwidth": "3.0"
                            },
                            "PredErrorVars": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PredErrorVars",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "expires": "1552089600",
                                "units": "Celsius_scale",
                                "long_name": "prediction error variance",
                                "scale_min": "0.0",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "PearsonR": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PearsonR",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "1.0",
                                "scale_min": "-1.0",
                                "ncolor": "254",
                                "CS": "-0.9960159",
                                "colorscalename": "correlationcolorscale",
                                "CE": "0.9960159",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "units": "unitless",
                                "long_name": "Pearson correlation skill values",
                                "missing_value": "-999.0",
                                "pointwidth": "1.0"
                            },
                            "InputObs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "InputObs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Celsius_scale",
                                "long_name": "input observations",
                                "missing_value": "-999.0",
                                "pointwidth": "1.0"
                            },
                            "hindcast_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "hindcast time",
                                "pointwidth": "3",
                                "calendar": "360",
                                "units": "months since 1960-01-01"
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "40.0",
                                "ncolor": "254",
                                "scale_min": "-40.0",
                                "CS": "-40",
                                "colorscalename": "temp_colors",
                                "CE": "40",
                                "maxncolor": "254",
                                "colormap": "255",
                                "expires": "1552089600",
                                "units": "Celsius_scale",
                                "long_name": "current forecast",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "CrossValHind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "CrossValHind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Celsius_scale",
                                "long_name": "cross-validated hindcasts",
                                "missing_value": "-999.0",
                                "pointwidth": "1.0"
                            }
                        }
                    },
                    "precipitation": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "precipitation",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "target_date": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "target_date",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "forecast time",
                            "expires": "1552089600",
                            "calendar": "360",
                            "units": "months since 1960-01-01",
                            "pointwidth": "3.0"
                        },
                        "PredErrorVars": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "PredErrorVars",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "expires": "1552089600",
                            "units": "mm/day",
                            "long_name": "prediction error variance",
                            "scale_min": "0.0",
                            "missing_value": "-999.0",
                            "pointwidth": "0"
                        },
                        "PearsonR": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "PearsonR",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_max": "1.0",
                            "scale_min": "-1.0",
                            "ncolor": "254",
                            "CS": "-0.9960159",
                            "colorscalename": "correlationcolorscale",
                            "CE": "0.9960159",
                            "maxncolor": "254",
                            "colormap": "2763429",
                            "units": "unitless",
                            "long_name": "Pearson correlation skill values",
                            "missing_value": "-999.0",
                            "pointwidth": "1.0"
                        },
                        "InputObs": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "InputObs",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "mm/day",
                            "long_name": "input observations",
                            "missing_value": "-999.0",
                            "pointwidth": "1.0"
                        },
                        "hindcast_date": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "hindcast_date",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "hindcast time",
                            "pointwidth": "3",
                            "calendar": "360",
                            "units": "months since 1960-01-01"
                        },
                        "Forecast": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Forecast",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "maxncolor": "254",
                            "colorscalename": "prcp_0to500_colors",
                            "colormap": "341760",
                            "scale_max": "500.0",
                            "ncolor": "254",
                            "scale_min": "0.0",
                            "CE": "500",
                            "CS": "0",
                            "expires": "1552089600",
                            "units": "mm/day",
                            "long_name": "current forecast",
                            "missing_value": "-999.0",
                            "pointwidth": "0"
                        },
                        "CrossValHind": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "CrossValHind",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "mm/day",
                            "long_name": "cross-validated hindcasts",
                            "missing_value": "-999.0",
                            "pointwidth": "1.0"
                        }
                    }
                },
                "Indonesia": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Indonesia",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "unknown_obs": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "unknown_obs",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "target_date": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "target_date",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "forecast time",
                            "pointwidth": "3",
                            "expires": "1552089600",
                            "calendar": "360",
                            "units": "months since 1960-01-01",
                            "bounds": "S",
                            "standard_name": "forecast_reference_time"
                        },
                        "PredErrorVars": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "PredErrorVars",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "expires": "1552089600",
                            "units": "mm/month",
                            "long_name": "prediction error variance",
                            "scale_min": "0.0",
                            "missing_value": "-999.0",
                            "pointwidth": "0"
                        },
                        "PearsonR": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "PearsonR",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_max": "1.0",
                            "scale_min": "-1.0",
                            "ncolor": "254",
                            "CS": "-0.9960159",
                            "colorscalename": "correlationcolorscale",
                            "CE": "0.9960159",
                            "maxncolor": "254",
                            "colormap": "2763429",
                            "units": "unitless",
                            "long_name": "Pearson correlation skill values",
                            "missing_value": "-999.0",
                            "modulo": "12.0",
                            "modulus": "12.0",
                            "pointwidth": "1.0"
                        },
                        "InputObs": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "InputObs",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "maxncolor": "254",
                            "colorscalename": "precip_colors",
                            "colormap": "290304",
                            "scale_max": "16.0",
                            "ncolor": "254",
                            "scale_min": "0.0",
                            "CE": "16",
                            "CS": "0",
                            "units": "mm/month",
                            "long_name": "input observations",
                            "missing_value": "-999.0",
                            "modulo": "12.0",
                            "modulus": "12.0",
                            "pointwidth": "1.0"
                        },
                        "hindcast_date": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "hindcast_date",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "hindcast time",
                            "pointwidth": "3",
                            "calendar": "360",
                            "units": "months since 1960-01-01"
                        },
                        "Forecast": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Forecast",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "maxncolor": "254",
                            "colorscalename": "precip_colors",
                            "colormap": "290304",
                            "scale_max": "16.0",
                            "ncolor": "254",
                            "scale_min": "0.0",
                            "CE": "16",
                            "CS": "0",
                            "expires": "1552089600",
                            "units": "mm/month",
                            "long_name": "current forecast",
                            "missing_value": "-999.0",
                            "pointwidth": "0"
                        },
                        "CrossValHind": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "CrossValHind",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "mm/month",
                            "long_name": "cross-validated hindcasts",
                            "missing_value": "-999.0",
                            "modulo": "12.0",
                            "modulus": "12.0",
                            "pointwidth": "1.0"
                        }
                    },
                    "target_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "target_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "forecast time",
                        "pointwidth": "3",
                        "expires": "1552089600",
                        "calendar": "360",
                        "units": "months since 1960-01-01",
                        "bounds": "S",
                        "standard_name": "forecast_reference_time"
                    },
                    "PredErrorVars": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PredErrorVars",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "expires": "1552089600",
                        "units": "mm/month",
                        "long_name": "prediction error variance",
                        "scale_min": "0.0",
                        "missing_value": "-999.0",
                        "pointwidth": "0"
                    },
                    "PearsonR": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "PearsonR",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "scale_max": "1.0",
                        "scale_min": "-1.0",
                        "ncolor": "254",
                        "CS": "-0.9960159",
                        "colorscalename": "correlationcolorscale",
                        "CE": "0.9960159",
                        "maxncolor": "254",
                        "colormap": "2763429",
                        "units": "unitless",
                        "long_name": "Pearson correlation skill values",
                        "missing_value": "-999.0",
                        "modulo": "12.0",
                        "modulus": "12.0",
                        "pointwidth": "1.0"
                    },
                    "InputObs": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "InputObs",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "precip_colors",
                        "colormap": "290304",
                        "scale_max": "16.0",
                        "ncolor": "254",
                        "scale_min": "0.0",
                        "CE": "16",
                        "CS": "0",
                        "units": "mm/month",
                        "long_name": "input observations",
                        "missing_value": "-999.0",
                        "modulo": "12.0",
                        "modulus": "12.0",
                        "pointwidth": "1.0"
                    },
                    "hindcast_date": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "hindcast_date",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "long_name": "hindcast time",
                        "pointwidth": "3",
                        "calendar": "360",
                        "units": "months since 1960-01-01"
                    },
                    "GPCC_obs": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "GPCC_obs",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "History": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "History",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "PearsonR": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PearsonR",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "1.0",
                                "scale_min": "-1.0",
                                "ncolor": "254",
                                "CS": "-0.9960159",
                                "colorscalename": "correlationcolorscale",
                                "CE": "0.9960159",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "units": "unitless",
                                "long_name": "Pearson correlation skill values",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "InputObs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "InputObs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "scale_max": "16.0",
                                "ncolor": "254",
                                "scale_min": "0.0",
                                "CE": "16",
                                "CS": "0",
                                "units": "mm/month",
                                "long_name": "input observations",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "hindcast_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "hindcast time",
                                "pointwidth": "3",
                                "calendar": "360",
                                "units": "months since 1960-01-01"
                            },
                            "CrossValHind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "CrossValHind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/month",
                                "long_name": "cross-validated hindcasts",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            }
                        },
                        "Forecast": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Forecast",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "target_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "target_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "forecast time",
                                "pointwidth": "3",
                                "expires": "1552089600",
                                "calendar": "360",
                                "units": "months since 1960-01-01",
                                "bounds": "S",
                                "standard_name": "forecast_reference_time"
                            },
                            "PredErrorVars": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PredErrorVars",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "expires": "1552089600",
                                "units": "mm/month",
                                "long_name": "prediction error variance",
                                "scale_min": "0.0",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "scale_max": "16.0",
                                "ncolor": "254",
                                "scale_min": "0.0",
                                "CE": "16",
                                "CS": "0",
                                "expires": "1552089600",
                                "units": "mm/month",
                                "long_name": "current forecast",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            }
                        }
                    },
                    "Forecast": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Forecast",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "maxncolor": "254",
                        "colorscalename": "precip_colors",
                        "colormap": "290304",
                        "scale_max": "16.0",
                        "ncolor": "254",
                        "scale_min": "0.0",
                        "CE": "16",
                        "CS": "0",
                        "expires": "1552089600",
                        "units": "mm/month",
                        "long_name": "current forecast",
                        "missing_value": "-999.0",
                        "pointwidth": "0"
                    },
                    "CrossValHind": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "CrossValHind",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "units": "mm/month",
                        "long_name": "cross-validated hindcasts",
                        "missing_value": "-999.0",
                        "modulo": "12.0",
                        "modulus": "12.0",
                        "pointwidth": "1.0"
                    },
                    "CMAP_obs": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "CMAP_obs",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "History": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "History",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "PearsonR": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PearsonR",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "1.0",
                                "scale_min": "-1.0",
                                "ncolor": "254",
                                "CS": "-0.9960159",
                                "colorscalename": "correlationcolorscale",
                                "CE": "0.9960159",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "units": "unitless",
                                "long_name": "Pearson correlation skill values",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "InputObs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "InputObs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "scale_max": "16.0",
                                "ncolor": "254",
                                "scale_min": "0.0",
                                "CE": "16",
                                "CS": "0",
                                "units": "mm/day",
                                "long_name": "input observations",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "hindcast_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "hindcast time",
                                "pointwidth": "3",
                                "calendar": "360",
                                "units": "months since 1960-01-01"
                            },
                            "CrossValHind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "CrossValHind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/day",
                                "long_name": "cross-validated hindcasts",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            }
                        },
                        "Forecast": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Forecast",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "target_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "target_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "forecast time",
                                "pointwidth": "3",
                                "expires": "1552089600",
                                "calendar": "360",
                                "units": "months since 1960-01-01",
                                "bounds": "S",
                                "standard_name": "forecast_reference_time"
                            },
                            "PredErrorVars": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PredErrorVars",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "expires": "1552089600",
                                "units": "mm/day",
                                "long_name": "prediction error variance",
                                "scale_min": "0.0",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "scale_max": "16.0",
                                "ncolor": "254",
                                "scale_min": "0.0",
                                "CE": "16",
                                "CS": "0",
                                "expires": "1552089600",
                                "units": "mm/day",
                                "long_name": "current forecast",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            }
                        }
                    },
                    "CHIRPS_obs": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "CHIRPS_obs",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "History": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "History",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "PearsonR": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PearsonR",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "1.0",
                                "scale_min": "-1.0",
                                "ncolor": "254",
                                "CS": "-0.9960159",
                                "colorscalename": "correlationcolorscale",
                                "CE": "0.9960159",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "units": "unitless",
                                "long_name": "Pearson correlation skill values",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "InputObs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "InputObs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "scale_max": "16.0",
                                "ncolor": "254",
                                "scale_min": "0.0",
                                "CE": "16",
                                "CS": "0",
                                "units": "mm/day",
                                "long_name": "input observations",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "hindcast_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "hindcast time",
                                "pointwidth": "3",
                                "calendar": "360",
                                "units": "months since 1960-01-01"
                            },
                            "CrossValHind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "CrossValHind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/day",
                                "long_name": "cross-validated hindcasts",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            }
                        },
                        "Forecast": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Forecast",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "target_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "target_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "forecast time",
                                "pointwidth": "3",
                                "expires": "1552089600",
                                "calendar": "360",
                                "units": "months since 1960-01-01",
                                "bounds": "S",
                                "standard_name": "forecast_reference_time"
                            },
                            "PredErrorVars": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PredErrorVars",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "expires": "1552089600",
                                "units": "mm/day",
                                "long_name": "prediction error variance",
                                "scale_min": "0.0",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "scale_max": "16.0",
                                "ncolor": "254",
                                "scale_min": "0.0",
                                "CE": "16",
                                "CS": "0",
                                "expires": "1552089600",
                                "units": "mm/day",
                                "long_name": "current forecast",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            }
                        }
                    },
                    "APHR_obs": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "APHR_obs",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "History": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "History",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "PearsonR": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PearsonR",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "1.0",
                                "scale_min": "-1.0",
                                "ncolor": "254",
                                "CS": "-0.9960159",
                                "colorscalename": "correlationcolorscale",
                                "CE": "0.9960159",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "units": "unitless",
                                "long_name": "Pearson correlation skill values",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "InputObs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "InputObs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "scale_max": "16.0",
                                "ncolor": "254",
                                "scale_min": "0.0",
                                "CE": "16",
                                "CS": "0",
                                "units": "mm/day",
                                "long_name": "input observations",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "hindcast_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "hindcast time",
                                "pointwidth": "3",
                                "calendar": "360",
                                "units": "months since 1960-01-01"
                            },
                            "CrossValHind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "CrossValHind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/day",
                                "long_name": "cross-validated hindcasts",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            }
                        },
                        "Forecast": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Forecast",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "target_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "target_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "forecast time",
                                "pointwidth": "3",
                                "expires": "1552089600",
                                "calendar": "360",
                                "units": "months since 1960-01-01",
                                "bounds": "S",
                                "standard_name": "forecast_reference_time"
                            },
                            "PredErrorVars": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PredErrorVars",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "expires": "1552089600",
                                "units": "mm/day",
                                "long_name": "prediction error variance",
                                "scale_min": "0.0",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "scale_max": "16.0",
                                "ncolor": "254",
                                "scale_min": "0.0",
                                "CE": "16",
                                "CS": "0",
                                "expires": "1552089600",
                                "units": "mm/day",
                                "long_name": "current forecast",
                                "missing_value": "-999.0",
                                "pointwidth": "0"
                            }
                        }
                    }
                },
                "GHA": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "GHA",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "GPCC": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "GPCC",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "History": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "History",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "PearsonR": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PearsonR",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "-1.0",
                                "scale_max": "1.0",
                                "CE": "1",
                                "CS": "-1",
                                "ncolor": "254",
                                "colorscalename": "correlationcolorscale",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "missing_value": "-999.0",
                                "long_name": "Pearson correlation skill values",
                                "units": "unitless",
                                "pointwidth": "0"
                            },
                            "InputObs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "InputObs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "CS": "0",
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "ncolor": "254",
                                "missing_value": "-999.0",
                                "long_name": "input observations",
                                "units": "mm/day",
                                "pointwidth": "0"
                            },
                            "hindcast_length": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast_length",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Length of hindcast time",
                                "history": "Averaged in T with overlapping interval 3",
                                "units": "days",
                                "missing_value": "NaN",
                                "calendar": "360",
                                "pointwidth": "1.0"
                            },
                            "hindcast_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "hindcast time",
                                "pointwidth": "3",
                                "calendar": "360",
                                "units": "months since 1960-01-01"
                            },
                            "CrossValHind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "CrossValHind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "CS": "0",
                                "maxncolor": "254",
                                "colorscalename": "precip_colors",
                                "colormap": "290304",
                                "ncolor": "254",
                                "missing_value": "-999.0",
                                "long_name": "cross-validated hindcasts",
                                "units": "mm/day",
                                "pointwidth": "0"
                            }
                        },
                        "Forecast": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Forecast",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "target_length": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "target_length",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "Length of forecast time",
                                "history": "Averaged in T with overlapping interval 3",
                                "units": "days",
                                "missing_value": "NaN",
                                "calendar": "360",
                                "pointwidth": "1.0"
                            },
                            "target_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "target_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "forecast time",
                                "pointwidth": "3",
                                "expires": "1552089600",
                                "calendar": "360",
                                "units": "months since 1960-01-01",
                                "bounds": "S",
                                "standard_name": "forecast_reference_time"
                            },
                            "PredErrorVars": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PredErrorVars",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "CS": "0",
                                "maxncolor": "256",
                                "ncolor": "254",
                                "colormap": "12632256",
                                "colorscalename": "rainbowcolorscale",
                                "missing_value": "-999.0",
                                "long_name": "prediction error variance",
                                "units": "mm2/day2",
                                "expires": "1552089600",
                                "pointwidth": "0"
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "maxncolor": "254",
                                "colormap": "25600",
                                "scale_max": "1000.0",
                                "ncolor": "254",
                                "scale_min": "0.0",
                                "CE": "1000",
                                "CS": "0",
                                "long_name": "forecast",
                                "missing_value": "NaN",
                                "expires": "1552089600",
                                "units": "mm",
                                "history": "Averaged in T with overlapping interval 3",
                                "file_missing_value": "-999.0",
                                "pointwidth": "0"
                            }
                        }
                    }
                },
                "FooDSECuRE": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "FooDSECuRE",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Sudan": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Sudan",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "JJAS": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "JJAS",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "History": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "History",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PearsonR_prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PearsonR_prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "-1.0",
                                    "scale_max": "1.0",
                                    "CE": "1",
                                    "CS": "-1",
                                    "ncolor": "254",
                                    "colorscalename": "correlationcolorscale",
                                    "maxncolor": "254",
                                    "colormap": "2763429",
                                    "units": "unitless",
                                    "long_name": "Precipitation Pearson\\'s Correlation",
                                    "pointwidth": "0"
                                },
                                "Input_prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Input_prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "precip_colors",
                                    "colormap": "290304",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "long_name": "Precipitation input observations",
                                    "units": "mm/month",
                                    "pointwidth": "0"
                                },
                                "hindcast_date": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hindcast_date",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "hindcast time",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "4",
                                    "calendar": "360",
                                    "standard_name": "forecast_reference_time"
                                },
                                "CrossValPred_prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CrossValPred_prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "precip_colors",
                                    "colormap": "290304",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "long_name": "Precipitation cross-validated hindcasts",
                                    "units": "mm/month",
                                    "pointwidth": "0"
                                }
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "target_date": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "target_date",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "forecast time",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "4",
                                    "expires": "1586131200",
                                    "calendar": "360",
                                    "bounds": "S",
                                    "standard_name": "forecast_reference_time"
                                },
                                "PredErrVar_prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PredErrVar_prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "precip_colors",
                                    "colormap": "290304",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "expires": "1586131200",
                                    "units": "mm2/month2",
                                    "long_name": "Precipitation prediction error variance",
                                    "pointwidth": "0"
                                },
                                "Forecast_prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Forecast_prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "precip_colors",
                                    "colormap": "290304",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "expires": "1586131200",
                                    "units": "mm/month",
                                    "long_name": "Precipitation current forecast",
                                    "pointwidth": "0"
                                }
                            }
                        }
                    },
                    "Philippines": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Philippines",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "JFMA": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "JFMA",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "History": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "History",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "the_geom": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "the_geom",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Provinces Geometry",
                                    "units": "unitless",
                                    "PGtype": "bytea",
                                    "OpenGISSimpleFeature": "MULTIPOLYGON",
                                    "SpatialReferenceSystemWKT": "]]"
                                },
                                "regcode": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "regcode",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Region Code",
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "PGtype": "float8"
                                },
                                "provname": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "provname",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Province Name",
                                    "units": "ids",
                                    "PGtype": "varchar"
                                },
                                "PearsonR_WD1": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PearsonR_WD1",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "-1.0",
                                    "scale_max": "1.0",
                                    "CE": "1",
                                    "CS": "-1",
                                    "ncolor": "254",
                                    "colorscalename": "correlationcolorscale",
                                    "maxncolor": "254",
                                    "colormap": "2763429",
                                    "missing_value": "-9999.0",
                                    "long_name": "WD1 Pearson\\'s Correlation",
                                    "units": "unitless",
                                    "pointwidth": "0"
                                },
                                "label": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "label",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "ids",
                                    "PGtype": "text"
                                },
                                "Input_WD1": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Input_WD1",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "wetday_freq_colors",
                                    "colormap": "255",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "long_name": "WD1 input observations",
                                    "units": "days",
                                    "pointwidth": "0"
                                },
                                "hindcast_date": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hindcast_date",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "hindcast time",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "4",
                                    "calendar": "360",
                                    "standard_name": "forecast_reference_time"
                                },
                                "CrossValPred_WD1": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CrossValPred_WD1",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "wetday_freq_colors",
                                    "colormap": "255",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "long_name": "WD1 cross-validated hindcasts",
                                    "units": "days",
                                    "pointwidth": "0"
                                }
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "the_geom": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "the_geom",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Provinces Geometry",
                                    "units": "unitless",
                                    "PGtype": "bytea",
                                    "OpenGISSimpleFeature": "MULTIPOLYGON",
                                    "SpatialReferenceSystemWKT": "]]"
                                },
                                "TercileProb_WD1": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TercileProb_WD1",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "maxncolor": "254",
                                    "colorscalename": "tercileclassesscale",
                                    "colormap": "6303920",
                                    "scale_max": "100.0",
                                    "ncolor": "254",
                                    "scale_min": "0.0",
                                    "CE": "100",
                                    "CS": "0",
                                    "missing_value": "-1.0",
                                    "long_name": "WD1 Tercile Probability",
                                    "units": "percent",
                                    "expires": "1617667200",
                                    "pointwidth": "0"
                                },
                                "target_date": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "target_date",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "forecast time",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "4",
                                    "expires": "1617667200",
                                    "calendar": "360",
                                    "bounds": "S",
                                    "standard_name": "forecast_reference_time"
                                },
                                "regcode": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "regcode",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Region Code",
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "PGtype": "float8"
                                },
                                "provname": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "provname",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Province Name",
                                    "units": "ids",
                                    "PGtype": "varchar"
                                },
                                "PredErrVar_WD1": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PredErrVar_WD1",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "wetday_freq_colors",
                                    "colormap": "255",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "long_name": "WD1 prediction error variance",
                                    "units": "days2",
                                    "expires": "1617667200",
                                    "pointwidth": "0"
                                },
                                "label": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "label",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "ids",
                                    "PGtype": "text"
                                },
                                "Forecast_WD1": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Forecast_WD1",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "wetday_freq_colors",
                                    "colormap": "255",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "long_name": "WD1 current forecast",
                                    "units": "days",
                                    "expires": "1617667200",
                                    "pointwidth": "0"
                                },
                                "DomTercileProb_WD1": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "DomTercileProb_WD1",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "maxncolor": "254",
                                    "long_name": "WD1 Dominant Tercile Probabilities",
                                    "colormap": "25600",
                                    "scale_max": "33.0",
                                    "ncolor": "254",
                                    "scale_min": "1.0",
                                    "CE": "33",
                                    "CS": "1",
                                    "CLIST": ">80 Above",
                                    "missing_value": "NaN",
                                    "fnname": "maskle",
                                    "history": "dominant_class over C[Below Normal, Above Normal]",
                                    "expires": "1617667200",
                                    "units": "ids",
                                    "file_missing_value": "0",
                                    "colorscalename": "halfgreyscale",
                                    "pointwidth": "0"
                                }
                            }
                        },
                        "AMJJA": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "AMJJA",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "History": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "History",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "the_geom": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "the_geom",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Provinces Geometry",
                                    "units": "unitless",
                                    "PGtype": "bytea",
                                    "OpenGISSimpleFeature": "MULTIPOLYGON",
                                    "SpatialReferenceSystemWKT": "]]"
                                },
                                "regcode": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "regcode",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Region Code",
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "PGtype": "float8"
                                },
                                "provname": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "provname",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Province Name",
                                    "units": "ids",
                                    "PGtype": "varchar"
                                },
                                "PearsonR_WD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PearsonR_WD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "-1.0",
                                    "scale_max": "1.0",
                                    "CE": "1",
                                    "CS": "-1",
                                    "ncolor": "254",
                                    "colorscalename": "correlationcolorscale",
                                    "maxncolor": "254",
                                    "colormap": "2763429",
                                    "missing_value": "-9999.0",
                                    "long_name": "WD5 Pearson\\'s Correlation",
                                    "units": "unitless",
                                    "pointwidth": "0"
                                },
                                "label": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "label",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "ids",
                                    "PGtype": "text"
                                },
                                "Input_WD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Input_WD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "wetday_freq_colors",
                                    "colormap": "255",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "long_name": "WD5 input observations",
                                    "units": "days",
                                    "pointwidth": "0"
                                },
                                "hindcast_date": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hindcast_date",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "hindcast time",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "5",
                                    "calendar": "360",
                                    "standard_name": "forecast_reference_time"
                                },
                                "CrossValPred_WD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CrossValPred_WD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "wetday_freq_colors",
                                    "colormap": "255",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "long_name": "WD5 cross-validated hindcasts",
                                    "units": "days",
                                    "pointwidth": "0"
                                }
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "the_geom": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "the_geom",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Provinces Geometry",
                                    "units": "unitless",
                                    "PGtype": "bytea",
                                    "OpenGISSimpleFeature": "MULTIPOLYGON",
                                    "SpatialReferenceSystemWKT": "]]"
                                },
                                "TercileProb_WD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TercileProb_WD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "maxncolor": "254",
                                    "colorscalename": "tercileclassesscale",
                                    "colormap": "6303920",
                                    "scale_max": "100.0",
                                    "ncolor": "254",
                                    "scale_min": "0.0",
                                    "CE": "100",
                                    "CS": "0",
                                    "missing_value": "-1.0",
                                    "long_name": "WD5 Tercile Probability",
                                    "units": "percent",
                                    "expires": "1617667200",
                                    "pointwidth": "0"
                                },
                                "target_date": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "target_date",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "forecast time",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "5",
                                    "expires": "1617667200",
                                    "calendar": "360",
                                    "bounds": "S",
                                    "standard_name": "forecast_reference_time"
                                },
                                "regcode": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "regcode",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Region Code",
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "PGtype": "float8"
                                },
                                "provname": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "provname",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Province Name",
                                    "units": "ids",
                                    "PGtype": "varchar"
                                },
                                "PredErrVar_WD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PredErrVar_WD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "wetday_freq_colors",
                                    "colormap": "255",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "long_name": "WD5 prediction error variance",
                                    "units": "days2",
                                    "expires": "1617667200",
                                    "pointwidth": "0"
                                },
                                "label": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "label",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "ids",
                                    "PGtype": "text"
                                },
                                "Forecast_WD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Forecast_WD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "wetday_freq_colors",
                                    "colormap": "255",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "long_name": "WD5 current forecast",
                                    "units": "days",
                                    "expires": "1617667200",
                                    "pointwidth": "0"
                                },
                                "DomTercileProb_WD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "DomTercileProb_WD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "maxncolor": "254",
                                    "long_name": "WD5 Dominant Tercile Probabilities",
                                    "colormap": "25600",
                                    "scale_max": "33.0",
                                    "ncolor": "254",
                                    "scale_min": "1.0",
                                    "CE": "33",
                                    "CS": "1",
                                    "CLIST": ">80 Above",
                                    "missing_value": "NaN",
                                    "fnname": "maskle",
                                    "history": "dominant_class over C[Below Normal, Above Normal]",
                                    "expires": "1617667200",
                                    "units": "ids",
                                    "file_missing_value": "0",
                                    "colorscalename": "halfgreyscale",
                                    "pointwidth": "0"
                                }
                            }
                        }
                    },
                    "Niger": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Niger",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "JJAS": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "JJAS",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "History": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "History",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PearsonR_prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PearsonR_prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "-1.0",
                                    "scale_max": "1.0",
                                    "CE": "1",
                                    "CS": "-1",
                                    "ncolor": "254",
                                    "colorscalename": "correlationcolorscale",
                                    "maxncolor": "254",
                                    "colormap": "2763429",
                                    "units": "unitless",
                                    "long_name": "Precipitation Pearson\\'s Correlation",
                                    "pointwidth": "0"
                                },
                                "Input_prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Input_prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "precip_colors",
                                    "colormap": "290304",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "long_name": "Precipitation input observations",
                                    "units": "mm/month",
                                    "pointwidth": "0"
                                },
                                "hindcast_date": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hindcast_date",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "hindcast time",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "4",
                                    "calendar": "360",
                                    "standard_name": "forecast_reference_time"
                                },
                                "CrossValPred_prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "CrossValPred_prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "precip_colors",
                                    "colormap": "290304",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "long_name": "Precipitation cross-validated hindcasts",
                                    "units": "mm/month",
                                    "pointwidth": "0"
                                }
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "target_date": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "target_date",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "forecast time",
                                    "units": "months since 1960-01-01",
                                    "pointwidth": "4",
                                    "expires": "1586131200",
                                    "calendar": "360",
                                    "bounds": "S",
                                    "standard_name": "forecast_reference_time"
                                },
                                "PredErrVar_prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PredErrVar_prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "precip_colors",
                                    "colormap": "290304",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "expires": "1586131200",
                                    "units": "mm2/month2",
                                    "long_name": "Precipitation prediction error variance",
                                    "pointwidth": "0"
                                },
                                "Forecast_prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Forecast_prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_min": "0.0",
                                    "CS": "0",
                                    "maxncolor": "254",
                                    "colorscalename": "precip_colors",
                                    "colormap": "290304",
                                    "ncolor": "254",
                                    "missing_value": "-9999.0",
                                    "expires": "1586131200",
                                    "units": "mm/month",
                                    "long_name": "Precipitation current forecast",
                                    "pointwidth": "0"
                                }
                            }
                        }
                    }
                },
                "ChileIV": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ChileIV",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "Streamflow": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Streamflow",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "obs": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "obs",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "target_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "target_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "forecast time",
                                "pointwidth": "4",
                                "expires": "1552089600",
                                "calendar": "360",
                                "units": "months since 1960-01-01",
                                "bounds": "S",
                                "standard_name": "forecast_reference_time"
                            },
                            "PredErrorVars": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PredErrorVars",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "expires": "1552089600",
                                "units": "m3/s",
                                "long_name": "prediction error variance",
                                "scale_min": "0.0",
                                "pointwidth": "0"
                            },
                            "PearsonR": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PearsonR",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "1.0",
                                "scale_min": "-1.0",
                                "ncolor": "254",
                                "CS": "-0.9960159",
                                "colorscalename": "correlationcolorscale",
                                "CE": "0.9960159",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "missing_value": "-999.0",
                                "units": "unitless",
                                "long_name": "Pearson correlation skill values"
                            },
                            "lon": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lon",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "-69.800003",
                                "scale_min": "-71.5",
                                "units": "degree_east",
                                "long_name": "longitude"
                            },
                            "lat": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lat",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "-29.299999",
                                "scale_min": "-32.0",
                                "units": "degree_north",
                                "long_name": "latitude"
                            },
                            "InputObs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "InputObs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m3/s",
                                "long_name": "input observations",
                                "missing_value": "-999.0"
                            },
                            "hindcast_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "hindcast time",
                                "pointwidth": "4",
                                "calendar": "360",
                                "units": "months since 1960-01-01"
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "CS": "0",
                                "maxncolor": "254",
                                "colorscalename": "LST_colors",
                                "colormap": "255",
                                "ncolor": "254",
                                "missing_value": "-999.0",
                                "expires": "1552089600",
                                "units": "m3/s",
                                "long_name": "current forecast",
                                "pointwidth": "0"
                            },
                            "CrossValHind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "CrossValHind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m3/s",
                                "long_name": "cross-validated hindcasts",
                                "missing_value": "-999.0"
                            }
                        },
                        "CFS": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "CFS",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "target_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "target_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "forecast time",
                                "pointwidth": "4",
                                "expires": "1585785600",
                                "calendar": "360",
                                "units": "months since 1960-01-01",
                                "bounds": "S",
                                "standard_name": "forecast_reference_time"
                            },
                            "PredErrorVars": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PredErrorVars",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "missing_value": "-999.0",
                                "expires": "1585785600",
                                "units": "m3/s",
                                "long_name": "prediction error variance",
                                "scale_min": "0.0",
                                "pointwidth": "0"
                            },
                            "PearsonR": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PearsonR",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "1.0",
                                "scale_min": "-1.0",
                                "ncolor": "254",
                                "CS": "-0.9960159",
                                "colorscalename": "correlationcolorscale",
                                "CE": "0.9960159",
                                "maxncolor": "254",
                                "colormap": "2763429",
                                "missing_value": "-999.0",
                                "units": "unitless",
                                "long_name": "Pearson correlation skill values"
                            },
                            "lon": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lon",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "-69.800003",
                                "scale_min": "-71.5",
                                "units": "degree_east",
                                "long_name": "longitude"
                            },
                            "lat": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "lat",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_max": "-29.299999",
                                "scale_min": "-32.0",
                                "units": "degree_north",
                                "long_name": "latitude"
                            },
                            "InputObs": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "InputObs",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m3/s",
                                "long_name": "input observations",
                                "missing_value": "-999.0"
                            },
                            "hindcast_date": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hindcast_date",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "long_name": "hindcast time",
                                "pointwidth": "4",
                                "calendar": "360",
                                "units": "months since 1960-01-01"
                            },
                            "Forecast": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Forecast",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "scale_min": "0.0",
                                "CS": "0",
                                "maxncolor": "254",
                                "colorscalename": "LST_colors",
                                "colormap": "255",
                                "ncolor": "254",
                                "missing_value": "-999.0",
                                "expires": "1585785600",
                                "units": "m3/s",
                                "long_name": "current forecast",
                                "pointwidth": "0"
                            },
                            "CrossValHind": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "CrossValHind",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m3/s",
                                "long_name": "cross-validated hindcasts",
                                "missing_value": "-999.0"
                            }
                        }
                    },
                    "Precipitation": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "Precipitation",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "target_date": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "target_date",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "forecast time",
                            "pointwidth": "4",
                            "expires": "1585785600",
                            "calendar": "360",
                            "units": "months since 1960-01-01",
                            "standard_name": "forecast_reference_time"
                        },
                        "PredErrorVars": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "PredErrorVars",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "missing_value": "-999.0",
                            "expires": "1585785600",
                            "units": "mm",
                            "long_name": "prediction error variance",
                            "scale_min": "0.0",
                            "pointwidth": "0"
                        },
                        "PearsonR": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "PearsonR",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_max": "1.0",
                            "scale_min": "-1.0",
                            "ncolor": "254",
                            "CS": "-0.9960159",
                            "colorscalename": "correlationcolorscale",
                            "CE": "0.9960159",
                            "maxncolor": "254",
                            "colormap": "2763429",
                            "missing_value": "-999.0",
                            "units": "unitless",
                            "long_name": "Pearson correlation skill values",
                            "pointwidth": "0"
                        },
                        "lon": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lon",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_max": "-69.800003",
                            "scale_min": "-71.5",
                            "units": "degree_east",
                            "long_name": "longitude"
                        },
                        "lat": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "lat",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "scale_max": "-29.299999",
                            "scale_min": "-32.0",
                            "units": "degree_north",
                            "long_name": "latitude"
                        },
                        "InputObs": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "InputObs",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "mm",
                            "long_name": "input observations",
                            "missing_value": "-999.0",
                            "pointwidth": "0"
                        },
                        "hindcast_date": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "hindcast_date",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "long_name": "hindcast time",
                            "pointwidth": "4",
                            "calendar": "360",
                            "units": "months since 1960-01-01"
                        },
                        "Forecast": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Forecast",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "maxncolor": "254",
                            "colorscalename": "prcp_0to500_colors",
                            "colormap": "341760",
                            "scale_max": "500.0",
                            "ncolor": "254",
                            "scale_min": "0.0",
                            "CE": "500",
                            "CS": "0",
                            "missing_value": "-999.0",
                            "expires": "1585785600",
                            "units": "mm",
                            "long_name": "current forecast",
                            "pointwidth": "0"
                        },
                        "CrossValHind": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "CrossValHind",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "mm",
                            "long_name": "cross-validated hindcasts",
                            "missing_value": "-999.0",
                            "pointwidth": "0"
                        }
                    }
                },
                "S_25": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_25",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Start time",
                    "expires": "1552089600",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "Y_11": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_11",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.5"
                },
                "X_09": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_09",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "0.5"
                },
                "STNID_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "STNID_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "gridtype": "0",
                    "long_name": "Station",
                    "pointwidth": "1.0"
                },
                "S_24": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_24",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1552089600",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "STNID": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "STNID",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "gridtype": "0",
                    "long_name": "Station",
                    "pointwidth": "1.0"
                },
                "T2_07": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T2_07",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Training period",
                    "pointwidth": "12"
                },
                "S_23": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_23",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1552089600",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "Y_10": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_10",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.5"
                },
                "T2_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T2_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Training period",
                    "pointwidth": "12"
                },
                "X_08": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_08",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "0.5"
                },
                "S_22": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_22",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1552089600",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "T2_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T2_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Training period",
                    "pointwidth": "12"
                },
                "S_21": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_21",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1552089600",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "Y_09": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_09",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "pointwidth": "0.5"
                },
                "T2_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T2_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Training period",
                    "pointwidth": "12"
                },
                "X_07": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_07",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "pointwidth": "0.5"
                },
                "S_20": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_20",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1552089600",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "Y_08": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_08",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "0.5"
                },
                "T2_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T2_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Training period",
                    "pointwidth": "12"
                },
                "T": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulo": "12.0",
                    "modulus": "12.0",
                    "calendar": "360",
                    "standard_name": "time",
                    "pointwidth": "1.0"
                },
                "X_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "long_name": "Longitude",
                    "pointwidth": "0.5"
                },
                "Y_07": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_07",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "2.5"
                },
                "X_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "long_name": "Longitude",
                    "pointwidth": "2.5"
                },
                "Y_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "0.05"
                },
                "X_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "long_name": "Longitude",
                    "pointwidth": "0.05"
                },
                "S_19": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_19",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1552089600",
                    "calendar": "360",
                    "long_name": "Forecast Issue Date",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "S_18": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_18",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "0.0"
                },
                "Y_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "0.25"
                },
                "X_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "long_name": "Longitude",
                    "pointwidth": "0.25"
                },
                "S_17": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_17",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1552089600",
                    "calendar": "360",
                    "long_name": "Forecast Issue Date",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "S_16": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_16",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulo": "12.0",
                    "modulus": "12.0",
                    "calendar": "360",
                    "long_name": "Hindcast Issue Date",
                    "pointwidth": "0"
                },
                "S_15": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_15",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "0.0"
                },
                "Y_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "0.5"
                },
                "L_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "long_name": "Forecast Lead Time in Months",
                    "pointwidth": "1.0"
                },
                "X_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "long_name": "Longitude",
                    "pointwidth": "0.5"
                },
                "S_14": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_14",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1552089600",
                    "calendar": "360",
                    "long_name": "Forecast Issue Date",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "Y_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "0.5"
                },
                "Y_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "0.5"
                },
                "X_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "long_name": "Longitude",
                    "pointwidth": "0.5"
                },
                "S_13": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_13",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulus": "12.0",
                    "modulo": "12.0",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "S_12": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_12",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "S_11": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_11",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "0"
                },
                "S_10": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_10",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulus": "12.0",
                    "modulo": "12.0",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "S_09": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_09",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "S_08": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_08",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "0"
                },
                "C": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "C",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "gridtype": "2",
                    "long_name": "Tercile Classes"
                },
                "gid_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "S_07": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_07",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1617667200",
                    "calendar": "360",
                    "pointwidth": "0",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time"
                },
                "gid": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "gid",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "unitless",
                    "gridtype": "2"
                },
                "S_06": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_06",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "1",
                    "modulus": "12.0",
                    "modulo": "12.0",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "S_05": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_05",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "S_04": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_04",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "pointwidth": "0"
                },
                "Y_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "0.5"
                },
                "Y": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "Y",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_north",
                    "gridtype": "0",
                    "standard_name": "latitude",
                    "long_name": "Latitude",
                    "pointwidth": "0.5"
                },
                "X": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "X",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "degree_east",
                    "gridtype": "0",
                    "standard_name": "longitude",
                    "long_name": "Longitude",
                    "pointwidth": "0.5"
                },
                "S_03": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_03",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1586131200",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "S_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1552089600",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "L_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "pointwidth": "0"
                },
                "T2_02": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T2_02",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Training period",
                    "pointwidth": "12"
                },
                "S_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1585785600",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "L_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "pointwidth": "0"
                },
                "T2_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T2_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Training period",
                    "pointwidth": "12"
                },
                "ID_01": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ID_01",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "gridtype": "0",
                    "pointwidth": "1.0"
                },
                "S": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "S",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "expires": "1585785600",
                    "calendar": "360",
                    "long_name": "Start time",
                    "standard_name": "forecast_reference_time",
                    "pointwidth": "0"
                },
                "L": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "L",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months",
                    "gridtype": "0",
                    "pointwidth": "0"
                },
                "T2": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "T2",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "months since 1960-01-01",
                    "gridtype": "0",
                    "calendar": "360",
                    "long_name": "Training period",
                    "pointwidth": "12"
                },
                "ID": {
                    "iridl_type": "DataSet",
                    "iridl_ds_name": "ID",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "units": "ids",
                    "gridtype": "2"
                },
                "dir": "SOURCES/IRI/FD/CPT"
            },
            "ECHAM3": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/IRI/FD/ECHAM3",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "ECHAM3",
                "restriction": "Public",
                "Forecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/IRI/FD/ECHAM3/Forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "Forecast",
                    "restriction": "requires dlauth tokens"
                },
                "History": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/IRI/FD/ECHAM3/History",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "History",
                    "restriction": "Public",
                    "MONTHLY": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/IRI/FD/ECHAM3/History/MONTHLY",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "MONTHLY",
                        "restriction": "Public",
                        "R25004": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "R25004",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "Conventions": "IRIDL",
                                "filepattern": "/mstore/iri/forecast/data/echam/history/25004/25004fcst_%4d.01",
                                "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM3/.History/.MONTHLY/.R25004/.griblist.html"
                            },
                            "total_air_column": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "total_air_column",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "VVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "vertically integrated meridional velocity",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-480666.0",
                                    "units": "kg m s-1",
                                    "grib_name": "VVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "468635.0",
                                    "gribparam": "111"
                                },
                                "VQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "vertically integrated meridional moisture flux",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1925.5742",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "VQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "2353.3718",
                                    "gribparam": "113"
                                },
                                "UVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "vertically integrated zonal velocity",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-333873.0",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "UVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "599607.25",
                                    "gribparam": "110"
                                },
                                "UQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "vertically integrated zonal moisture flux",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1918.8711",
                                    "units": "kg m s-1",
                                    "grib_name": "UQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "1988.2036",
                                    "gribparam": "112"
                                },
                                "QVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "vertically integrated specific humidity",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-6.4091949",
                                    "units": "kg/m2",
                                    "grib_name": "QVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "86.696793",
                                    "gribparam": "230"
                                },
                                "cltm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "cltm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "cloud cover total mean[0-1]",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "cltm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "1.0",
                                    "gribparam": "164"
                                },
                                "ALWCVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALWCVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "vertically integrated liquid water content",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "kg/m2",
                                    "grib_name": "ALWCVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "1.9643555",
                                    "gribparam": "231"
                                }
                            },
                            "top": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "top",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "0",
                                        "long_name": "Net Shortwave Radiation (top)",
                                        "calendar": "360",
                                        "process": "31",
                                        "scale_min": "0.0",
                                        "units": "Wm-2",
                                        "grib_name": "rst",
                                        "PTVersion": "0",
                                        "gribleveltype": "1",
                                        "scale_max": "1192.5",
                                        "gribparam": "178"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "0",
                                        "long_name": "longwave flux",
                                        "calendar": "360",
                                        "process": "31",
                                        "scale_min": "-379.13428",
                                        "units": "Wm-2",
                                        "grib_name": "rlt",
                                        "PTVersion": "0",
                                        "gribleveltype": "1",
                                        "scale_max": "-68.352051",
                                        "gribparam": "179"
                                    }
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "0",
                                            "long_name": "solar flux",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-684.40796",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0U",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "105"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "0",
                                            "long_name": "solar flux",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "1193.7188",
                                            "gribparam": "103"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "0",
                                            "long_name": "longwave flux",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-379.13428",
                                            "units": "W/m2",
                                            "grib_name": "TRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "-68.352051",
                                            "gribparam": "104"
                                        }
                                    }
                                }
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "zg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "zg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Geopotential",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-5387.7891",
                                    "units": "m2 s-2",
                                    "grib_name": "zg",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "59908.211",
                                    "gribparam": "129"
                                },
                                "u3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u*3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "u*^3",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "1.28755784E-15",
                                    "units": "unitless",
                                    "grib_name": "u*3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "3.57389450E-04",
                                    "gribparam": "159"
                                },
                                "TSLIN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TSLIN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "TSLIN heat",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-2149.8203",
                                    "units": "W/m2",
                                    "grib_name": "TSLIN",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "1142.7476",
                                    "gribparam": "220"
                                },
                                "TD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "soil temperature",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "184.98486",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD5",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "321.37402",
                                    "gribparam": "209"
                                },
                                "TD4": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD4",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "soil temperature",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "181.06958",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD4",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "326.56592",
                                    "gribparam": "208"
                                },
                                "TD3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "soil temperature",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.65356",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "339.92017",
                                    "gribparam": "207"
                                },
                                "td": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "deep soil temperature",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "192.80615",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "316.14502",
                                    "gribparam": "170"
                                },
                                "tauv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "V-component of Surface Wind Stress",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-3.4604301",
                                    "units": "Nm-2",
                                    "grib_name": "tauv",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "4.6445599",
                                    "gribparam": "181"
                                },
                                "tauu": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauu",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "U-component of Surface Wind Stress",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-3.6259575",
                                    "units": "Nm-2",
                                    "grib_name": "tauu",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "4.4954176",
                                    "gribparam": "180"
                                },
                                "Tasmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Tasmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "maximum air temperature (surface)",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.71631",
                                    "units": "Kelvin_scale",
                                    "grib_name": "Tasmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "341.80078",
                                    "gribparam": "214"
                                },
                                "tasmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tasmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "minimum air temperature (surface)",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.64746",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tasmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "331.18115",
                                    "gribparam": "215"
                                },
                                "tas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "air temperature (surface)",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.66211",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "338.1499",
                                    "gribparam": "169"
                                },
                                "stemp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "stemp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Surface Temperature",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.65356",
                                    "units": "unitless",
                                    "grib_name": "stemp",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "339.92017",
                                    "gribparam": "139"
                                },
                                "srun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "srun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "surface runoff",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "srun",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "2.45391857E-06",
                                    "gribparam": "160"
                                },
                                "SRADSU": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SRADSU",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "shortwave radiation upward (surface)",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-691.87061",
                                    "units": "W/m2",
                                    "grib_name": "SRADSU",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "0.9914551",
                                    "gribparam": "204"
                                },
                                "soilm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soilm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "soil wetness",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "soilm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "0.2000008",
                                    "gribparam": "140"
                                },
                                "SNMEL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SNMEL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "snow melt",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "SNMEL",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "2.28692079E-06",
                                    "gribparam": "218"
                                },
                                "snd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "snd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Snow Depth",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "m",
                                    "grib_name": "snd",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "13.99585",
                                    "gribparam": "141"
                                },
                                "slp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "slp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "151",
                                    "long_name": "mean sea level pressure",
                                    "gribleveltype": "102",
                                    "Z": "Z_05",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25004 hybrid_lev P",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                },
                                "pss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Surface Pressure",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "46227.625",
                                    "units": "Pa",
                                    "grib_name": "pss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "109555.19",
                                    "gribparam": "134"
                                },
                                "prl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Large Scale Precipitation",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prl",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "2.65421113E-06",
                                    "gribparam": "142"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "260",
                                    "long_name": "Total Precipitation",
                                    "grib_name": "totprcp",
                                    "units": "m/s",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prc": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prc",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Convective Precipitation",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prc",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "3.19129322E-06",
                                    "gribparam": "143"
                                },
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "0",
                                        "long_name": "Net Shortwave Radiation (surface)",
                                        "calendar": "360",
                                        "process": "31",
                                        "scale_min": "-14.222672",
                                        "units": "Wm-2",
                                        "grib_name": "rss",
                                        "PTVersion": "0",
                                        "gribleveltype": "1",
                                        "scale_max": "998.04688",
                                        "gribparam": "176"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "0",
                                        "long_name": "longwave flux",
                                        "calendar": "360",
                                        "process": "31",
                                        "scale_min": "-291.77075",
                                        "units": "Wm-2",
                                        "grib_name": "rls",
                                        "PTVersion": "0",
                                        "gribleveltype": "1",
                                        "scale_max": "121.18408",
                                        "gribparam": "177"
                                    }
                                },
                                "hfss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Surface Flux of Sensible Heat",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1481.6172",
                                    "units": "Wm-2",
                                    "grib_name": "hfss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "1301.637",
                                    "gribparam": "146"
                                },
                                "hfls": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfls",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Surface Flux of Latent Heat",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-2451.7578",
                                    "units": "Wm-2",
                                    "grib_name": "hfls",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "430.98242",
                                    "gribparam": "147"
                                },
                                "evs": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "evs",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Evaporation",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-9.80478944E-07",
                                    "units": "m (H2O)",
                                    "grib_name": "evs",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "1.64414075E-07",
                                    "gribparam": "182"
                                },
                                "dpsdy": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdy",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "274",
                                    "long_name": "Meridional Deriv. of Surface Pres.",
                                    "grib_name": "dpsdy",
                                    "units": "kilogram meter-2 second-2",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "dpsdx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "273",
                                    "long_name": "Zonal Deriv. of Surface Pres.",
                                    "grib_name": "dpsdx",
                                    "units": "kilogram meter-2 second-2",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "0",
                                            "long_name": "solar flux",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-2278.4609",
                                            "units": "W/m2",
                                            "grib_name": "SRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "0.03125",
                                            "gribparam": "106"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "0",
                                            "long_name": "longwave flux",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-727.72119",
                                            "units": "W/m2",
                                            "grib_name": "TRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "-58.949463",
                                            "gribparam": "107"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "solar flux",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "1011.5781",
                                            "gribparam": "101"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "0",
                                            "long_name": "longwave flux",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-291.77075",
                                            "units": "W/m2",
                                            "grib_name": "TRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "59.243164",
                                            "gribparam": "102"
                                        }
                                    }
                                },
                                "ALBEDO": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALBEDO",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Albedo (surface)",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.04891968",
                                    "units": "unitless",
                                    "grib_name": "ALBEDO",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "0.8019387",
                                    "gribparam": "175"
                                }
                            },
                            "PressureLevel": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PressureLevel",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "132",
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "131",
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Kelvin_scale",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Temperature",
                                    "calendar": "360",
                                    "process": "31",
                                    "grib_name": "ta",
                                    "PTVersion": "0",
                                    "gribparam": "130"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "vorticity",
                                    "calendar": "360",
                                    "process": "31",
                                    "grib_name": "rvort",
                                    "PTVersion": "0",
                                    "gribparam": "138"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "148",
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "156",
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "fnname": "max",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "kilogram meter-1 second-3",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "135",
                                    "long_name": "vertical pressure velocity",
                                    "grib_name": "ua",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Specific Humidity",
                                    "calendar": "360",
                                    "process": "31",
                                    "grib_name": "hus",
                                    "PTVersion": "0",
                                    "gribparam": "133"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Divergence",
                                    "calendar": "360",
                                    "process": "31",
                                    "grib_name": "div",
                                    "PTVersion": "0",
                                    "gribparam": "155"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "149",
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                }
                            },
                            "hybrid_lev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hybrid_lev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "132",
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "units": "m/s",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "131",
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "units": "m/s",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Temperature",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-22.848301",
                                    "units": "Kelvin_scale",
                                    "grib_name": "ta",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "409.66205",
                                    "gribparam": "130"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "vorticity",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1.68606730E-05",
                                    "units": "s-1",
                                    "grib_name": "rvort",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "2.36537871E-05",
                                    "gribparam": "138"
                                },
                                "Rv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for moist air"
                                },
                                "Rd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for dry air"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "148",
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "units": "meter2 second-1",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1.68606730E-05",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "2.36537871E-05"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "156",
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "units": "m",
                                    "fnname": "max",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "pressure",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "135",
                                    "long_name": "vertical pressure velocity",
                                    "units": "Pa/s",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25004 hybrid_lev omegahalf",
                                    "grib_name": "ua",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "logpsl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "logpsl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Log Surface Pressure",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-0.03099993",
                                    "units": "unitless",
                                    "grib_name": "logpsl",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "16.256054",
                                    "gribparam": "152"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Specific Humidity",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-0.008156321",
                                    "units": "unitless",
                                    "grib_name": "hus",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "0.01511904",
                                    "gribparam": "133"
                                },
                                "gravity": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "gravity",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s2",
                                    "long_name": "earth\\'s gravity"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Divergence",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-2.17277375E-06",
                                    "units": "s-1",
                                    "grib_name": "div",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "2.06693835E-06",
                                    "gribparam": "155"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "149",
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "units": "meter2 second-1",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-2.17277375E-06",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "2.06693835E-06"
                                },
                                "BC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "BC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "ACLCAC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ACLCAC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "cloud cover",
                                    "calendar": "360",
                                    "process": "31",
                                    "units": "unitless",
                                    "scale_min": "0.0",
                                    "grib_name": "ACLCAC",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "1.0",
                                    "gribparam": "223"
                                },
                                "AC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Pa"
                                }
                            },
                            "above_ground": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "above_ground",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "10m windspeed",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.005932529",
                                    "units": "unitless",
                                    "grib_name": "wind10",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "39.517067",
                                    "gribparam": "171"
                                },
                                "vas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "V-wind at 10",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-35.15921",
                                    "units": "m/s",
                                    "grib_name": "vas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "33.774658",
                                    "gribparam": "166"
                                },
                                "uas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "uas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "U-wind at 10",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-32.999084",
                                    "units": "m/s",
                                    "grib_name": "uas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "35.353714",
                                    "gribparam": "165"
                                },
                                "td2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Dewpoint at 2 m",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "169.07593",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "304.90161",
                                    "gribparam": "168"
                                },
                                "t2mmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "max 2m temp",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "183.78467",
                                    "units": "unitless",
                                    "grib_name": "t2mmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "329.95337",
                                    "gribparam": "201"
                                },
                                "t2mmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "min 2m temp",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "183.68628",
                                    "units": "unitless",
                                    "grib_name": "t2mmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "325.12134",
                                    "gribparam": "202"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Temperature at 2 m",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "183.73608",
                                    "units": "Kelvin_scale",
                                    "grib_name": "t2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "327.67871",
                                    "gribparam": "167"
                                }
                            },
                            "Z_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "sp_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "long_name": "complex"
                            },
                            "Z_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Z_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0"
                            },
                            "Y_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "Z_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0",
                                "long_name": "Height"
                            },
                            "sp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "Z": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "pointwidth": "1.0"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "pointwidth": "2.8125",
                                "modulus": "360.0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM3/History/MONTHLY/R25004"
                        },
                        "R25005": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "R25005",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "Conventions": "IRIDL",
                                "filepattern": "/mstore/iri/forecast/data/echam/history/25005/25005fcst_%4d.01",
                                "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM3/.History/.MONTHLY/.R25005/.griblist.html"
                            },
                            "total_air_column": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "total_air_column",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "VVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-449085.0",
                                    "units": "kg m s-1",
                                    "grib_name": "VVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "477803.56",
                                    "gribparam": "111",
                                    "process": "31"
                                },
                                "VQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2046.0117",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "VQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "2458.4805",
                                    "gribparam": "113",
                                    "process": "31"
                                },
                                "UVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-358273.0",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "UVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "629064.69",
                                    "gribparam": "110",
                                    "process": "31"
                                },
                                "UQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1710.4648",
                                    "units": "kg m s-1",
                                    "grib_name": "UQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "1847.939",
                                    "gribparam": "112",
                                    "process": "31"
                                },
                                "QVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated specific humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-6.5536499",
                                    "units": "kg/m2",
                                    "grib_name": "QVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "88.415474",
                                    "gribparam": "230",
                                    "process": "31"
                                },
                                "cltm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "cltm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover total mean[0-1]",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "cltm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "1.0",
                                    "gribparam": "164",
                                    "process": "31"
                                },
                                "ALWCVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALWCVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated liquid water content",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "kg/m2",
                                    "grib_name": "ALWCVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "1.9521484",
                                    "gribparam": "231",
                                    "process": "31"
                                }
                            },
                            "top": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "top",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (top)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "0.0",
                                        "units": "Wm-2",
                                        "grib_name": "rst",
                                        "PTVersion": "0",
                                        "gribleveltype": "1",
                                        "scale_max": "1192.4688",
                                        "gribparam": "178",
                                        "process": "31"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-376.65625",
                                        "units": "Wm-2",
                                        "grib_name": "rlt",
                                        "PTVersion": "0",
                                        "gribleveltype": "1",
                                        "scale_max": "-67.124756",
                                        "gribparam": "179",
                                        "process": "31"
                                    }
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-683.52295",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0U",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "105",
                                            "process": "31"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "1193.6875",
                                            "gribparam": "103",
                                            "process": "31"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-376.65625",
                                            "units": "W/m2",
                                            "grib_name": "TRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "-67.124756",
                                            "gribparam": "104",
                                            "process": "31"
                                        }
                                    }
                                }
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "zg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "zg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Geopotential",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-5387.7891",
                                    "units": "m2 s-2",
                                    "grib_name": "zg",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "59908.211",
                                    "gribparam": "129",
                                    "process": "31"
                                },
                                "u3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u*3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "u*^3",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "1.21634948E-15",
                                    "units": "unitless",
                                    "grib_name": "u*3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "3.70047987E-04",
                                    "gribparam": "159",
                                    "process": "31"
                                },
                                "TSLIN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TSLIN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "TSLIN heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1863.3438",
                                    "units": "W/m2",
                                    "grib_name": "TSLIN",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "1086.4329",
                                    "gribparam": "220",
                                    "process": "31"
                                },
                                "TD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "184.95459",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD5",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "321.37036",
                                    "gribparam": "209",
                                    "process": "31"
                                },
                                "TD4": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD4",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "180.87109",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD4",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "326.70557",
                                    "gribparam": "208",
                                    "process": "31"
                                },
                                "TD3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "179.53418",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "339.44629",
                                    "gribparam": "207",
                                    "process": "31"
                                },
                                "td": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "deep soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "192.47876",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "316.17139",
                                    "gribparam": "170",
                                    "process": "31"
                                },
                                "tauv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-3.8241749",
                                    "units": "Nm-2",
                                    "grib_name": "tauv",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "3.6891708",
                                    "gribparam": "181",
                                    "process": "31"
                                },
                                "tauu": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauu",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-4.3125763",
                                    "units": "Nm-2",
                                    "grib_name": "tauu",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "4.8918047",
                                    "gribparam": "180",
                                    "process": "31"
                                },
                                "Tasmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Tasmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "maximum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "179.5625",
                                    "units": "Kelvin_scale",
                                    "grib_name": "Tasmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "341.3645",
                                    "gribparam": "214",
                                    "process": "31"
                                },
                                "tasmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tasmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "minimum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "179.52832",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tasmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "330.27173",
                                    "gribparam": "215",
                                    "process": "31"
                                },
                                "tas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "179.53931",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "337.82812",
                                    "gribparam": "169",
                                    "process": "31"
                                },
                                "stemp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "stemp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "179.53418",
                                    "units": "unitless",
                                    "grib_name": "stemp",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "339.44629",
                                    "gribparam": "139",
                                    "process": "31"
                                },
                                "srun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "srun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "surface runoff",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "srun",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "2.28331191E-06",
                                    "gribparam": "160",
                                    "process": "31"
                                },
                                "SRADSU": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SRADSU",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "shortwave radiation upward (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-755.42407",
                                    "units": "W/m2",
                                    "grib_name": "SRADSU",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "2.291748",
                                    "gribparam": "204",
                                    "process": "31"
                                },
                                "soilm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soilm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil wetness",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "soilm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "0.2000008",
                                    "gribparam": "140",
                                    "process": "31"
                                },
                                "SNMEL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SNMEL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "snow melt",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "SNMEL",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "1.87964179E-06",
                                    "gribparam": "218",
                                    "process": "31"
                                },
                                "snd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "snd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Snow Depth",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m",
                                    "grib_name": "snd",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "10.0",
                                    "gribparam": "141",
                                    "process": "31"
                                },
                                "slp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "slp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "151",
                                    "long_name": "mean sea level pressure",
                                    "gribleveltype": "102",
                                    "Z": "Z_05",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25005 hybrid_lev P",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                },
                                "pss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "46466.312",
                                    "units": "Pa",
                                    "grib_name": "pss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "109496.06",
                                    "gribparam": "134",
                                    "process": "31"
                                },
                                "prl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Large Scale Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prl",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "2.47487333E-06",
                                    "gribparam": "142",
                                    "process": "31"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "260",
                                    "long_name": "Total Precipitation",
                                    "grib_name": "totprcp",
                                    "units": "m/s",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "process": "31"
                                },
                                "prc": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prc",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Convective Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prc",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "3.06649599E-06",
                                    "gribparam": "143",
                                    "process": "31"
                                },
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (surface)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-32.947937",
                                        "units": "Wm-2",
                                        "grib_name": "rss",
                                        "PTVersion": "0",
                                        "gribleveltype": "1",
                                        "scale_max": "999.125",
                                        "gribparam": "176",
                                        "process": "31"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-290.17456",
                                        "units": "Wm-2",
                                        "grib_name": "rls",
                                        "PTVersion": "0",
                                        "gribleveltype": "1",
                                        "scale_max": "105.60205",
                                        "gribparam": "177",
                                        "process": "31"
                                    }
                                },
                                "hfss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Sensible Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1381.8281",
                                    "units": "Wm-2",
                                    "grib_name": "hfss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "849.07471",
                                    "gribparam": "146",
                                    "process": "31"
                                },
                                "hfls": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfls",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Latent Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1996.9023",
                                    "units": "Wm-2",
                                    "grib_name": "hfls",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "435.73828",
                                    "gribparam": "147",
                                    "process": "31"
                                },
                                "evs": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "evs",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Evaporation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-7.98539077E-07",
                                    "units": "m (H2O)",
                                    "grib_name": "evs",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "1.58640546E-07",
                                    "gribparam": "182",
                                    "process": "31"
                                },
                                "dpsdy": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdy",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "274",
                                    "long_name": "Meridional Deriv. of Surface Pres.",
                                    "grib_name": "dpsdy",
                                    "units": "kilogram meter-2 second-2",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "process": "31"
                                },
                                "dpsdx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "273",
                                    "long_name": "Zonal Deriv. of Surface Pres.",
                                    "grib_name": "dpsdx",
                                    "units": "kilogram meter-2 second-2",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "process": "31"
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-2649.0859",
                                            "units": "W/m2",
                                            "grib_name": "SRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "0.03125",
                                            "gribparam": "106",
                                            "process": "31"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-724.5979",
                                            "units": "W/m2",
                                            "grib_name": "TRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "-58.779541",
                                            "gribparam": "107",
                                            "process": "31"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "10",
                                            "calendar": "360",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "1017.6562",
                                            "gribparam": "101",
                                            "process": "31"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-290.17456",
                                            "units": "W/m2",
                                            "grib_name": "TRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1",
                                            "scale_max": "44.848877",
                                            "gribparam": "102",
                                            "process": "31"
                                        }
                                    }
                                },
                                "ALBEDO": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALBEDO",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Albedo (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.04906815",
                                    "units": "unitless",
                                    "grib_name": "ALBEDO",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "0.8019523",
                                    "gribparam": "175",
                                    "process": "31"
                                }
                            },
                            "PressureLevel": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PressureLevel",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "132",
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "131",
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Kelvin_scale",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "ta",
                                    "PTVersion": "0",
                                    "gribparam": "130",
                                    "process": "31"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "rvort",
                                    "PTVersion": "0",
                                    "gribparam": "138",
                                    "process": "31"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "148",
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "156",
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "fnname": "max",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "kilogram meter-1 second-3",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "135",
                                    "long_name": "vertical pressure velocity",
                                    "grib_name": "ua",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "hus",
                                    "PTVersion": "0",
                                    "gribparam": "133",
                                    "process": "31"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "div",
                                    "PTVersion": "0",
                                    "gribparam": "155",
                                    "process": "31"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "149",
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                }
                            },
                            "hybrid_lev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hybrid_lev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "132",
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "units": "m/s",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "process": "31"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "131",
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "units": "m/s",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "process": "31"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-23.157942",
                                    "units": "Kelvin_scale",
                                    "grib_name": "ta",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "409.7746",
                                    "gribparam": "130",
                                    "process": "31"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.66701084E-05",
                                    "units": "s-1",
                                    "grib_name": "rvort",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "2.32847542E-05",
                                    "gribparam": "138",
                                    "process": "31"
                                },
                                "Rv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for moist air"
                                },
                                "Rd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for dry air"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "148",
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "units": "meter2 second-1",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.66701084E-05",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "2.32847542E-05",
                                    "process": "31"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "156",
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "units": "m",
                                    "fnname": "max",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "process": "31"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "pressure",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "process": "31"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "135",
                                    "long_name": "vertical pressure velocity",
                                    "units": "Pa/s",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25005 hybrid_lev omegahalf",
                                    "grib_name": "ua",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "process": "31"
                                },
                                "logpsl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "logpsl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Log Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-0.03152702",
                                    "units": "unitless",
                                    "grib_name": "logpsl",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "16.256054",
                                    "gribparam": "152",
                                    "process": "31"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-0.008007026",
                                    "units": "unitless",
                                    "grib_name": "hus",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "0.01507445",
                                    "gribparam": "133",
                                    "process": "31"
                                },
                                "gravity": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "gravity",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s2",
                                    "long_name": "earth\\'s gravity"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2.14723718E-06",
                                    "units": "s-1",
                                    "grib_name": "div",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "1.96223755E-06",
                                    "gribparam": "155",
                                    "process": "31"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "gribparam": "149",
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "units": "meter2 second-1",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2.14723718E-06",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "1.96223755E-06",
                                    "process": "31"
                                },
                                "BC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "BC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "ACLCAC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ACLCAC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "units": "unitless",
                                    "scale_min": "0.0",
                                    "grib_name": "ACLCAC",
                                    "PTVersion": "0",
                                    "gribleveltype": "109",
                                    "scale_max": "1.0",
                                    "gribparam": "223",
                                    "process": "31"
                                },
                                "AC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Pa"
                                }
                            },
                            "above_ground": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "above_ground",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "10m windspeed",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.006682973",
                                    "units": "unitless",
                                    "grib_name": "wind10",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "34.791058",
                                    "gribparam": "171",
                                    "process": "31"
                                },
                                "vas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-31.870132",
                                    "units": "m/s",
                                    "grib_name": "vas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "32.882111",
                                    "gribparam": "166",
                                    "process": "31"
                                },
                                "uas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "uas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-33.390701",
                                    "units": "m/s",
                                    "grib_name": "uas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "32.952484",
                                    "gribparam": "165",
                                    "process": "31"
                                },
                                "td2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Dewpoint at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "169.68677",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "304.38574",
                                    "gribparam": "168",
                                    "process": "31"
                                },
                                "t2mmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "max 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "184.57227",
                                    "units": "unitless",
                                    "grib_name": "t2mmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "330.27783",
                                    "gribparam": "201",
                                    "process": "31"
                                },
                                "t2mmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "min 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "184.40527",
                                    "units": "unitless",
                                    "grib_name": "t2mmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "325.43384",
                                    "gribparam": "202",
                                    "process": "31"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "184.46313",
                                    "units": "Kelvin_scale",
                                    "grib_name": "t2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1",
                                    "scale_max": "328.93896",
                                    "gribparam": "167",
                                    "process": "31"
                                }
                            },
                            "Z_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "sp_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "long_name": "complex"
                            },
                            "Z_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Z_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0"
                            },
                            "Y_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "Z_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0",
                                "long_name": "Height"
                            },
                            "sp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "Z": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "pointwidth": "1.0"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "pointwidth": "2.8125",
                                "modulus": "360.0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM3/History/MONTHLY/R25005"
                        },
                        "R25006": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "R25006",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "Conventions": "IRIDL",
                                "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM3/.History/.MONTHLY/.R25006/.griblist.html",
                                "filepattern": "/mstore/iri/forecast/data/echam/history/25006/25006fcst_%4d.01"
                            },
                            "total_air_column": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "total_air_column",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "VVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "478127.0",
                                    "gribparam": "111",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-434749.0",
                                    "units": "kg m s-1",
                                    "grib_name": "VVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "VQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2402.9756",
                                    "gribparam": "113",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1932.8789",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "VQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "UVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "608848.19",
                                    "gribparam": "110",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-299621.81",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "UVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "UQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1971.3162",
                                    "gribparam": "112",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1843.5312",
                                    "units": "kg m s-1",
                                    "grib_name": "UQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "QVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "85.219368",
                                    "gribparam": "230",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated specific humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-6.2508087",
                                    "units": "kg/m2",
                                    "grib_name": "QVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "cltm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "cltm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.0",
                                    "gribparam": "164",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover total mean[0-1]",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "cltm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "ALWCVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALWCVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.8405151",
                                    "gribparam": "231",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated liquid water content",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "kg/m2",
                                    "grib_name": "ALWCVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "top": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "top",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1192.4688",
                                        "gribparam": "178",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (top)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "0.0",
                                        "units": "Wm-2",
                                        "grib_name": "rst",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "-66.82959",
                                        "gribparam": "179",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-374.65918",
                                        "units": "Wm-2",
                                        "grib_name": "rlt",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    }
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "105",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-685.43237",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0U",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1193.6562",
                                            "gribparam": "103",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-66.82959",
                                            "gribparam": "104",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-374.65918",
                                            "units": "W/m2",
                                            "grib_name": "TRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    }
                                }
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "zg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "zg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "59908.211",
                                    "gribparam": "129",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Geopotential",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-5387.7891",
                                    "units": "m2 s-2",
                                    "grib_name": "zg",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "u3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u*3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.97145748E-04",
                                    "gribparam": "159",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "u*^3",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "1.34949628E-15",
                                    "units": "unitless",
                                    "grib_name": "u*3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TSLIN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TSLIN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1009.9243",
                                    "gribparam": "220",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "TSLIN heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2086.1914",
                                    "units": "W/m2",
                                    "grib_name": "TSLIN",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "321.12891",
                                    "gribparam": "209",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "183.11572",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD5",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD4": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD4",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "326.3335",
                                    "gribparam": "208",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "179.19312",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD4",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "339.67798",
                                    "gribparam": "207",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "177.8938",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "td": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "316.302",
                                    "gribparam": "170",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "deep soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "191.48096",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tauv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "5.5244732",
                                    "gribparam": "181",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-3.3637857",
                                    "units": "Nm-2",
                                    "grib_name": "tauv",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tauu": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauu",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "4.3828039",
                                    "gribparam": "180",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-4.2395811",
                                    "units": "Nm-2",
                                    "grib_name": "tauu",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "Tasmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Tasmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "341.61133",
                                    "gribparam": "214",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "maximum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "177.91113",
                                    "units": "Kelvin_scale",
                                    "grib_name": "Tasmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tasmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tasmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "330.31567",
                                    "gribparam": "215",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "minimum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "177.89355",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tasmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "337.96387",
                                    "gribparam": "169",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "177.89893",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "stemp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "stemp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "339.67798",
                                    "gribparam": "139",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "177.8938",
                                    "units": "unitless",
                                    "grib_name": "stemp",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "srun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "srun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.39926158E-06",
                                    "gribparam": "160",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "surface runoff",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "srun",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "SRADSU": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SRADSU",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.1320801",
                                    "gribparam": "204",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "shortwave radiation upward (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-697.42505",
                                    "units": "W/m2",
                                    "grib_name": "SRADSU",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "soilm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soilm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.2000008",
                                    "gribparam": "140",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil wetness",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "soilm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "SNMEL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SNMEL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.23674579E-06",
                                    "gribparam": "218",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "snow melt",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "SNMEL",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "snd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "snd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "15.161621",
                                    "gribparam": "141",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Snow Depth",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m",
                                    "grib_name": "snd",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "slp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "slp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "mean sea level pressure",
                                    "gribleveltype": "102",
                                    "gribparam": "151",
                                    "Z": "Z_05",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25006 hybrid_lev P",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "pss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "109461.88",
                                    "gribparam": "134",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "46482.125",
                                    "units": "Pa",
                                    "grib_name": "pss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.33156607E-06",
                                    "gribparam": "142",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Large Scale Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prl",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Total Precipitation",
                                    "grib_name": "totprcp",
                                    "gribparam": "260",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prc": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prc",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.12004704E-06",
                                    "gribparam": "143",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Convective Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prc",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "999.57812",
                                        "gribparam": "176",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (surface)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-11.206589",
                                        "units": "Wm-2",
                                        "grib_name": "rss",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "103.47583",
                                        "gribparam": "177",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-282.46265",
                                        "units": "Wm-2",
                                        "grib_name": "rls",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    }
                                },
                                "hfss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1010.9685",
                                    "gribparam": "146",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Sensible Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1568.8477",
                                    "units": "Wm-2",
                                    "grib_name": "hfss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "hfls": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfls",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "401.51489",
                                    "gribparam": "147",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Latent Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2011.1836",
                                    "units": "Wm-2",
                                    "grib_name": "hfls",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "evs": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "evs",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.50800361E-07",
                                    "gribparam": "182",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Evaporation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-8.04237061E-07",
                                    "units": "m (H2O)",
                                    "grib_name": "evs",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "dpsdy": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdy",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Meridional Deriv. of Surface Pres.",
                                    "grib_name": "dpsdy",
                                    "gribparam": "274",
                                    "units": "kilogram meter-2 second-2",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "dpsdx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Zonal Deriv. of Surface Pres.",
                                    "grib_name": "dpsdx",
                                    "gribparam": "273",
                                    "units": "kilogram meter-2 second-2",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03125",
                                            "gribparam": "106",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-2437.0117",
                                            "units": "W/m2",
                                            "grib_name": "SRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-56.693848",
                                            "gribparam": "107",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-724.52295",
                                            "units": "W/m2",
                                            "grib_name": "TRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1022.5312",
                                            "gribparam": "101",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "10",
                                            "calendar": "360",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "46.420166",
                                            "gribparam": "102",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-282.88818",
                                            "units": "W/m2",
                                            "grib_name": "TRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    }
                                },
                                "ALBEDO": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALBEDO",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.8019494",
                                    "gribparam": "175",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Albedo (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.04899573",
                                    "units": "unitless",
                                    "grib_name": "ALBEDO",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "PressureLevel": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PressureLevel",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "Kelvin_scale",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "130",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "ta",
                                    "PTVersion": "0"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "138",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "rvort",
                                    "PTVersion": "0"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "fnname": "max",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "kilogram meter-1 second-3",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "vertical pressure velocity",
                                    "gribparam": "135",
                                    "grib_name": "ua",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "133",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "hus",
                                    "PTVersion": "0"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "155",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "div",
                                    "PTVersion": "0"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                }
                            },
                            "hybrid_lev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hybrid_lev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "409.56641",
                                    "gribparam": "130",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-22.708986",
                                    "units": "Kelvin_scale",
                                    "grib_name": "ta",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.39773999E-05",
                                    "gribparam": "138",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.73379340E-05",
                                    "units": "s-1",
                                    "grib_name": "rvort",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "Rv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for moist air"
                                },
                                "Rd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for dry air"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.39773999E-05",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.73379340E-05",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "units": "m",
                                    "fnname": "max",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "pressure",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "vertical pressure velocity",
                                    "units": "Pa/s",
                                    "gribparam": "135",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25006 hybrid_lev omegahalf",
                                    "grib_name": "ua",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "logpsl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "logpsl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "16.256054",
                                    "gribparam": "152",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Log Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-0.0305445",
                                    "units": "unitless",
                                    "grib_name": "logpsl",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.01515977",
                                    "gribparam": "133",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-0.008108891",
                                    "units": "unitless",
                                    "grib_name": "hus",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "gravity": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "gravity",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s2",
                                    "long_name": "earth\\'s gravity"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.04394200E-06",
                                    "gribparam": "155",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2.08850565E-06",
                                    "units": "s-1",
                                    "grib_name": "div",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.04394200E-06",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2.08850565E-06",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "BC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "BC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "ACLCAC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ACLCAC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.0",
                                    "gribparam": "223",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "ACLCAC",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "AC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Pa"
                                }
                            },
                            "above_ground": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "above_ground",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "38.048679",
                                    "gribparam": "171",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "10m windspeed",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.008250136",
                                    "units": "unitless",
                                    "grib_name": "wind10",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "vas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "33.242691",
                                    "gribparam": "166",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-31.796066",
                                    "units": "m/s",
                                    "grib_name": "vas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "uas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "uas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "37.011673",
                                    "gribparam": "165",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-36.122818",
                                    "units": "m/s",
                                    "grib_name": "uas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "td2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "304.2146",
                                    "gribparam": "168",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Dewpoint at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "167.9624",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2mmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "329.49878",
                                    "gribparam": "201",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "max 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "182.448",
                                    "units": "unitless",
                                    "grib_name": "t2mmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2mmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "325.09375",
                                    "gribparam": "202",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "min 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "182.39575",
                                    "units": "unitless",
                                    "grib_name": "t2mmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "327.32471",
                                    "gribparam": "167",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "182.41187",
                                    "units": "Kelvin_scale",
                                    "grib_name": "t2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "Z_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "long_name": "complex"
                            },
                            "sp_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Y_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "Z_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0"
                            },
                            "Z_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0",
                                "long_name": "Height"
                            },
                            "sp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "Z": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "pointwidth": "1.0"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "pointwidth": "2.8125",
                                "modulus": "360.0"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM3/History/MONTHLY/R25006"
                        },
                        "R25007": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "R25007",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "Conventions": "IRIDL",
                                "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM3/.History/.MONTHLY/.R25007/.griblist.html",
                                "filepattern": "/mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01"
                            },
                            "total_air_column": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "total_air_column",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "VVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "460819.0",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 total_air_column VVI",
                                    "gribparam": "111",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-467332.0",
                                    "units": "kg m s-1",
                                    "grib_name": "VVI",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "VQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2520.8372",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 total_air_column VQVI",
                                    "gribparam": "113",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-2005.9727",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "VQVI",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "UVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "604443.06",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 total_air_column UVI",
                                    "gribparam": "110",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-339541.0",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "UVI",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "UQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2011.5613",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 total_air_column UQVI",
                                    "gribparam": "112",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-1859.0195",
                                    "units": "kg m s-1",
                                    "grib_name": "UQVI",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "QVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "91.118973",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 total_air_column QVI",
                                    "gribparam": "230",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated specific humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-6.4927979",
                                    "units": "kg/m2",
                                    "grib_name": "QVI",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "cltm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "cltm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.0",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 total_air_column cltm",
                                    "gribparam": "164",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover total mean[0-1]",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "cltm",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "ALWCVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALWCVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.9045715",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 total_air_column ALWCVI",
                                    "gribparam": "231",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated liquid water content",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "0.0",
                                    "units": "kg/m2",
                                    "grib_name": "ALWCVI",
                                    "process": "31",
                                    "gribleveltype": "1"
                                }
                            },
                            "top": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "top",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1192.4688",
                                        "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 top net swflx",
                                        "gribparam": "178",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (top)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "PTVersion": "0",
                                        "scale_min": "0.0",
                                        "units": "Wm-2",
                                        "grib_name": "rst",
                                        "process": "31",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "-69.439209",
                                        "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 top net lwflx",
                                        "gribparam": "179",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "PTVersion": "0",
                                        "scale_min": "-378.37573",
                                        "units": "Wm-2",
                                        "grib_name": "rlt",
                                        "process": "31",
                                        "gribleveltype": "1"
                                    }
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 top clear_sky upward solr",
                                            "gribparam": "105",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "PTVersion": "0",
                                            "scale_min": "-684.42969",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0U",
                                            "process": "31",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1193.6562",
                                            "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 top clear_sky net solr",
                                            "gribparam": "103",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "PTVersion": "0",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0",
                                            "process": "31",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-69.439209",
                                            "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 top clear_sky net lwflx",
                                            "gribparam": "104",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "PTVersion": "0",
                                            "scale_min": "-378.37573",
                                            "units": "W/m2",
                                            "grib_name": "TRAF0",
                                            "process": "31",
                                            "gribleveltype": "1"
                                        }
                                    }
                                }
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "zg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "zg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "59908.211",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface zg",
                                    "gribparam": "129",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Geopotential",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-5387.7891",
                                    "units": "m2 s-2",
                                    "grib_name": "zg",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "u3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u*3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.18504870E-04",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface u*3",
                                    "gribparam": "159",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "u*^3",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "5.29799627E-16",
                                    "units": "unitless",
                                    "grib_name": "u*3",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "TSLIN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TSLIN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "989.71167",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface TSLIN",
                                    "gribparam": "220",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "TSLIN heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-1912.6367",
                                    "units": "W/m2",
                                    "grib_name": "TSLIN",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "TD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "321.33911",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface TD5",
                                    "gribparam": "209",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "185.18921",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD5",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "TD4": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD4",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "327.21753",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface TD4",
                                    "gribparam": "208",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "181.40894",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD4",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "TD3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "339.67969",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface TD3",
                                    "gribparam": "207",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "180.21704",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD3",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "td": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "316.38452",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface td",
                                    "gribparam": "170",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "deep soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "191.54346",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "tauv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "4.1279154",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface tauv",
                                    "gribparam": "181",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-3.7660151",
                                    "units": "Nm-2",
                                    "grib_name": "tauv",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "tauu": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauu",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "4.7298355",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface tauu",
                                    "gribparam": "180",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-4.5387793",
                                    "units": "Nm-2",
                                    "grib_name": "tauu",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "Tasmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Tasmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "342.64307",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface Tasmx",
                                    "gribparam": "214",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "maximum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "180.23022",
                                    "units": "Kelvin_scale",
                                    "grib_name": "Tasmx",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "tasmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tasmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "330.86792",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface tasmn",
                                    "gribparam": "215",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "minimum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "180.2041",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tasmn",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "tas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "338.94116",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface tas",
                                    "gribparam": "169",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "180.21338",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tas",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "stemp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "stemp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "339.67969",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface stemp",
                                    "gribparam": "139",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "180.21704",
                                    "units": "unitless",
                                    "grib_name": "stemp",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "srun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "srun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.47242860E-06",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface srun",
                                    "gribparam": "160",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "surface runoff",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "srun",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "SRADSU": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SRADSU",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.6994629",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface SRADSU",
                                    "gribparam": "204",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "shortwave radiation upward (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-741.28516",
                                    "units": "W/m2",
                                    "grib_name": "SRADSU",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "soilm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soilm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.2000008",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface soilm",
                                    "gribparam": "140",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil wetness",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "soilm",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "SNMEL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SNMEL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.47184653E-06",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface SNMEL",
                                    "gribparam": "218",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "snow melt",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "SNMEL",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "snd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "snd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "11.056885",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface snd",
                                    "gribparam": "141",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Snow Depth",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "0.0",
                                    "units": "m",
                                    "grib_name": "snd",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "slp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "slp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "mean sea level pressure",
                                    "gribleveltype": "102",
                                    "gribparam": "151",
                                    "Z": "Z_05",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25007 hybrid_lev P",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                },
                                "pss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "109374.44",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface pss",
                                    "gribparam": "134",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "46468.5",
                                    "units": "Pa",
                                    "grib_name": "pss",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "prl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.56992644E-06",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface prl",
                                    "gribparam": "142",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Large Scale Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prl",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Total Precipitation",
                                    "grib_name": "totprcp",
                                    "gribparam": "260",
                                    "units": "m/s",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface prc",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "prc": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prc",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.14606586E-06",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface prc",
                                    "gribparam": "143",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Convective Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prc",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1007.6094",
                                        "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface net swflx",
                                        "gribparam": "176",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (surface)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "PTVersion": "0",
                                        "scale_min": "-5.6693115",
                                        "units": "Wm-2",
                                        "grib_name": "rss",
                                        "process": "31",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "112.10278",
                                        "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface net lwflx",
                                        "gribparam": "177",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "PTVersion": "0",
                                        "scale_min": "-282.13184",
                                        "units": "Wm-2",
                                        "grib_name": "rls",
                                        "process": "31",
                                        "gribleveltype": "1"
                                    }
                                },
                                "hfss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "933.40601",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface hfss",
                                    "gribparam": "146",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Sensible Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-1370.832",
                                    "units": "Wm-2",
                                    "grib_name": "hfss",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "hfls": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfls",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "404.24146",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface hfls",
                                    "gribparam": "147",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Latent Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-2087.0781",
                                    "units": "Wm-2",
                                    "grib_name": "hfls",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "evs": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "evs",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.54082045E-07",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface evs",
                                    "gribparam": "182",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Evaporation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-8.34568709E-07",
                                    "units": "m (H2O)",
                                    "grib_name": "evs",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "dpsdy": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdy",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Meridional Deriv. of Surface Pres.",
                                    "grib_name": "dpsdy",
                                    "gribparam": "274",
                                    "units": "kilogram meter-2 second-2",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface pss",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "dpsdx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Zonal Deriv. of Surface Pres.",
                                    "grib_name": "dpsdx",
                                    "gribparam": "273",
                                    "units": "kilogram meter-2 second-2",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface pss",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03125",
                                            "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface clear_sky upward solr",
                                            "gribparam": "106",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "PTVersion": "0",
                                            "scale_min": "-2633.3867",
                                            "units": "W/m2",
                                            "grib_name": "SRAFSU",
                                            "process": "31",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-59.709961",
                                            "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface clear_sky upward lwflx",
                                            "gribparam": "107",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "PTVersion": "0",
                                            "scale_min": "-734.06714",
                                            "units": "W/m2",
                                            "grib_name": "TRAFSU",
                                            "process": "31",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1015.0938",
                                            "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface clear_sky net solr",
                                            "gribparam": "101",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "10",
                                            "calendar": "360",
                                            "PTVersion": "0",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAFS",
                                            "process": "31",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "47.539795",
                                            "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface clear_sky net lwflx",
                                            "gribparam": "102",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "PTVersion": "0",
                                            "scale_min": "-282.13184",
                                            "units": "W/m2",
                                            "grib_name": "TRAFS",
                                            "process": "31",
                                            "gribleveltype": "1"
                                        }
                                    }
                                },
                                "ALBEDO": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALBEDO",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.8019526",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 surface ALBEDO",
                                    "gribparam": "175",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Albedo (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "0.04886818",
                                    "units": "unitless",
                                    "grib_name": "ALBEDO",
                                    "process": "31",
                                    "gribleveltype": "1"
                                }
                            },
                            "PressureLevel": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PressureLevel",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "Kelvin_scale",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "130",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "grib_name": "ta",
                                    "process": "31"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "138",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "grib_name": "rvort",
                                    "process": "31"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "fnname": "max",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "kilogram meter-1 second-3",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "vertical pressure velocity",
                                    "gribparam": "135",
                                    "grib_name": "ua",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "133",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "grib_name": "hus",
                                    "process": "31"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "155",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "grib_name": "div",
                                    "process": "31"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31"
                                }
                            },
                            "hybrid_lev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hybrid_lev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "units": "m/s",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 hybrid_lev rvort",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "units": "m/s",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 hybrid_lev rvort",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "409.53256",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 hybrid_lev ta",
                                    "gribparam": "130",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-23.23621",
                                    "units": "Kelvin_scale",
                                    "grib_name": "ta",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.37318236E-05",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 hybrid_lev rvort",
                                    "gribparam": "138",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-1.69907362E-05",
                                    "units": "s-1",
                                    "grib_name": "rvort",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "Rv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for moist air"
                                },
                                "Rd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for dry air"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.37318236E-05",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 hybrid_lev rvort",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-1.69907362E-05",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "units": "m",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 hybrid_lev hus",
                                    "fnname": "max",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "pressure",
                                    "units": "Pa",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 hybrid_lev logpsl",
                                    "fnname": "eexp",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "vertical pressure velocity",
                                    "units": "Pa/s",
                                    "gribparam": "135",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25007 hybrid_lev omegahalf",
                                    "grib_name": "ua",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "logpsl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "logpsl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "16.256054",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 hybrid_lev logpsl",
                                    "gribparam": "152",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Log Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-0.03144214",
                                    "units": "unitless",
                                    "grib_name": "logpsl",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.01532626",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 hybrid_lev hus",
                                    "gribparam": "133",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-0.008086637",
                                    "units": "unitless",
                                    "grib_name": "hus",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "gravity": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "gravity",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s2",
                                    "long_name": "earth\\'s gravity"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.02316573E-06",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 hybrid_lev div",
                                    "gribparam": "155",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-2.17241495E-06",
                                    "units": "s-1",
                                    "grib_name": "div",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.02316573E-06",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 hybrid_lev div",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-2.17241495E-06",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "BC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "BC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "ACLCAC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ACLCAC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.0",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 hybrid_lev ACLCAC",
                                    "gribparam": "223",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "ACLCAC",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "AC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Pa"
                                }
                            },
                            "above_ground": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "above_ground",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "36.995594",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 above_ground wind10",
                                    "gribparam": "171",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "10m windspeed",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "0.005953394",
                                    "units": "unitless",
                                    "grib_name": "wind10",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "vas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "32.687515",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 above_ground vas",
                                    "gribparam": "166",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-32.601196",
                                    "units": "m/s",
                                    "grib_name": "vas",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "uas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "uas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "32.788483",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 above_ground uas",
                                    "gribparam": "165",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "-34.030426",
                                    "units": "m/s",
                                    "grib_name": "uas",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "td2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "305.20972",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 above_ground td2m",
                                    "gribparam": "168",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Dewpoint at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "169.99731",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td2m",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "t2mmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "330.79175",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 above_ground t2mmx",
                                    "gribparam": "201",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "max 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "184.89185",
                                    "units": "unitless",
                                    "grib_name": "t2mmx",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "t2mmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "325.89648",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 above_ground t2mmn",
                                    "gribparam": "202",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "min 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "184.80298",
                                    "units": "unitless",
                                    "grib_name": "t2mmn",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "328.27563",
                                    "history": "T:  0000 1 Jan 1925 to 1800 30 Dec 1929 appended from /mstore/iri/forecast/data/echam/history/25007/25007fcst_%4d.01 above_ground t2m",
                                    "gribparam": "167",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "scale_min": "184.83301",
                                    "units": "Kelvin_scale",
                                    "grib_name": "t2m",
                                    "process": "31",
                                    "gribleveltype": "1"
                                }
                            },
                            "Z_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "long_name": "complex"
                            },
                            "sp_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Y_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "Z_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0"
                            },
                            "Z_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0",
                                "long_name": "Height"
                            },
                            "sp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "Z": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "pointwidth": "1.0"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "pointwidth": "2.8125",
                                "modulus": "360.0"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM3/History/MONTHLY/R25007"
                        },
                        "R25008": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "R25008",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "Conventions": "IRIDL",
                                "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM3/.History/.MONTHLY/.R25008/.griblist.html",
                                "filepattern": "/mstore/iri/forecast/data/echam/history/25008/25008fcst_%4d.01"
                            },
                            "total_air_column": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "total_air_column",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "VVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "493604.44",
                                    "gribparam": "111",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-485520.0",
                                    "units": "kg m s-1",
                                    "grib_name": "VVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "VQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2256.4504",
                                    "gribparam": "113",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2099.4844",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "VQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "UVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "619632.38",
                                    "gribparam": "110",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-364576.0",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "UVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "UQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1981.9138",
                                    "gribparam": "112",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1789.4531",
                                    "units": "kg m s-1",
                                    "grib_name": "UQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "QVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "88.049217",
                                    "gribparam": "230",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated specific humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-6.3419495",
                                    "units": "kg/m2",
                                    "grib_name": "QVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "cltm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "cltm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.0",
                                    "gribparam": "164",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover total mean[0-1]",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "cltm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "ALWCVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALWCVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.9219971",
                                    "gribparam": "231",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated liquid water content",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "kg/m2",
                                    "grib_name": "ALWCVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "top": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "top",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1192.5",
                                        "gribparam": "178",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (top)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "0.0",
                                        "units": "Wm-2",
                                        "grib_name": "rst",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "-67.211182",
                                        "gribparam": "179",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-374.0061",
                                        "units": "Wm-2",
                                        "grib_name": "rlt",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    }
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "105",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-684.1958",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0U",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1193.6562",
                                            "gribparam": "103",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-67.211182",
                                            "gribparam": "104",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-374.0061",
                                            "units": "W/m2",
                                            "grib_name": "TRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    }
                                }
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "zg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "zg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "59908.211",
                                    "gribparam": "129",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Geopotential",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-5387.7891",
                                    "units": "m2 s-2",
                                    "grib_name": "zg",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "u3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u*3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "4.18156385E-04",
                                    "gribparam": "159",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "u*^3",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "7.54308039E-16",
                                    "units": "unitless",
                                    "grib_name": "u*3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TSLIN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TSLIN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1022.7419",
                                    "gribparam": "220",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "TSLIN heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2425.8359",
                                    "units": "W/m2",
                                    "grib_name": "TSLIN",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "321.51685",
                                    "gribparam": "209",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "184.17236",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD5",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD4": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD4",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "327.07397",
                                    "gribparam": "208",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "179.99194",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD4",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "339.99219",
                                    "gribparam": "207",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "178.64966",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "td": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "316.30518",
                                    "gribparam": "170",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "deep soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "192.40649",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tauv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "4.8717413",
                                    "gribparam": "181",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-4.0070276",
                                    "units": "Nm-2",
                                    "grib_name": "tauv",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tauu": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauu",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "4.9424572",
                                    "gribparam": "180",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-4.4226437",
                                    "units": "Nm-2",
                                    "grib_name": "tauu",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "Tasmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Tasmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "342.02002",
                                    "gribparam": "214",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "maximum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "178.65576",
                                    "units": "Kelvin_scale",
                                    "grib_name": "Tasmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tasmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tasmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "330.85303",
                                    "gribparam": "215",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "minimum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "178.62451",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tasmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "338.55981",
                                    "gribparam": "169",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "178.6355",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "stemp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "stemp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "339.99219",
                                    "gribparam": "139",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "178.64966",
                                    "units": "unitless",
                                    "grib_name": "stemp",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "srun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "srun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.66486313E-06",
                                    "gribparam": "160",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "surface runoff",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "srun",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "SRADSU": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SRADSU",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.9619141",
                                    "gribparam": "204",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "shortwave radiation upward (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-679.93994",
                                    "units": "W/m2",
                                    "grib_name": "SRADSU",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "soilm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soilm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.2000008",
                                    "gribparam": "140",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil wetness",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "soilm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "SNMEL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SNMEL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.66428106E-06",
                                    "gribparam": "218",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "snow melt",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "SNMEL",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "snd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "snd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "16.945312",
                                    "gribparam": "141",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Snow Depth",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m",
                                    "grib_name": "snd",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "slp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "slp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "mean sea level pressure",
                                    "gribleveltype": "102",
                                    "gribparam": "151",
                                    "Z": "Z_05",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25008 hybrid_lev P",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "pss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "109437.81",
                                    "gribparam": "134",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "46424.5",
                                    "units": "Pa",
                                    "grib_name": "pss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.46474519E-06",
                                    "gribparam": "142",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Large Scale Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prl",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Total Precipitation",
                                    "grib_name": "totprcp",
                                    "gribparam": "260",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prc": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prc",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.83984298E-06",
                                    "gribparam": "143",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Convective Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prc",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "999.73438",
                                        "gribparam": "176",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (surface)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-13.859985",
                                        "units": "Wm-2",
                                        "grib_name": "rss",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "105.30835",
                                        "gribparam": "177",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-315.26172",
                                        "units": "Wm-2",
                                        "grib_name": "rls",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    }
                                },
                                "hfss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1090.2732",
                                    "gribparam": "146",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Sensible Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1923.1602",
                                    "units": "Wm-2",
                                    "grib_name": "hfss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "hfls": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfls",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "356.6936",
                                    "gribparam": "147",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Latent Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2224.8398",
                                    "units": "Wm-2",
                                    "grib_name": "hfls",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "evs": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "evs",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.34059576E-07",
                                    "gribparam": "182",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Evaporation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-8.89674993E-07",
                                    "units": "m (H2O)",
                                    "grib_name": "evs",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "dpsdy": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdy",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Meridional Deriv. of Surface Pres.",
                                    "grib_name": "dpsdy",
                                    "gribparam": "274",
                                    "units": "kilogram meter-2 second-2",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "dpsdx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Zonal Deriv. of Surface Pres.",
                                    "grib_name": "dpsdx",
                                    "gribparam": "273",
                                    "units": "kilogram meter-2 second-2",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.02734375",
                                            "gribparam": "106",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-2191.4727",
                                            "units": "W/m2",
                                            "grib_name": "SRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-57.627686",
                                            "gribparam": "107",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-730.33252",
                                            "units": "W/m2",
                                            "grib_name": "TRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1011.7969",
                                            "gribparam": "101",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "10",
                                            "calendar": "360",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "51.492676",
                                            "gribparam": "102",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-315.26172",
                                            "units": "W/m2",
                                            "grib_name": "TRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    }
                                },
                                "ALBEDO": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALBEDO",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.801943",
                                    "gribparam": "175",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Albedo (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.04904336",
                                    "units": "unitless",
                                    "grib_name": "ALBEDO",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "PressureLevel": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PressureLevel",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "Kelvin_scale",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "130",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "ta",
                                    "PTVersion": "0"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "138",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "rvort",
                                    "PTVersion": "0"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "fnname": "max",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "kilogram meter-1 second-3",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "vertical pressure velocity",
                                    "gribparam": "135",
                                    "grib_name": "ua",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "133",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "hus",
                                    "PTVersion": "0"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "155",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "div",
                                    "PTVersion": "0"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                }
                            },
                            "hybrid_lev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hybrid_lev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "409.50806",
                                    "gribparam": "130",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-22.783413",
                                    "units": "Kelvin_scale",
                                    "grib_name": "ta",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.33916853E-05",
                                    "gribparam": "138",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.73417611E-05",
                                    "units": "s-1",
                                    "grib_name": "rvort",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "Rv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for moist air"
                                },
                                "Rd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for dry air"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.33916853E-05",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.73417611E-05",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "units": "m",
                                    "fnname": "max",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "pressure",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "vertical pressure velocity",
                                    "units": "Pa/s",
                                    "gribparam": "135",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25008 hybrid_lev omegahalf",
                                    "grib_name": "ua",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "logpsl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "logpsl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "16.256054",
                                    "gribparam": "152",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Log Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-0.03099901",
                                    "units": "unitless",
                                    "grib_name": "logpsl",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.01513811",
                                    "gribparam": "133",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-0.008050728",
                                    "units": "unitless",
                                    "grib_name": "hus",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "gravity": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "gravity",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s2",
                                    "long_name": "earth\\'s gravity"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.98069984E-06",
                                    "gribparam": "155",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2.32712273E-06",
                                    "units": "s-1",
                                    "grib_name": "div",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "units": "meter2 second-1",
                                    "scale_max": "1.98069984E-06",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2.32712273E-06",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "BC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "BC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "ACLCAC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ACLCAC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.0",
                                    "gribparam": "223",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "ACLCAC",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "AC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Pa"
                                }
                            },
                            "above_ground": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "above_ground",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "37.6077",
                                    "gribparam": "171",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "10m windspeed",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.007634297",
                                    "units": "unitless",
                                    "grib_name": "wind10",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "vas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "36.310181",
                                    "gribparam": "166",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-35.464081",
                                    "units": "m/s",
                                    "grib_name": "vas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "uas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "uas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "32.223206",
                                    "gribparam": "165",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-35.156708",
                                    "units": "m/s",
                                    "grib_name": "uas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "td2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "304.75464",
                                    "gribparam": "168",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Dewpoint at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "168.11133",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2mmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "328.64917",
                                    "gribparam": "201",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "max 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "182.63501",
                                    "units": "unitless",
                                    "grib_name": "t2mmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2mmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "325.19531",
                                    "gribparam": "202",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "min 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "182.56958",
                                    "units": "unitless",
                                    "grib_name": "t2mmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "327.55835",
                                    "gribparam": "167",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "182.58911",
                                    "units": "Kelvin_scale",
                                    "grib_name": "t2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "Z_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "long_name": "complex"
                            },
                            "sp_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Y_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "Z_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0"
                            },
                            "Z_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0",
                                "long_name": "Height"
                            },
                            "sp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "Z": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "pointwidth": "1.0"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "pointwidth": "2.8125",
                                "modulus": "360.0"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM3/History/MONTHLY/R25008"
                        },
                        "R25009": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "R25009",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "Conventions": "IRIDL",
                                "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM3/.History/.MONTHLY/.R25009/.griblist.html",
                                "filepattern": "/mstore/iri/forecast/data/echam/history/25009/25009fcst_%4d.01"
                            },
                            "total_air_column": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "total_air_column",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "VVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "467932.31",
                                    "gribparam": "111",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-490315.0",
                                    "units": "kg m s-1",
                                    "grib_name": "VVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "VQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2218.7336",
                                    "gribparam": "113",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-2626.3594",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "VQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "UVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "607632.69",
                                    "gribparam": "110",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-302972.75",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "UVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "UQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2289.7646",
                                    "gribparam": "112",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1813.1719",
                                    "units": "kg m s-1",
                                    "grib_name": "UQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "QVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "88.092567",
                                    "gribparam": "230",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated specific humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-5.268692",
                                    "units": "kg/m2",
                                    "grib_name": "QVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "cltm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "cltm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.0",
                                    "gribparam": "164",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover total mean[0-1]",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "cltm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "ALWCVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALWCVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.017334",
                                    "gribparam": "231",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated liquid water content",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "kg/m2",
                                    "grib_name": "ALWCVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "top": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "top",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1192.3438",
                                        "gribparam": "178",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (top)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "process": "31",
                                        "scale_min": "0.0",
                                        "units": "Wm-2",
                                        "grib_name": "rst",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "-66.940918",
                                        "gribparam": "179",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "process": "31",
                                        "scale_min": "-376.12451",
                                        "units": "Wm-2",
                                        "grib_name": "rlt",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    }
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "105",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-685.02124",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0U",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1193.625",
                                            "gribparam": "103",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-66.940918",
                                            "gribparam": "104",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-376.12451",
                                            "units": "W/m2",
                                            "grib_name": "TRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    }
                                }
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "zg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "zg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "59908.211",
                                    "gribparam": "129",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Geopotential",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-5387.7891",
                                    "units": "m2 s-2",
                                    "grib_name": "zg",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "u3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u*3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.86416912E-04",
                                    "gribparam": "159",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "u*^3",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "3.53458379E-16",
                                    "units": "unitless",
                                    "grib_name": "u*3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TSLIN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TSLIN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "959.77759",
                                    "gribparam": "220",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "TSLIN heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1996.3945",
                                    "units": "W/m2",
                                    "grib_name": "TSLIN",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "321.28247",
                                    "gribparam": "209",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "184.13013",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD5",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD4": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD4",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "326.68896",
                                    "gribparam": "208",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "180.46338",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD4",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "340.34937",
                                    "gribparam": "207",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.18701",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "td": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "316.36792",
                                    "gribparam": "170",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "deep soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "192.27319",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tauv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "5.1649532",
                                    "gribparam": "181",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-3.3528652",
                                    "units": "Nm-2",
                                    "grib_name": "tauv",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tauu": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauu",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "4.4213371",
                                    "gribparam": "180",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-3.8254166",
                                    "units": "Nm-2",
                                    "grib_name": "tauu",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "Tasmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Tasmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "342.48633",
                                    "gribparam": "214",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "maximum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.21509",
                                    "units": "Kelvin_scale",
                                    "grib_name": "Tasmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tasmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tasmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "330.51685",
                                    "gribparam": "215",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "minimum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.17212",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tasmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "338.73267",
                                    "gribparam": "169",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.1853",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "stemp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "stemp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "340.34937",
                                    "gribparam": "139",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.18701",
                                    "units": "unitless",
                                    "grib_name": "stemp",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "srun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "srun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.32120510E-06",
                                    "gribparam": "160",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "surface runoff",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "srun",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "SRADSU": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SRADSU",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.5183105",
                                    "gribparam": "204",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "shortwave radiation upward (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-751.44043",
                                    "units": "W/m2",
                                    "grib_name": "SRADSU",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "soilm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soilm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.2000008",
                                    "gribparam": "140",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil wetness",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "soilm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "SNMEL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SNMEL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.05420656E-06",
                                    "gribparam": "218",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "snow melt",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "SNMEL",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "snd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "snd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "13.348877",
                                    "gribparam": "141",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Snow Depth",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "m",
                                    "grib_name": "snd",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "slp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "slp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "mean sea level pressure",
                                    "gribleveltype": "102",
                                    "gribparam": "151",
                                    "Z": "Z_05",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25009 hybrid_lev P",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                },
                                "pss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "109870.12",
                                    "gribparam": "134",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "46256.938",
                                    "units": "Pa",
                                    "grib_name": "pss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.89495802E-06",
                                    "gribparam": "142",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Large Scale Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prl",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Total Precipitation",
                                    "grib_name": "totprcp",
                                    "gribparam": "260",
                                    "units": "m/s",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prc": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prc",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.22150299E-06",
                                    "gribparam": "143",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Convective Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prc",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1004.2656",
                                        "gribparam": "176",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (surface)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "process": "31",
                                        "scale_min": "-8.5990906",
                                        "units": "Wm-2",
                                        "grib_name": "rss",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "108.47925",
                                        "gribparam": "177",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "process": "31",
                                        "scale_min": "-284.60181",
                                        "units": "Wm-2",
                                        "grib_name": "rls",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    }
                                },
                                "hfss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "882.33228",
                                    "gribparam": "146",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Sensible Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1353.832",
                                    "units": "Wm-2",
                                    "grib_name": "hfss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "hfls": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfls",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "390.42456",
                                    "gribparam": "147",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Latent Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-2116.9766",
                                    "units": "Wm-2",
                                    "grib_name": "hfls",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "evs": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "evs",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.48259005E-07",
                                    "gribparam": "182",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Evaporation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-8.46561306E-07",
                                    "units": "m (H2O)",
                                    "grib_name": "evs",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "dpsdy": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdy",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Meridional Deriv. of Surface Pres.",
                                    "grib_name": "dpsdy",
                                    "gribparam": "274",
                                    "units": "kilogram meter-2 second-2",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "dpsdx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Zonal Deriv. of Surface Pres.",
                                    "grib_name": "dpsdx",
                                    "gribparam": "273",
                                    "units": "kilogram meter-2 second-2",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03125",
                                            "gribparam": "106",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-2608.4375",
                                            "units": "W/m2",
                                            "grib_name": "SRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-58.340332",
                                            "gribparam": "107",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-730.86182",
                                            "units": "W/m2",
                                            "grib_name": "TRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1009.5",
                                            "gribparam": "101",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "10",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "53.355225",
                                            "gribparam": "102",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-284.60181",
                                            "units": "W/m2",
                                            "grib_name": "TRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    }
                                },
                                "ALBEDO": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALBEDO",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.8019441",
                                    "gribparam": "175",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Albedo (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.04904038",
                                    "units": "unitless",
                                    "grib_name": "ALBEDO",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "PressureLevel": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PressureLevel",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "Kelvin_scale",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "130",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "grib_name": "ta",
                                    "PTVersion": "0"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "138",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "grib_name": "rvort",
                                    "PTVersion": "0"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "fnname": "max",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "kilogram meter-1 second-3",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "vertical pressure velocity",
                                    "gribparam": "135",
                                    "grib_name": "ua",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "133",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "grib_name": "hus",
                                    "PTVersion": "0"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "155",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "grib_name": "div",
                                    "PTVersion": "0"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0"
                                }
                            },
                            "hybrid_lev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hybrid_lev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "units": "m/s",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "units": "m/s",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "409.52737",
                                    "gribparam": "130",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-22.849165",
                                    "units": "Kelvin_scale",
                                    "grib_name": "ta",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.38848534E-05",
                                    "gribparam": "138",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1.84280307E-05",
                                    "units": "s-1",
                                    "grib_name": "rvort",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "Rv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for moist air"
                                },
                                "Rd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for dry air"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.38848534E-05",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1.84280307E-05",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "units": "m",
                                    "fnname": "max",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "pressure",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "vertical pressure velocity",
                                    "units": "Pa/s",
                                    "gribparam": "135",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25009 hybrid_lev omegahalf",
                                    "grib_name": "ua",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "logpsl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "logpsl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "16.256054",
                                    "gribparam": "152",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Log Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-0.03091387",
                                    "units": "unitless",
                                    "grib_name": "logpsl",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.01512086",
                                    "gribparam": "133",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-0.007998929",
                                    "units": "unitless",
                                    "grib_name": "hus",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "gravity": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "gravity",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s2",
                                    "long_name": "earth\\'s gravity"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.03414243E-06",
                                    "gribparam": "155",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-2.18189825E-06",
                                    "units": "s-1",
                                    "grib_name": "div",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.03414243E-06",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-2.18189825E-06",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "BC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "BC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "ACLCAC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ACLCAC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.0",
                                    "gribparam": "223",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "ACLCAC",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "AC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Pa"
                                }
                            },
                            "above_ground": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "above_ground",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "36.322193",
                                    "gribparam": "171",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "10m windspeed",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.005152076",
                                    "units": "unitless",
                                    "grib_name": "wind10",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "vas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "32.609451",
                                    "gribparam": "166",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-32.401703",
                                    "units": "m/s",
                                    "grib_name": "vas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "uas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "uas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "31.73584",
                                    "gribparam": "165",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-36.24617",
                                    "units": "m/s",
                                    "grib_name": "uas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "td2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "304.30884",
                                    "gribparam": "168",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Dewpoint at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "168.35742",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2mmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "328.56152",
                                    "gribparam": "201",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "max 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "182.91675",
                                    "units": "unitless",
                                    "grib_name": "t2mmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2mmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "325.01514",
                                    "gribparam": "202",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "min 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "182.85986",
                                    "units": "unitless",
                                    "grib_name": "t2mmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "327.45239",
                                    "gribparam": "167",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "182.88135",
                                    "units": "Kelvin_scale",
                                    "grib_name": "t2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "Z_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "long_name": "complex"
                            },
                            "sp_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Y_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "Z_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0"
                            },
                            "Z_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0",
                                "long_name": "Height"
                            },
                            "sp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "Z": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "pointwidth": "1.0"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "pointwidth": "2.8125",
                                "modulus": "360.0"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM3/History/MONTHLY/R25009"
                        },
                        "R25010": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "R25010",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "Conventions": "IRIDL",
                                "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM3/.History/.MONTHLY/.R25010/.griblist.html",
                                "filepattern": "/mstore/iri/forecast/data/echam/history/25010/25010fcst_%4d.01"
                            },
                            "total_air_column": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "total_air_column",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "VVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "445616.31",
                                    "gribparam": "111",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-465519.0",
                                    "units": "kg m s-1",
                                    "grib_name": "VVI",
                                    "gribleveltype": "1"
                                },
                                "VQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2191.1255",
                                    "gribparam": "113",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1966.2148",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "VQVI",
                                    "gribleveltype": "1"
                                },
                                "UVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "621150.56",
                                    "gribparam": "110",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-312240.0",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "UVI",
                                    "gribleveltype": "1"
                                },
                                "UQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2166.5793",
                                    "gribparam": "112",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1660.2461",
                                    "units": "kg m s-1",
                                    "grib_name": "UQVI",
                                    "gribleveltype": "1"
                                },
                                "QVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "87.926834",
                                    "gribparam": "230",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated specific humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-6.1117554",
                                    "units": "kg/m2",
                                    "grib_name": "QVI",
                                    "gribleveltype": "1"
                                },
                                "cltm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "cltm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.0",
                                    "gribparam": "164",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover total mean[0-1]",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "cltm",
                                    "gribleveltype": "1"
                                },
                                "ALWCVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALWCVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.9179993",
                                    "gribparam": "231",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated liquid water content",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "kg/m2",
                                    "grib_name": "ALWCVI",
                                    "gribleveltype": "1"
                                }
                            },
                            "top": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "top",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1192.4688",
                                        "gribparam": "178",
                                        "PTVersion": "0",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (top)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "process": "31",
                                        "scale_min": "0.0",
                                        "units": "Wm-2",
                                        "grib_name": "rst",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "-67.564941",
                                        "gribparam": "179",
                                        "PTVersion": "0",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "process": "31",
                                        "scale_min": "-381.35205",
                                        "units": "Wm-2",
                                        "grib_name": "rlt",
                                        "gribleveltype": "1"
                                    }
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "105",
                                            "PTVersion": "0",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-683.22144",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0U",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1193.6875",
                                            "gribparam": "103",
                                            "PTVersion": "0",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-67.541504",
                                            "gribparam": "104",
                                            "PTVersion": "0",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-381.35205",
                                            "units": "W/m2",
                                            "grib_name": "TRAF0",
                                            "gribleveltype": "1"
                                        }
                                    }
                                }
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "zg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "zg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "59908.211",
                                    "gribparam": "129",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Geopotential",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-5387.7891",
                                    "units": "m2 s-2",
                                    "grib_name": "zg",
                                    "gribleveltype": "1"
                                },
                                "u3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u*3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.13237309E-04",
                                    "gribparam": "159",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "u*^3",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "9.63926670E-16",
                                    "units": "unitless",
                                    "grib_name": "u*3",
                                    "gribleveltype": "1"
                                },
                                "TSLIN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TSLIN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1038.0132",
                                    "gribparam": "220",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "TSLIN heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1665.0625",
                                    "units": "W/m2",
                                    "grib_name": "TSLIN",
                                    "gribleveltype": "1"
                                },
                                "TD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "320.99585",
                                    "gribparam": "209",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "184.67383",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD5",
                                    "gribleveltype": "1"
                                },
                                "TD4": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD4",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "326.55664",
                                    "gribparam": "208",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "180.58838",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD4",
                                    "gribleveltype": "1"
                                },
                                "TD3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "339.80957",
                                    "gribparam": "207",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.15137",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD3",
                                    "gribleveltype": "1"
                                },
                                "td": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "316.16187",
                                    "gribparam": "170",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "deep soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "192.55615",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td",
                                    "gribleveltype": "1"
                                },
                                "tauv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "4.7001305",
                                    "gribparam": "181",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-3.7978182",
                                    "units": "Nm-2",
                                    "grib_name": "tauv",
                                    "gribleveltype": "1"
                                },
                                "tauu": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauu",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "4.1663103",
                                    "gribparam": "180",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-3.8647652",
                                    "units": "Nm-2",
                                    "grib_name": "tauu",
                                    "gribleveltype": "1"
                                },
                                "Tasmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Tasmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "341.15454",
                                    "gribparam": "214",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "maximum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.26318",
                                    "units": "Kelvin_scale",
                                    "grib_name": "Tasmx",
                                    "gribleveltype": "1"
                                },
                                "tasmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tasmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "330.32666",
                                    "gribparam": "215",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "minimum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.15112",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tasmn",
                                    "gribleveltype": "1"
                                },
                                "tas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "337.55273",
                                    "gribparam": "169",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.20166",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tas",
                                    "gribleveltype": "1"
                                },
                                "stemp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "stemp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "339.80957",
                                    "gribparam": "139",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "179.15137",
                                    "units": "unitless",
                                    "grib_name": "stemp",
                                    "gribleveltype": "1"
                                },
                                "srun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "srun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.38086795E-06",
                                    "gribparam": "160",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "surface runoff",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "srun",
                                    "gribleveltype": "1"
                                },
                                "SRADSU": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SRADSU",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "47.150635",
                                    "gribparam": "204",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "shortwave radiation upward (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-756.11377",
                                    "units": "W/m2",
                                    "grib_name": "SRADSU",
                                    "gribleveltype": "1"
                                },
                                "soilm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soilm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.2000008",
                                    "gribparam": "140",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil wetness",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "soilm",
                                    "gribleveltype": "1"
                                },
                                "SNMEL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SNMEL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.96852488E-06",
                                    "gribparam": "218",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "snow melt",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "SNMEL",
                                    "gribleveltype": "1"
                                },
                                "snd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "snd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "17.749512",
                                    "gribparam": "141",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Snow Depth",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "m",
                                    "grib_name": "snd",
                                    "gribleveltype": "1"
                                },
                                "slp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "slp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "mean sea level pressure",
                                    "gribleveltype": "102",
                                    "gribparam": "151",
                                    "Z": "Z_05",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25010 hybrid_lev P",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31"
                                },
                                "pss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "109442.62",
                                    "gribparam": "134",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "46457.688",
                                    "units": "Pa",
                                    "grib_name": "pss",
                                    "gribleveltype": "1"
                                },
                                "prl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.44344119E-06",
                                    "gribparam": "142",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Large Scale Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prl",
                                    "gribleveltype": "1"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Total Precipitation",
                                    "grib_name": "totprcp",
                                    "gribparam": "260",
                                    "units": "m/s",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "prc": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prc",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "4.26324550E-06",
                                    "gribparam": "143",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Convective Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prc",
                                    "gribleveltype": "1"
                                },
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1000.3281",
                                        "gribparam": "176",
                                        "PTVersion": "0",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (surface)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "process": "31",
                                        "scale_min": "-267.20264",
                                        "units": "Wm-2",
                                        "grib_name": "rss",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "126.73267",
                                        "gribparam": "177",
                                        "PTVersion": "0",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "process": "31",
                                        "scale_min": "-289.01807",
                                        "units": "Wm-2",
                                        "grib_name": "rls",
                                        "gribleveltype": "1"
                                    }
                                },
                                "hfss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "874.24365",
                                    "gribparam": "146",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Sensible Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1155.792",
                                    "units": "Wm-2",
                                    "grib_name": "hfss",
                                    "gribleveltype": "1"
                                },
                                "hfls": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfls",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "385.11011",
                                    "gribparam": "147",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Latent Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-2151.832",
                                    "units": "Wm-2",
                                    "grib_name": "hfls",
                                    "gribleveltype": "1"
                                },
                                "evs": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "evs",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.45395745E-07",
                                    "gribparam": "182",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Evaporation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-8.60508408E-07",
                                    "units": "m (H2O)",
                                    "grib_name": "evs",
                                    "gribleveltype": "1"
                                },
                                "dpsdy": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdy",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Meridional Deriv. of Surface Pres.",
                                    "grib_name": "dpsdy",
                                    "gribparam": "274",
                                    "units": "kilogram meter-2 second-2",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "dpsdx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Zonal Deriv. of Surface Pres.",
                                    "grib_name": "dpsdx",
                                    "gribparam": "273",
                                    "units": "kilogram meter-2 second-2",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "gribleveltype": "1"
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03125",
                                            "gribparam": "106",
                                            "PTVersion": "0",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-2692.8398",
                                            "units": "W/m2",
                                            "grib_name": "SRAFSU",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-58.383057",
                                            "gribparam": "107",
                                            "PTVersion": "0",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-721.09204",
                                            "units": "W/m2",
                                            "grib_name": "TRAFSU",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1012.4531",
                                            "gribparam": "101",
                                            "PTVersion": "0",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "10",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAFS",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "48.513916",
                                            "gribparam": "102",
                                            "PTVersion": "0",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "process": "31",
                                            "scale_min": "-289.01807",
                                            "units": "W/m2",
                                            "grib_name": "TRAFS",
                                            "gribleveltype": "1"
                                        }
                                    }
                                },
                                "ALBEDO": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALBEDO",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.8019529",
                                    "gribparam": "175",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Albedo (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.04872704",
                                    "units": "unitless",
                                    "grib_name": "ALBEDO",
                                    "gribleveltype": "1"
                                }
                            },
                            "PressureLevel": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PressureLevel",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "Kelvin_scale",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "130",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "grib_name": "ta"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "138",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "grib_name": "rvort"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "fnname": "max",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "kilogram meter-1 second-3",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "vertical pressure velocity",
                                    "gribparam": "135",
                                    "grib_name": "ua",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "133",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "grib_name": "hus"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "155",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "grib_name": "div"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31"
                                }
                            },
                            "hybrid_lev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hybrid_lev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "units": "m/s",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "units": "m/s",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "409.57468",
                                    "gribparam": "130",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-22.929979",
                                    "units": "Kelvin_scale",
                                    "grib_name": "ta",
                                    "gribleveltype": "109"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.40235804E-05",
                                    "gribparam": "138",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1.67076851E-05",
                                    "units": "s-1",
                                    "grib_name": "rvort",
                                    "gribleveltype": "109"
                                },
                                "Rv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for moist air"
                                },
                                "Rd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for dry air"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.40235804E-05",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-1.67076851E-05",
                                    "gribleveltype": "109"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "units": "m",
                                    "fnname": "max",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "pressure",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "vertical pressure velocity",
                                    "units": "Pa/s",
                                    "gribparam": "135",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25010 hybrid_lev omegahalf",
                                    "grib_name": "ua",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "gribleveltype": "109"
                                },
                                "logpsl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "logpsl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "16.256054",
                                    "gribparam": "152",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Log Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-0.03186858",
                                    "units": "unitless",
                                    "grib_name": "logpsl",
                                    "gribleveltype": "109"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.01517402",
                                    "gribparam": "133",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-0.007945029",
                                    "units": "unitless",
                                    "grib_name": "hus",
                                    "gribleveltype": "109"
                                },
                                "gravity": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "gravity",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s2",
                                    "long_name": "earth\\'s gravity"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.04045386E-06",
                                    "gribparam": "155",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-2.19304707E-06",
                                    "units": "s-1",
                                    "grib_name": "div",
                                    "gribleveltype": "109"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.04045386E-06",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-2.19304707E-06",
                                    "gribleveltype": "109"
                                },
                                "BC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "BC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "ACLCAC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ACLCAC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.0",
                                    "gribparam": "223",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "ACLCAC",
                                    "gribleveltype": "109"
                                },
                                "AC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Pa"
                                }
                            },
                            "above_ground": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "above_ground",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "39.201103",
                                    "gribparam": "171",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "10m windspeed",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "0.008588158",
                                    "units": "unitless",
                                    "grib_name": "wind10",
                                    "gribleveltype": "1"
                                },
                                "vas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "31.874802",
                                    "gribparam": "166",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-39.171387",
                                    "units": "m/s",
                                    "grib_name": "vas",
                                    "gribleveltype": "1"
                                },
                                "uas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "uas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "33.695572",
                                    "gribparam": "165",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "-34.695984",
                                    "units": "m/s",
                                    "grib_name": "uas",
                                    "gribleveltype": "1"
                                },
                                "td2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "304.90918",
                                    "gribparam": "168",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Dewpoint at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "169.15479",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td2m",
                                    "gribleveltype": "1"
                                },
                                "t2mmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "328.83057",
                                    "gribparam": "201",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "max 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "183.92529",
                                    "units": "unitless",
                                    "grib_name": "t2mmx",
                                    "gribleveltype": "1"
                                },
                                "t2mmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "325.27539",
                                    "gribparam": "202",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "min 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "183.78784",
                                    "units": "unitless",
                                    "grib_name": "t2mmn",
                                    "gribleveltype": "1"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "327.66235",
                                    "gribparam": "167",
                                    "PTVersion": "0",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "process": "31",
                                    "scale_min": "183.82983",
                                    "units": "Kelvin_scale",
                                    "grib_name": "t2m",
                                    "gribleveltype": "1"
                                }
                            },
                            "Z_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "long_name": "complex"
                            },
                            "sp_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Y_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "Z_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0"
                            },
                            "Z_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0",
                                "long_name": "Height"
                            },
                            "sp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "Z": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "pointwidth": "1.0"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "pointwidth": "2.8125",
                                "modulus": "360.0"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM3/History/MONTHLY/R25010"
                        },
                        "R25011": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "R25011",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "Conventions": "IRIDL",
                                "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM3/.History/.MONTHLY/.R25011/.griblist.html",
                                "filepattern": "/mstore/iri/forecast/data/echam/history/25011/25011fcst_%4d.01"
                            },
                            "total_air_column": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "total_air_column",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "VVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "478046.0",
                                    "gribparam": "111",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-551080.0",
                                    "units": "kg m s-1",
                                    "grib_name": "VVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "VQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2667.3711",
                                    "gribparam": "113",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2798.6602",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "VQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "UVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "905412.0",
                                    "gribparam": "110",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-540668.0",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "UVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "UQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2509.2832",
                                    "gribparam": "112",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1812.3945",
                                    "units": "kg m s-1",
                                    "grib_name": "UQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "QVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "149.71355",
                                    "gribparam": "230",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated specific humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-6.1803436",
                                    "units": "kg/m2",
                                    "grib_name": "QVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "cltm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "cltm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.0",
                                    "gribparam": "164",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover total mean[0-1]",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "cltm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "ALWCVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALWCVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.4591675",
                                    "gribparam": "231",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated liquid water content",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "kg/m2",
                                    "grib_name": "ALWCVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "top": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "top",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1779.8438",
                                        "gribparam": "178",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (top)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "0.0",
                                        "units": "Wm-2",
                                        "grib_name": "rst",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "-68.689209",
                                        "gribparam": "179",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-655.0022",
                                        "units": "Wm-2",
                                        "grib_name": "rlt",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    }
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "105",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-1010.3528",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0U",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1789.4375",
                                            "gribparam": "103",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-68.669434",
                                            "gribparam": "104",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-655.0022",
                                            "units": "W/m2",
                                            "grib_name": "TRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    }
                                }
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "zg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "zg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "59908.211",
                                    "gribparam": "129",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Geopotential",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-5387.7891",
                                    "units": "m2 s-2",
                                    "grib_name": "zg",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "u3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u*3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.08543444E-04",
                                    "gribparam": "159",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "u*^3",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "4.80633811E-16",
                                    "units": "unitless",
                                    "grib_name": "u*3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TSLIN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TSLIN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "873.14453",
                                    "gribparam": "220",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "TSLIN heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1778.9375",
                                    "units": "W/m2",
                                    "grib_name": "TSLIN",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "321.87402",
                                    "gribparam": "209",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "185.34644",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD5",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD4": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD4",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "327.81226",
                                    "gribparam": "208",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "181.57397",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD4",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "340.94824",
                                    "gribparam": "207",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "180.36328",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "td": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "316.6499",
                                    "gribparam": "170",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "deep soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "193.56714",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tauv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.689868",
                                    "gribparam": "181",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-3.7032957",
                                    "units": "Nm-2",
                                    "grib_name": "tauv",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tauu": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauu",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "4.3592548",
                                    "gribparam": "180",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-4.0622053",
                                    "units": "Nm-2",
                                    "grib_name": "tauu",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "Tasmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Tasmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "343.04688",
                                    "gribparam": "214",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "maximum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "180.40796",
                                    "units": "Kelvin_scale",
                                    "grib_name": "Tasmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tasmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tasmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "330.92334",
                                    "gribparam": "215",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "minimum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "180.36084",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tasmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "629.96118",
                                    "gribparam": "169",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "180.38159",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "stemp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "stemp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "340.94824",
                                    "gribparam": "139",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "180.36328",
                                    "units": "unitless",
                                    "grib_name": "stemp",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "srun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "srun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.25845724E-06",
                                    "gribparam": "160",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "surface runoff",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "srun",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "SRADSU": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SRADSU",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.536377",
                                    "gribparam": "204",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "shortwave radiation upward (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-956.12451",
                                    "units": "W/m2",
                                    "grib_name": "SRADSU",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "soilm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soilm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.2000008",
                                    "gribparam": "140",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil wetness",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "soilm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "SNMEL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SNMEL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.02038791E-06",
                                    "gribparam": "218",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "snow melt",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "SNMEL",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "snd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "snd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "19.662109",
                                    "gribparam": "141",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Snow Depth",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m",
                                    "grib_name": "snd",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "slp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "slp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "mean sea level pressure",
                                    "gribleveltype": "102",
                                    "gribparam": "151",
                                    "Z": "Z_05",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25011 hybrid_lev P",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "pss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "109503.25",
                                    "gribparam": "134",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "46332.0",
                                    "units": "Pa",
                                    "grib_name": "pss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.74012564E-06",
                                    "gribparam": "142",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Large Scale Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prl",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Total Precipitation",
                                    "grib_name": "totprcp",
                                    "gribparam": "260",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prc": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prc",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.40823317E-06",
                                    "gribparam": "143",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Convective Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prc",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1454.0938",
                                        "gribparam": "176",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (surface)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-17.505707",
                                        "units": "Wm-2",
                                        "grib_name": "rss",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "107.88086",
                                        "gribparam": "177",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-340.33081",
                                        "units": "Wm-2",
                                        "grib_name": "rls",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    }
                                },
                                "hfss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1007.4453",
                                    "gribparam": "146",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Sensible Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1374.9336",
                                    "units": "Wm-2",
                                    "grib_name": "hfss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "hfls": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfls",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "373.59595",
                                    "gribparam": "147",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Latent Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2130.3047",
                                    "units": "Wm-2",
                                    "grib_name": "hfls",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "evs": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "evs",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.35732989E-07",
                                    "gribparam": "182",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Evaporation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-8.51853656E-07",
                                    "units": "m (H2O)",
                                    "grib_name": "evs",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "dpsdy": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdy",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Meridional Deriv. of Surface Pres.",
                                    "grib_name": "dpsdy",
                                    "gribparam": "274",
                                    "units": "kilogram meter-2 second-2",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "dpsdx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Zonal Deriv. of Surface Pres.",
                                    "grib_name": "dpsdx",
                                    "gribparam": "273",
                                    "units": "kilogram meter-2 second-2",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03125",
                                            "gribparam": "106",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-2472.3906",
                                            "units": "W/m2",
                                            "grib_name": "SRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-59.929688",
                                            "gribparam": "107",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-1114.6746",
                                            "units": "W/m2",
                                            "grib_name": "TRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1455.5",
                                            "gribparam": "101",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "10",
                                            "calendar": "360",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "38.006348",
                                            "gribparam": "102",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-366.68091",
                                            "units": "W/m2",
                                            "grib_name": "TRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    }
                                },
                                "ALBEDO": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALBEDO",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.8019527",
                                    "gribparam": "175",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Albedo (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.04915214",
                                    "units": "unitless",
                                    "grib_name": "ALBEDO",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "PressureLevel": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PressureLevel",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "Kelvin_scale",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "130",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "ta",
                                    "PTVersion": "0"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "138",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "rvort",
                                    "PTVersion": "0"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "fnname": "max",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "kilogram meter-1 second-3",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "vertical pressure velocity",
                                    "gribparam": "135",
                                    "grib_name": "ua",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "133",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "hus",
                                    "PTVersion": "0"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "155",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "div",
                                    "PTVersion": "0"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                }
                            },
                            "hybrid_lev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hybrid_lev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "410.25278",
                                    "gribparam": "130",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-23.461668",
                                    "units": "Kelvin_scale",
                                    "grib_name": "ta",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.34272065E-05",
                                    "gribparam": "138",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.74529323E-05",
                                    "units": "s-1",
                                    "grib_name": "rvort",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "Rv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for moist air"
                                },
                                "Rd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for dry air"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.34272065E-05",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.74529323E-05",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "units": "m",
                                    "fnname": "max",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "pressure",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "vertical pressure velocity",
                                    "units": "Pa/s",
                                    "gribparam": "135",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25011 hybrid_lev omegahalf",
                                    "grib_name": "ua",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "logpsl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "logpsl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "16.256054",
                                    "gribparam": "152",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Log Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-0.03005534",
                                    "units": "unitless",
                                    "grib_name": "logpsl",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.01572531",
                                    "gribparam": "133",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-0.00848219",
                                    "units": "unitless",
                                    "grib_name": "hus",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "gravity": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "gravity",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s2",
                                    "long_name": "earth\\'s gravity"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.20168658E-06",
                                    "gribparam": "155",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2.03210629E-06",
                                    "units": "s-1",
                                    "grib_name": "div",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.20168658E-06",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2.03210629E-06",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "BC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "BC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "ACLCAC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ACLCAC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.0",
                                    "gribparam": "223",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "units": "unitless",
                                    "scale_min": "0.0",
                                    "grib_name": "ACLCAC",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "AC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Pa"
                                }
                            },
                            "above_ground": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "above_ground",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "41.92942",
                                    "gribparam": "171",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "10m windspeed",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.007747378",
                                    "units": "unitless",
                                    "grib_name": "wind10",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "vas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "32.036606",
                                    "gribparam": "166",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-35.580582",
                                    "units": "m/s",
                                    "grib_name": "vas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "uas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "uas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "41.55455",
                                    "gribparam": "165",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-36.319748",
                                    "units": "m/s",
                                    "grib_name": "uas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "td2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "601.30786",
                                    "gribparam": "168",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Dewpoint at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "170.12061",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2mmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "330.10742",
                                    "gribparam": "201",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "max 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "185.29517",
                                    "units": "unitless",
                                    "grib_name": "t2mmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2mmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "326.42285",
                                    "gribparam": "202",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "min 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "184.82349",
                                    "units": "unitless",
                                    "grib_name": "t2mmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "624.72925",
                                    "gribparam": "167",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "184.97974",
                                    "units": "Kelvin_scale",
                                    "grib_name": "t2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "Z_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "long_name": "complex"
                            },
                            "sp_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Y_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "Z_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0"
                            },
                            "Z_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0",
                                "long_name": "Height"
                            },
                            "sp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "Z": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "pointwidth": "1.0"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "pointwidth": "2.8125",
                                "modulus": "360.0"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM3/History/MONTHLY/R25011"
                        },
                        "R25012": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "R25012",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "Conventions": "IRIDL",
                                "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM3/.History/.MONTHLY/.R25012/.griblist.html",
                                "filepattern": "/mstore/iri/forecast/data/echam/history/25012/25012fcst_%4d.01"
                            },
                            "total_air_column": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "total_air_column",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "VVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "482960.0",
                                    "gribparam": "111",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-560480.0",
                                    "units": "kg m s-1",
                                    "grib_name": "VVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "VQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2588.9761",
                                    "gribparam": "113",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2746.9531",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "VQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "UVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "877223.31",
                                    "gribparam": "110",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-312549.0",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "UVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "UQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2114.4414",
                                    "gribparam": "112",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2027.1133",
                                    "units": "kg m s-1",
                                    "grib_name": "UQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "QVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "149.30864",
                                    "gribparam": "230",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated specific humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-5.3901062",
                                    "units": "kg/m2",
                                    "grib_name": "QVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "cltm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "cltm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.0",
                                    "gribparam": "164",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover total mean[0-1]",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "cltm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "ALWCVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALWCVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.1980591",
                                    "gribparam": "231",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated liquid water content",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "kg/m2",
                                    "grib_name": "ALWCVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "top": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "top",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1781.8125",
                                        "gribparam": "178",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (top)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "0.0",
                                        "units": "Wm-2",
                                        "grib_name": "rst",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "-73.2146",
                                        "gribparam": "179",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-654.6709",
                                        "units": "Wm-2",
                                        "grib_name": "rlt",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    }
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.009277344",
                                            "gribparam": "105",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-1026.9282",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0U",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1790.8438",
                                            "gribparam": "103",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-73.2146",
                                            "gribparam": "104",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-654.6709",
                                            "units": "W/m2",
                                            "grib_name": "TRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    }
                                }
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "zg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "zg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "59908.211",
                                    "gribparam": "129",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Geopotential",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-5387.7891",
                                    "units": "m2 s-2",
                                    "grib_name": "zg",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "u3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u*3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.52747738E-04",
                                    "gribparam": "159",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "u*^3",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "2.71116951E-15",
                                    "units": "unitless",
                                    "grib_name": "u*3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TSLIN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TSLIN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1272.6885",
                                    "gribparam": "220",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "TSLIN heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1668.8594",
                                    "units": "W/m2",
                                    "grib_name": "TSLIN",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "322.37012",
                                    "gribparam": "209",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "187.86011",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD5",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD4": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD4",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "327.8125",
                                    "gribparam": "208",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "184.20874",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD4",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "340.58057",
                                    "gribparam": "207",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "182.83423",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "td": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "316.69897",
                                    "gribparam": "170",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "deep soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "195.09912",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tauv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "5.0930653",
                                    "gribparam": "181",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-3.7569294",
                                    "units": "Nm-2",
                                    "grib_name": "tauv",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tauu": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauu",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.8333006",
                                    "gribparam": "180",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-3.8743963",
                                    "units": "Nm-2",
                                    "grib_name": "tauu",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "Tasmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Tasmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "342.11035",
                                    "gribparam": "214",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "maximum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "182.87769",
                                    "units": "Kelvin_scale",
                                    "grib_name": "Tasmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tasmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tasmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "331.323",
                                    "gribparam": "215",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "minimum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "182.82935",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tasmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "635.38135",
                                    "gribparam": "169",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "182.85303",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "stemp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "stemp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "340.58057",
                                    "gribparam": "139",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "182.83423",
                                    "units": "unitless",
                                    "grib_name": "stemp",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "srun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "srun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.38756184E-06",
                                    "gribparam": "160",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "surface runoff",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "srun",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "SRADSU": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SRADSU",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.8793945",
                                    "gribparam": "204",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "shortwave radiation upward (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1013.7268",
                                    "units": "W/m2",
                                    "grib_name": "SRADSU",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "soilm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soilm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.2000008",
                                    "gribparam": "140",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil wetness",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "soilm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "SNMEL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SNMEL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.38599023E-06",
                                    "gribparam": "218",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "snow melt",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "SNMEL",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "snd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "snd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "35.978516",
                                    "gribparam": "141",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Snow Depth",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m",
                                    "grib_name": "snd",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "slp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "slp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "mean sea level pressure",
                                    "gribleveltype": "102",
                                    "gribparam": "151",
                                    "Z": "Z_05",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25012 hybrid_lev P",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "pss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "109296.62",
                                    "gribparam": "134",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "45825.188",
                                    "units": "Pa",
                                    "grib_name": "pss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.12243355E-06",
                                    "gribparam": "142",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Large Scale Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prl",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Total Precipitation",
                                    "grib_name": "totprcp",
                                    "gribparam": "260",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prc": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prc",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "4.45393380E-06",
                                    "gribparam": "143",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Convective Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prc",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1448.9688",
                                        "gribparam": "176",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (surface)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-4.7123108",
                                        "units": "Wm-2",
                                        "grib_name": "rss",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "126.76147",
                                        "gribparam": "177",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-340.26489",
                                        "units": "Wm-2",
                                        "grib_name": "rls",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    }
                                },
                                "hfss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "891.74829",
                                    "gribparam": "146",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Sensible Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1531.7031",
                                    "units": "Wm-2",
                                    "grib_name": "hfss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "hfls": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfls",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "487.15845",
                                    "gribparam": "147",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Latent Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2216.9102",
                                    "units": "Wm-2",
                                    "grib_name": "hfls",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "evs": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "evs",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.85056706E-07",
                                    "gribparam": "182",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Evaporation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-8.86484486E-07",
                                    "units": "m (H2O)",
                                    "grib_name": "evs",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "dpsdy": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdy",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Meridional Deriv. of Surface Pres.",
                                    "grib_name": "dpsdy",
                                    "gribparam": "274",
                                    "units": "kilogram meter-2 second-2",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "dpsdx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Zonal Deriv. of Surface Pres.",
                                    "grib_name": "dpsdx",
                                    "gribparam": "273",
                                    "units": "kilogram meter-2 second-2",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03125",
                                            "gribparam": "106",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-2801.2188",
                                            "units": "W/m2",
                                            "grib_name": "SRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-63.289551",
                                            "gribparam": "107",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-1154.5693",
                                            "units": "W/m2",
                                            "grib_name": "TRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1450.7812",
                                            "gribparam": "101",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "10",
                                            "calendar": "360",
                                            "scale_min": "0.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "55.964355",
                                            "gribparam": "102",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-383.84961",
                                            "units": "W/m2",
                                            "grib_name": "TRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    }
                                },
                                "ALBEDO": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALBEDO",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.8018755",
                                    "gribparam": "175",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Albedo (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.04915786",
                                    "units": "unitless",
                                    "grib_name": "ALBEDO",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "PressureLevel": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PressureLevel",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "Kelvin_scale",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "130",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "ta",
                                    "PTVersion": "0"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "138",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "rvort",
                                    "PTVersion": "0"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "fnname": "max",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "kilogram meter-1 second-3",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "vertical pressure velocity",
                                    "gribparam": "135",
                                    "grib_name": "ua",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "133",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "hus",
                                    "PTVersion": "0"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "155",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "div",
                                    "PTVersion": "0"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                }
                            },
                            "hybrid_lev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hybrid_lev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "410.32977",
                                    "gribparam": "130",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-23.437391",
                                    "units": "Kelvin_scale",
                                    "grib_name": "ta",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.36937940E-05",
                                    "gribparam": "138",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.65099373E-05",
                                    "units": "s-1",
                                    "grib_name": "rvort",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "Rv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for moist air"
                                },
                                "Rd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for dry air"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.36937940E-05",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.65099373E-05",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "units": "m",
                                    "fnname": "max",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "pressure",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "vertical pressure velocity",
                                    "units": "Pa/s",
                                    "gribparam": "135",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25012 hybrid_lev omegahalf",
                                    "grib_name": "ua",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "logpsl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "logpsl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "16.256054",
                                    "gribparam": "152",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Log Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-0.03067389",
                                    "units": "unitless",
                                    "grib_name": "logpsl",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.01574094",
                                    "gribparam": "133",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-0.008453883",
                                    "units": "unitless",
                                    "grib_name": "hus",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "gravity": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "gravity",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s2",
                                    "long_name": "earth\\'s gravity"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.02659749E-06",
                                    "gribparam": "155",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.90319497E-06",
                                    "units": "s-1",
                                    "grib_name": "div",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.02659749E-06",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.90319497E-06",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "BC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "BC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "ACLCAC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ACLCAC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.0",
                                    "gribparam": "223",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "units": "unitless",
                                    "scale_min": "0.0",
                                    "grib_name": "ACLCAC",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "AC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Pa"
                                }
                            },
                            "above_ground": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "above_ground",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "45.97438",
                                    "gribparam": "171",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "10m windspeed",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.008206341",
                                    "units": "unitless",
                                    "grib_name": "wind10",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "vas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "38.025314",
                                    "gribparam": "166",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-45.625076",
                                    "units": "m/s",
                                    "grib_name": "vas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "uas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "uas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "36.12674",
                                    "gribparam": "165",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-45.353729",
                                    "units": "m/s",
                                    "grib_name": "uas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "td2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "602.68652",
                                    "gribparam": "168",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Dewpoint at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "171.89331",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2mmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "330.729",
                                    "gribparam": "201",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "max 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "187.20923",
                                    "units": "unitless",
                                    "grib_name": "t2mmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2mmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "326.61426",
                                    "gribparam": "202",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "min 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "187.01831",
                                    "units": "unitless",
                                    "grib_name": "t2mmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "629.81812",
                                    "gribparam": "167",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "187.09375",
                                    "units": "Kelvin_scale",
                                    "grib_name": "t2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "Z_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "long_name": "complex"
                            },
                            "sp_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Y_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "Z_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0"
                            },
                            "Z_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0",
                                "long_name": "Height"
                            },
                            "sp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "Z": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "pointwidth": "1.0"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "pointwidth": "2.8125",
                                "modulus": "360.0"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM3/History/MONTHLY/R25012"
                        },
                        "R25013": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "R25013",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "Conventions": "IRIDL",
                                "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM3/.History/.MONTHLY/.R25013/.griblist.html",
                                "filepattern": "/mstore/iri/forecast/data/echam/history/25013/25013fcst_%4d.01"
                            },
                            "total_air_column": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "total_air_column",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "VVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "453236.81",
                                    "gribparam": "111",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-454893.0",
                                    "units": "kg m s-1",
                                    "grib_name": "VVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "VQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "VQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2339.2837",
                                    "gribparam": "113",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated meridional moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2376.4609",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "VQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "UVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "649641.88",
                                    "gribparam": "110",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal velocity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-314595.0",
                                    "units": "kg m-1 s-1",
                                    "grib_name": "UVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "UQVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "UQVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2344.5933",
                                    "gribparam": "112",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated zonal moisture flux",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1937.3984",
                                    "units": "kg m s-1",
                                    "grib_name": "UQVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "QVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "QVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "143.7459",
                                    "gribparam": "230",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated specific humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-6.2583466",
                                    "units": "kg/m2",
                                    "grib_name": "QVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "cltm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "cltm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.0",
                                    "gribparam": "164",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover total mean[0-1]",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "cltm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "ALWCVI": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALWCVI",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.536377",
                                    "gribparam": "231",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vertically integrated liquid water content",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "kg/m2",
                                    "grib_name": "ALWCVI",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "top": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "top",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1778.9688",
                                        "gribparam": "178",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (top)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "0.0",
                                        "units": "Wm-2",
                                        "grib_name": "rst",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "-70.909668",
                                        "gribparam": "179",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-654.37744",
                                        "units": "Wm-2",
                                        "grib_name": "rlt",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    }
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "27919.611",
                                            "gribparam": "105",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-682.84131",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0U",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "28569.141",
                                            "gribparam": "103",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-1559.8594",
                                            "units": "W/m2",
                                            "grib_name": "SRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1417295.9",
                                            "gribparam": "104",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-59920.125",
                                            "units": "W/m2",
                                            "grib_name": "TRAF0",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    }
                                }
                            },
                            "surface": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "surface",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "zg": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "zg",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "59908.211",
                                    "gribparam": "129",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Geopotential",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-5387.7891",
                                    "units": "m2 s-2",
                                    "grib_name": "zg",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "u3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u*3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.81900167E-04",
                                    "gribparam": "159",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "u*^3",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "8.90759329E-16",
                                    "units": "unitless",
                                    "grib_name": "u*3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TSLIN": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TSLIN",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "958.58374",
                                    "gribparam": "220",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "TSLIN heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2017.3828",
                                    "units": "W/m2",
                                    "grib_name": "TSLIN",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD5": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD5",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "322.51636",
                                    "gribparam": "209",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "185.57715",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD5",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD4": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD4",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "328.02026",
                                    "gribparam": "208",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "181.8418",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD4",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "TD3": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "TD3",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "340.87817",
                                    "gribparam": "207",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "180.58667",
                                    "units": "Kelvin_scale",
                                    "grib_name": "TD3",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "td": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "317.2998",
                                    "gribparam": "170",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "deep soil temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "194.35352",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tauv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.5823364",
                                    "gribparam": "181",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-3.6576271",
                                    "units": "Nm-2",
                                    "grib_name": "tauv",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tauu": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tauu",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.9693193",
                                    "gribparam": "180",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-component of Surface Wind Stress",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-4.0555048",
                                    "units": "Nm-2",
                                    "grib_name": "tauu",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "Tasmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Tasmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "343.03125",
                                    "gribparam": "214",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "maximum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "180.62134",
                                    "units": "Kelvin_scale",
                                    "grib_name": "Tasmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tasmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tasmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "331.23755",
                                    "gribparam": "215",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "minimum air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "180.58667",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tasmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "tas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "tas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "626.58154",
                                    "gribparam": "169",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "air temperature (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "180.60327",
                                    "units": "Kelvin_scale",
                                    "grib_name": "tas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "stemp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "stemp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "340.87817",
                                    "gribparam": "139",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "180.58667",
                                    "units": "unitless",
                                    "grib_name": "stemp",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "srun": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "srun",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.25793337E-06",
                                    "gribparam": "160",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "surface runoff",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "srun",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "SRADSU": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SRADSU",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.0227051",
                                    "gribparam": "204",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "shortwave radiation upward (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1003.7019",
                                    "units": "W/m2",
                                    "grib_name": "SRADSU",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "soilm": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soilm",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.2000008",
                                    "gribparam": "140",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "soil wetness",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "unitless",
                                    "grib_name": "soilm",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "SNMEL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "SNMEL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.11247243E-06",
                                    "gribparam": "218",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "snow melt",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "SNMEL",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "snd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "snd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "19.360352",
                                    "gribparam": "141",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Snow Depth",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m",
                                    "grib_name": "snd",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "slp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "slp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "mean sea level pressure",
                                    "gribleveltype": "102",
                                    "gribparam": "151",
                                    "Z": "Z_05",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25013 hybrid_lev P",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "pss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "pss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "109462.19",
                                    "gribparam": "134",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "46602.125",
                                    "units": "Pa",
                                    "grib_name": "pss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.75153434E-06",
                                    "gribparam": "142",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Large Scale Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prl",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prcp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prcp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Total Precipitation",
                                    "grib_name": "totprcp",
                                    "gribparam": "260",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "prc": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "prc",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "3.44734872E-06",
                                    "gribparam": "143",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Convective Precipitation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.0",
                                    "units": "m/s",
                                    "grib_name": "prc",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "net": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "net",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "swflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "swflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "1454.8438",
                                        "gribparam": "176",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Net Shortwave Radiation (surface)",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-43.462997",
                                        "units": "Wm-2",
                                        "grib_name": "rss",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    },
                                    "lwflx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lwflx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "scale_max": "138.80029",
                                        "gribparam": "177",
                                        "process": "31",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave flux",
                                        "PDS_TimeRange": "0",
                                        "calendar": "360",
                                        "scale_min": "-336.84814",
                                        "units": "Wm-2",
                                        "grib_name": "rls",
                                        "PTVersion": "0",
                                        "gribleveltype": "1"
                                    }
                                },
                                "hfss": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfss",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "889.01709",
                                    "gribparam": "146",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Sensible Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1262.2461",
                                    "units": "Wm-2",
                                    "grib_name": "hfss",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "hfls": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hfls",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "371.19263",
                                    "gribparam": "147",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Surface Flux of Latent Heat",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2309.4492",
                                    "units": "Wm-2",
                                    "grib_name": "hfls",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "evs": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "evs",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "1.30959052E-07",
                                    "gribparam": "182",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Evaporation",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-9.23644620E-07",
                                    "units": "m (H2O)",
                                    "grib_name": "evs",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "dpsdy": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdy",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Meridional Deriv. of Surface Pres.",
                                    "grib_name": "dpsdy",
                                    "gribparam": "274",
                                    "units": "kilogram meter-2 second-2",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "dpsdx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "dpsdx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "Zonal Deriv. of Surface Pres.",
                                    "grib_name": "dpsdx",
                                    "gribparam": "273",
                                    "units": "kilogram meter-2 second-2",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "clear_sky": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "clear_sky",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "upward": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "upward",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03125",
                                            "gribparam": "106",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-64549.062",
                                            "units": "W/m2",
                                            "grib_name": "SRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-10.289062",
                                            "gribparam": "107",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-14684.289",
                                            "units": "W/m2",
                                            "grib_name": "TRAFSU",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "solr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "solr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "882255.0",
                                            "gribparam": "101",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "solar flux",
                                            "PDS_TimeRange": "10",
                                            "calendar": "360",
                                            "scale_min": "-365521.0",
                                            "units": "W/m2",
                                            "grib_name": "SRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "3697670.8",
                                            "gribparam": "102",
                                            "process": "31",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "0",
                                            "calendar": "360",
                                            "scale_min": "-300281.25",
                                            "units": "W/m2",
                                            "grib_name": "TRAFS",
                                            "PTVersion": "0",
                                            "gribleveltype": "1"
                                        }
                                    }
                                },
                                "ALBEDO": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ALBEDO",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.8019445",
                                    "gribparam": "175",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Albedo (surface)",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-0.07235706",
                                    "units": "unitless",
                                    "grib_name": "ALBEDO",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "PressureLevel": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PressureLevel",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "Kelvin_scale",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "130",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "ta",
                                    "PTVersion": "0"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "138",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "rvort",
                                    "PTVersion": "0"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "m",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "fnname": "max",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "kilogram meter-1 second-3",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "vertical pressure velocity",
                                    "gribparam": "135",
                                    "grib_name": "ua",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "unitless",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "133",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "hus",
                                    "PTVersion": "0"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "gribparam": "155",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "grib_name": "div",
                                    "PTVersion": "0"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "missing_value": "NaN",
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "gribleveltype": "100",
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0"
                                }
                            },
                            "hybrid_lev": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "hybrid_lev",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "gribparam": "132",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "gribparam": "131",
                                    "units": "m/s",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "410.18787",
                                    "gribparam": "130",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-23.32205",
                                    "units": "Kelvin_scale",
                                    "grib_name": "ta",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.34751969E-05",
                                    "gribparam": "138",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "vorticity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.68117149E-05",
                                    "units": "s-1",
                                    "grib_name": "rvort",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "Rv": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rv",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for moist air"
                                },
                                "Rd": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Rd",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "J/kg/K",
                                    "long_name": "gas constant for dry air"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "gribparam": "148",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.34751969E-05",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-1.68117149E-05",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "gribparam": "156",
                                    "units": "m",
                                    "fnname": "max",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "pressure",
                                    "units": "Pa",
                                    "fnname": "eexp",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "omega": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "omega",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "vertical pressure velocity",
                                    "units": "Pa/s",
                                    "gribparam": "135",
                                    "history": "Z regridded on IRI FD ECHAM3 History SIX-HOURLY R25013 hybrid_lev omegahalf",
                                    "grib_name": "ua",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "logpsl": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "logpsl",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "16.256054",
                                    "gribparam": "152",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Log Surface Pressure",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-0.03126689",
                                    "units": "unitless",
                                    "grib_name": "logpsl",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "0.01570506",
                                    "gribparam": "133",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Specific Humidity",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-0.00855885",
                                    "units": "unitless",
                                    "grib_name": "hus",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "gravity": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "gravity",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s2",
                                    "long_name": "earth\\'s gravity"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.04053094E-06",
                                    "gribparam": "155",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Divergence",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2.18568857E-06",
                                    "units": "s-1",
                                    "grib_name": "div",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "gribparam": "149",
                                    "units": "meter2 second-1",
                                    "scale_max": "2.04053094E-06",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-2.18568857E-06",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "BC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "BC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "ACLCAC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ACLCAC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "2.0",
                                    "gribparam": "223",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "cloud cover",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "units": "unitless",
                                    "scale_min": "0.0",
                                    "grib_name": "ACLCAC",
                                    "PTVersion": "0",
                                    "gribleveltype": "109"
                                },
                                "AC": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "AC",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Pa"
                                }
                            },
                            "above_ground": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "above_ground",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "wind10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "wind10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "47.258011",
                                    "gribparam": "171",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "10m windspeed",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "0.009316683",
                                    "units": "unitless",
                                    "grib_name": "wind10",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "vas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "vas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "36.788528",
                                    "gribparam": "166",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "V-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-44.740768",
                                    "units": "m/s",
                                    "grib_name": "vas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "uas": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "uas",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "39.467575",
                                    "gribparam": "165",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "U-wind at 10",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "-39.257034",
                                    "units": "m/s",
                                    "grib_name": "uas",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "td2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "td2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "601.61157",
                                    "gribparam": "168",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Dewpoint at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "170.6123",
                                    "units": "Kelvin_scale",
                                    "grib_name": "td2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2mmx": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmx",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "330.20801",
                                    "gribparam": "201",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "max 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "185.58472",
                                    "units": "unitless",
                                    "grib_name": "t2mmx",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2mmn": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2mmn",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "326.35962",
                                    "gribparam": "202",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "min 2m temp",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "185.55591",
                                    "units": "unitless",
                                    "grib_name": "t2mmn",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                },
                                "t2m": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "t2m",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "scale_max": "620.87329",
                                    "gribparam": "167",
                                    "process": "31",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "long_name": "Temperature at 2 m",
                                    "PDS_TimeRange": "0",
                                    "calendar": "360",
                                    "scale_min": "185.56567",
                                    "units": "Kelvin_scale",
                                    "grib_name": "t2m",
                                    "PTVersion": "0",
                                    "gribleveltype": "1"
                                }
                            },
                            "Z_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "long_name": "complex"
                            },
                            "sp_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Y_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "Z_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0"
                            },
                            "Z_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0",
                                "long_name": "Height"
                            },
                            "sp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "Z": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "pointwidth": "1.0"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "pointwidth": "2.8125",
                                "modulus": "360.0"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM3/History/MONTHLY/R25013"
                        },
                        "ensemble": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ensemble",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "Conventions": "IRIDL"
                            },
                            "z": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "z",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m",
                                "long_name": "height"
                            },
                            "vqint": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "vqint",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unknown",
                                "long_name": "integrated meridional moisture flux"
                            },
                            "v": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "v",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m/s",
                                "long_name": "meridional velocity"
                            },
                            "uqint": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "uqint",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unknown",
                                "long_name": "integrated zonal moisture flux"
                            },
                            "u": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "u",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m/s",
                                "long_name": "zonal velocity"
                            },
                            "t2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "t2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Kelvin_scale",
                                "long_name": "temperature at 2m"
                            },
                            "PressureLevel": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "PressureLevel",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "v": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "v",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "132",
                                    "long_name": "meridional velocity",
                                    "grib_name": "va",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "PTVersion": "0",
                                    "calendar": "360",
                                    "process": "31"
                                },
                                "u": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "u",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m/s",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "131",
                                    "long_name": "zonal velocity",
                                    "grib_name": "ua",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "PTVersion": "0",
                                    "calendar": "360",
                                    "process": "31"
                                },
                                "ta": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "ta",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "Kelvin_scale",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Temperature",
                                    "PTVersion": "0",
                                    "calendar": "360",
                                    "grib_name": "ta",
                                    "gribparam": "130",
                                    "process": "31"
                                },
                                "rvort": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "rvort",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "vorticity",
                                    "PTVersion": "0",
                                    "calendar": "360",
                                    "grib_name": "rvort",
                                    "gribparam": "138",
                                    "process": "31"
                                },
                                "psi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "psi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "148",
                                    "long_name": "streamfunction",
                                    "grib_name": "strm",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "PTVersion": "0",
                                    "calendar": "360",
                                    "process": "31"
                                },
                                "phi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "phi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "156",
                                    "long_name": "geopotential height",
                                    "grib_name": "zg",
                                    "fnname": "max",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "PTVersion": "0",
                                    "calendar": "360",
                                    "process": "31"
                                },
                                "hus": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hus",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Specific Humidity",
                                    "PTVersion": "0",
                                    "calendar": "360",
                                    "grib_name": "hus",
                                    "gribparam": "133",
                                    "process": "31"
                                },
                                "Div": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Div",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "s-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "long_name": "Divergence",
                                    "PTVersion": "0",
                                    "calendar": "360",
                                    "grib_name": "div",
                                    "gribparam": "155",
                                    "process": "31"
                                },
                                "chi": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "chi",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "meter2 second-1",
                                    "history": "Boxes with less than 0.0% dropped",
                                    "missing_value": "NaN",
                                    "gribleveltype": "100",
                                    "gribparam": "149",
                                    "long_name": "velocity potential",
                                    "grib_name": "vpot",
                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                    "PDS_TimeRange": "0",
                                    "PTVersion": "0",
                                    "calendar": "360",
                                    "process": "31"
                                }
                            },
                            "prcp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "prcp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/day",
                                "long_name": "precipitation rate"
                            },
                            "M_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "M_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "member"
                            },
                            "M_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "M_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "member"
                            },
                            "T_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "pointwidth": "1.0",
                                "standard_name": "time"
                            },
                            "M_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "M_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "member"
                            },
                            "P_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "T_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "pointwidth": "1.0"
                            },
                            "M_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "M_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "calendar": "standard"
                            },
                            "M": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "M",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "member"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "pointwidth": "1.0",
                                "standard_name": "time"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "pointwidth": "2.8125",
                                "standard_name": "longitude"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM3/History/MONTHLY/ensemble"
                        },
                        "ensemble_mean": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "ensemble_mean",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "Conventions": "IRIDL"
                            },
                            "t2m": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "t2m",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "Kelvin_scale",
                                "long_name": "temperature at 2m"
                            },
                            "prcp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "prcp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mm/day",
                                "long_name": "precipitation rate"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "standard_name": "longitude",
                                "pointwidth": "2.8125"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0",
                                "standard_name": "latitude"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "months since 1960-01-01",
                                "gridtype": "0",
                                "calendar": "360",
                                "standard_name": "time",
                                "pointwidth": "1.0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM3/History/MONTHLY/ensemble_mean"
                        },
                        "banned_long": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type",
                            "R25004",
                            "R25005",
                            "R25006",
                            "R25007",
                            "R25008",
                            "R25009",
                            "R25010",
                            "R25011",
                            "R25012",
                            "R25013",
                            "ensemble",
                            "ensemble_mean"
                        ]
                    },
                    "SIXHOURLY": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/IRI/FD/ECHAM3/History/SIX-HOURLY",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "SIX-HOURLY",
                        "restriction": "requires dlauth tokens"
                    },
                    "banned_long": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type",
                        "MONTHLY",
                        "SIXHOURLY"
                    ]
                },
                "banned_long": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type",
                    "Forecast",
                    "History"
                ]
            },
            "ECHAM4p5": {
                "iridl_type": "Source",
                "invalid": [],
                "dir": "SOURCES/IRI/FD/ECHAM4p5",
                "banned": [
                    "dir",
                    "invalid",
                    "parent",
                    "name",
                    "banned",
                    "banned_long",
                    "iridl_ds_name",
                    "iridl_type"
                ],
                "iridl_ds_name": "ECHAM4p5",
                "restriction": "Public",
                "Forecast": {
                    "iridl_type": "Source",
                    "invalid": [],
                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast",
                    "banned": [
                        "dir",
                        "invalid",
                        "parent",
                        "name",
                        "banned",
                        "banned_long",
                        "iridl_ds_name",
                        "iridl_type"
                    ],
                    "iridl_ds_name": "Forecast",
                    "restriction": "Public",
                    "ECMWFSST": {
                        "iridl_type": "DataSet",
                        "iridl_ds_name": "ECMWF-SST",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "NC_GLOBAL": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "NC_GLOBAL",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "note": "When using the data, please include the acknowledgement: The computing for this project was provided (or partially provided) by a grant from the NCAR CSL program to the IRI",
                            "dataset_documentationhtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.ECMWF-SST/.dataset_documentation.html",
                            "iridlhasSemantics": "iriref:Li_S",
                            "Conventions": "IRIDL"
                        },
                        "SST_scenarios": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "SST_scenarios",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "ensemble24": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "ensemble24",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "MONTHLY": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "MONTHLY",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "meridional velocity",
                                        "units": "meters/second",
                                        "missing_value": "-999.0"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "zonal velocity",
                                        "units": "meters/second",
                                        "missing_value": "-999.0"
                                    },
                                    "temp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "temp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "temperature",
                                        "units": "Kelvin_scale",
                                        "missing_value": "-999.0"
                                    },
                                    "tauy": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauy",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "surface meridional wind stress",
                                        "units": "newton/ meter2",
                                        "missing_value": "-999.0"
                                    },
                                    "taux": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "taux",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "surface zonal wind stress",
                                        "units": "newton/ meter2",
                                        "missing_value": "-999.0"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "temperature at 2m",
                                        "units": "Kelvin_scale",
                                        "missing_value": "-999.0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "calendar": "360",
                                        "long_name": "Forecast Time",
                                        "units": "months since 1960-01-01",
                                        "standard_name": "time",
                                        "pointwidth": "1.0"
                                    },
                                    "st": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "st",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "surface temperature",
                                        "units": "Kelvin_scale",
                                        "missing_value": "-999.0"
                                    },
                                    "slp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "slp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "sea level pressure",
                                        "units": "pascals",
                                        "missing_value": "-999.0"
                                    },
                                    "sh": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sh",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "surface sensible heat flux",
                                        "units": "W/m2",
                                        "missing_value": "-999.0"
                                    },
                                    "q": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "q",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "specific humidity",
                                        "units": "kg/kg",
                                        "missing_value": "-999.0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "total precipitation",
                                        "units": "unitless",
                                        "missing_value": "-999.0"
                                    },
                                    "omg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "vertical pressure velocity",
                                        "units": "unitless",
                                        "missing_value": "-999.0"
                                    },
                                    "olr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "olr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "outgoing longwave radiation",
                                        "units": "W/m2",
                                        "missing_value": "-999.0"
                                    },
                                    "nswt": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nswt",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "net shortwave at toa",
                                        "units": "W/m2",
                                        "missing_value": "-999.0"
                                    },
                                    "nswg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nswg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "net shortwave at ground",
                                        "units": "W/m2",
                                        "missing_value": "-999.0"
                                    },
                                    "nlwg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nlwg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "net longwave at ground",
                                        "units": "W/m2",
                                        "missing_value": "-999.0"
                                    },
                                    "lh": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lh",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "surface latent heat flux",
                                        "units": "W/m2",
                                        "missing_value": "-999.0"
                                    },
                                    "gz": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gz",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "geopotential height",
                                        "missing_value": "-999.0"
                                    },
                                    "evap": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "evap",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "evaporation",
                                        "units": "meters/second",
                                        "missing_value": "-999.0"
                                    },
                                    "cld": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "cld",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "total cloud cover",
                                        "units": "fraction",
                                        "missing_value": "-999.0"
                                    }
                                }
                            }
                        },
                        "SST_ensemble_mean": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "SST_ensemble_mean",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "ensemble24": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "ensemble24",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "MONTHLY": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "MONTHLY",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "meridional velocity",
                                        "units": "meters/second",
                                        "missing_value": "-999.0"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "zonal velocity",
                                        "units": "meters/second",
                                        "missing_value": "-999.0"
                                    },
                                    "temp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "temp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "temperature",
                                        "units": "Kelvin_scale",
                                        "missing_value": "-999.0"
                                    },
                                    "tauy": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauy",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "surface meridional wind stress",
                                        "units": "newton/ meter2",
                                        "missing_value": "-999.0"
                                    },
                                    "taux": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "taux",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "surface zonal wind stress",
                                        "units": "newton/ meter2",
                                        "missing_value": "-999.0"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "temperature at 2m",
                                        "units": "Kelvin_scale",
                                        "missing_value": "-999.0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "calendar": "360",
                                        "long_name": "Forecast Time",
                                        "units": "months since 1960-01-01",
                                        "standard_name": "time",
                                        "pointwidth": "1.0"
                                    },
                                    "st": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "st",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "surface temperature",
                                        "units": "Kelvin_scale",
                                        "missing_value": "-999.0"
                                    },
                                    "slp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "slp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "sea level pressure",
                                        "units": "pascals",
                                        "missing_value": "-999.0"
                                    },
                                    "sh": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sh",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "surface sensible heat flux",
                                        "units": "W/m2",
                                        "missing_value": "-999.0"
                                    },
                                    "q": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "q",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "specific humidity",
                                        "units": "kg/kg",
                                        "missing_value": "-999.0"
                                    },
                                    "prec": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prec",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "total precipitation",
                                        "units": "unitless",
                                        "missing_value": "-999.0"
                                    },
                                    "omg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "vertical pressure velocity",
                                        "units": "unitless",
                                        "missing_value": "-999.0"
                                    },
                                    "olr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "olr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "outgoing longwave radiation",
                                        "units": "W/m2",
                                        "missing_value": "-999.0"
                                    },
                                    "nswt": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nswt",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "net shortwave at toa",
                                        "units": "W/m2",
                                        "missing_value": "-999.0"
                                    },
                                    "nswg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nswg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "net shortwave at ground",
                                        "units": "W/m2",
                                        "missing_value": "-999.0"
                                    },
                                    "nlwg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "nlwg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "net longwave at ground",
                                        "units": "W/m2",
                                        "missing_value": "-999.0"
                                    },
                                    "lh": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lh",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "surface latent heat flux",
                                        "units": "W/m2",
                                        "missing_value": "-999.0"
                                    },
                                    "gz": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gz",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "geopotential height",
                                        "missing_value": "-999.0"
                                    },
                                    "evap": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "evap",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "evaporation",
                                        "units": "meters/second",
                                        "missing_value": "-999.0"
                                    },
                                    "cld": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "cld",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "total cloud cover",
                                        "units": "fraction",
                                        "missing_value": "-999.0"
                                    }
                                }
                            }
                        },
                        "Z": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Z",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "mb",
                            "gridtype": "0",
                            "long_name": "Pressure"
                        },
                        "Y": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "Y",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_north",
                            "gridtype": "0",
                            "standard_name": "latitude"
                        },
                        "L": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "L",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "months",
                            "gridtype": "0",
                            "standard_name": "forecast_period",
                            "long_name": "Lead Time",
                            "pointwidth": "1.0"
                        },
                        "X": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "X",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "degree_east",
                            "gridtype": "1",
                            "standard_name": "longitude",
                            "pointwidth": "2.8125"
                        },
                        "M": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "M",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "unitless",
                            "gridtype": "0",
                            "long_name": "ensemble member",
                            "pointwidth": "1.0"
                        },
                        "S": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "S",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "units": "months since 1960-01-01",
                            "gridtype": "0",
                            "calendar": "360",
                            "standard_name": "forecast_reference_time",
                            "long_name": "Start Time",
                            "pointwidth": "0"
                        },
                        "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/ECMWF-SST"
                    },
                    "asst": {
                        "iridl_type": "Source",
                        "invalid": [],
                        "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst",
                        "banned": [
                            "dir",
                            "invalid",
                            "parent",
                            "name",
                            "banned",
                            "banned_long",
                            "iridl_ds_name",
                            "iridl_type"
                        ],
                        "iridl_ds_name": "asst",
                        "restriction": "Public",
                        "SIXHOURLY": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "SIX-HOURLY",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "sep2001PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "sep2001griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.SIX-HOURLY/.sep2001/.griblist.html",
                                "oct2001PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "oct2001griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.SIX-HOURLY/.oct2001/.griblist.html",
                                "nov2001PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "nov2001griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.SIX-HOURLY/.nov2001/.griblist.html",
                                "may2002PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "may2002griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.SIX-HOURLY/.may2002/.griblist.html",
                                "mar2002PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "mar2002griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.SIX-HOURLY/.mar2002/.griblist.html",
                                "jan2002PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "jan2002griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.SIX-HOURLY/.jan2002/.griblist.html",
                                "feb2002PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "feb2002griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.SIX-HOURLY/.feb2002/.griblist.html",
                                "dec2001PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "dec2001griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.SIX-HOURLY/.dec2001/.griblist.html",
                                "aug2001PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "aug2001griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.SIX-HOURLY/.aug2001/.griblist.html",
                                "apr2002PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "apr2002griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.SIX-HOURLY/.apr2002/.griblist.html",
                                "Conventions": "IRIDL"
                            },
                            "sep2001": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sep2001",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "QVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vertically integrated specific humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.02369691",
                                        "units": "kg/m2",
                                        "grib_name": "QVI",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "100.541",
                                        "gribparam": "230"
                                    },
                                    "CLTOPMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLTOPMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum height of convective cloud tops",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "8454.8711",
                                        "units": "Pa",
                                        "grib_name": "CLTOPMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "100000.0",
                                        "gribparam": "217"
                                    },
                                    "cltm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "cltm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "cloud cover total mean[0-1]",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "cltm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "164"
                                    }
                                },
                                "top": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "top",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "SRAD0U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRAD0U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (top)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-814.09155",
                                        "units": "W/m2",
                                        "grib_name": "SRAD0U",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "203"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (top)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rst",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1180.0",
                                            "gribparam": "178"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-403.40381",
                                            "units": "Wm-2",
                                            "grib_name": "rlt",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-71.068115",
                                            "gribparam": "179"
                                        }
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2031.1562",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0U",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2420.2266",
                                                "gribparam": "105"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1181.25",
                                                "gribparam": "187"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-403.40381",
                                                "units": "W/m2",
                                                "grib_name": "TRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-70.935303",
                                                "gribparam": "188"
                                            }
                                        }
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "zg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "zg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Geopotential",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7517.7578",
                                        "units": "m2 s-2",
                                        "grib_name": "zg",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "58762.242",
                                        "gribparam": "129"
                                    },
                                    "TSLIN": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TSLIN",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "TSLIN heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-96.768417",
                                        "units": "W/m2",
                                        "grib_name": "TSLIN",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.054245",
                                        "gribparam": "220"
                                    },
                                    "TRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "longwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-749.04761",
                                        "units": "W/m2",
                                        "grib_name": "TRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "-60.147461",
                                        "gribparam": "205"
                                    },
                                    "tauv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-5.0189714",
                                        "units": "Nm-2",
                                        "grib_name": "tauv",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "6.4329119",
                                        "gribparam": "181"
                                    },
                                    "tauu": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauu",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7.503911",
                                        "units": "Nm-2",
                                        "grib_name": "tauu",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "8.6344156",
                                        "gribparam": "180"
                                    },
                                    "tas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "air temperature (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.64001",
                                        "units": "Kelvin_scale",
                                        "grib_name": "tas",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "340.53094",
                                        "gribparam": "169"
                                    },
                                    "stemp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "stemp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.55408",
                                        "units": "unitless",
                                        "grib_name": "stemp",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "348.875",
                                        "gribparam": "139"
                                    },
                                    "srun": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "srun",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "surface runoff",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "srun",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.74563274E-06",
                                        "gribparam": "160"
                                    },
                                    "SRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-706.68433",
                                        "units": "W/m2",
                                        "grib_name": "SRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "204"
                                    },
                                    "soilm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil wetness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "soilm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.7324371",
                                        "gribparam": "140"
                                    },
                                    "SNMEL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SNMEL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "snow melt",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m/s",
                                        "grib_name": "SNMEL",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.19348988E-06",
                                        "gribparam": "218"
                                    },
                                    "snd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "snd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "snd",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.901367",
                                        "gribparam": "141"
                                    },
                                    "slp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "slp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "151",
                                        "long_name": "mean sea level pressure",
                                        "gribleveltype": "102",
                                        "Z": "Z_10",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY sep2001 hybrid_lev P",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "SICED": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SICED",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "SICED",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.5",
                                        "gribparam": "211"
                                    },
                                    "sfr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sfr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sfc roughness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "1.49999996E-05",
                                        "units": "m",
                                        "grib_name": "sfr",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "20.00148",
                                        "gribparam": "173"
                                    },
                                    "SEAICE": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SEAICE",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice cover",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "SEAICE",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "210"
                                    },
                                    "pss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "pss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "46502.473",
                                        "units": "Pa",
                                        "grib_name": "pss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "112836.48",
                                        "gribparam": "134"
                                    },
                                    "prs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Fall",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-7.05861028E-27",
                                        "units": "unitless",
                                        "grib_name": "prs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "9.28300324E-07",
                                        "gribparam": "144"
                                    },
                                    "prl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Large Scale Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "grib_name": "prl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "2.15917112E-06",
                                        "gribparam": "142"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "260",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "totprcp",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "prc": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prc",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Convective Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-1.44560339E-23",
                                        "grib_name": "prc",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.78634377E-06",
                                        "gribparam": "143"
                                    },
                                    "PERPW": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PERPW",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Primary wave mean period",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-484390.56",
                                        "units": "s",
                                        "grib_name": "PERPW",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "509471.81",
                                        "gribparam": "108"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (surface)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "978.32812",
                                            "gribparam": "176"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-302.75366",
                                            "units": "Wm-2",
                                            "grib_name": "rls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "82.91745",
                                            "gribparam": "177"
                                        }
                                    },
                                    "lsm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lsm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "land-sea mask",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "(0,1)",
                                        "grib_name": "lsm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "172"
                                    },
                                    "logpsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "logpsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Log Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.03195572",
                                        "units": "unitless",
                                        "grib_name": "logpsl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.258551",
                                        "gribparam": "152"
                                    },
                                    "hfss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Sensible Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-929.09717",
                                        "units": "Wm-2",
                                        "grib_name": "hfss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1316.8865",
                                        "gribparam": "146"
                                    },
                                    "hfls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Latent Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1723.9268",
                                        "units": "Wm-2",
                                        "grib_name": "hfls",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "241.52393",
                                        "gribparam": "147"
                                    },
                                    "evs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "evs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Evaporation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-6.89350031E-07",
                                        "units": "m (H2O)",
                                        "grib_name": "evs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "9.65756328E-08",
                                        "gribparam": "182"
                                    },
                                    "dpsdy": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdy",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "274",
                                        "long_name": "Meridional Deriv. of Surface Pres.",
                                        "grib_name": "dpsdy",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "dpsdx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "273",
                                        "long_name": "Zonal Deriv. of Surface Pres.",
                                        "grib_name": "dpsdx",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2094.5542",
                                                "units": "W/m2",
                                                "grib_name": "SRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2580.5107",
                                                "gribparam": "106"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-340792.62",
                                                "units": "W/m2",
                                                "grib_name": "TRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "695053.62",
                                                "gribparam": "107"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "983.07812",
                                                "gribparam": "185"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-302.75366",
                                                "units": "W/m2",
                                                "grib_name": "TRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "44.574326",
                                                "gribparam": "186"
                                            }
                                        }
                                    },
                                    "ALBEDO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ALBEDO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Albedo (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.06999999",
                                        "units": "unitless",
                                        "grib_name": "ALBEDO",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.8004687",
                                        "gribparam": "175"
                                    }
                                },
                                "soil": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soil",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "TDCL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TDCL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temp level CL",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "209.27393",
                                        "units": "m (H2O)",
                                        "grib_name": "TDCL",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "310.6774",
                                        "gribparam": "183"
                                    },
                                    "td": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "deep soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "208.61873",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "314.63721",
                                        "gribparam": "170"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY sep2001 hybrid_lev P 0000 1 Sep 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY sep2001 hybrid_lev P 0000 1 Sep 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY sep2001 hybrid_lev P 0000 1 Sep 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY sep2001 hybrid_lev P 0000 1 Sep 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribparam": "138"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY sep2001 hybrid_lev P 0000 1 Sep 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY sep2001 hybrid_lev P 0000 1 Sep 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY sep2001 hybrid_lev P 0000 1 Sep 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY sep2001 hybrid_lev P 0000 1 Sep 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.01011254",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "scale_max": "0.03295235",
                                        "gribparam": "133"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY sep2001 hybrid_lev P 0000 1 Sep 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY sep2001 hybrid_lev P 0000 1 Sep 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-22.011106",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "410.94366",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.62981305E-05",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.92021253E-05",
                                        "gribparam": "138"
                                    },
                                    "Rv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for moist air"
                                    },
                                    "Rd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for dry air"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.62981305E-05",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.92021253E-05"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "pressure",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY sep2001 hybrid_lev omegahalf",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.01011254",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "0.03295235",
                                        "gribparam": "133"
                                    },
                                    "gravity": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gravity",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s2",
                                        "long_name": "earth\\'s gravity"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.37861764E-06",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.38590428E-06",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.37861764E-06",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.38590428E-06"
                                    },
                                    "BC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "BC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless"
                                    },
                                    "AC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "AC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa"
                                    }
                                },
                                "filepattern": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "filepattern",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "above_ground": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "above_ground",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "wind10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "wind10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "10m windspeed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.01415058",
                                        "units": "unitless",
                                        "grib_name": "wind10",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "39.516331",
                                        "gribparam": "171"
                                    },
                                    "WIMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "WIMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum 10m wind speed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.02882166",
                                        "units": "m/s",
                                        "grib_name": "WIMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "41.043995",
                                        "gribparam": "216"
                                    },
                                    "vas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-34.856873",
                                        "units": "m/s",
                                        "grib_name": "vas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "36.763214",
                                        "gribparam": "166"
                                    },
                                    "uas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "uas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-40.969223",
                                        "units": "m/s",
                                        "grib_name": "uas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "36.12175",
                                        "gribparam": "165"
                                    },
                                    "td2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Dewpoint at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "3.16980469E-08",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "0.05351752",
                                        "gribparam": "168"
                                    },
                                    "t2mmx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "max 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "183.40935",
                                        "units": "unitless",
                                        "grib_name": "t2mmx",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "342.56317",
                                        "gribparam": "201"
                                    },
                                    "t2mmn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "min 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "183.11377",
                                        "units": "unitless",
                                        "grib_name": "t2mmn",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "327.08813",
                                        "gribparam": "202"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "183.14806",
                                        "units": "Kelvin_scale",
                                        "grib_name": "t2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "339.06738",
                                        "gribparam": "167"
                                    }
                                }
                            },
                            "oct2001": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "oct2001",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "QVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vertically integrated specific humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.02203228",
                                        "units": "kg/m2",
                                        "grib_name": "QVI",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "97.0998",
                                        "gribparam": "230"
                                    },
                                    "CLTOPMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLTOPMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum height of convective cloud tops",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "8482.9023",
                                        "units": "Pa",
                                        "grib_name": "CLTOPMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "100000.0",
                                        "gribparam": "217"
                                    },
                                    "cltm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "cltm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "cloud cover total mean[0-1]",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "cltm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "164"
                                    }
                                },
                                "top": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "top",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "SRAD0U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRAD0U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (top)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-810.30127",
                                        "units": "W/m2",
                                        "grib_name": "SRAD0U",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "203"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (top)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rst",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1180.2188",
                                            "gribparam": "178"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-400.74683",
                                            "units": "Wm-2",
                                            "grib_name": "rlt",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-70.802002",
                                            "gribparam": "179"
                                        }
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-1957.4448",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0U",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2299.8687",
                                                "gribparam": "105"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1181.5938",
                                                "gribparam": "187"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-400.74683",
                                                "units": "W/m2",
                                                "grib_name": "TRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-70.700439",
                                                "gribparam": "188"
                                            }
                                        }
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "zg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "zg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Geopotential",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7517.7578",
                                        "units": "m2 s-2",
                                        "grib_name": "zg",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "58762.242",
                                        "gribparam": "129"
                                    },
                                    "TSLIN": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TSLIN",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "TSLIN heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-94.052689",
                                        "units": "W/m2",
                                        "grib_name": "TSLIN",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.05557251",
                                        "gribparam": "220"
                                    },
                                    "TRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "longwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-747.0625",
                                        "units": "W/m2",
                                        "grib_name": "TRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "-60.853271",
                                        "gribparam": "205"
                                    },
                                    "tauv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-5.1365061",
                                        "units": "Nm-2",
                                        "grib_name": "tauv",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "6.7102699",
                                        "gribparam": "181"
                                    },
                                    "tauu": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauu",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7.0213451",
                                        "units": "Nm-2",
                                        "grib_name": "tauu",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "7.9920235",
                                        "gribparam": "180"
                                    },
                                    "tas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "air temperature (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "181.14819",
                                        "units": "Kelvin_scale",
                                        "grib_name": "tas",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "341.20801",
                                        "gribparam": "169"
                                    },
                                    "stemp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "stemp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "181.02661",
                                        "units": "unitless",
                                        "grib_name": "stemp",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "349.04868",
                                        "gribparam": "139"
                                    },
                                    "srun": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "srun",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "surface runoff",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "srun",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.88605134E-06",
                                        "gribparam": "160"
                                    },
                                    "SRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-707.29663",
                                        "units": "W/m2",
                                        "grib_name": "SRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "204"
                                    },
                                    "soilm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil wetness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "soilm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.7324371",
                                        "gribparam": "140"
                                    },
                                    "SNMEL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SNMEL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "snow melt",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m/s",
                                        "grib_name": "SNMEL",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.07992673E-06",
                                        "gribparam": "218"
                                    },
                                    "snd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "snd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "snd",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.987793",
                                        "gribparam": "141"
                                    },
                                    "slp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "slp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "151",
                                        "long_name": "mean sea level pressure",
                                        "gribleveltype": "102",
                                        "Z": "Z_10",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY oct2001 hybrid_lev P",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "SICED": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SICED",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "SICED",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.5",
                                        "gribparam": "211"
                                    },
                                    "sfr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sfr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sfc roughness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "1.49999996E-05",
                                        "units": "m",
                                        "grib_name": "sfr",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "20.00148",
                                        "gribparam": "173"
                                    },
                                    "SEAICE": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SEAICE",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice cover",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "SEAICE",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "210"
                                    },
                                    "pss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "pss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "46776.164",
                                        "units": "Pa",
                                        "grib_name": "pss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "112785.89",
                                        "gribparam": "134"
                                    },
                                    "prs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Fall",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-7.05861028E-27",
                                        "units": "unitless",
                                        "grib_name": "prs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "9.57195539E-07",
                                        "gribparam": "144"
                                    },
                                    "prl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Large Scale Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "grib_name": "prl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "2.10458347E-06",
                                        "gribparam": "142"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "260",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "totprcp",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "prc": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prc",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Convective Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-1.44560339E-23",
                                        "grib_name": "prc",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.64645871E-06",
                                        "gribparam": "143"
                                    },
                                    "PERPW": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PERPW",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Primary wave mean period",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-460414.25",
                                        "units": "s",
                                        "grib_name": "PERPW",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "508835.19",
                                        "gribparam": "108"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (surface)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "977.35938",
                                            "gribparam": "176"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-295.22241",
                                            "units": "Wm-2",
                                            "grib_name": "rls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "70.311279",
                                            "gribparam": "177"
                                        }
                                    },
                                    "lsm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lsm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "land-sea mask",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "(0,1)",
                                        "grib_name": "lsm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "172"
                                    },
                                    "logpsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "logpsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Log Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.03259419",
                                        "units": "unitless",
                                        "grib_name": "logpsl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.258545",
                                        "gribparam": "152"
                                    },
                                    "hfss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Sensible Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-890.92603",
                                        "units": "Wm-2",
                                        "grib_name": "hfss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1198.384",
                                        "gribparam": "146"
                                    },
                                    "hfls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Latent Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1597.8557",
                                        "units": "Wm-2",
                                        "grib_name": "hfls",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "254.5874",
                                        "gribparam": "147"
                                    },
                                    "FOREST": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FOREST",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vegetation type",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "FOREST",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.9492188",
                                        "gribparam": "212"
                                    },
                                    "evs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "evs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Evaporation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-6.38937763E-07",
                                        "units": "m (H2O)",
                                        "grib_name": "evs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.01801135E-07",
                                        "gribparam": "182"
                                    },
                                    "dpsdy": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdy",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "274",
                                        "long_name": "Meridional Deriv. of Surface Pres.",
                                        "grib_name": "dpsdy",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "dpsdx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "273",
                                        "long_name": "Zonal Deriv. of Surface Pres.",
                                        "grib_name": "dpsdx",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2280.9502",
                                                "units": "W/m2",
                                                "grib_name": "SRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2280.686",
                                                "gribparam": "106"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-360390.5",
                                                "units": "W/m2",
                                                "grib_name": "TRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "672458.38",
                                                "gribparam": "107"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "978.76562",
                                                "gribparam": "185"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-295.22241",
                                                "units": "W/m2",
                                                "grib_name": "TRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "38.007263",
                                                "gribparam": "186"
                                            }
                                        }
                                    },
                                    "ALBEDO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ALBEDO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Albedo (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.06999999",
                                        "units": "unitless",
                                        "grib_name": "ALBEDO",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.8004687",
                                        "gribparam": "175"
                                    }
                                },
                                "soil": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soil",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "TDCL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TDCL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temp level CL",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "209.41071",
                                        "units": "m (H2O)",
                                        "grib_name": "TDCL",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "310.67343",
                                        "gribparam": "183"
                                    },
                                    "TD5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "194.27815",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD5",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "319.96912",
                                        "gribparam": "209"
                                    },
                                    "TD3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "181.02661",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD3",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "344.80453",
                                        "gribparam": "207"
                                    },
                                    "td": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "deep soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "208.85321",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "315.01315",
                                        "gribparam": "170"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY oct2001 hybrid_lev P 0000 1 Oct 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY oct2001 hybrid_lev P 0000 1 Oct 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY oct2001 hybrid_lev P 0000 1 Oct 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY oct2001 hybrid_lev P 0000 1 Oct 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribparam": "138"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY oct2001 hybrid_lev P 0000 1 Oct 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY oct2001 hybrid_lev P 0000 1 Oct 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY oct2001 hybrid_lev P 0000 1 Oct 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY oct2001 hybrid_lev P 0000 1 Oct 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.009740736",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "scale_max": "0.03203419",
                                        "gribparam": "133"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY oct2001 hybrid_lev P 0000 1 Oct 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY oct2001 hybrid_lev P 0000 1 Oct 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-22.189262",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "410.87601",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.58565126E-05",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.92014068E-05",
                                        "gribparam": "138"
                                    },
                                    "Rv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for moist air"
                                    },
                                    "Rd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for dry air"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.58565126E-05",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.92014068E-05"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "pressure",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY oct2001 hybrid_lev omegahalf",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.009740736",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "0.03203419",
                                        "gribparam": "133"
                                    },
                                    "gravity": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gravity",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s2",
                                        "long_name": "earth\\'s gravity"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.27378064E-06",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.23643383E-06",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.27378064E-06",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.23643383E-06"
                                    },
                                    "BC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "BC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless"
                                    },
                                    "AC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "AC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa"
                                    }
                                },
                                "filepattern": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "filepattern",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "above_ground": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "above_ground",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "wind10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "wind10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "10m windspeed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.01781493",
                                        "units": "unitless",
                                        "grib_name": "wind10",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "38.639454",
                                        "gribparam": "171"
                                    },
                                    "WIMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "WIMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum 10m wind speed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.03018009",
                                        "units": "m/s",
                                        "grib_name": "WIMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "39.720284",
                                        "gribparam": "216"
                                    },
                                    "vas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-33.841614",
                                        "units": "m/s",
                                        "grib_name": "vas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "35.07431",
                                        "gribparam": "166"
                                    },
                                    "uas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "uas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-37.529984",
                                        "units": "m/s",
                                        "grib_name": "uas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "38.455627",
                                        "gribparam": "165"
                                    },
                                    "td2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Dewpoint at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "3.81825167E-08",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "0.05472569",
                                        "gribparam": "168"
                                    },
                                    "t2mmx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "max 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "183.88918",
                                        "units": "unitless",
                                        "grib_name": "t2mmx",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "337.99075",
                                        "gribparam": "201"
                                    },
                                    "t2mmn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "min 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "183.71666",
                                        "units": "unitless",
                                        "grib_name": "t2mmn",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "324.14752",
                                        "gribparam": "202"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "183.79305",
                                        "units": "Kelvin_scale",
                                        "grib_name": "t2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "334.52423",
                                        "gribparam": "167"
                                    }
                                }
                            },
                            "nov2001": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "nov2001",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "QVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vertically integrated specific humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.02195099",
                                        "units": "kg/m2",
                                        "grib_name": "QVI",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "91.349518",
                                        "gribparam": "230"
                                    },
                                    "CLTOPMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLTOPMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum height of convective cloud tops",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "8504.8242",
                                        "units": "Pa",
                                        "grib_name": "CLTOPMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "100000.0",
                                        "gribparam": "217"
                                    },
                                    "cltm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "cltm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "cloud cover total mean[0-1]",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "cltm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "164"
                                    }
                                },
                                "top": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "top",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "SRAD0U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRAD0U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (top)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-813.31763",
                                        "units": "W/m2",
                                        "grib_name": "SRAD0U",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "203"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (top)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rst",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1180.1875",
                                            "gribparam": "178"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-411.72266",
                                            "units": "Wm-2",
                                            "grib_name": "rlt",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-71.874023",
                                            "gribparam": "179"
                                        }
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2074.7466",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0U",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2300.6279",
                                                "gribparam": "105"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1181.4688",
                                                "gribparam": "187"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-411.72266",
                                                "units": "W/m2",
                                                "grib_name": "TRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-73.023193",
                                                "gribparam": "188"
                                            }
                                        }
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "zg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "zg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Geopotential",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7517.7578",
                                        "units": "m2 s-2",
                                        "grib_name": "zg",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "58762.242",
                                        "gribparam": "129"
                                    },
                                    "TSLIN": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TSLIN",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "TSLIN heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-95.060181",
                                        "units": "W/m2",
                                        "grib_name": "TSLIN",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.06510925",
                                        "gribparam": "220"
                                    },
                                    "TRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "longwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-763.8208",
                                        "units": "W/m2",
                                        "grib_name": "TRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "-59.332275",
                                        "gribparam": "205"
                                    },
                                    "tauv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-6.3768969",
                                        "units": "Nm-2",
                                        "grib_name": "tauv",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "6.8446803",
                                        "gribparam": "181"
                                    },
                                    "tauu": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauu",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-6.7599573",
                                        "units": "Nm-2",
                                        "grib_name": "tauu",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "7.6744623",
                                        "gribparam": "180"
                                    },
                                    "tas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "air temperature (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.07471",
                                        "units": "Kelvin_scale",
                                        "grib_name": "tas",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "339.87646",
                                        "gribparam": "169"
                                    },
                                    "stemp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "stemp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.06883",
                                        "units": "unitless",
                                        "grib_name": "stemp",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "350.53156",
                                        "gribparam": "139"
                                    },
                                    "srun": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "srun",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "surface runoff",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "srun",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.89177592E-06",
                                        "gribparam": "160"
                                    },
                                    "SRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-730.10181",
                                        "units": "W/m2",
                                        "grib_name": "SRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "204"
                                    },
                                    "soilm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil wetness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "soilm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.7324371",
                                        "gribparam": "140"
                                    },
                                    "SNMEL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SNMEL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "snow melt",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m/s",
                                        "grib_name": "SNMEL",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.17495074E-06",
                                        "gribparam": "218"
                                    },
                                    "snd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "snd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "snd",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "17.072754",
                                        "gribparam": "141"
                                    },
                                    "slp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "slp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "151",
                                        "long_name": "mean sea level pressure",
                                        "gribleveltype": "102",
                                        "Z": "Z_10",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY nov2001 hybrid_lev P",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "SICED": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SICED",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "SICED",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.5",
                                        "gribparam": "211"
                                    },
                                    "sfr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sfr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sfc roughness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "1.49999996E-05",
                                        "units": "m",
                                        "grib_name": "sfr",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "20.00148",
                                        "gribparam": "173"
                                    },
                                    "SEAICE": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SEAICE",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice cover",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "SEAICE",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "210"
                                    },
                                    "pss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "pss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "46531.035",
                                        "units": "Pa",
                                        "grib_name": "pss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "112788.16",
                                        "gribparam": "134"
                                    },
                                    "prs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Fall",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-1.41172175E-26",
                                        "units": "unitless",
                                        "grib_name": "prs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.18589264E-06",
                                        "gribparam": "144"
                                    },
                                    "prl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Large Scale Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "grib_name": "prl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "2.05659876E-06",
                                        "gribparam": "142"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "260",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "totprcp",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "prc": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prc",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Convective Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-1.80700392E-23",
                                        "grib_name": "prc",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.51756296E-06",
                                        "gribparam": "143"
                                    },
                                    "PERPW": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PERPW",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Primary wave mean period",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-461046.0",
                                        "units": "s",
                                        "grib_name": "PERPW",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "507801.25",
                                        "gribparam": "108"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (surface)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "981.1875",
                                            "gribparam": "176"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-296.24609",
                                            "units": "Wm-2",
                                            "grib_name": "rls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "63.776657",
                                            "gribparam": "177"
                                        }
                                    },
                                    "lsm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lsm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "land-sea mask",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "(0,1)",
                                        "grib_name": "lsm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "172"
                                    },
                                    "logpsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "logpsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Log Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.03177311",
                                        "units": "unitless",
                                        "grib_name": "logpsl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.258644",
                                        "gribparam": "152"
                                    },
                                    "hfss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Sensible Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-935.2561",
                                        "units": "Wm-2",
                                        "grib_name": "hfss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1699.0305",
                                        "gribparam": "146"
                                    },
                                    "hfls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Latent Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1958.4976",
                                        "units": "Wm-2",
                                        "grib_name": "hfls",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "245.13257",
                                        "gribparam": "147"
                                    },
                                    "FOREST": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FOREST",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vegetation type",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "FOREST",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.9492188",
                                        "gribparam": "212"
                                    },
                                    "evs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "evs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Evaporation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-7.83148323E-07",
                                        "units": "m (H2O)",
                                        "grib_name": "evs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "9.80207346E-08",
                                        "gribparam": "182"
                                    },
                                    "dpsdy": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdy",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "274",
                                        "long_name": "Meridional Deriv. of Surface Pres.",
                                        "grib_name": "dpsdy",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "dpsdx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "273",
                                        "long_name": "Zonal Deriv. of Surface Pres.",
                                        "grib_name": "dpsdx",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2260.6941",
                                                "units": "W/m2",
                                                "grib_name": "SRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2505.0957",
                                                "gribparam": "106"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-366529.12",
                                                "units": "W/m2",
                                                "grib_name": "TRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "683574.56",
                                                "gribparam": "107"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "981.1875",
                                                "gribparam": "185"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-296.24609",
                                                "units": "W/m2",
                                                "grib_name": "TRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "32.215759",
                                                "gribparam": "186"
                                            }
                                        }
                                    },
                                    "ALBEDO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ALBEDO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Albedo (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.06999999",
                                        "units": "unitless",
                                        "grib_name": "ALBEDO",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.8004687",
                                        "gribparam": "175"
                                    }
                                },
                                "soil": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soil",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "TDCL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TDCL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temp level CL",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "209.37915",
                                        "units": "m (H2O)",
                                        "grib_name": "TDCL",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "310.65991",
                                        "gribparam": "183"
                                    },
                                    "TD5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "194.48915",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD5",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "320.0416",
                                        "gribparam": "209"
                                    },
                                    "TD3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.06883",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD3",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "345.9339",
                                        "gribparam": "207"
                                    },
                                    "td": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "deep soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "208.94403",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "314.66507",
                                        "gribparam": "170"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY nov2001 hybrid_lev P 0000 1 Nov 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY nov2001 hybrid_lev P 0000 1 Nov 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY nov2001 hybrid_lev P 0000 1 Nov 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY nov2001 hybrid_lev P 0000 1 Nov 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribparam": "138"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY nov2001 hybrid_lev P 0000 1 Nov 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY nov2001 hybrid_lev P 0000 1 Nov 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY nov2001 hybrid_lev P 0000 1 Nov 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY nov2001 hybrid_lev P 0000 1 Nov 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.008954212",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "scale_max": "0.02971217",
                                        "gribparam": "133"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY nov2001 hybrid_lev P 0000 1 Nov 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY nov2001 hybrid_lev P 0000 1 Nov 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-22.111877",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "410.25348",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.42175786E-05",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.91621493E-05",
                                        "gribparam": "138"
                                    },
                                    "Rv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for moist air"
                                    },
                                    "Rd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for dry air"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.42175786E-05",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.91621493E-05"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "pressure",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY nov2001 hybrid_lev omegahalf",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.008954212",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "0.02971217",
                                        "gribparam": "133"
                                    },
                                    "gravity": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gravity",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s2",
                                        "long_name": "earth\\'s gravity"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.26730322E-06",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.42827673E-06",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.26730322E-06",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.42827673E-06"
                                    },
                                    "BC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "BC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless"
                                    },
                                    "AC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "AC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa"
                                    }
                                },
                                "filepattern": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "filepattern",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "above_ground": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "above_ground",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "wind10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "wind10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "10m windspeed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.01585075",
                                        "units": "unitless",
                                        "grib_name": "wind10",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "37.488258",
                                        "gribparam": "171"
                                    },
                                    "WIMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "WIMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum 10m wind speed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.03440671",
                                        "units": "m/s",
                                        "grib_name": "WIMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "38.766277",
                                        "gribparam": "216"
                                    },
                                    "vas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-33.275696",
                                        "units": "m/s",
                                        "grib_name": "vas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "33.913086",
                                        "gribparam": "166"
                                    },
                                    "uas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "uas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-35.306305",
                                        "units": "m/s",
                                        "grib_name": "uas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "35.903198",
                                        "gribparam": "165"
                                    },
                                    "td2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Dewpoint at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "2.79916108E-08",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "0.04161635",
                                        "gribparam": "168"
                                    },
                                    "t2mmx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "max 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "184.40092",
                                        "units": "unitless",
                                        "grib_name": "t2mmx",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "335.47098",
                                        "gribparam": "201"
                                    },
                                    "t2mmn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "min 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "184.05199",
                                        "units": "unitless",
                                        "grib_name": "t2mmn",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "326.17755",
                                        "gribparam": "202"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "184.09607",
                                        "units": "Kelvin_scale",
                                        "grib_name": "t2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "335.47015",
                                        "gribparam": "167"
                                    }
                                }
                            },
                            "may2002": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "may2002",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "QVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vertically integrated specific humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.02268085",
                                        "units": "kg/m2",
                                        "grib_name": "QVI",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "101.35134",
                                        "gribparam": "230"
                                    },
                                    "CLTOPMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLTOPMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum height of convective cloud tops",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "8458.2578",
                                        "units": "Pa",
                                        "grib_name": "CLTOPMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "100000.0",
                                        "gribparam": "217"
                                    },
                                    "cltm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "cltm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "cloud cover total mean[0-1]",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "cltm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "164"
                                    }
                                },
                                "top": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "top",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "SRAD0U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRAD0U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (top)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-805.75977",
                                        "units": "W/m2",
                                        "grib_name": "SRAD0U",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "203"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (top)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rst",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1169.875",
                                            "gribparam": "178"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-417.64819",
                                            "units": "Wm-2",
                                            "grib_name": "rlt",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-67.590576",
                                            "gribparam": "179"
                                        }
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-1810.627",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0U",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2380.5686",
                                                "gribparam": "105"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1171.8438",
                                                "gribparam": "187"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-417.64819",
                                                "units": "W/m2",
                                                "grib_name": "TRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-67.590576",
                                                "gribparam": "188"
                                            }
                                        }
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "zg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "zg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Geopotential",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7517.7578",
                                        "units": "m2 s-2",
                                        "grib_name": "zg",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "58762.242",
                                        "gribparam": "129"
                                    },
                                    "TSLIN": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TSLIN",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "TSLIN heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-97.054443",
                                        "units": "W/m2",
                                        "grib_name": "TSLIN",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.009368896",
                                        "gribparam": "220"
                                    },
                                    "TRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "longwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-750.39209",
                                        "units": "W/m2",
                                        "grib_name": "TRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "-57.69043",
                                        "gribparam": "205"
                                    },
                                    "tauv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-5.2450733",
                                        "units": "Nm-2",
                                        "grib_name": "tauv",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "5.4910698",
                                        "gribparam": "181"
                                    },
                                    "tauu": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauu",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-6.0852108",
                                        "units": "Nm-2",
                                        "grib_name": "tauu",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "6.4828739",
                                        "gribparam": "180"
                                    },
                                    "tas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "air temperature (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "178.73286",
                                        "units": "Kelvin_scale",
                                        "grib_name": "tas",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "339.703",
                                        "gribparam": "169"
                                    },
                                    "stemp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "stemp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "178.76479",
                                        "units": "unitless",
                                        "grib_name": "stemp",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "346.00079",
                                        "gribparam": "139"
                                    },
                                    "srun": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "srun",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "surface runoff",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "srun",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.80930169E-06",
                                        "gribparam": "160"
                                    },
                                    "SRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-735.98218",
                                        "units": "W/m2",
                                        "grib_name": "SRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "204"
                                    },
                                    "soilm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil wetness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "soilm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.7324371",
                                        "gribparam": "140"
                                    },
                                    "SNMEL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SNMEL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "snow melt",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m/s",
                                        "grib_name": "SNMEL",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.23571954E-06",
                                        "gribparam": "218"
                                    },
                                    "snd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "snd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "snd",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "17.172363",
                                        "gribparam": "141"
                                    },
                                    "slp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "slp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "151",
                                        "long_name": "mean sea level pressure",
                                        "gribleveltype": "102",
                                        "Z": "Z_10",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY may2002 hybrid_lev P",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "SICED": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SICED",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "SICED",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.5",
                                        "gribparam": "211"
                                    },
                                    "sfr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sfr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sfc roughness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "1.49999996E-05",
                                        "units": "m",
                                        "grib_name": "sfr",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "20.00148",
                                        "gribparam": "173"
                                    },
                                    "SEAICE": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SEAICE",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice cover",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "SEAICE",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "210"
                                    },
                                    "pss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "pss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "47327.711",
                                        "units": "Pa",
                                        "grib_name": "pss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "112742.3",
                                        "gribparam": "134"
                                    },
                                    "prs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Fall",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-7.05861028E-27",
                                        "units": "unitless",
                                        "grib_name": "prs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.05294919E-06",
                                        "gribparam": "144"
                                    },
                                    "prl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Large Scale Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "grib_name": "prl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "2.55270857E-06",
                                        "gribparam": "142"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "260",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "totprcp",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "prc": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prc",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Convective Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-1.44560339E-23",
                                        "grib_name": "prc",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.47685728E-06",
                                        "gribparam": "143"
                                    },
                                    "PERPW": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PERPW",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Primary wave mean period",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-460175.5",
                                        "units": "s",
                                        "grib_name": "PERPW",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "502922.94",
                                        "gribparam": "108"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (surface)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "968.90625",
                                            "gribparam": "176"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-282.00977",
                                            "units": "Wm-2",
                                            "grib_name": "rls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "81.45018",
                                            "gribparam": "177"
                                        }
                                    },
                                    "lsm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lsm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "land-sea mask",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "(0,1)",
                                        "grib_name": "lsm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "172"
                                    },
                                    "logpsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "logpsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Log Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.03288324",
                                        "units": "unitless",
                                        "grib_name": "logpsl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.258514",
                                        "gribparam": "152"
                                    },
                                    "hfss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Sensible Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-973.62573",
                                        "units": "Wm-2",
                                        "grib_name": "hfss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1404.5789",
                                        "gribparam": "146"
                                    },
                                    "hfls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Latent Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1614.4563",
                                        "units": "Wm-2",
                                        "grib_name": "hfls",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "256.06665",
                                        "gribparam": "147"
                                    },
                                    "FOREST": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FOREST",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vegetation type",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "FOREST",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.9492188",
                                        "gribparam": "212"
                                    },
                                    "evs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "evs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Evaporation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-6.45575938E-07",
                                        "units": "m (H2O)",
                                        "grib_name": "evs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.02396484E-07",
                                        "gribparam": "182"
                                    },
                                    "dpsdy": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdy",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "274",
                                        "long_name": "Meridional Deriv. of Surface Pres.",
                                        "grib_name": "dpsdy",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "dpsdx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "273",
                                        "long_name": "Zonal Deriv. of Surface Pres.",
                                        "grib_name": "dpsdx",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2166.262",
                                                "units": "W/m2",
                                                "grib_name": "SRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2226.4883",
                                                "gribparam": "106"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-316039.31",
                                                "units": "W/m2",
                                                "grib_name": "TRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "667932.44",
                                                "gribparam": "107"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "970.17188",
                                                "gribparam": "185"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-282.00977",
                                                "units": "W/m2",
                                                "grib_name": "TRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "47.673096",
                                                "gribparam": "186"
                                            }
                                        }
                                    },
                                    "ALBEDO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ALBEDO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Albedo (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.06999999",
                                        "units": "unitless",
                                        "grib_name": "ALBEDO",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.8004687",
                                        "gribparam": "175"
                                    }
                                },
                                "soil": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soil",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "TDCL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TDCL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temp level CL",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "209.46811",
                                        "units": "m (H2O)",
                                        "grib_name": "TDCL",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "310.25977",
                                        "gribparam": "183"
                                    },
                                    "TD5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "193.23495",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD5",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "319.41663",
                                        "gribparam": "209"
                                    },
                                    "TD3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "178.76479",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD3",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "341.909",
                                        "gribparam": "207"
                                    },
                                    "td": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "deep soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "208.56224",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "314.13382",
                                        "gribparam": "170"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY may2002 hybrid_lev P 0000 1 May 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY may2002 hybrid_lev P 0000 1 May 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY may2002 hybrid_lev P 0000 1 May 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY may2002 hybrid_lev P 0000 1 May 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribparam": "138"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY may2002 hybrid_lev P 0000 1 May 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY may2002 hybrid_lev P 0000 1 May 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY may2002 hybrid_lev P 0000 1 May 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY may2002 hybrid_lev P 0000 1 May 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.01359124",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "scale_max": "0.03245457",
                                        "gribparam": "133"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY may2002 hybrid_lev P 0000 1 May 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY may2002 hybrid_lev P 0000 1 May 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-22.402082",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "410.79141",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.62070719E-05",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.90237552E-05",
                                        "gribparam": "138"
                                    },
                                    "Rv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for moist air"
                                    },
                                    "Rd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for dry air"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.62070719E-05",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.90237552E-05"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "pressure",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY may2002 hybrid_lev omegahalf",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.01359124",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "0.03245457",
                                        "gribparam": "133"
                                    },
                                    "gravity": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gravity",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s2",
                                        "long_name": "earth\\'s gravity"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.18547507E-06",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.25758959E-06",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.18547507E-06",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.25758959E-06"
                                    },
                                    "BC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "BC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless"
                                    },
                                    "AC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "AC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa"
                                    }
                                },
                                "filepattern": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "filepattern",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "above_ground": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "above_ground",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "wind10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "wind10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "10m windspeed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.01807361",
                                        "units": "unitless",
                                        "grib_name": "wind10",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "36.802582",
                                        "gribparam": "171"
                                    },
                                    "WIMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "WIMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum 10m wind speed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.03341689",
                                        "units": "m/s",
                                        "grib_name": "WIMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "37.801003",
                                        "gribparam": "216"
                                    },
                                    "vas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-35.386703",
                                        "units": "m/s",
                                        "grib_name": "vas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "32.557709",
                                        "gribparam": "166"
                                    },
                                    "uas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "uas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-36.726135",
                                        "units": "m/s",
                                        "grib_name": "uas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "36.20784",
                                        "gribparam": "165"
                                    },
                                    "td2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Dewpoint at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "2.65481823E-08",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "0.04376921",
                                        "gribparam": "168"
                                    },
                                    "t2mmx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "max 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "182.77348",
                                        "units": "unitless",
                                        "grib_name": "t2mmx",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "340.74591",
                                        "gribparam": "201"
                                    },
                                    "t2mmn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "min 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "182.47511",
                                        "units": "unitless",
                                        "grib_name": "t2mmn",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "328.30576",
                                        "gribparam": "202"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "182.53017",
                                        "units": "Kelvin_scale",
                                        "grib_name": "t2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "336.63055",
                                        "gribparam": "167"
                                    }
                                }
                            },
                            "mar2002": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "mar2002",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "QVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vertically integrated specific humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.02092659",
                                        "units": "kg/m2",
                                        "grib_name": "QVI",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "100.37366",
                                        "gribparam": "230"
                                    },
                                    "CLTOPMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLTOPMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum height of convective cloud tops",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "8459.9219",
                                        "units": "Pa",
                                        "grib_name": "CLTOPMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "100000.0",
                                        "gribparam": "217"
                                    },
                                    "cltm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "cltm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "cloud cover total mean[0-1]",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "cltm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "164"
                                    }
                                },
                                "top": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "top",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "SRAD0U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRAD0U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (top)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-809.87915",
                                        "units": "W/m2",
                                        "grib_name": "SRAD0U",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "203"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (top)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rst",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1179.2188",
                                            "gribparam": "178"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-416.10107",
                                            "units": "Wm-2",
                                            "grib_name": "rlt",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-70.513672",
                                            "gribparam": "179"
                                        }
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2221.127",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0U",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2266.5801",
                                                "gribparam": "105"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1180.8438",
                                                "gribparam": "187"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-416.10107",
                                                "units": "W/m2",
                                                "grib_name": "TRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-70.201172",
                                                "gribparam": "188"
                                            }
                                        }
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "zg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "zg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Geopotential",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7517.7578",
                                        "units": "m2 s-2",
                                        "grib_name": "zg",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "58762.242",
                                        "gribparam": "129"
                                    },
                                    "TSLIN": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TSLIN",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "TSLIN heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-99.271332",
                                        "units": "W/m2",
                                        "grib_name": "TSLIN",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.01947021",
                                        "gribparam": "220"
                                    },
                                    "TRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "longwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-741.67822",
                                        "units": "W/m2",
                                        "grib_name": "TRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "-60.109375",
                                        "gribparam": "205"
                                    },
                                    "tauv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-6.3640909",
                                        "units": "Nm-2",
                                        "grib_name": "tauv",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "6.6285334",
                                        "gribparam": "181"
                                    },
                                    "tauu": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauu",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7.3651667",
                                        "units": "Nm-2",
                                        "grib_name": "tauu",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "8.413579",
                                        "gribparam": "180"
                                    },
                                    "tas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "air temperature (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.62958",
                                        "units": "Kelvin_scale",
                                        "grib_name": "tas",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "339.54669",
                                        "gribparam": "169"
                                    },
                                    "stemp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "stemp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.63219",
                                        "units": "unitless",
                                        "grib_name": "stemp",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "347.69504",
                                        "gribparam": "139"
                                    },
                                    "srun": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "srun",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "surface runoff",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "srun",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.77705226E-06",
                                        "gribparam": "160"
                                    },
                                    "SRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-730.26562",
                                        "units": "W/m2",
                                        "grib_name": "SRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "204"
                                    },
                                    "soilm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil wetness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "soilm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.7324371",
                                        "gribparam": "140"
                                    },
                                    "SNMEL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SNMEL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "snow melt",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m/s",
                                        "grib_name": "SNMEL",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.28964894E-06",
                                        "gribparam": "218"
                                    },
                                    "snd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "snd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "snd",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "17.050781",
                                        "gribparam": "141"
                                    },
                                    "slp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "slp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "151",
                                        "long_name": "mean sea level pressure",
                                        "gribleveltype": "102",
                                        "Z": "Z_10",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY mar2002 hybrid_lev P",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "SICED": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SICED",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "SICED",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.5",
                                        "gribparam": "211"
                                    },
                                    "sfr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sfr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sfc roughness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "1.49999996E-05",
                                        "units": "m",
                                        "grib_name": "sfr",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "20.00148",
                                        "gribparam": "173"
                                    },
                                    "SEAICE": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SEAICE",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice cover",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "SEAICE",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "210"
                                    },
                                    "pss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "pss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "46515.105",
                                        "units": "Pa",
                                        "grib_name": "pss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "112935.03",
                                        "gribparam": "134"
                                    },
                                    "prs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Fall",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-7.05861028E-27",
                                        "units": "unitless",
                                        "grib_name": "prs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.06352172E-06",
                                        "gribparam": "144"
                                    },
                                    "prl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Large Scale Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "grib_name": "prl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.91412437E-06",
                                        "gribparam": "142"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "260",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "totprcp",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "prc": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prc",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Convective Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-1.62630428E-23",
                                        "grib_name": "prc",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.56440149E-06",
                                        "gribparam": "143"
                                    },
                                    "PERPW": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PERPW",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Primary wave mean period",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-474417.56",
                                        "units": "s",
                                        "grib_name": "PERPW",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "518819.19",
                                        "gribparam": "108"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (surface)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "984.1875",
                                            "gribparam": "176"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-296.59326",
                                            "units": "Wm-2",
                                            "grib_name": "rls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "77.221848",
                                            "gribparam": "177"
                                        }
                                    },
                                    "lsm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lsm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "land-sea mask",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "(0,1)",
                                        "grib_name": "lsm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "172"
                                    },
                                    "logpsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "logpsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Log Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.03155754",
                                        "units": "unitless",
                                        "grib_name": "logpsl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.258539",
                                        "gribparam": "152"
                                    },
                                    "hfss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Sensible Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-854.45996",
                                        "units": "Wm-2",
                                        "grib_name": "hfss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1805.426",
                                        "gribparam": "146"
                                    },
                                    "hfls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Latent Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2318.238",
                                        "units": "Wm-2",
                                        "grib_name": "hfls",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "239.09888",
                                        "gribparam": "147"
                                    },
                                    "FOREST": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FOREST",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vegetation type",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "FOREST",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.9492188",
                                        "gribparam": "212"
                                    },
                                    "evs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "evs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Evaporation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-9.26998553E-07",
                                        "units": "m (H2O)",
                                        "grib_name": "evs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "9.56092094E-08",
                                        "gribparam": "182"
                                    },
                                    "dpsdy": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdy",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "274",
                                        "long_name": "Meridional Deriv. of Surface Pres.",
                                        "grib_name": "dpsdy",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "dpsdx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "273",
                                        "long_name": "Zonal Deriv. of Surface Pres.",
                                        "grib_name": "dpsdx",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2032.45",
                                                "units": "W/m2",
                                                "grib_name": "SRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2188.0452",
                                                "gribparam": "106"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-348064.38",
                                                "units": "W/m2",
                                                "grib_name": "TRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "717521.06",
                                                "gribparam": "107"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "984.1875",
                                                "gribparam": "185"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-296.59326",
                                                "units": "W/m2",
                                                "grib_name": "TRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "54.60672",
                                                "gribparam": "186"
                                            }
                                        }
                                    },
                                    "ALBEDO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ALBEDO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Albedo (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.06999999",
                                        "units": "unitless",
                                        "grib_name": "ALBEDO",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.8004687",
                                        "gribparam": "175"
                                    }
                                },
                                "soil": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soil",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "TDCL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TDCL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temp level CL",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "209.42003",
                                        "units": "m (H2O)",
                                        "grib_name": "TDCL",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "310.6062",
                                        "gribparam": "183"
                                    },
                                    "TD5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "195.02078",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD5",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "319.58698",
                                        "gribparam": "209"
                                    },
                                    "TD3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.63219",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD3",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "343.31613",
                                        "gribparam": "207"
                                    },
                                    "td": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "deep soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "208.50362",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "314.41003",
                                        "gribparam": "170"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY mar2002 hybrid_lev P 0000 1 Mar 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY mar2002 hybrid_lev P 0000 1 Mar 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY mar2002 hybrid_lev P 0000 1 Mar 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY mar2002 hybrid_lev P 0000 1 Mar 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribparam": "138"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY mar2002 hybrid_lev P 0000 1 Mar 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY mar2002 hybrid_lev P 0000 1 Mar 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY mar2002 hybrid_lev P 0000 1 Mar 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY mar2002 hybrid_lev P 0000 1 Mar 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.01531013",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "scale_max": "0.03264626",
                                        "gribparam": "133"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY mar2002 hybrid_lev P 0000 1 Mar 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY mar2002 hybrid_lev P 0000 1 Mar 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-22.176682",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "410.77588",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.59884912E-05",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.88163303E-05",
                                        "gribparam": "138"
                                    },
                                    "Rv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for moist air"
                                    },
                                    "Rd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for dry air"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.59884912E-05",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.88163303E-05"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "pressure",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY mar2002 hybrid_lev omegahalf",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.01531013",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "0.03264626",
                                        "gribparam": "133"
                                    },
                                    "gravity": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gravity",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s2",
                                        "long_name": "earth\\'s gravity"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.36894539E-06",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.28596105E-06",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.36894539E-06",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.28596105E-06"
                                    },
                                    "BC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "BC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless"
                                    },
                                    "AC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "AC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa"
                                    }
                                },
                                "filepattern": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "filepattern",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "above_ground": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "above_ground",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "wind10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "wind10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "10m windspeed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0159791",
                                        "units": "unitless",
                                        "grib_name": "wind10",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "42.27898",
                                        "gribparam": "171"
                                    },
                                    "WIMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "WIMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum 10m wind speed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.02674647",
                                        "units": "m/s",
                                        "grib_name": "WIMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "42.813232",
                                        "gribparam": "216"
                                    },
                                    "vas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-35.251785",
                                        "units": "m/s",
                                        "grib_name": "vas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "37.360947",
                                        "gribparam": "166"
                                    },
                                    "uas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "uas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-42.186966",
                                        "units": "m/s",
                                        "grib_name": "uas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "36.328003",
                                        "gribparam": "165"
                                    },
                                    "td2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Dewpoint at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "3.03914973E-08",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "0.03910954",
                                        "gribparam": "168"
                                    },
                                    "t2mmx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "max 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "182.76421",
                                        "units": "unitless",
                                        "grib_name": "t2mmx",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "341.79041",
                                        "gribparam": "201"
                                    },
                                    "t2mmn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "min 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "182.7029",
                                        "units": "unitless",
                                        "grib_name": "t2mmn",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "329.12115",
                                        "gribparam": "202"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "182.75308",
                                        "units": "Kelvin_scale",
                                        "grib_name": "t2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "336.15546",
                                        "gribparam": "167"
                                    }
                                }
                            },
                            "jan2002": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "jan2002",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "QVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vertically integrated specific humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.02704778",
                                        "units": "kg/m2",
                                        "grib_name": "QVI",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "99.05706",
                                        "gribparam": "230"
                                    },
                                    "CLTOPMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLTOPMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum height of convective cloud tops",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "8457.8008",
                                        "units": "Pa",
                                        "grib_name": "CLTOPMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "100000.0",
                                        "gribparam": "217"
                                    },
                                    "cltm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "cltm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "cloud cover total mean[0-1]",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "cltm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "164"
                                    }
                                },
                                "top": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "top",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "SRAD0U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRAD0U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (top)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-810.58423",
                                        "units": "W/m2",
                                        "grib_name": "SRAD0U",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "203"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (top)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rst",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1180.1875",
                                            "gribparam": "178"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-411.1792",
                                            "units": "Wm-2",
                                            "grib_name": "rlt",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-70.566406",
                                            "gribparam": "179"
                                        }
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2064.3323",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0U",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2299.7405",
                                                "gribparam": "105"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1181.5312",
                                                "gribparam": "187"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-411.1792",
                                                "units": "W/m2",
                                                "grib_name": "TRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-70.566406",
                                                "gribparam": "188"
                                            }
                                        }
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "zg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "zg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Geopotential",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7517.7578",
                                        "units": "m2 s-2",
                                        "grib_name": "zg",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "58762.242",
                                        "gribparam": "129"
                                    },
                                    "TSLIN": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TSLIN",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "TSLIN heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-93.540085",
                                        "units": "W/m2",
                                        "grib_name": "TSLIN",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.05239868",
                                        "gribparam": "220"
                                    },
                                    "TRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "longwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-760.85596",
                                        "units": "W/m2",
                                        "grib_name": "TRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "-60.435791",
                                        "gribparam": "205"
                                    },
                                    "tauv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-5.4310846",
                                        "units": "Nm-2",
                                        "grib_name": "tauv",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "7.2612991",
                                        "gribparam": "181"
                                    },
                                    "tauu": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauu",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-6.8249741",
                                        "units": "Nm-2",
                                        "grib_name": "tauu",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "7.5346527",
                                        "gribparam": "180"
                                    },
                                    "tas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "air temperature (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.83926",
                                        "units": "Kelvin_scale",
                                        "grib_name": "tas",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "341.70184",
                                        "gribparam": "169"
                                    },
                                    "stemp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "stemp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.79222",
                                        "units": "unitless",
                                        "grib_name": "stemp",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "349.86002",
                                        "gribparam": "139"
                                    },
                                    "srun": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "srun",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "surface runoff",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "srun",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.90316405E-06",
                                        "gribparam": "160"
                                    },
                                    "SRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-723.51343",
                                        "units": "W/m2",
                                        "grib_name": "SRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "204"
                                    },
                                    "soilm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil wetness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "soilm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.7324371",
                                        "gribparam": "140"
                                    },
                                    "SNMEL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SNMEL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "snow melt",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m/s",
                                        "grib_name": "SNMEL",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.30294939E-06",
                                        "gribparam": "218"
                                    },
                                    "snd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "snd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "snd",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.998535",
                                        "gribparam": "141"
                                    },
                                    "slp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "slp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "151",
                                        "long_name": "mean sea level pressure",
                                        "gribleveltype": "102",
                                        "Z": "Z_10",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY jan2002 hybrid_lev P",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "SICED": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SICED",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "SICED",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.5",
                                        "gribparam": "211"
                                    },
                                    "sfr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sfr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sfc roughness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "1.49999996E-05",
                                        "units": "m",
                                        "grib_name": "sfr",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "20.00148",
                                        "gribparam": "173"
                                    },
                                    "SEAICE": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SEAICE",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice cover",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "SEAICE",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "210"
                                    },
                                    "pss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "pss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "46702.785",
                                        "units": "Pa",
                                        "grib_name": "pss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "113060.6",
                                        "gribparam": "134"
                                    },
                                    "prs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Fall",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-1.41172175E-26",
                                        "units": "unitless",
                                        "grib_name": "prs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.09270434E-06",
                                        "gribparam": "144"
                                    },
                                    "prl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Large Scale Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "grib_name": "prl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.96745236E-06",
                                        "gribparam": "142"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "260",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "totprcp",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "prc": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prc",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Convective Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-1.49077924E-23",
                                        "grib_name": "prc",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.68647409E-06",
                                        "gribparam": "143"
                                    },
                                    "PERPW": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PERPW",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Primary wave mean period",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-463740.62",
                                        "units": "s",
                                        "grib_name": "PERPW",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "496806.38",
                                        "gribparam": "108"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (surface)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "983.51562",
                                            "gribparam": "176"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-314.95898",
                                            "units": "Wm-2",
                                            "grib_name": "rls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "80.493744",
                                            "gribparam": "177"
                                        }
                                    },
                                    "lsm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lsm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "land-sea mask",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "(0,1)",
                                        "grib_name": "lsm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "172"
                                    },
                                    "logpsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "logpsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Log Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.03236537",
                                        "units": "unitless",
                                        "grib_name": "logpsl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.258587",
                                        "gribparam": "152"
                                    },
                                    "hfss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Sensible Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1032.5278",
                                        "units": "Wm-2",
                                        "grib_name": "hfss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1547.8467",
                                        "gribparam": "146"
                                    },
                                    "hfls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Latent Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1624.7356",
                                        "units": "Wm-2",
                                        "grib_name": "hfls",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "238.63062",
                                        "gribparam": "147"
                                    },
                                    "FOREST": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FOREST",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vegetation type",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "FOREST",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.9492188",
                                        "gribparam": "212"
                                    },
                                    "evs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "evs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Evaporation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-6.49686342E-07",
                                        "units": "m (H2O)",
                                        "grib_name": "evs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "9.54233599E-08",
                                        "gribparam": "182"
                                    },
                                    "dpsdy": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdy",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "274",
                                        "long_name": "Meridional Deriv. of Surface Pres.",
                                        "grib_name": "dpsdy",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "dpsdx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "273",
                                        "long_name": "Zonal Deriv. of Surface Pres.",
                                        "grib_name": "dpsdx",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2131.4304",
                                                "units": "W/m2",
                                                "grib_name": "SRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2284.9915",
                                                "gribparam": "106"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-357191.88",
                                                "units": "W/m2",
                                                "grib_name": "TRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "666316.19",
                                                "gribparam": "107"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "983.51562",
                                                "gribparam": "185"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-314.95898",
                                                "units": "W/m2",
                                                "grib_name": "TRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "46.585953",
                                                "gribparam": "186"
                                            }
                                        }
                                    },
                                    "ALBEDO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ALBEDO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Albedo (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.06999999",
                                        "units": "unitless",
                                        "grib_name": "ALBEDO",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.8004687",
                                        "gribparam": "175"
                                    }
                                },
                                "soil": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soil",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "TDCL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TDCL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temp level CL",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "209.38565",
                                        "units": "m (H2O)",
                                        "grib_name": "TDCL",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "310.6785",
                                        "gribparam": "183"
                                    },
                                    "TD5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "195.19817",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD5",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "319.1582",
                                        "gribparam": "209"
                                    },
                                    "TD3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.79222",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD3",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "345.82489",
                                        "gribparam": "207"
                                    },
                                    "td": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "deep soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "208.92708",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "314.04733",
                                        "gribparam": "170"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY jan2002 hybrid_lev P 0000 1 Jan 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY jan2002 hybrid_lev P 0000 1 Jan 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY jan2002 hybrid_lev P 0000 1 Jan 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY jan2002 hybrid_lev P 0000 1 Jan 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribparam": "138"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY jan2002 hybrid_lev P 0000 1 Jan 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY jan2002 hybrid_lev P 0000 1 Jan 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY jan2002 hybrid_lev P 0000 1 Jan 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY jan2002 hybrid_lev P 0000 1 Jan 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.009485044",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "scale_max": "0.03199366",
                                        "gribparam": "133"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY jan2002 hybrid_lev P 0000 1 Jan 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY jan2002 hybrid_lev P 0000 1 Jan 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-21.953468",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "410.57355",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.62666965E-05",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.70162366E-05",
                                        "gribparam": "138"
                                    },
                                    "Rv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for moist air"
                                    },
                                    "Rd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for dry air"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.62666965E-05",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.70162366E-05"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "pressure",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY jan2002 hybrid_lev omegahalf",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.009485044",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "0.03199366",
                                        "gribparam": "133"
                                    },
                                    "gravity": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gravity",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s2",
                                        "long_name": "earth\\'s gravity"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.30605565E-06",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.26322118E-06",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.30605565E-06",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.26322118E-06"
                                    },
                                    "BC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "BC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless"
                                    },
                                    "AC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "AC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa"
                                    }
                                },
                                "filepattern": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "filepattern",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "above_ground": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "above_ground",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "wind10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "wind10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "10m windspeed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.02115323",
                                        "units": "unitless",
                                        "grib_name": "wind10",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "37.692329",
                                        "gribparam": "171"
                                    },
                                    "WIMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "WIMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum 10m wind speed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.03339912",
                                        "units": "m/s",
                                        "grib_name": "WIMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "38.737904",
                                        "gribparam": "216"
                                    },
                                    "vas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-34.371262",
                                        "units": "m/s",
                                        "grib_name": "vas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "35.957397",
                                        "gribparam": "166"
                                    },
                                    "uas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "uas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-34.347733",
                                        "units": "m/s",
                                        "grib_name": "uas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "36.203125",
                                        "gribparam": "165"
                                    },
                                    "td2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Dewpoint at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "3.84435701E-08",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "0.041143",
                                        "gribparam": "168"
                                    },
                                    "t2mmx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "max 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "184.48193",
                                        "units": "unitless",
                                        "grib_name": "t2mmx",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "344.71381",
                                        "gribparam": "201"
                                    },
                                    "t2mmn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "min 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "184.08356",
                                        "units": "unitless",
                                        "grib_name": "t2mmn",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "328.38965",
                                        "gribparam": "202"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "184.25795",
                                        "units": "Kelvin_scale",
                                        "grib_name": "t2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "337.98111",
                                        "gribparam": "167"
                                    }
                                }
                            },
                            "feb2002": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "feb2002",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "QVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vertically integrated specific humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.03488032",
                                        "units": "kg/m2",
                                        "grib_name": "QVI",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "99.846771",
                                        "gribparam": "230"
                                    },
                                    "CLTOPMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLTOPMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum height of convective cloud tops",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "8455.1797",
                                        "units": "Pa",
                                        "grib_name": "CLTOPMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "100000.0",
                                        "gribparam": "217"
                                    },
                                    "cltm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "cltm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "cloud cover total mean[0-1]",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "cltm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "164"
                                    }
                                },
                                "top": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "top",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "SRAD0U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRAD0U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (top)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-813.09912",
                                        "units": "W/m2",
                                        "grib_name": "SRAD0U",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "203"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (top)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rst",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1179.7812",
                                            "gribparam": "178"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-397.24756",
                                            "units": "Wm-2",
                                            "grib_name": "rlt",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-70.805908",
                                            "gribparam": "179"
                                        }
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2247.2288",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0U",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2203.4553",
                                                "gribparam": "105"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1181.1875",
                                                "gribparam": "187"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-397.24756",
                                                "units": "W/m2",
                                                "grib_name": "TRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-70.860596",
                                                "gribparam": "188"
                                            }
                                        }
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "zg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "zg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Geopotential",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7517.7578",
                                        "units": "m2 s-2",
                                        "grib_name": "zg",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "58762.242",
                                        "gribparam": "129"
                                    },
                                    "TSLIN": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TSLIN",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "TSLIN heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-95.238434",
                                        "units": "W/m2",
                                        "grib_name": "TSLIN",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.01913452",
                                        "gribparam": "220"
                                    },
                                    "TRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "longwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-753.16504",
                                        "units": "W/m2",
                                        "grib_name": "TRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "-60.475342",
                                        "gribparam": "205"
                                    },
                                    "tauv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-5.4546604",
                                        "units": "Nm-2",
                                        "grib_name": "tauv",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "7.4612103",
                                        "gribparam": "181"
                                    },
                                    "tauu": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauu",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-6.9264154",
                                        "units": "Nm-2",
                                        "grib_name": "tauu",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "7.6453075",
                                        "gribparam": "180"
                                    },
                                    "tas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "air temperature (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.87392",
                                        "units": "Kelvin_scale",
                                        "grib_name": "tas",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "340.32678",
                                        "gribparam": "169"
                                    },
                                    "stemp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "stemp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.81883",
                                        "units": "unitless",
                                        "grib_name": "stemp",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "348.68488",
                                        "gribparam": "139"
                                    },
                                    "srun": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "srun",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "surface runoff",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "srun",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.73317585E-06",
                                        "gribparam": "160"
                                    },
                                    "SRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-735.54175",
                                        "units": "W/m2",
                                        "grib_name": "SRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "204"
                                    },
                                    "soilm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil wetness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "soilm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.7324371",
                                        "gribparam": "140"
                                    },
                                    "SNMEL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SNMEL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "snow melt",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m/s",
                                        "grib_name": "SNMEL",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.23851351E-06",
                                        "gribparam": "218"
                                    },
                                    "snd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "snd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "snd",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.998535",
                                        "gribparam": "141"
                                    },
                                    "slp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "slp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "151",
                                        "long_name": "mean sea level pressure",
                                        "gribleveltype": "102",
                                        "Z": "Z_10",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY feb2002 hybrid_lev P",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "SICED": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SICED",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "SICED",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.5",
                                        "gribparam": "211"
                                    },
                                    "sfr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sfr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sfc roughness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "1.49999996E-05",
                                        "units": "m",
                                        "grib_name": "sfr",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "20.00148",
                                        "gribparam": "173"
                                    },
                                    "SEAICE": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SEAICE",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice cover",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "SEAICE",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "210"
                                    },
                                    "pss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "pss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "46560.832",
                                        "units": "Pa",
                                        "grib_name": "pss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "112875.64",
                                        "gribparam": "134"
                                    },
                                    "prs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Fall",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-7.05861028E-27",
                                        "units": "unitless",
                                        "grib_name": "prs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "9.37710695E-07",
                                        "gribparam": "144"
                                    },
                                    "prl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Large Scale Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "grib_name": "prl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "2.04583489E-06",
                                        "gribparam": "142"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "260",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "totprcp",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "prc": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prc",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Convective Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-1.62630428E-23",
                                        "grib_name": "prc",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.50068547E-06",
                                        "gribparam": "143"
                                    },
                                    "PERPW": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PERPW",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Primary wave mean period",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-445982.81",
                                        "units": "s",
                                        "grib_name": "PERPW",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "496051.56",
                                        "gribparam": "108"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (surface)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "979.3125",
                                            "gribparam": "176"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-277.52539",
                                            "units": "Wm-2",
                                            "grib_name": "rls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "84.088242",
                                            "gribparam": "177"
                                        }
                                    },
                                    "lsm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lsm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "land-sea mask",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "(0,1)",
                                        "grib_name": "lsm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "172"
                                    },
                                    "logpsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "logpsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Log Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.0311103",
                                        "units": "unitless",
                                        "grib_name": "logpsl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.258545",
                                        "gribparam": "152"
                                    },
                                    "hfss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Sensible Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-856.79688",
                                        "units": "Wm-2",
                                        "grib_name": "hfss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1366.1519",
                                        "gribparam": "146"
                                    },
                                    "hfls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Latent Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1703.7241",
                                        "units": "Wm-2",
                                        "grib_name": "hfls",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "238.58105",
                                        "gribparam": "147"
                                    },
                                    "FOREST": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FOREST",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vegetation type",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "FOREST",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.9492188",
                                        "gribparam": "212"
                                    },
                                    "evs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "evs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Evaporation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-6.81271615E-07",
                                        "units": "m (H2O)",
                                        "grib_name": "evs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "9.54036636E-08",
                                        "gribparam": "182"
                                    },
                                    "dpsdy": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdy",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "274",
                                        "long_name": "Meridional Deriv. of Surface Pres.",
                                        "grib_name": "dpsdy",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "dpsdx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "273",
                                        "long_name": "Zonal Deriv. of Surface Pres.",
                                        "grib_name": "dpsdx",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-1809.0818",
                                                "units": "W/m2",
                                                "grib_name": "SRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2185.7769",
                                                "gribparam": "106"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-350935.25",
                                                "units": "W/m2",
                                                "grib_name": "TRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "664182.56",
                                                "gribparam": "107"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "980.625",
                                                "gribparam": "185"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-277.56885",
                                                "units": "W/m2",
                                                "grib_name": "TRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "49.658936",
                                                "gribparam": "186"
                                            }
                                        }
                                    },
                                    "ALBEDO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ALBEDO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Albedo (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.06999999",
                                        "units": "unitless",
                                        "grib_name": "ALBEDO",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.8004687",
                                        "gribparam": "175"
                                    }
                                },
                                "soil": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soil",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "TDCL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TDCL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temp level CL",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "209.38564",
                                        "units": "m (H2O)",
                                        "grib_name": "TDCL",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "310.67847",
                                        "gribparam": "183"
                                    },
                                    "TD5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "194.97694",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD5",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "320.0224",
                                        "gribparam": "209"
                                    },
                                    "TD3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.81883",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD3",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "344.43097",
                                        "gribparam": "207"
                                    },
                                    "td": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "deep soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "208.70685",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "314.1283",
                                        "gribparam": "170"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY feb2002 hybrid_lev P 0000 1 Feb 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY feb2002 hybrid_lev P 0000 1 Feb 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY feb2002 hybrid_lev P 0000 1 Feb 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY feb2002 hybrid_lev P 0000 1 Feb 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribparam": "138"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY feb2002 hybrid_lev P 0000 1 Feb 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY feb2002 hybrid_lev P 0000 1 Feb 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY feb2002 hybrid_lev P 0000 1 Feb 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY feb2002 hybrid_lev P 0000 1 Feb 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.01137783",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "scale_max": "0.03360097",
                                        "gribparam": "133"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY feb2002 hybrid_lev P 0000 1 Feb 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY feb2002 hybrid_lev P 0000 1 Feb 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-22.187309",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "410.76309",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.61985918E-05",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.85822773E-05",
                                        "gribparam": "138"
                                    },
                                    "Rv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for moist air"
                                    },
                                    "Rd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for dry air"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.61985918E-05",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.85822773E-05"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "pressure",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY feb2002 hybrid_lev omegahalf",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.01137783",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "0.03360097",
                                        "gribparam": "133"
                                    },
                                    "gravity": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gravity",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s2",
                                        "long_name": "earth\\'s gravity"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.38839561E-06",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.26970610E-06",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.38839561E-06",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.26970610E-06"
                                    },
                                    "BC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "BC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless"
                                    },
                                    "AC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "AC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa"
                                    }
                                },
                                "filepattern": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "filepattern",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "above_ground": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "above_ground",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "wind10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "wind10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "10m windspeed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.01536447",
                                        "units": "unitless",
                                        "grib_name": "wind10",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "38.656155",
                                        "gribparam": "171"
                                    },
                                    "WIMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "WIMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum 10m wind speed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.02947626",
                                        "units": "m/s",
                                        "grib_name": "WIMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "39.055088",
                                        "gribparam": "216"
                                    },
                                    "vas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-37.634888",
                                        "units": "m/s",
                                        "grib_name": "vas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "37.456253",
                                        "gribparam": "166"
                                    },
                                    "uas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "uas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-37.424118",
                                        "units": "m/s",
                                        "grib_name": "uas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "38.367371",
                                        "gribparam": "165"
                                    },
                                    "td2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Dewpoint at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "3.75571254E-08",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "0.04436133",
                                        "gribparam": "168"
                                    },
                                    "t2mmx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "max 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "183.55582",
                                        "units": "unitless",
                                        "grib_name": "t2mmx",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "341.68939",
                                        "gribparam": "201"
                                    },
                                    "t2mmn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "min 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "183.24422",
                                        "units": "unitless",
                                        "grib_name": "t2mmn",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "328.03485",
                                        "gribparam": "202"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "183.2849",
                                        "units": "Kelvin_scale",
                                        "grib_name": "t2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "337.36197",
                                        "gribparam": "167"
                                    }
                                }
                            },
                            "dec2001": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "dec2001",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "QVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vertically integrated specific humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.03557465",
                                        "units": "kg/m2",
                                        "grib_name": "QVI",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "92.073624",
                                        "gribparam": "230"
                                    },
                                    "CLTOPMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLTOPMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum height of convective cloud tops",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "8489.2148",
                                        "units": "Pa",
                                        "grib_name": "CLTOPMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "100000.0",
                                        "gribparam": "217"
                                    },
                                    "cltm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "cltm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "cloud cover total mean[0-1]",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "cltm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "164"
                                    }
                                },
                                "top": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "top",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "SRAD0U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRAD0U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (top)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-812.79492",
                                        "units": "W/m2",
                                        "grib_name": "SRAD0U",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "203"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (top)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rst",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1180.0938",
                                            "gribparam": "178"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-408.59521",
                                            "units": "Wm-2",
                                            "grib_name": "rlt",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-73.749023",
                                            "gribparam": "179"
                                        }
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2118.4343",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0U",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2453.8953",
                                                "gribparam": "105"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1181.2812",
                                                "gribparam": "187"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-408.59521",
                                                "units": "W/m2",
                                                "grib_name": "TRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-74.573242",
                                                "gribparam": "188"
                                            }
                                        }
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "zg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "zg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Geopotential",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7517.7578",
                                        "units": "m2 s-2",
                                        "grib_name": "zg",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "58762.242",
                                        "gribparam": "129"
                                    },
                                    "TSLIN": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TSLIN",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "TSLIN heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-91.146027",
                                        "units": "W/m2",
                                        "grib_name": "TSLIN",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.08717346",
                                        "gribparam": "220"
                                    },
                                    "TRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "longwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-746.68018",
                                        "units": "W/m2",
                                        "grib_name": "TRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "-63.656494",
                                        "gribparam": "205"
                                    },
                                    "tauv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-5.9358654",
                                        "units": "Nm-2",
                                        "grib_name": "tauv",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "7.397995",
                                        "gribparam": "181"
                                    },
                                    "tauu": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauu",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7.0853472",
                                        "units": "Nm-2",
                                        "grib_name": "tauu",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "8.6395912",
                                        "gribparam": "180"
                                    },
                                    "tas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "air temperature (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "183.15521",
                                        "units": "Kelvin_scale",
                                        "grib_name": "tas",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "341.13153",
                                        "gribparam": "169"
                                    },
                                    "stemp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "stemp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "182.9679",
                                        "units": "unitless",
                                        "grib_name": "stemp",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "348.00699",
                                        "gribparam": "139"
                                    },
                                    "srun": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "srun",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "surface runoff",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "srun",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.67187579E-06",
                                        "gribparam": "160"
                                    },
                                    "SRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-735.00732",
                                        "units": "W/m2",
                                        "grib_name": "SRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "204"
                                    },
                                    "soilm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil wetness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "soilm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.7324371",
                                        "gribparam": "140"
                                    },
                                    "SNMEL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SNMEL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "snow melt",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m/s",
                                        "grib_name": "SNMEL",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.26363011E-06",
                                        "gribparam": "218"
                                    },
                                    "snd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "snd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "snd",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "17.081543",
                                        "gribparam": "141"
                                    },
                                    "slp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "slp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "151",
                                        "long_name": "mean sea level pressure",
                                        "gribleveltype": "102",
                                        "Z": "Z_10",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY dec2001 hybrid_lev P",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "SICED": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SICED",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "SICED",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.5",
                                        "gribparam": "211"
                                    },
                                    "sfr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sfr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sfc roughness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "1.49999996E-05",
                                        "units": "m",
                                        "grib_name": "sfr",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "20.00148",
                                        "gribparam": "173"
                                    },
                                    "SEAICE": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SEAICE",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice cover",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "SEAICE",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "210"
                                    },
                                    "pss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "pss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "46447.082",
                                        "units": "Pa",
                                        "grib_name": "pss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "112766.77",
                                        "gribparam": "134"
                                    },
                                    "prs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Fall",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-5.29395617E-27",
                                        "units": "unitless",
                                        "grib_name": "prs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "9.40657571E-07",
                                        "gribparam": "144"
                                    },
                                    "prl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Large Scale Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "grib_name": "prl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "2.07052426E-06",
                                        "gribparam": "142"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "260",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "totprcp",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "prc": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prc",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Convective Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-1.80700392E-23",
                                        "grib_name": "prc",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.54814097E-06",
                                        "gribparam": "143"
                                    },
                                    "PERPW": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PERPW",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Primary wave mean period",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-488946.94",
                                        "units": "s",
                                        "grib_name": "PERPW",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "505826.25",
                                        "gribparam": "108"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (surface)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "985.25",
                                            "gribparam": "176"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-290.83179",
                                            "units": "Wm-2",
                                            "grib_name": "rls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "77.640167",
                                            "gribparam": "177"
                                        }
                                    },
                                    "lsm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lsm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "land-sea mask",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "(0,1)",
                                        "grib_name": "lsm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "172"
                                    },
                                    "logpsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "logpsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Log Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.03202488",
                                        "units": "unitless",
                                        "grib_name": "logpsl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.258549",
                                        "gribparam": "152"
                                    },
                                    "hfss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Sensible Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-874.28247",
                                        "units": "Wm-2",
                                        "grib_name": "hfss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1383.1174",
                                        "gribparam": "146"
                                    },
                                    "hfls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Latent Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1499.7095",
                                        "units": "Wm-2",
                                        "grib_name": "hfls",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "254.64087",
                                        "gribparam": "147"
                                    },
                                    "FOREST": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FOREST",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vegetation type",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "FOREST",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.9492188",
                                        "gribparam": "212"
                                    },
                                    "evs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "evs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Evaporation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-5.99691873E-07",
                                        "units": "m (H2O)",
                                        "grib_name": "evs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.01822934E-07",
                                        "gribparam": "182"
                                    },
                                    "dpsdy": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdy",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "274",
                                        "long_name": "Meridional Deriv. of Surface Pres.",
                                        "grib_name": "dpsdy",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "dpsdx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "273",
                                        "long_name": "Zonal Deriv. of Surface Pres.",
                                        "grib_name": "dpsdx",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2342.7966",
                                                "units": "W/m2",
                                                "grib_name": "SRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2289.6626",
                                                "gribparam": "106"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-382793.56",
                                                "units": "W/m2",
                                                "grib_name": "TRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "652948.62",
                                                "gribparam": "107"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "985.25",
                                                "gribparam": "185"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-290.83179",
                                                "units": "W/m2",
                                                "grib_name": "TRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "38.681763",
                                                "gribparam": "186"
                                            }
                                        }
                                    },
                                    "ALBEDO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ALBEDO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Albedo (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.06999999",
                                        "units": "unitless",
                                        "grib_name": "ALBEDO",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.8004687",
                                        "gribparam": "175"
                                    }
                                },
                                "soil": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soil",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "TDCL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TDCL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temp level CL",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "209.38374",
                                        "units": "m (H2O)",
                                        "grib_name": "TDCL",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "310.67249",
                                        "gribparam": "183"
                                    },
                                    "TD5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "196.28421",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD5",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "318.47131",
                                        "gribparam": "209"
                                    },
                                    "TD3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "182.9679",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD3",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "343.60812",
                                        "gribparam": "207"
                                    },
                                    "td": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "deep soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "208.90562",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "314.66095",
                                        "gribparam": "170"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY dec2001 hybrid_lev P 0000 1 Dec 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY dec2001 hybrid_lev P 0000 1 Dec 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY dec2001 hybrid_lev P 0000 1 Dec 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY dec2001 hybrid_lev P 0000 1 Dec 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribparam": "138"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY dec2001 hybrid_lev P 0000 1 Dec 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY dec2001 hybrid_lev P 0000 1 Dec 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY dec2001 hybrid_lev P 0000 1 Dec 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY dec2001 hybrid_lev P 0000 1 Dec 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.01055825",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "scale_max": "0.03030396",
                                        "gribparam": "133"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY dec2001 hybrid_lev P 0000 1 Dec 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY dec2001 hybrid_lev P 0000 1 Dec 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-22.004139",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "410.06427",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.50287642E-05",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.87862588E-05",
                                        "gribparam": "138"
                                    },
                                    "Rv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for moist air"
                                    },
                                    "Rd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for dry air"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.50287642E-05",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.87862588E-05"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "pressure",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY dec2001 hybrid_lev omegahalf",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.01055825",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "0.03030396",
                                        "gribparam": "133"
                                    },
                                    "gravity": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gravity",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s2",
                                        "long_name": "earth\\'s gravity"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.37937661E-06",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.37325298E-06",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.37937661E-06",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.37325298E-06"
                                    },
                                    "BC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "BC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless"
                                    },
                                    "AC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "AC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa"
                                    }
                                },
                                "filepattern": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "filepattern",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "above_ground": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "above_ground",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "wind10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "wind10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "10m windspeed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.01584013",
                                        "units": "unitless",
                                        "grib_name": "wind10",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "39.124069",
                                        "gribparam": "171"
                                    },
                                    "WIMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "WIMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum 10m wind speed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0237495",
                                        "units": "m/s",
                                        "grib_name": "WIMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "41.731964",
                                        "gribparam": "216"
                                    },
                                    "vas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-34.219193",
                                        "units": "m/s",
                                        "grib_name": "vas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "36.452301",
                                        "gribparam": "166"
                                    },
                                    "uas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "uas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-35.024048",
                                        "units": "m/s",
                                        "grib_name": "uas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "39.749634",
                                        "gribparam": "165"
                                    },
                                    "td2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Dewpoint at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "3.52528815E-08",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "0.04341219",
                                        "gribparam": "168"
                                    },
                                    "t2mmx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "max 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "186.1965",
                                        "units": "unitless",
                                        "grib_name": "t2mmx",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "339.62634",
                                        "gribparam": "201"
                                    },
                                    "t2mmn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "min 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "185.91681",
                                        "units": "unitless",
                                        "grib_name": "t2mmn",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "327.91937",
                                        "gribparam": "202"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "185.94714",
                                        "units": "Kelvin_scale",
                                        "grib_name": "t2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "338.0726",
                                        "gribparam": "167"
                                    }
                                }
                            },
                            "aug2001": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "aug2001",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "QVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vertically integrated specific humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.01789523",
                                        "units": "kg/m2",
                                        "grib_name": "QVI",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "98.627937",
                                        "gribparam": "230"
                                    },
                                    "CLTOPMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLTOPMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum height of convective cloud tops",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "8454.8867",
                                        "units": "Pa",
                                        "grib_name": "CLTOPMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "100000.0",
                                        "gribparam": "217"
                                    },
                                    "cltm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "cltm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "cloud cover total mean[0-1]",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "cltm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "164"
                                    }
                                },
                                "top": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "top",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "SRAD0U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRAD0U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (top)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-804.1272",
                                        "units": "W/m2",
                                        "grib_name": "SRAD0U",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "203"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (top)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rst",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1169.9062",
                                            "gribparam": "178"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-402.04858",
                                            "units": "Wm-2",
                                            "grib_name": "rlt",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-72.137695",
                                            "gribparam": "179"
                                        }
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-1755.1604",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0U",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2748.3533",
                                                "gribparam": "105"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1172.3438",
                                                "gribparam": "187"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-402.04858",
                                                "units": "W/m2",
                                                "grib_name": "TRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-72.132324",
                                                "gribparam": "188"
                                            }
                                        }
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "zg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "zg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Geopotential",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7517.7578",
                                        "units": "m2 s-2",
                                        "grib_name": "zg",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "58762.242",
                                        "gribparam": "129"
                                    },
                                    "TSLIN": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TSLIN",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "TSLIN heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-96.058121",
                                        "units": "W/m2",
                                        "grib_name": "TSLIN",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.008560181",
                                        "gribparam": "220"
                                    },
                                    "TRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "longwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-749.34399",
                                        "units": "W/m2",
                                        "grib_name": "TRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "-61.129639",
                                        "gribparam": "205"
                                    },
                                    "tauv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-5.2699871",
                                        "units": "Nm-2",
                                        "grib_name": "tauv",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "5.8405657",
                                        "gribparam": "181"
                                    },
                                    "tauu": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauu",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-5.5451746",
                                        "units": "Nm-2",
                                        "grib_name": "tauu",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "9.1268787",
                                        "gribparam": "180"
                                    },
                                    "tas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "air temperature (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "181.30821",
                                        "units": "Kelvin_scale",
                                        "grib_name": "tas",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "340.80145",
                                        "gribparam": "169"
                                    },
                                    "stemp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "stemp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "181.18692",
                                        "units": "unitless",
                                        "grib_name": "stemp",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "349.67676",
                                        "gribparam": "139"
                                    },
                                    "srun": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "srun",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "surface runoff",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "srun",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.73226488E-06",
                                        "gribparam": "160"
                                    },
                                    "SRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-676.07812",
                                        "units": "W/m2",
                                        "grib_name": "SRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "204"
                                    },
                                    "soilm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil wetness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "soilm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.7168884",
                                        "gribparam": "140"
                                    },
                                    "SNMEL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SNMEL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "snow melt",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m/s",
                                        "grib_name": "SNMEL",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.39148324E-06",
                                        "gribparam": "218"
                                    },
                                    "snd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "snd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "snd",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.913086",
                                        "gribparam": "141"
                                    },
                                    "slp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "slp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "151",
                                        "long_name": "mean sea level pressure",
                                        "gribleveltype": "102",
                                        "Z": "Z_10",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY aug2001 hybrid_lev P",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "SICED": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SICED",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "SICED",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.5",
                                        "gribparam": "211"
                                    },
                                    "sfr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sfr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sfc roughness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "1.49999996E-05",
                                        "units": "m",
                                        "grib_name": "sfr",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "20.00148",
                                        "gribparam": "173"
                                    },
                                    "SEAICE": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SEAICE",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice cover",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "SEAICE",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "210"
                                    },
                                    "pss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "pss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "47520.363",
                                        "units": "Pa",
                                        "grib_name": "pss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "112918.14",
                                        "gribparam": "134"
                                    },
                                    "prs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Fall",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-7.05861028E-27",
                                        "units": "unitless",
                                        "grib_name": "prs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.12964665E-06",
                                        "gribparam": "144"
                                    },
                                    "prl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Large Scale Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "grib_name": "prl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "2.07356766E-06",
                                        "gribparam": "142"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "260",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "totprcp",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "prc": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prc",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Convective Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-1.80700392E-23",
                                        "grib_name": "prc",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.52658311E-06",
                                        "gribparam": "143"
                                    },
                                    "PERPW": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PERPW",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Primary wave mean period",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-459463.94",
                                        "units": "s",
                                        "grib_name": "PERPW",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "473930.75",
                                        "gribparam": "108"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (surface)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "964.21875",
                                            "gribparam": "176"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-289.14624",
                                            "units": "Wm-2",
                                            "grib_name": "rls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "83.518982",
                                            "gribparam": "177"
                                        }
                                    },
                                    "lsm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lsm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "land-sea mask",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "(0,1)",
                                        "grib_name": "lsm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "172"
                                    },
                                    "logpsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "logpsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Log Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.03160577",
                                        "units": "unitless",
                                        "grib_name": "logpsl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.25857",
                                        "gribparam": "152"
                                    },
                                    "hfss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Sensible Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-967.3894",
                                        "units": "Wm-2",
                                        "grib_name": "hfss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1555.7266",
                                        "gribparam": "146"
                                    },
                                    "hfls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Latent Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2187.0928",
                                        "units": "Wm-2",
                                        "grib_name": "hfls",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "275.37305",
                                        "gribparam": "147"
                                    },
                                    "evs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "evs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Evaporation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-8.74557202E-07",
                                        "units": "m (H2O)",
                                        "grib_name": "evs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.10111927E-07",
                                        "gribparam": "182"
                                    },
                                    "dpsdy": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdy",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "274",
                                        "long_name": "Meridional Deriv. of Surface Pres.",
                                        "grib_name": "dpsdy",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "dpsdx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "273",
                                        "long_name": "Zonal Deriv. of Surface Pres.",
                                        "grib_name": "dpsdx",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2310.3999",
                                                "units": "W/m2",
                                                "grib_name": "SRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2661.9663",
                                                "gribparam": "106"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-338603.44",
                                                "units": "W/m2",
                                                "grib_name": "TRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "680255.56",
                                                "gribparam": "107"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "968.32812",
                                                "gribparam": "185"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-289.14624",
                                                "units": "W/m2",
                                                "grib_name": "TRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "47.128067",
                                                "gribparam": "186"
                                            }
                                        }
                                    },
                                    "ALBEDO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ALBEDO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Albedo (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.06999999",
                                        "units": "unitless",
                                        "grib_name": "ALBEDO",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.8004687",
                                        "gribparam": "175"
                                    }
                                },
                                "soil": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soil",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "TDCL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TDCL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temp level CL",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "209.27872",
                                        "units": "m (H2O)",
                                        "grib_name": "TDCL",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "310.66962",
                                        "gribparam": "183"
                                    },
                                    "td": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "deep soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "208.64293",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "314.47345",
                                        "gribparam": "170"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY aug2001 hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY aug2001 hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY aug2001 hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY aug2001 hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribparam": "138"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY aug2001 hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY aug2001 hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY aug2001 hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY aug2001 hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.009193584",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "scale_max": "0.03196654",
                                        "gribparam": "133"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY aug2001 hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "div",
                                        "PTVersion": "128",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY aug2001 hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-20.251757",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "410.93295",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.62243377E-05",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.92037551E-05",
                                        "gribparam": "138"
                                    },
                                    "Rv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for moist air"
                                    },
                                    "Rd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for dry air"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.62243377E-05",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.92037551E-05"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "pressure",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY aug2001 hybrid_lev omegahalf",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.009193584",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "0.03196654",
                                        "gribparam": "133"
                                    },
                                    "gravity": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gravity",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s2",
                                        "long_name": "earth\\'s gravity"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.23289680E-06",
                                        "units": "s-1",
                                        "grib_name": "div",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.21615664E-06",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.23289680E-06",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.21615664E-06"
                                    },
                                    "BC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "BC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless"
                                    },
                                    "AC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "AC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa"
                                    }
                                },
                                "filepattern": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "filepattern",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "above_ground": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "above_ground",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "wind10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "wind10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "10m windspeed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.01865815",
                                        "units": "unitless",
                                        "grib_name": "wind10",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "39.309048",
                                        "gribparam": "171"
                                    },
                                    "WIMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "WIMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum 10m wind speed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.03494264",
                                        "units": "m/s",
                                        "grib_name": "WIMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "40.877903",
                                        "gribparam": "216"
                                    },
                                    "vas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-34.906662",
                                        "units": "m/s",
                                        "grib_name": "vas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "34.587128",
                                        "gribparam": "166"
                                    },
                                    "uas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "uas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-37.760162",
                                        "units": "m/s",
                                        "grib_name": "uas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "36.860809",
                                        "gribparam": "165"
                                    },
                                    "td2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Dewpoint at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "2.75820398E-08",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "0.04707075",
                                        "gribparam": "168"
                                    },
                                    "t2mmx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "max 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "184.89082",
                                        "units": "unitless",
                                        "grib_name": "t2mmx",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "342.06573",
                                        "gribparam": "201"
                                    },
                                    "t2mmn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "min 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "184.77397",
                                        "units": "unitless",
                                        "grib_name": "t2mmn",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "328.68161",
                                        "gribparam": "202"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "184.80574",
                                        "units": "Kelvin_scale",
                                        "grib_name": "t2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "341.6304",
                                        "gribparam": "167"
                                    }
                                }
                            },
                            "apr2002": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "apr2002",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "QVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vertically integrated specific humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.02459955",
                                        "units": "kg/m2",
                                        "grib_name": "QVI",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "100.46806",
                                        "gribparam": "230"
                                    },
                                    "CLTOPMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLTOPMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum height of convective cloud tops",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "8477.4883",
                                        "units": "Pa",
                                        "grib_name": "CLTOPMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "100000.0",
                                        "gribparam": "217"
                                    },
                                    "cltm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "cltm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "cloud cover total mean[0-1]",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "cltm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "164"
                                    }
                                },
                                "top": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "top",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "SRAD0U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRAD0U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (top)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-800.5625",
                                        "units": "W/m2",
                                        "grib_name": "SRAD0U",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "203"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (top)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rst",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1165.4062",
                                            "gribparam": "178"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-403.13745",
                                            "units": "Wm-2",
                                            "grib_name": "rlt",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-70.485352",
                                            "gribparam": "179"
                                        }
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-2131.5298",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0U",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2519.9031",
                                                "gribparam": "105"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1166.0625",
                                                "gribparam": "187"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-403.13745",
                                                "units": "W/m2",
                                                "grib_name": "TRAF0",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-70.000977",
                                                "gribparam": "188"
                                            }
                                        }
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "zg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "zg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Geopotential",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-7517.7578",
                                        "units": "m2 s-2",
                                        "grib_name": "zg",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "58762.242",
                                        "gribparam": "129"
                                    },
                                    "TSLIN": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TSLIN",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "TSLIN heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-94.686401",
                                        "units": "W/m2",
                                        "grib_name": "TSLIN",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.009674072",
                                        "gribparam": "220"
                                    },
                                    "TRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "longwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-741.37354",
                                        "units": "W/m2",
                                        "grib_name": "TRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "-59.938477",
                                        "gribparam": "205"
                                    },
                                    "tauv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-5.3738956",
                                        "units": "Nm-2",
                                        "grib_name": "tauv",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "6.3319511",
                                        "gribparam": "181"
                                    },
                                    "tauu": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauu",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-component of Surface Wind Stress",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-6.7149887",
                                        "units": "Nm-2",
                                        "grib_name": "tauu",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "7.8551531",
                                        "gribparam": "180"
                                    },
                                    "tas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "air temperature (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.45923",
                                        "units": "Kelvin_scale",
                                        "grib_name": "tas",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "340.00369",
                                        "gribparam": "169"
                                    },
                                    "stemp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "stemp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.45122",
                                        "units": "unitless",
                                        "grib_name": "stemp",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "346.99146",
                                        "gribparam": "139"
                                    },
                                    "srun": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "srun",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "surface runoff",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "srun",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.90132823E-06",
                                        "gribparam": "160"
                                    },
                                    "SRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "shortwave radiation upward (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-721.07202",
                                        "units": "W/m2",
                                        "grib_name": "SRADSU",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "204"
                                    },
                                    "soilm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil wetness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "soilm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.7324371",
                                        "gribparam": "140"
                                    },
                                    "SNMEL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SNMEL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "snow melt",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m/s",
                                        "grib_name": "SNMEL",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.23851351E-06",
                                        "gribparam": "218"
                                    },
                                    "snd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "snd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "snd",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.952148",
                                        "gribparam": "141"
                                    },
                                    "slp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "slp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "151",
                                        "long_name": "mean sea level pressure",
                                        "gribleveltype": "102",
                                        "Z": "Z_10",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY apr2002 hybrid_lev P",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "SICED": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SICED",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice depth",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "SICED",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.5",
                                        "gribparam": "211"
                                    },
                                    "sfr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sfr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sfc roughness",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "1.49999996E-05",
                                        "units": "m",
                                        "grib_name": "sfr",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "20.00148",
                                        "gribparam": "173"
                                    },
                                    "SEAICE": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SEAICE",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "sea ice cover",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "SEAICE",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "210"
                                    },
                                    "pss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "pss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "46750.191",
                                        "units": "Pa",
                                        "grib_name": "pss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "112855.17",
                                        "gribparam": "134"
                                    },
                                    "prs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Snow Fall",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-7.05861028E-27",
                                        "units": "unitless",
                                        "grib_name": "prs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "9.80280561E-07",
                                        "gribparam": "144"
                                    },
                                    "prl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Large Scale Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "0.0",
                                        "grib_name": "prl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "2.20188167E-06",
                                        "gribparam": "142"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "260",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "totprcp",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "prc": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prc",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Convective Precipitation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-1.53595383E-23",
                                        "grib_name": "prc",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.72678222E-06",
                                        "gribparam": "143"
                                    },
                                    "PERPW": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PERPW",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Primary wave mean period",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-455568.81",
                                        "units": "s",
                                        "grib_name": "PERPW",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "504181.31",
                                        "gribparam": "108"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Net Shortwave Radiation (surface)",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "948.26562",
                                            "gribparam": "176"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave flux",
                                            "calendar": "standard",
                                            "subcenter": "255",
                                            "process": "50",
                                            "gribNumBits": "16",
                                            "scale_min": "-280.39526",
                                            "units": "Wm-2",
                                            "grib_name": "rls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "81.313919",
                                            "gribparam": "177"
                                        }
                                    },
                                    "lsm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lsm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "land-sea mask",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "(0,1)",
                                        "grib_name": "lsm",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "172"
                                    },
                                    "logpsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "logpsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Log Surface Pressure",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.0317284",
                                        "units": "unitless",
                                        "grib_name": "logpsl",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "16.25852",
                                        "gribparam": "152"
                                    },
                                    "hfss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Sensible Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1013.5713",
                                        "units": "Wm-2",
                                        "grib_name": "hfss",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "1431.041",
                                        "gribparam": "146"
                                    },
                                    "hfls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Surface Flux of Latent Heat",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1967.2639",
                                        "units": "Wm-2",
                                        "grib_name": "hfls",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "238.1958",
                                        "gribparam": "147"
                                    },
                                    "FOREST": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "FOREST",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vegetation type",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "FOREST",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.9492188",
                                        "gribparam": "212"
                                    },
                                    "evs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "evs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Evaporation",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "24",
                                        "scale_min": "-7.86653800E-07",
                                        "units": "m (H2O)",
                                        "grib_name": "evs",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "9.52467474E-08",
                                        "gribparam": "182"
                                    },
                                    "dpsdy": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdy",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "274",
                                        "long_name": "Meridional Deriv. of Surface Pres.",
                                        "grib_name": "dpsdy",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "dpsdx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "273",
                                        "long_name": "Zonal Deriv. of Surface Pres.",
                                        "grib_name": "dpsdx",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-1987.9719",
                                                "units": "W/m2",
                                                "grib_name": "SRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "2117.3147",
                                                "gribparam": "106"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-366108.75",
                                                "units": "W/m2",
                                                "grib_name": "TRAFSU",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "692607.75",
                                                "gribparam": "107"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "solar flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "948.26562",
                                                "gribparam": "185"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "subcenter": "255",
                                                "process": "50",
                                                "gribNumBits": "16",
                                                "scale_min": "-280.39526",
                                                "units": "W/m2",
                                                "grib_name": "TRAFS",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "49.933517",
                                                "gribparam": "186"
                                            }
                                        }
                                    },
                                    "ALBEDO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ALBEDO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Albedo (surface)",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "8",
                                        "scale_min": "0.06999999",
                                        "units": "unitless",
                                        "grib_name": "ALBEDO",
                                        "PTVersion": "128",
                                        "gribleveltype": "1",
                                        "scale_max": "0.8004687",
                                        "gribparam": "175"
                                    }
                                },
                                "soil": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soil",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "TDCL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TDCL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temp level CL",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "209.53712",
                                        "units": "m (H2O)",
                                        "grib_name": "TDCL",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "310.49008",
                                        "gribparam": "183"
                                    },
                                    "TD5": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD5",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "193.93007",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD5",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "319.547",
                                        "gribparam": "209"
                                    },
                                    "TD3": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TD3",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "180.45122",
                                        "units": "Kelvin_scale",
                                        "grib_name": "TD3",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "342.85083",
                                        "gribparam": "207"
                                    },
                                    "td": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "deep soil temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "208.74364",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td",
                                        "PTVersion": "128",
                                        "gribleveltype": "111",
                                        "scale_max": "314.63263",
                                        "gribparam": "170"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY apr2002 hybrid_lev P 0000 1 Apr 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY apr2002 hybrid_lev P 0000 1 Apr 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY apr2002 hybrid_lev P 0000 1 Apr 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY apr2002 hybrid_lev P 0000 1 Apr 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribparam": "138"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY apr2002 hybrid_lev P 0000 1 Apr 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY apr2002 hybrid_lev P 0000 1 Apr 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY apr2002 hybrid_lev P 0000 1 Apr 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY apr2002 hybrid_lev P 0000 1 Apr 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.009347893",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "scale_max": "0.03162933",
                                        "gribparam": "133"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY apr2002 hybrid_lev P 0000 1 Apr 2002",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst SIX-HOURLY apr2002 hybrid_lev P 0000 1 Apr 2002",
                                        "missing_value": "NaN",
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128"
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-22.370047",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "410.88324",
                                        "gribparam": "130"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "vorticity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.59607007E-05",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.89484126E-05",
                                        "gribparam": "138"
                                    },
                                    "Rv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for moist air"
                                    },
                                    "Rd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for dry air"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-1.59607007E-05",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "1.89484126E-05"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "pressure",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "1"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst SIX-HOURLY apr2002 hybrid_lev omegahalf",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "gribleveltype": "109"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Specific Humidity",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-0.009347893",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "0.03162933",
                                        "gribparam": "133"
                                    },
                                    "gravity": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gravity",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s2",
                                        "long_name": "earth\\'s gravity"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Divergence",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.38020630E-06",
                                        "units": "s-1",
                                        "grib_name": "Div",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.35597895E-06",
                                        "gribparam": "155"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-2.38020630E-06",
                                        "PTVersion": "128",
                                        "gribleveltype": "109",
                                        "scale_max": "2.35597895E-06"
                                    },
                                    "BC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "BC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless"
                                    },
                                    "AC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "AC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa"
                                    }
                                },
                                "filepattern": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "filepattern",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "above_ground": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "above_ground",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "wind10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "wind10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "10m windspeed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.008328676",
                                        "units": "unitless",
                                        "grib_name": "wind10",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "40.846344",
                                        "gribparam": "171"
                                    },
                                    "WIMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "WIMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "maximum 10m wind speed",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "0.02697593",
                                        "units": "m/s",
                                        "grib_name": "WIMAX",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "41.234123",
                                        "gribparam": "216"
                                    },
                                    "vas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "V-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-35.419174",
                                        "units": "m/s",
                                        "grib_name": "vas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "35.488831",
                                        "gribparam": "166"
                                    },
                                    "uas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "uas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "U-wind at 10",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "-39.464005",
                                        "units": "m/s",
                                        "grib_name": "uas",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "35.195572",
                                        "gribparam": "165"
                                    },
                                    "td2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Dewpoint at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "2.82435053E-08",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "0.04385199",
                                        "gribparam": "168"
                                    },
                                    "t2mmx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "max 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "182.38966",
                                        "units": "unitless",
                                        "grib_name": "t2mmx",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "340.75372",
                                        "gribparam": "201"
                                    },
                                    "t2mmn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "min 2m temp",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "182.08791",
                                        "units": "unitless",
                                        "grib_name": "t2mmn",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "327.32294",
                                        "gribparam": "202"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "long_name": "Temperature at 2 m",
                                        "calendar": "standard",
                                        "subcenter": "255",
                                        "process": "50",
                                        "gribNumBits": "16",
                                        "scale_min": "182.1909",
                                        "units": "Kelvin_scale",
                                        "grib_name": "t2m",
                                        "PTVersion": "128",
                                        "gribleveltype": "105",
                                        "scale_max": "335.41809",
                                        "gribparam": "167"
                                    }
                                }
                            },
                            "T_09": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T_09",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "0.25",
                                "defaultvalue": "454.75"
                            },
                            "S_09": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "S_09",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "long_name": "Start Time",
                                "pointwidth": "0"
                            },
                            "T_08": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T_08",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "0.25",
                                "defaultvalue": "484.75"
                            },
                            "S_08": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "S_08",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "long_name": "Start Time",
                                "pointwidth": "0"
                            },
                            "T_07": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T_07",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "0.25",
                                "defaultvalue": "515.75"
                            },
                            "S_07": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "S_07",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "long_name": "Start Time",
                                "pointwidth": "0"
                            },
                            "T_06": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T_06",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2002-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "0.25",
                                "defaultvalue": "333.75"
                            },
                            "S_06": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "S_06",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2002-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "long_name": "Start Time",
                                "pointwidth": "0"
                            },
                            "T_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2002-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "0.25",
                                "defaultvalue": "272.75"
                            },
                            "S_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "S_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2002-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "long_name": "Start Time",
                                "pointwidth": "0"
                            },
                            "T_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "0.25",
                                "defaultvalue": "576.75"
                            },
                            "S_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "S_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "long_name": "Start Time",
                                "pointwidth": "0"
                            },
                            "T_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "0.25",
                                "defaultvalue": "607.75"
                            },
                            "S_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "S_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "long_name": "Start Time",
                                "pointwidth": "0"
                            },
                            "T_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "0.25",
                                "defaultvalue": "545.75"
                            },
                            "S_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "S_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "long_name": "Start Time",
                                "pointwidth": "0"
                            },
                            "T_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "0.25",
                                "defaultvalue": "333.75"
                            },
                            "S_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "S_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "long_name": "Start Time",
                                "pointwidth": "0"
                            },
                            "Z_10": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_10",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "long_name": "Height",
                                "pointwidth": "1.0"
                            },
                            "Z_09": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_09",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "cm_down",
                                "gridtype": "0",
                                "long_name": "Depth",
                                "pointwidth": "0"
                            },
                            "Z_08": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_08",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "cm_down",
                                "gridtype": "0",
                                "long_name": "Depth",
                                "pointwidth": "0"
                            },
                            "Z_07": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_07",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "cm_down",
                                "gridtype": "0",
                                "long_name": "Depth",
                                "pointwidth": "0"
                            },
                            "Z_06": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_06",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "cm_down",
                                "gridtype": "0",
                                "long_name": "Depth",
                                "pointwidth": "0"
                            },
                            "P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "sp_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "long_name": "complex"
                            },
                            "Z_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Z_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0"
                            },
                            "Y_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "Z_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "long_name": "Height",
                                "pointwidth": "1.0"
                            },
                            "sp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Z_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m_above_gnd",
                                "gridtype": "0",
                                "long_name": "Height",
                                "pointwidth": "0"
                            },
                            "Z": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m_above_gnd",
                                "gridtype": "0",
                                "long_name": "Height",
                                "pointwidth": "0"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2002-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "0.25",
                                "defaultvalue": "303.75"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "modulus": "360.0",
                                "pointwidth": "2.8125"
                            },
                            "M": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "M",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "1.0"
                            },
                            "S": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "S",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2002-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "long_name": "Start Time",
                                "pointwidth": "0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/SIX-HOURLY"
                        },
                        "apr2002": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/apr2002",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "apr2002",
                            "restriction": "Public",
                            "SIXHOURLY": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "SIX-HOURLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "NC_GLOBAL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "NC_GLOBAL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "mem24PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem24griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem24/.griblist.html",
                                    "mem24filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc24_%6d.01",
                                    "mem24year0": "200210",
                                    "mem23PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem23griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem23/.griblist.html",
                                    "mem23filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc23_%6d.01",
                                    "mem23year0": "200210",
                                    "mem22PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem22griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem22/.griblist.html",
                                    "mem22filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc22_%6d.01",
                                    "mem22year0": "200210",
                                    "mem21PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem21griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem21/.griblist.html",
                                    "mem21filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc21_%6d.01",
                                    "mem21year0": "200210",
                                    "mem20PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem20griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem20/.griblist.html",
                                    "mem20filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc20_%6d.01",
                                    "mem20year0": "200210",
                                    "mem19PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem19griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem19/.griblist.html",
                                    "mem19filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc19_%6d.01",
                                    "mem19year0": "200210",
                                    "mem18PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem18griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem18/.griblist.html",
                                    "mem18filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc18_%6d.01",
                                    "mem18year0": "200210",
                                    "mem17PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem17griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem17/.griblist.html",
                                    "mem17filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc17_%6d.01",
                                    "mem17year0": "200210",
                                    "mem16PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem16griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem16/.griblist.html",
                                    "mem16filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc16_%6d.01",
                                    "mem16year0": "200210",
                                    "mem15PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem15griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem15/.griblist.html",
                                    "mem15filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc15_%6d.01",
                                    "mem15year0": "200210",
                                    "mem14PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem14griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem14/.griblist.html",
                                    "mem14filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc14_%6d.01",
                                    "mem14year0": "200210",
                                    "mem13PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem13griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem13/.griblist.html",
                                    "mem13filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc13_%6d.01",
                                    "mem13year0": "200210",
                                    "mem12PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem12griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem12/.griblist.html",
                                    "mem12filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc12_%6d.01",
                                    "mem12year0": "200210",
                                    "mem11PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem11griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem11/.griblist.html",
                                    "mem11filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc11_%6d.01",
                                    "mem11year0": "200210",
                                    "mem10PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem10griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem10/.griblist.html",
                                    "mem10filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc10_%6d.01",
                                    "mem10year0": "200210",
                                    "mem09PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem09griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem09/.griblist.html",
                                    "mem09filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc09_%6d.01",
                                    "mem09year0": "200210",
                                    "mem08PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem08griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem08/.griblist.html",
                                    "mem08filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc08_%6d.01",
                                    "mem08year0": "200210",
                                    "mem07PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem07griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem07/.griblist.html",
                                    "mem07filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc07_%6d.01",
                                    "mem07year0": "200210",
                                    "mem06PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem06griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem06/.griblist.html",
                                    "mem06filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc06_%6d.01",
                                    "mem06year0": "200210",
                                    "mem05PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem05griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem05/.griblist.html",
                                    "mem05filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc05_%6d.01",
                                    "mem05year0": "200210",
                                    "mem04PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem04griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem04/.griblist.html",
                                    "mem04filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc04_%6d.01",
                                    "mem04year0": "200210",
                                    "mem03PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem03griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem03/.griblist.html",
                                    "mem03filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc03_%6d.01",
                                    "mem03year0": "200210",
                                    "mem02PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem02griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem02/.griblist.html",
                                    "mem02filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc02_%6d.01",
                                    "mem02year0": "200210",
                                    "mem01PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem01griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.apr2002/.SIX-HOURLY/.mem01/.griblist.html",
                                    "mem01filepattern": "/mstore/iri/forecast/data/echam4/asst/apr02/30008fc01_%6d.01",
                                    "mem01year0": "200210",
                                    "Conventions": "IRIDL"
                                },
                                "mem24": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem24",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03627859",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "96.148956",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8523.2344",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-783.91235",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1161.2188",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-395.60986",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-77.218018",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1749.3152",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1952.9929",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.2812",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-395.60986",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-76.280029",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-90.007629",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.009674072",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-730.64282",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-66.735596",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.681591",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "5.8996019",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.1196175",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "6.3276234",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.39154",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "339.10242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.40321",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "344.46848",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.21048492E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-696.64722",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.21051562E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "15.487793",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47201.867",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112165.81",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.68290328E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.45708838E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.81813107E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.53595383E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.38858570E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-428172.62",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "447176.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "936.65625",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-238.60886",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "67.148941",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03145241",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258434",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-658.01636",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1097.7483",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1340.1887",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "181.70947",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.35903951E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "7.26613223E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1596.1526",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1775.0283",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-243549.56",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "671596.56",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "936.65625",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-238.60886",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "34.822845",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.24059",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.89545",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "197.8936",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "318.745",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.40321",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "340.71066",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.38182",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "313.79504",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.00486014",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02996711",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.880489",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.52521",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.58640032E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83171051E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.58640032E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83171051E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem24 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.00486014",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02996711",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.02520437E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "1.99295164E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.02520437E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "1.99295164E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02652667",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.811302",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.04409317",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "38.089733",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-31.837341",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "31.605087",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-37.231339",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "34.047394",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "7.45237116E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03597466",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "188.34941",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "336.41708",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "187.8222",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.03113",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "187.85246",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "333.69202",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem23": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem23",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.02459955",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "98.870628",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8489.6484",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-785.60938",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1163.25",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-391.51099",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-70.525146",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1562.1396",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1973.1355",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.7812",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-391.51099",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-70.345459",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-93.312469",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.008773804",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-723.27197",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-62.866455",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.8795147",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "5.0811443",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.5557623",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "6.9474549",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.69714",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "337.76422",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.4045",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "346.99146",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.12399584E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-691.95386",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.01423939E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "16.666016",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47578.738",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112444.18",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.29395617E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.06403739E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.81027406E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.26490257E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.72678222E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-418921.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "478715.06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "928.875",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-253.49649",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "71.708206",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03004393",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258476",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-671.32617",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "968.99951",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1346.0564",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "177.54761",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.38250220E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "7.09968901E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1488.7334",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1907.3376",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-278086.69",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "659325.94",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "934.34375",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-253.49649",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "31.810074",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.54117",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "310.1088",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "197.60117",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "318.90411",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.4045",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "342.85083",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.77115",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "314.00952",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004564557",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.03162933",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.868237",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.53522",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.54397985E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.85088866E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.54397985E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.85088866E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem23 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004564557",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.03162933",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.00627119E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.08002939E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.00627119E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.08002939E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.0258178",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.2225",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0533101",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "36.830452",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-30.678604",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "35.488831",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-35.585358",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "33.946671",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "4.63529872E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03707661",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.54939",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "337.94232",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.15999",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "323.8736",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.34132",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "328.83789",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem22": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem22",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03901024",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "94.237259",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8518.1172",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-796.3855",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1165.2188",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-387.97974",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-72.356201",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1959.1589",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1790.9146",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.2188",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-387.97974",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-72.264648",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-87.979904",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.009033203",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-720.62598",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-61.94751",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.7121153",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "5.5417352",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.6751099",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "6.266324",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "181.9631",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "337.53479",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "181.92494",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "341.51178",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.21613698E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-717.16406",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.10856490E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "15.675049",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47204.512",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112657.03",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.31466707E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "2.02944443E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.29403702E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-401384.88",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "474824.69",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "941.8125",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-263.42773",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "72.966461",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.0317284",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258392",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-684.42505",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1040.2339",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1374.7517",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "180.03101",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.49724689E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "7.19887794E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1458.5359",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1781.7429",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-330238.5",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "638178.06",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "941.8125",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-263.42773",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "39.817215",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.42857",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.55554",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "196.20354",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "318.40216",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "181.92494",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "337.63873",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.36971",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "313.633",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.003462188",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02848081",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.848389",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.172",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.57988052E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79769013E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.57988052E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79769013E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem22 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.003462188",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02848081",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.86073805E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "1.92335301E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.86073805E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "1.92335301E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02709888",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.299248",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.04974181",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "37.7356",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-31.605194",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "31.658203",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-33.49054",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "34.974091",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "3.71530717E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.04020831",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.4312",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "334.74847",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.35759",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "322.93115",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.38605",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "329.02142",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem21": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem21",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.05193512",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "96.193306",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8514.5273",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-791.61987",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1162.625",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-393.9856",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-77.386963",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-2131.5298",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "2361.949",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.4688",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-393.9856",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-77.914551",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-87.691818",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.00869751",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-735.83325",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-67.147217",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.8210649",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "5.7531404",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-6.7149887",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "6.11022",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.64415",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "338.21466",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.6779",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "345.43146",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.21365656E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-699.73999",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.007568359",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.13327405E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "16.558594",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47104.195",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112054.72",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-8.82326093E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.61122999E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "2.14566739E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.31836134E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-425286.31",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "424593.75",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "930.92188",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-280.39526",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "63.459305",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.0312387",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258366",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-671.30151",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "992.51001",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1160.9504",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "192.29883",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.64231562E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "7.68964128E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1716.2632",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "2074.7163",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-264486.69",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "662644.06",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "935.89062",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-280.39526",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "34.862076",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.0269",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "310.05298",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "198.17204",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "319.36807",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.6779",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "341.3299",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.48401",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "314.41125",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004848529",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.03123225",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.908205",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.60532",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.58919065E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.74960969E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.58919065E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.74960969E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem21 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004848529",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.03123225",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.38020630E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.01945295E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.38020630E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.01945295E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02733697",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.300312",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.05433573",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "35.80513",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-29.950668",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "31.754959",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-34.846085",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "34.593246",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.07414564E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.04052566",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "189.24924",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "335.5033",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "188.90219",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "327.32294",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "188.99925",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "333.67578",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem20": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem20",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03993061",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "93.478439",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8551.4805",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-799.625",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1163.5938",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-385.22192",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-76.358887",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1906.9905",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "2017.6917",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1164.9375",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-385.22192",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-76.263916",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-88.491119",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.009307861",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-730.0459",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-65.047607",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.9627523",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "3.5000877",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.6572523",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "6.3679981",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.15778",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "338.60889",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.10625",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "341.93671",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.16216586E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-666.73267",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.04919309E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "16.36084",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47365.758",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112171.95",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-6.89317185E-30",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.31122782E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.49681171E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.17455236E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.37232962E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-446191.75",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "419767.06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "933.03125",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-271.46289",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "70.684296",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03104872",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.25848",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-768.89673",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "826.32861",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1248.8982",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "164.29199",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.99399448E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "6.56962698E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1917.4736",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "2077.2239",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-300193.12",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "608946.44",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "944.32812",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-271.46289",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "27.995422",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.53712",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.68164",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "196.61838",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "318.0072",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.10625",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "338.31171",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "208.74364",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "313.17139",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.003853964",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.0306637",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.168953",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.46375",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.51836630E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83732573E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.51836630E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83732573E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem20 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.003853964",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.0306637",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.97706777E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.14203692E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.97706777E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.14203692E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02983372",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.757587",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06051524",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "37.702366",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-31.879715",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "31.732941",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-37.565506",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "31.400482",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "5.95735052E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03807382",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "187.07111",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "334.68628",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "186.87204",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "325.08368",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "186.9476",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "333.92078",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem19": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem19",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.04303698",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "91.348541",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8518.6367",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-791.41797",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1161.6875",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-386.4873",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-73.300293",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1829.8682",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "2519.9031",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1166.0625",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-386.4873",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-73.139893",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-88.323959",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.009353638",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-723.74146",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-63.243164",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.3234224",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "3.9024134",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.9026203",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "5.7632637",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.89685",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "338.10349",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.92517",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "340.39465",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.38701523E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-686.06421",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.18056778E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "15.715088",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47515.355",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112756.33",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.36156358E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.76309857E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.21796120E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-435120.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "434923.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "941.3125",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-240.2489",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "66.15358",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03112894",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258402",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-720.85156",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1397.8811",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1967.2639",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "238.1958",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7.86653800E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "9.52467474E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1964.3911",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1944.5405",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-325653.06",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "633899.62",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "941.3125",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-240.2489",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "27.15155",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.42233",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.88522",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "195.79343",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "318.63763",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.92517",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "336.54309",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.6938",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "313.68109",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004232366",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.0282158",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.274216",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.41989",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.56099177E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.88040704E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.56099177E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.88040704E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem19 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004232366",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.0282158",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.14717397E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.07267226E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.14717397E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.07267226E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.03041011",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.078278",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.05671916",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "35.456184",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-29.958847",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "31.42749",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-32.305099",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "32.64502",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "4.91974639E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03492945",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.84273",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "335.84106",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.27533",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.23157",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.32986",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "333.50275",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem18": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem18",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.04101126",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "93.08596",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8517.9258",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-795.42065",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1162.7812",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-390.59009",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-73.104736",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1879.8738",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1765.1277",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.5",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-390.59009",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-72.770752",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-88.306839",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.008514404",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-723.01147",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-62.274902",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.9795876",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "4.0742331",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.6609936",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "6.7626929",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.20239",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "337.75903",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.19865",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "342.96436",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.26150780E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-682.03784",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.11089321E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "16.48584",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47372.73",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112412.98",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.20581571E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "9.80280561E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.82562815E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.42301546E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.41785449E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-405300.94",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "445482.88",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "935.625",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-261.18237",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "68.358765",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.02915773",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258402",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-670.43408",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "910.98022",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1222.5098",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "189.11572",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.88847377E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "7.56198233E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1809.4314",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1940.5793",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-279403.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "617394.94",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "939.40625",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-261.18237",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "35.083038",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.31544",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.24707",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "195.03979",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "317.89798",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.19865",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "338.84131",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.29239",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "312.8855",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.009347893",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02819964",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.509649",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.24139",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.59207593E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.85462322E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.59207593E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.85462322E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem18 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.009347893",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02819964",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.30564160E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "1.99038300E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.30564160E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "1.99038300E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.03575553",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "38.519421",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06431341",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "39.117733",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-31.087845",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "32.360046",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-36.896317",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "34.919983",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "5.42359864E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03680121",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.97688",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "337.64795",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.75427",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.30072",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.79369",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "332.88184",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem17": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem17",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03659699",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "91.45507",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8478.5781",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-789.28467",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1165.4062",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-403.13745",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-73.934814",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1763.4604",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "2135.2605",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.4062",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-403.13745",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-73.802002",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-94.315781",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.009628296",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-724.73218",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-63.289307",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.2230682",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "5.4407997",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.3103552",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "5.5759048",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.9525",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "337.99298",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.99185",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "342.26096",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.38229086E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-681.73511",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.21787889E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "15.054932",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47501.148",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112417.41",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-6.73161534E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.34387436E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.65268671E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.48465142E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-406743.44",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "454053.81",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "933.15625",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-259.73657",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "71.648773",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03131089",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258379",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1013.5713",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "945.7251",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1156.6265",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "234.76685",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.62502555E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "9.38796063E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1491.6008",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1783.1257",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-292513.69",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "618900.12",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "934.35938",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-259.74927",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "38.564148",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.12006",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "310.29047",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "196.98254",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "319.43365",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.99185",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "338.2258",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.15858",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "314.31189",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.005203657",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02928355",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.93755",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.37985",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.54989884E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84380242E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.54989884E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84380242E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem17 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.005203657",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02928355",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.87245678E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.09458972E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.87245678E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.09458972E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.01902881",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.852341",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.02697593",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "37.432152",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-30.586624",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "29.730209",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-34.359894",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "34.91304",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "6.39119548E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03849806",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.42506",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "337.10727",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.16843",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.46802",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.18327",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "330.5845",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem16": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem16",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03239161",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "96.549843",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8500.6445",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-789.12158",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1164.5",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-389.7981",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-73.656494",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1713.4277",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "2001.5286",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.3125",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-389.7981",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-73.609619",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-91.70575",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.007965088",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-720.00806",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-63.253662",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.5865507",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "5.8119993",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.2396288",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "5.839942",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.91658",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "337.46707",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.91646",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "345.49811",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.32915170E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-683.03857",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.13769784E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "16.598145",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47152.582",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112855.17",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-8.82326093E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.95789652E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.55087707E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.22410574E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-425969.56",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "430210.94",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "948.26562",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-268.26147",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "67.848679",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03080785",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258408",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-679.92188",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "983.68506",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1472.9768",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "194.36865",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.89002184E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "7.77248488E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1491.8547",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "2012.9202",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-289958.62",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "672495.81",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "948.26562",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-268.40674",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "31.856934",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.04552",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "308.94559",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "195.92912",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "318.29572",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.91646",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "341.53717",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.03236",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "313.14557",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.00685313",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.0308288",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.550734",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.44028",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.59032097E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.78370283E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.59032097E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.78370283E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem16 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.00685313",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.0308288",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.17917909E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.08066422E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.17917909E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.08066422E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.030589",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.769672",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.05507858",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "37.384418",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-29.80603",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "30.067093",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-36.449051",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "33.757095",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "5.26239816E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03630194",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.3307",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "333.60797",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.02136",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.73172",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.10753",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "329.3573",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem15": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem15",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03512947",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "100.46806",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8532.1406",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-791.06079",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1163.2188",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-390.6377",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-73.414062",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1658.48",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1708.9458",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.4688",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-390.6377",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-73.015625",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-93.38382",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.009597778",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-726.83887",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-63.031494",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.6341724",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "4.1077127",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.7169638",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "6.5309181",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.79463",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "338.33118",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.66354",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "344.00107",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.13905014E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-661.37329",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.13921124E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "16.263184",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47589.035",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112449.95",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-6.73161534E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.84967199E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.63506809E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.41709393E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-429263.62",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "443231.06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "934.65625",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-250.80386",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "81.313919",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.0310252",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.25843",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-668.72168",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "920.37378",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1399.1733",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "177.8042",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.59490218E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "7.11006862E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1769.1882",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "2020.4529",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-270233.88",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "639934.38",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "934.65625",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-250.80386",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "33.340561",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.14941",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.4931",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "195.11737",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "318.8653",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.66354",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "339.56747",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.08759",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "313.23611",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.006514385",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02911441",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.62188",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.48895",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.53734727E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79654198E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.53734727E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79654198E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem15 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.006514385",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02911441",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.93231745E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "1.91183608E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.93231745E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "1.91183608E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02065541",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.911312",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03317188",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "35.822472",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-32.635101",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "32.127365",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-34.80304",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "34.041702",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "5.54388535E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03778274",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "186.39259",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "331.87418",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "186.12982",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "322.50183",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "186.14215",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "328.18787",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem14": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem14",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03991813",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "94.80703",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8478.4922",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-796.3291",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1164.0312",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-388.91406",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-72.125244",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1769.2209",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "2134.2803",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1164.4375",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-388.91406",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-72.203369",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-90.282913",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.009063721",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-719.47925",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-61.636475",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.820097",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "4.0618095",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-6.7108974",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "5.5767136",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "181.72482",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "337.76776",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "181.66173",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "342.33371",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.42156318E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-672.96509",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.14142313E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "15.390137",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47450.312",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112781.88",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.76465199E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.31981004E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.58916282E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.44842688E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.35959681E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-446407.31",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "441880.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "936.875",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-262.77661",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "74.054825",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.0306636",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.25841",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-688.20801",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1431.041",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1684.8704",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "220.57275",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-6.73732472E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "8.81977940E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1546.7065",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1931.6453",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-262044.0",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "626748.75",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "938.42188",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-262.77661",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "43.645691",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.1292",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "310.30124",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "194.55466",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "319.10046",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "181.66173",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "338.13254",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.04555",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "314.30353",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004902184",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.0279946",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.910177",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.46445",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.57638096E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.77908714E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.57638096E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.77908714E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem14 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004902184",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.0279946",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.17015122E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.03396576E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.17015122E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.03396576E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02179695",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.436974",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.04707358",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "37.050003",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-32.678802",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "29.154251",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-35.379028",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "32.853104",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "3.78490803E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03589486",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "184.37177",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "335.18732",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "184.19308",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "325.44824",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.23666",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "333.66223",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem13": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem13",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.04660582",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "96.247231",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8505.375",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-795.10913",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1164.5625",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-386.86523",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-74.751221",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1899.8164",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "2200.6743",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.3438",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-386.86523",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-80.266357",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-85.037994",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.008621216",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-723.65137",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-66.773438",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.6645813",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "4.7966251",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.5465584",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "6.7632618",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.36566",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "338.06784",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.33679",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "341.02118",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.29361945E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-695.34595",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.00216130E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "16.952148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47415.652",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112783.51",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.85005773E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "2.03751301E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.48257038E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-412242.5",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "405432.88",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "931.03125",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-263.08301",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "70.1082",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03056035",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258505",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-679.29565",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1200.5361",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1627.3806",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "210.34863",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-6.50743914E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "8.41111500E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1784.1311",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "2063.4109",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-285209.0",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "677776.25",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "934.26562",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-263.08301",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "48.600586",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.90398",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "310.49008",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "196.05373",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "319.547",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.33679",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "337.34927",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.39993",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "314.63263",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.005137093",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.03089631",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-22.161226",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.88324",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.57203394E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79652543E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.57203394E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79652543E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem13 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.005137093",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.03089631",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.34894856E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.06611776E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.34894856E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.06611776E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02290366",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.765766",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.04388163",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "36.213707",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-30.342178",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "30.078171",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-34.579636",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "32.435272",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "9.91271349E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03760876",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "188.8206",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "338.04352",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "188.69492",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "325.58325",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "188.7612",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "330.6532",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem12": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem12",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03350377",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "93.62442",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8489.25",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-789.87524",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1160.875",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-386.28662",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-70.485352",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1813.7671",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1827.5251",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.375",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-386.28662",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-70.000977",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-94.13559",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.008117676",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-707.68945",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-60.600098",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.3738956",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "5.3912811",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.9379225",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "6.0997114",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "181.01407",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "335.88245",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "180.99878",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "344.53238",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.43682018E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-692.95898",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.01493788E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "16.852051",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47341.145",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112107.55",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.04871003E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.74535181E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.76682488E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.29734769E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-402245.69",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "466009.69",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "932.07812",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-267.49561",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "69.782166",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03094661",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258402",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-735.02173",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1160.1282",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1693.8923",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "220.323",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-6.77340154E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "8.81014728E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1980.5737",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1990.6643",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-271278.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "687383.38",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "937.51562",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-267.57275",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "49.933517",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.01451",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.99512",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "195.99687",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "319.29434",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "180.99878",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "340.298",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "208.87514",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "313.84189",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004026297",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.0288512",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.71361",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.44614",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.52403691E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79802464E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.52403691E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79802464E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem12 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004026297",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.0288512",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.99249325E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.35597895E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.99249325E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.35597895E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02764439",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.331028",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.05633492",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "36.509285",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-31.150391",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "29.73587",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-33.612488",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "33.025803",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "5.24204680E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03579079",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "184.1768",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "338.34943",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "183.77364",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.72528",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "183.78525",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "330.33856",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem11": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem11",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03720867",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "96.61869",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8522.0195",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-798.46289",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1164.9062",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-385.76733",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-75.369629",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1596.5273",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "2101.7866",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1164.9062",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-385.76733",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-75.268066",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-94.686401",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.009063721",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-741.37354",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-65.908203",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.2028971",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "4.3305235",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.1441755",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "5.7074299",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.92404",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "340.00369",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.83701",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "343.30737",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.51408915E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-659.08472",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.11915870E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "14.521729",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47712.27",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112672.03",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.02525767E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.55532143E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.41776218E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-419532.06",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "500458.88",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "941.85938",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-277.8501",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "73.006409",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.02986393",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.2584",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-674.71387",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1123.5544",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1254.6582",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "180.86841",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.01702743E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "7.23287314E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1987.9719",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1941.0579",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-294780.31",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "623320.62",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "941.85938",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-277.8501",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "37.302933",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.62575",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.58456",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "196.82095",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "318.60635",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.83701",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "339.35034",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.46455",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "313.55206",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.005938847",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02857718",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.693485",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.42438",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.59607007E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.73115805E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.59607007E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.73115805E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem11 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.005938847",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02857718",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.00608861E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "1.99695364E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.00608861E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "1.99695364E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.022109",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.839085",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.04956756",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "35.616554",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-31.331299",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "30.403442",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-32.299744",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "32.720612",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "9.37129130E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.04346215",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "187.715",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "334.97134",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "187.43599",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.61786",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "187.59218",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "334.05447",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03777539",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "99.510597",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8518.3398",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-795.96973",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1162.375",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-378.33716",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-71.991455",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1984.7434",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1787.3799",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.625",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-378.33716",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-71.439453",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-88.219376",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.008300781",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-720.09741",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-60.014404",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.3045835",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "3.7702875",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.6601534",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "7.8551531",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "180.50195",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "337.46753",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "180.49174",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "342.31717",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.90132823E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-704.72192",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "9.98668838E-07",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "16.37207",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47414.613",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112237.09",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.86823455E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "2.20188167E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.42538920E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-399521.5",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "462547.25",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "934.42188",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-240.73732",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "68.856064",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03094104",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258411",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-666.58618",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1293.427",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1511.0798",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "223.21021",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-6.04238551E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "7.97854511E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1555.9319",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1788.0273",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-272088.81",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "648743.25",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "936.07812",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-240.73732",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "45.56308",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.15417",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.07019",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "193.93007",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "318.14905",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "180.49174",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "338.24295",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "208.88196",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "312.99017",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.003082571",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02937465",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.801489",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.13678",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.51762506E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.80159186E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.51762506E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.80159186E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem10 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.003082571",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02937465",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.83409531E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "1.97643908E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.83409531E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "1.97643908E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02465612",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.791508",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03899628",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "36.742413",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-35.419174",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "30.486847",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-33.569397",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "34.258606",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "3.32324994E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03996732",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "184.33495",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "338.37805",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "183.97168",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "325.72763",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.17424",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "332.20419",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem09": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem09",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.04092359",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "92.928825",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8477.4883",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-793.91797",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1165.25",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-390.49365",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-75.770996",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1682.3726",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "2122.0393",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.25",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-390.49365",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-75.143555",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-89.33638",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.00944519",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-725.30542",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-65.679443",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.7479124",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "4.7751904",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.84587",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "6.8396034",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.6019",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "338.16113",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.44714",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "341.63654",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.54419172E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-669.78906",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.17006130E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "15.629883",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47930.047",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112189.52",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7.05861028E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.43198370E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.59489070E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.46801756E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-455568.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "413195.19",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "937.875",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-251.35263",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "69.120438",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03105404",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258465",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-712.74805",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1195.5969",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1265.1101",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "213.98291",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.05882099E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "8.55655173E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1965.552",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "2117.3147",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-279126.31",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "621088.12",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "938.98438",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-252.3257",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "37.453552",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.2652",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "308.95074",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "197.2623",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "319.25763",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.44714",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "337.35529",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.50562",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "313.28119",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.005804721",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.0307179",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.633232",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.61325",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.49581674E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81226333E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.49581674E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81226333E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem09 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.005804721",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.0307179",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.98700627E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.10568192E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.98700627E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.10568192E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02998615",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.510921",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0554593",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "36.514301",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-33.356415",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "30.535355",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-35.776505",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "34.293869",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8.23673645E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03632406",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "186.54773",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "334.43698",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "186.08665",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.95065",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "186.29047",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "334.43665",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem08": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem08",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.04529924",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "94.087654",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8483.0625",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-789.39795",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1165.25",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-387.14038",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-75.020996",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1692.2327",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1681.019",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.25",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-387.14038",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-74.31543",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-87.945618",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.008407593",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-712.73291",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-62.311279",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.1772776",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "4.9135103",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.5000591",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "5.8621206",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.24687",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "336.8284",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.15356",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "344.53204",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.34362563E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-681.02661",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.08283712E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "14.997803",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47624.996",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112344.84",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.18478191E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.95353664E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7.45389068E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.30079809E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-447660.19",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "461708.75",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "929.75",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-252.59955",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "72.030655",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.0300294",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258438",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-685.8335",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "903.4873",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1327.4255",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "195.05151",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.30800321E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "7.79946561E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1855.6016",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "2049.8787",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-283919.44",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "653254.56",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "929.92188",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-252.59955",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "49.894608",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.36423",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.80563",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "195.6915",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "318.59351",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.15356",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "340.76953",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.49959",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "313.32111",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004289951",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.03023825",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.72757",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.67609",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.54932313E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89484126E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.54932313E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89484126E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem08 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004289951",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.03023825",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.96906490E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.01639227E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.96906490E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.01639227E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.008328676",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.144417",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.02916894",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "37.457752",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-33.578537",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "31.631149",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-35.700165",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "35.195572",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "5.10924103E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.04385199",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "184.72069",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "333.81165",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "184.68315",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "326.69745",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.70293",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "331.04056",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem07": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem07",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.02960935",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "93.472145",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8524.5117",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-795.90942",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1165.0",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-387.31934",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-75.928467",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1639.1538",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1646.6848",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-387.31934",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-75.701416",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-87.957977",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.009567261",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-721.80688",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-65.458008",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.068306",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "4.2929535",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.7372818",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "5.6343164",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.52043",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "336.97156",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.4966",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "344.18042",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.30390902E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-697.07764",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.13071292E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "16.177734",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47361.051",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112010.8",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.76465199E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.78131471E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.77478455E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.02773335E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.31304148E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-413983.44",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "460490.19",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "938.40625",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-257.68359",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "70.888077",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03064918",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258434",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-906.18945",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1116.7324",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1611.7651",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "208.21118",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-6.44499778E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "8.32569356E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1830.343",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1836.1873",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-280829.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "672246.12",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "939.70312",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-260.41577",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "39.479675",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.37369",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.73892",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "197.08278",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "318.61978",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.4966",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "340.26636",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.66171",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "313.41071",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.00547599",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02924974",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.673056",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.44095",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.55156977E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84473301E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.55156977E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84473301E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem07 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.00547599",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02924974",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.91558252E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.12312193E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.91558252E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.12312193E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.03589405",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.241856",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.05884494",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "35.397331",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-30.577072",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "30.740829",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-34.344696",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "31.730438",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "7.47391482E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03599248",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "188.12172",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "337.04614",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "187.7177",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "326.56503",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "187.85127",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "335.41809",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem06": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem06",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03152031",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "94.452423",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8524.6875",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-792.68555",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1164.125",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-387.92822",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-73.998535",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1991.3086",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1988.6287",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1164.9688",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-388.31592",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-76.086182",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-89.380493",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.008514404",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-720.02441",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-65.723877",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.2747183",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "5.9546909",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.8894777",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "5.9654369",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.66342",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "336.82288",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.52245",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "341.48358",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.51822701E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-686.49219",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.06505468E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "13.988281",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47255.484",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112422.84",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.63959776E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "9.20973093E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "2.03002264E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.44560339E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.39890210E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-414398.94",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "417848.62",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "936.9375",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-244.75374",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "65.463501",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03101481",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258387",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-926.44092",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "970.95654",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1546.7542",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "215.45142",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-6.18503691E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "8.61523688E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1473.1694",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "2053.4302",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-338282.69",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "692607.75",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "940.64062",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-244.75374",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "42.840515",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.09023",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "310.3031",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "198.46538",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "319.22241",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.52245",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "337.50702",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.48723",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "313.74503",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004641026",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02958141",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-22.370047",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.74066",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.58235071E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.80325551E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.58235071E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.80325551E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem06 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004641026",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02958141",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.98887642E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "1.98603902E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.98887642E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "1.98603902E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.0304443",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.085705",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.05735423",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "37.272125",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-34.963074",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "30.338394",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-34.265106",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "33.303391",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "6.66074698E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03861117",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "186.96304",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "336.29993",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "186.82076",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "326.35577",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "186.82343",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "331.70093",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem05": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem05",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03605735",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "94.431412",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8484.7812",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-793.34204",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1162.5312",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-385.02124",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-72.5896",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-2065.8008",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1820.4502",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.5312",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-385.02124",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-72.5896",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-92.084656",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.008132935",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-728.2395",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-62.591553",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.5870457",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "4.5369625",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.0982971",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "7.4924746",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.46017",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "338.67242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.46136",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "344.50153",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.32606010E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-721.07202",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.07145752E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "13.136719",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "46750.191",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112265.06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "9.03751527E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.68592658E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.26490257E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.26971941E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-414857.06",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "420229.62",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "929.65625",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-252.17979",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "71.292053",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.02978467",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258486",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-699.29932",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1224.4534",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1711.7449",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "185.75684",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-6.84478891E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "7.42770681E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1374.2615",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1909.1243",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-366108.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "652938.69",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "933.34375",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-255.16867",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "47.792297",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.31898",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.93039",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "196.86673",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "319.31512",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.46136",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "340.22833",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.55833",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "314.21619",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.00664258",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02898406",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.839323",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.68506",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.54824811E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81722207E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.54824811E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81722207E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem05 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.00664258",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02898406",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.13638396E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.02102819E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.13638396E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.02102819E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02725686",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.331867",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.05261023",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "35.813015",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-29.764191",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "35.189957",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-33.65921",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "33.474869",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "5.90056715E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03545133",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.77502",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "340.75372",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.71112",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "326.02145",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "185.71632",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "332.24335",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem04": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem04",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03307148",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "95.999802",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8517.7344",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-800.5625",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1164.3125",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-384.76025",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-71.773438",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1701.7109",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1777.4355",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.7812",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-385.21436",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-71.240967",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-93.788239",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.008590698",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-732.24341",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-59.938477",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.9598465",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "4.936533",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.5813532",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "5.4304857",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "180.45923",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "338.7489",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "180.45122",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "343.16492",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.23528196E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-675.36646",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.20329787E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "15.682861",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47871.238",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112393.02",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.68290328E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.33194270E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.57240549E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.07290842E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.26654925E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-403193.0",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "448493.19",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "937.23438",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-250.92404",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "66.230957",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03105561",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258383",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-796.92407",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1153.5298",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1357.2017",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "198.23779",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.42706914E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "7.92696824E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1518.8611",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1888.9104",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-294263.19",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "653850.81",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "937.23438",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-250.92404",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "33.124527",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.21255",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.94904",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "194.28372",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "318.29745",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "180.45122",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "338.99109",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.16824",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "313.55231",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.006084036",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.03004619",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.593603",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.30182",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.56452461E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.75563910E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.56452461E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.75563910E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem04 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.006084036",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.03004619",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.09166342E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "1.90662820E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.09166342E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "1.90662820E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.0208987",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "40.846344",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0465067",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "41.234123",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-30.774368",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "33.320801",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-39.464005",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "32.691574",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "2.82435053E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03564991",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "183.5701",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "333.67444",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "183.44012",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.90656",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "183.45073",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "331.21817",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem03": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem03",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03059787",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "93.995544",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8500.1367",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-780.36084",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1164.6875",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-388.36011",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-72.769287",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1670.3254",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1751.0156",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1165.4375",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-389.68579",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-72.860596",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-94.332504",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.008224487",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-719.37354",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-62.119385",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.2146616",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "4.2608585",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.9211969",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "6.4515162",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.06325",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "336.86365",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.00282",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "345.38202",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.80755285E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-664.71118",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.23851351E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "13.831787",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47363.723",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112688.59",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.64697809E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "9.36357935E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.80756581E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.41305736E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-407831.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "504181.31",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "932.25",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-248.94284",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "60.057114",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03109005",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.25852",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-830.50293",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1006.416",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1490.7393",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "214.66406",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.96104883E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "8.58392184E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1635.9639",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "2054.2886",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-270703.19",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "641440.31",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "932.25",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-249.13109",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "34.778519",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.41583",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.9881",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "195.52847",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "317.7088",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.00282",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "341.67108",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.51045",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "312.3894",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.006348886",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02876055",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.518559",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.12747",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.55473372E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.80532279E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.55473372E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.80532279E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem03 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.006348886",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02876055",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.92746711E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.02011347E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.92746711E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.02011347E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02942631",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.736862",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.04633677",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "36.17514",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-31.580399",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "31.543777",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-33.830505",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "32.530304",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "4.79083901E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03410744",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "185.56148",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "335.58167",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "184.81645",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.75571",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.9608",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "329.89062",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem02": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem02",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03254087",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "90.980011",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8541.0977",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-792.43237",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1162.875",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-386.41138",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-74.041992",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1879.873",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "1796.2861",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1164.7188",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-386.65308",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-74.041992",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-86.398865",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.008956909",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-716.26465",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-64.669434",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.3659678",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "6.3319511",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.1347218",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "6.1672411",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "183.88605",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "336.83447",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "183.82028",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "339.40259",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.30698106E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-686.51709",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "9.56817530E-07",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "14.756104",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47894.355",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112576.96",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-8.82326093E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.51342008E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.68301290E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-9.93852012E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.25761460E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-416245.75",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "426382.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "930.875",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-235.70496",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "71.320572",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03151661",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258463",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-713.69531",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1105.3835",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1537.8005",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "201.13184",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-6.14923408E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "8.04283218E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1642.0623",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1981.9111",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-287006.44",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "630764.56",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "939.625",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-235.70496",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "40.049561",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.91696",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "309.71579",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "197.06844",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "316.97455",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "183.82028",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "335.70547",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.06052",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "312.97717",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004304886",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02839269",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.960825",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.60532",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.56024689E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82692602E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.56024689E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82692602E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem02 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.004304886",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.02839269",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.07188782E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.10166718E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-2.07188782E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.10166718E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02530534",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.897972",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03852065",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "37.36945",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-31.203064",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "30.253937",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-36.210953",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "32.147354",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "6.36002824E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.04047823",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "182.38966",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "331.71124",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "182.08791",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "323.86108",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "182.1909",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "328.99121",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "mem01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03967282",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "scale_max": "94.298286",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "230",
                                            "gribNumBits": "16"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "8523.1289",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "scale_max": "100000.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "217",
                                            "gribNumBits": "16"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-786.88672",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "203",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "scale_max": "1163.9375",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "178",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-400.95996",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "scale_max": "-74.80835",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "179",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1835.9365",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "scale_max": "2269.5825",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "105",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "scale_max": "1164.9375",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "187",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-400.95996",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "scale_max": "-74.80957",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "188",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "scale_max": "58762.242",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "129",
                                            "gribNumBits": "16"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-94.282104",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "scale_max": "0.008407593",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "220",
                                            "gribNumBits": "16"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-713.44287",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "scale_max": "-66.012207",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "205",
                                            "gribNumBits": "16"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.0278273",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "scale_max": "3.7287235",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "181",
                                            "gribNumBits": "16"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-4.8627081",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "scale_max": "5.7300968",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "180",
                                            "gribNumBits": "16"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.86731",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "scale_max": "336.73975",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "169",
                                            "gribNumBits": "16"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.88388",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "341.27887",
                                            "gribparam": "139",
                                            "gribNumBits": "16"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.24014718E-06",
                                            "gribparam": "160",
                                            "gribNumBits": "24"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-713.83228",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "scale_max": "0.0078125",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "204",
                                            "gribNumBits": "16"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "gribNumBits": "16"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "scale_max": "1.01869227E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "218",
                                            "gribNumBits": "16"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "scale_max": "15.643799",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "141",
                                            "gribNumBits": "16"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "scale_max": "1.5",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "211",
                                            "gribNumBits": "16"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "scale_max": "20.00148",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "173",
                                            "gribNumBits": "16"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "gribNumBits": "8"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "47749.289",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "scale_max": "112708.81",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "134",
                                            "gribNumBits": "16"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.29995747E-07",
                                            "gribparam": "144",
                                            "gribNumBits": "24"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "scale_max": "1.87066905E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "142",
                                            "gribNumBits": "24"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "scale_max": "1.43979605E-06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "143",
                                            "gribNumBits": "24"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-396976.62",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "scale_max": "437979.06",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "108",
                                            "gribNumBits": "16"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "scale_max": "931.09375",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "176",
                                                "gribNumBits": "16"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "PDS_TimeRange": "10",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "process": "50",
                                                "scale_min": "-241.43286",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "scale_max": "79.032547",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "gribparam": "177",
                                                "gribNumBits": "16"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "scale_max": "1.0",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "172",
                                            "gribNumBits": "8"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.03018327",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258457",
                                            "gribparam": "152",
                                            "gribNumBits": "16"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-766.79468",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "scale_max": "1060.8723",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "146",
                                            "gribNumBits": "16"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1480.4631",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "scale_max": "225.16724",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "147",
                                            "gribNumBits": "16"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "subcenter": "255",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "gribNumBits": "8"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-5.91995786E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "scale_max": "9.00364796E-08",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "182",
                                            "gribNumBits": "24"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-1760.2402",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "scale_max": "1824.6965",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "106",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-267350.19",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "scale_max": "683060.44",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "107",
                                                    "gribNumBits": "16"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "scale_max": "943.26562",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "185",
                                                    "gribNumBits": "16"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "PDS_TimeRange": "10",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "process": "50",
                                                    "scale_min": "-241.43286",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "scale_max": "36.252975",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "gribparam": "186",
                                                    "gribNumBits": "16"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "scale_max": "0.8004687",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "175",
                                            "gribNumBits": "8"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "210.61252",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "scale_max": "310.11987",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "183",
                                            "gribNumBits": "16"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "197.65523",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "scale_max": "318.71252",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "209",
                                            "gribNumBits": "16"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "184.88388",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "scale_max": "337.25934",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "207",
                                            "gribNumBits": "16"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "209.76393",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "scale_max": "314.30414",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "170",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.006617144",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.03126534",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-21.782598",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "scale_max": "410.50278",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130",
                                            "gribNumBits": "16"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.52218881E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "scale_max": "1.85910903E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138",
                                            "gribNumBits": "16"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.52218881E-05",
                                            "gribleveltype": "109",
                                            "scale_max": "1.85910903E-05",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst apr2002 SIX-HOURLY mem01 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-0.006617144",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "scale_max": "0.03126534",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "133",
                                            "gribNumBits": "16"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.88534989E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "scale_max": "2.10272106E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155",
                                            "gribNumBits": "16"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-1.88534989E-06",
                                            "gribleveltype": "109",
                                            "scale_max": "2.10272106E-06",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "0.02743905",
                                            "grib_name": "wind10",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.393349",
                                            "gribparam": "171",
                                            "gribNumBits": "16"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "0.03815768",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "scale_max": "34.715351",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "216",
                                            "gribNumBits": "16"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-29.321854",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "scale_max": "31.394455",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "166",
                                            "gribNumBits": "16"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "-33.715561",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "scale_max": "33.211304",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "165",
                                            "gribNumBits": "16"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "7.13231429E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "scale_max": "0.03771548",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "168",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "188.52554",
                                            "grib_name": "t2mmx",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "337.35016",
                                            "gribparam": "201",
                                            "gribNumBits": "16"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "process": "50",
                                            "units": "unitless",
                                            "scale_min": "188.38184",
                                            "grib_name": "t2mmn",
                                            "subcenter": "255",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "325.39337",
                                            "gribparam": "202",
                                            "gribNumBits": "16"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "PDS_TimeRange": "10",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "process": "50",
                                            "scale_min": "188.5114",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "scale_max": "334.19153",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "167",
                                            "gribNumBits": "16"
                                        }
                                    }
                                },
                                "Z_10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "1.0",
                                    "long_name": "Height"
                                },
                                "Z_09": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_09",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "cm_down",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Depth"
                                },
                                "Z_08": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_08",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "cm_down",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Depth"
                                },
                                "Z_07": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_07",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "cm_down",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Depth"
                                },
                                "Z_06": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_06",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "cm_down",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Depth"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "mb",
                                    "gridtype": "0",
                                    "long_name": "pressure"
                                },
                                "sp_01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sp_01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "1.0"
                                },
                                "C": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "C",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "ids",
                                    "gridtype": "2",
                                    "long_name": "complex"
                                },
                                "Z_05": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_05",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "0.0"
                                },
                                "Z_04": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_04",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0"
                                },
                                "Y_01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Y_01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "degree_north",
                                    "gridtype": "0"
                                },
                                "Z_03": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_03",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "1.0",
                                    "long_name": "Height"
                                },
                                "sp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "1.0"
                                },
                                "Z_02": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_02",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "0.0"
                                },
                                "Z_01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m_above_gnd",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Height"
                                },
                                "Z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m_above_gnd",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Height"
                                },
                                "Y": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Y",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "degree_north",
                                    "gridtype": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "days since 2002-01-01 00:00:00",
                                    "gridtype": "0",
                                    "pointwidth": "0.25",
                                    "calendar": "standard",
                                    "defaultvalue": "303.75"
                                },
                                "X": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "X",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "degree_east",
                                    "gridtype": "1",
                                    "pointwidth": "2.8125",
                                    "modulus": "360.0"
                                },
                                "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/apr2002/SIX-HOURLY"
                            },
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type",
                                "SIXHOURLY"
                            ]
                        },
                        "aug2001": {
                            "iridl_type": "DataSet",
                            "iridl_ds_name": "aug2001",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "NC_GLOBAL": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "NC_GLOBAL",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "SIXHOURLYPressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem24PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem24griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem24/.griblist.html",
                                "SIXHOURLYmem24year0": "200111",
                                "SIXHOURLYmem24filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc24_%6d.01",
                                "SIXHOURLYmem23PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem23griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem23/.griblist.html",
                                "SIXHOURLYmem23year0": "200111",
                                "SIXHOURLYmem23filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc23_%6d.01",
                                "SIXHOURLYmem22PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem22griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem22/.griblist.html",
                                "SIXHOURLYmem22year0": "200111",
                                "SIXHOURLYmem22filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc22_%6d.01",
                                "SIXHOURLYmem21PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem21griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem21/.griblist.html",
                                "SIXHOURLYmem21year0": "200111",
                                "SIXHOURLYmem21filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc21_%6d.01",
                                "SIXHOURLYmem20PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem20griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem20/.griblist.html",
                                "SIXHOURLYmem20year0": "200111",
                                "SIXHOURLYmem20filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc20_%6d.01",
                                "SIXHOURLYmem19PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem19griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem19/.griblist.html",
                                "SIXHOURLYmem19year0": "200111",
                                "SIXHOURLYmem19filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc19_%6d.01",
                                "SIXHOURLYmem18PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem18griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem18/.griblist.html",
                                "SIXHOURLYmem18year0": "200111",
                                "SIXHOURLYmem18filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc18_%6d.01",
                                "SIXHOURLYmem17PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem17griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem17/.griblist.html",
                                "SIXHOURLYmem17year0": "200111",
                                "SIXHOURLYmem17filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc17_%6d.01",
                                "SIXHOURLYmem16PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem16griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem16/.griblist.html",
                                "SIXHOURLYmem16year0": "200111",
                                "SIXHOURLYmem16filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc16_%6d.01",
                                "SIXHOURLYmem15PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem15griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem15/.griblist.html",
                                "SIXHOURLYmem15year0": "200111",
                                "SIXHOURLYmem15filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc15_%6d.01",
                                "SIXHOURLYmem14PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem14griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem14/.griblist.html",
                                "SIXHOURLYmem14year0": "200111",
                                "SIXHOURLYmem14filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc14_%6d.01",
                                "SIXHOURLYmem13PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem13griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem13/.griblist.html",
                                "SIXHOURLYmem13year0": "200111",
                                "SIXHOURLYmem13filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc13_%6d.01",
                                "SIXHOURLYmem12PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem12griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem12/.griblist.html",
                                "SIXHOURLYmem12year0": "200111",
                                "SIXHOURLYmem12filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc12_%6d.01",
                                "SIXHOURLYmem11PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem11griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem11/.griblist.html",
                                "SIXHOURLYmem11year0": "200111",
                                "SIXHOURLYmem11filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc11_%6d.01",
                                "SIXHOURLYmem10PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem10griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem10/.griblist.html",
                                "SIXHOURLYmem10year0": "200111",
                                "SIXHOURLYmem10filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc10_%6d.01",
                                "SIXHOURLYmem09PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem09griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem09/.griblist.html",
                                "SIXHOURLYmem09year0": "200111",
                                "SIXHOURLYmem09filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc09_%6d.01",
                                "SIXHOURLYmem08PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem08griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem08/.griblist.html",
                                "SIXHOURLYmem08year0": "200111",
                                "SIXHOURLYmem08filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc08_%6d.01",
                                "SIXHOURLYmem07PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem07griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem07/.griblist.html",
                                "SIXHOURLYmem07year0": "200111",
                                "SIXHOURLYmem07filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc07_%6d.01",
                                "SIXHOURLYmem06PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem06griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem06/.griblist.html",
                                "SIXHOURLYmem06year0": "200111",
                                "SIXHOURLYmem06filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc06_%6d.01",
                                "SIXHOURLYmem05PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem05griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem05/.griblist.html",
                                "SIXHOURLYmem05year0": "200111",
                                "SIXHOURLYmem05filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc05_%6d.01",
                                "SIXHOURLYmem04PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem04griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem04/.griblist.html",
                                "SIXHOURLYmem04year0": "200111",
                                "SIXHOURLYmem04filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc04_%6d.01",
                                "SIXHOURLYmem03PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem03griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem03/.griblist.html",
                                "SIXHOURLYmem03year0": "200111",
                                "SIXHOURLYmem03filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc03_%6d.01",
                                "SIXHOURLYmem02PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem02griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem02/.griblist.html",
                                "SIXHOURLYmem02year0": "200111",
                                "SIXHOURLYmem02filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc02_%6d.01",
                                "SIXHOURLYmem01PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                "SIXHOURLYmem01griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.mem01/.griblist.html",
                                "SIXHOURLYmem01year0": "200111",
                                "SIXHOURLYmem01filepattern": "/mstore/iri/forecast/data/echam4/asst/aug01/30000fc01_%6d.01",
                                "SIXHOURLYgriblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.aug2001/.SIX-HOURLY/.griblist.html",
                                "description": "forecast starting aug2001",
                                "Conventions": "IRIDL"
                            },
                            "SIXHOURLY": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "SIX-HOURLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "total_air_column": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "total_air_column",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "QVI": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "QVI",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "vertically integrated specific humidity",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "0.01789523",
                                        "units": "kg/m2",
                                        "grib_name": "QVI",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "98.627937",
                                        "gribparam": "230",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "CLTOPMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "CLTOPMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "maximum height of convective cloud tops",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "8454.8867",
                                        "units": "Pa",
                                        "grib_name": "CLTOPMAX",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "100000.0",
                                        "gribparam": "217",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "cltm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "cltm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "cloud cover total mean[0-1]",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "cltm",
                                        "gribNumBits": "8",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "164",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    }
                                },
                                "top": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "top",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "SRAD0U": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRAD0U",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "shortwave radiation upward (top)",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-804.1272",
                                        "units": "W/m2",
                                        "grib_name": "SRAD0U",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "203",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Net Shortwave Radiation (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rst",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1169.9062",
                                            "gribparam": "178",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-402.04858",
                                            "units": "Wm-2",
                                            "grib_name": "rlt",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-72.137695",
                                            "gribparam": "179",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "solar flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-1755.1604",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0U",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "2748.3533",
                                                "gribparam": "105",
                                                "PTVersion": "128",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "solar flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAF0",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1172.3438",
                                                "gribparam": "187",
                                                "PTVersion": "128",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-402.04858",
                                                "units": "W/m2",
                                                "grib_name": "TRAF0",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-72.132324",
                                                "gribparam": "188",
                                                "PTVersion": "128",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        }
                                    }
                                },
                                "surface": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "surface",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "zg": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "zg",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Geopotential",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-7517.7578",
                                        "units": "m2 s-2",
                                        "grib_name": "zg",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "58762.242",
                                        "gribparam": "129",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "TSLIN": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TSLIN",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "TSLIN heat",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-96.058121",
                                        "units": "W/m2",
                                        "grib_name": "TSLIN",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "0.008560181",
                                        "gribparam": "220",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "TRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "longwave radiation upward (surface)",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-749.34399",
                                        "units": "W/m2",
                                        "grib_name": "TRADSU",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "-61.129639",
                                        "gribparam": "205",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "tauv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "V-component of Surface Wind Stress",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-5.2699871",
                                        "units": "Nm-2",
                                        "grib_name": "tauv",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "5.8405657",
                                        "gribparam": "181",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "tauu": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tauu",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "U-component of Surface Wind Stress",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-5.5451746",
                                        "units": "Nm-2",
                                        "grib_name": "tauu",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "9.1268787",
                                        "gribparam": "180",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "tas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "tas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "air temperature (surface)",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "181.30821",
                                        "units": "Kelvin_scale",
                                        "grib_name": "tas",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "340.80145",
                                        "gribparam": "169",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "stemp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "stemp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Surface Temperature",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "181.18692",
                                        "units": "unitless",
                                        "grib_name": "stemp",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "349.67676",
                                        "gribparam": "139",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "srun": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "srun",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "surface runoff",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "srun",
                                        "gribNumBits": "24",
                                        "gribleveltype": "1",
                                        "scale_max": "1.73226488E-06",
                                        "gribparam": "160",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "SRADSU": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SRADSU",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "shortwave radiation upward (surface)",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-676.07812",
                                        "units": "W/m2",
                                        "grib_name": "SRADSU",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "0.0078125",
                                        "gribparam": "204",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "soilm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soilm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "soil wetness",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "soilm",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "0.7168884",
                                        "gribparam": "140",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "SNMEL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SNMEL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "snow melt",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "0.0",
                                        "units": "m/s",
                                        "grib_name": "SNMEL",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "1.39148324E-06",
                                        "gribparam": "218",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "snd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "snd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Snow Depth",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "snd",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "16.913086",
                                        "gribparam": "141",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "slp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "slp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "151",
                                        "long_name": "mean sea level pressure",
                                        "gribleveltype": "102",
                                        "Z": "Z_08",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY hybrid_lev P",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "SICED": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SICED",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "sea ice depth",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "0.0",
                                        "units": "m",
                                        "grib_name": "SICED",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "1.5",
                                        "gribparam": "211",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "sfr": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sfr",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "sfc roughness",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "1.49999996E-05",
                                        "units": "m",
                                        "grib_name": "sfr",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "20.00148",
                                        "gribparam": "173",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "SEAICE": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "SEAICE",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "sea ice cover",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "0.0",
                                        "units": "unitless",
                                        "grib_name": "SEAICE",
                                        "gribNumBits": "8",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "210",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "pss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "pss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Surface Pressure",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "47520.363",
                                        "units": "Pa",
                                        "grib_name": "pss",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "112918.14",
                                        "gribparam": "134",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "prs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Snow Fall",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-7.05861028E-27",
                                        "units": "unitless",
                                        "grib_name": "prs",
                                        "gribNumBits": "24",
                                        "gribleveltype": "1",
                                        "scale_max": "1.12964665E-06",
                                        "gribparam": "144",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "prl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Large Scale Precipitation",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "0.0",
                                        "units": "m/s",
                                        "grib_name": "prl",
                                        "gribNumBits": "24",
                                        "gribleveltype": "1",
                                        "scale_max": "2.07356766E-06",
                                        "gribparam": "142",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "prcp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prcp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "260",
                                        "long_name": "Total Precipitation",
                                        "grib_name": "totprcp",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribNumBits": "24",
                                        "gribleveltype": "1",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "prc": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "prc",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Convective Precipitation",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-1.80700392E-23",
                                        "units": "m/s",
                                        "grib_name": "prc",
                                        "gribNumBits": "24",
                                        "gribleveltype": "1",
                                        "scale_max": "1.52658311E-06",
                                        "gribparam": "143",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "PERPW": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PERPW",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Primary wave mean period",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-459463.94",
                                        "units": "s",
                                        "grib_name": "PERPW",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "473930.75",
                                        "gribparam": "108",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "net": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "net",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "swflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "swflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Net Shortwave Radiation (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "Wm-2",
                                            "grib_name": "rss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "964.21875",
                                            "gribparam": "176",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "lwflx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lwflx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave flux",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-289.14624",
                                            "units": "Wm-2",
                                            "grib_name": "rls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "83.518982",
                                            "gribparam": "177",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "lsm": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "lsm",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "land-sea mask",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "0.0",
                                        "units": "(0,1)",
                                        "grib_name": "lsm",
                                        "gribNumBits": "8",
                                        "gribleveltype": "1",
                                        "scale_max": "1.0",
                                        "gribparam": "172",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "logpsl": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "logpsl",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Log Surface Pressure",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-0.03160577",
                                        "units": "unitless",
                                        "grib_name": "logpsl",
                                        "gribleveltype": "1",
                                        "gribNumBits": "16",
                                        "scale_max": "16.25857",
                                        "gribparam": "152",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "hfss": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfss",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Surface Flux of Sensible Heat",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-967.3894",
                                        "units": "Wm-2",
                                        "grib_name": "hfss",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "1555.7266",
                                        "gribparam": "146",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "hfls": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hfls",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Surface Flux of Latent Heat",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-2187.0928",
                                        "units": "Wm-2",
                                        "grib_name": "hfls",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "scale_max": "275.37305",
                                        "gribparam": "147",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "evs": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "evs",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Evaporation",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-8.74557202E-07",
                                        "units": "m (H2O)",
                                        "grib_name": "evs",
                                        "gribNumBits": "24",
                                        "gribleveltype": "1",
                                        "scale_max": "1.10111927E-07",
                                        "gribparam": "182",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "dpsdy": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdy",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "274",
                                        "long_name": "Meridional Deriv. of Surface Pres.",
                                        "grib_name": "dpsdy",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "dpsdx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "dpsdx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "273",
                                        "long_name": "Zonal Deriv. of Surface Pres.",
                                        "grib_name": "dpsdx",
                                        "units": "kilogram meter-2 second-2",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "clear_sky": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "clear_sky",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "upward": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "upward",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "solar flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-2310.3999",
                                                "units": "W/m2",
                                                "grib_name": "SRAFSU",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "2661.9663",
                                                "gribparam": "106",
                                                "PTVersion": "128",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-338603.44",
                                                "units": "W/m2",
                                                "grib_name": "TRAFSU",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "680255.56",
                                                "gribparam": "107",
                                                "PTVersion": "128",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "solr": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "solr",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "solar flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "W/m2",
                                                "grib_name": "SRAFS",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "968.32812",
                                                "gribparam": "185",
                                                "PTVersion": "128",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-289.14624",
                                                "units": "W/m2",
                                                "grib_name": "TRAFS",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "47.128067",
                                                "gribparam": "186",
                                                "PTVersion": "128",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        }
                                    },
                                    "ALBEDO": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ALBEDO",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Albedo (surface)",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "0.06999999",
                                        "units": "unitless",
                                        "grib_name": "ALBEDO",
                                        "gribNumBits": "8",
                                        "gribleveltype": "1",
                                        "scale_max": "0.8004687",
                                        "gribparam": "175",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    }
                                },
                                "soil": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "soil",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "TDCL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "TDCL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "soil temp level CL",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "209.27872",
                                        "units": "m (H2O)",
                                        "grib_name": "TDCL",
                                        "gribNumBits": "16",
                                        "gribleveltype": "111",
                                        "scale_max": "310.66962",
                                        "gribparam": "183",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "td": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "deep soil temperature",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "208.64293",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td",
                                        "gribNumBits": "16",
                                        "gribleveltype": "111",
                                        "scale_max": "314.47345",
                                        "gribparam": "170",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    }
                                },
                                "PressureLevel": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "PressureLevel",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Temperature",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "gribNumBits": "16",
                                        "gribparam": "130",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "vorticity",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "gribNumBits": "16",
                                        "gribparam": "138",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Specific Humidity",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-0.009193584",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "gribNumBits": "16",
                                        "scale_max": "0.03196654",
                                        "gribparam": "133",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Divergence",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "units": "s-1",
                                        "grib_name": "div",
                                        "gribNumBits": "16",
                                        "gribparam": "155",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribleveltype": "100",
                                        "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY hybrid_lev P 0000 1 Aug 2001",
                                        "missing_value": "NaN",
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    }
                                },
                                "mem24": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem24",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0515791",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "95.502472",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8489.3477",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-787.68994",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1169.4062",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-396.04932",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-76.956299",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1390.3782",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1969.865",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.0625",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-396.04932",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-77.276611",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-89.419418",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008499146",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-731.49487",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-65.97583",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.6230211",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.9684801",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.209548",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.2490902",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "184.83569",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "339.00549",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "184.77106",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "344.71838",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.06470668E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-664.8208",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7168884",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "9.91858542E-07",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.334717",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48363.43",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112307.42",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-2.52435502E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.92119067E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.72185389E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.35525294E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.39814790E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-426050.25",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "418790.38",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "958.57812",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-280.76025",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "72.521652",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03153695",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258421",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-789.47144",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "837.12354",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1101.0654",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "204.50122",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.40285248E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.17712191E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1463.4897",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2244.52",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-266424.25",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "622635.56",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "959.9375",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-280.76025",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "44.380951",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.13875",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.9024",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.23442",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "314.11435",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.002913667",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02878369",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-20.026999",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.38504",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.55357629E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81051564E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.55357629E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81051564E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem24 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.002913667",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02878369",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.91086087E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84239400E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.91086087E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84239400E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.02478118",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.209949",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0514927",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.221008",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-30.444702",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "28.744659",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-33.771286",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.82579",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8.24602466E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03604253",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "188.30717",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "334.37115",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "187.95168",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "326.19702",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "188.26764",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "330.0954",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem23": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem23",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03720367",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "95.348129",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8534.6133",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-797.84326",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1165.75",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-391.69604",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-74.762695",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1276.0691",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2142.7576",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.5625",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-391.69604",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-74.708008",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-89.977707",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008331299",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-749.34399",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-64.113281",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.4691896",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.7177048",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.6885023",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.0899515",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.56169",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "340.80145",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.47786",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "341.07272",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.73226488E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-663.99341",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.713501",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.04546780E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.595215",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48206.766",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112398.88",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.68290328E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.91681180E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.68921872E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.44560339E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.40481200E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-430421.62",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "417228.81",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "960.84375",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-248.60091",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "66.670807",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03160577",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258512",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-967.3894",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "982.91675",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1269.7117",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "183.58716",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.07722120E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.34115986E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1749.0522",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1999.9668",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-275271.25",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "636417.75",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "960.84375",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-248.60091",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "40.67305",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.38464",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.89636",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.55934",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.1311",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005682319",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.0286475",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.864216",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.59805",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.59922347E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.77089441E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.59922347E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.77089441E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem23 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005682319",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.0286475",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.84372652E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.13637372E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.84372652E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.13637372E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.03335582",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.225739",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.071473",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "38.248302",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-30.899109",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.830734",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-37.031921",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.708282",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "4.35252616E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03675942",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "187.27806",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "337.17786",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "187.1416",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "325.75299",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "187.27708",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "331.01605",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem22": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem22",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03692907",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "94.323853",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8515.7695",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-793.53101",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1169.1562",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-400.49829",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-74.707275",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1539.7163",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2159.0369",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.4375",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-400.49829",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-74.502686",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-85.784531",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.00730896",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-743.33936",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-64.859131",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.2901068",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.3925591",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.6374302",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.4800501",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "184.02536",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "340.21634",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "184.01198",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "344.56479",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.13227532E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-668.19702",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007568359",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.713501",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.13231363E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.460693",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48291.098",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112039.11",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.68290328E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.08177459E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "2.07356766E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.36218557E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-442588.0",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "450630.0",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "957.5625",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-269.22876",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "72.372345",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.030943",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258387",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-936.20459",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1117.96",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1505.4851",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "184.03516",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-6.02001364E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.35907406E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-2310.3999",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2110.7935",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-230436.88",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "625885.56",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "957.5625",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-269.22876",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "43.826279",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.45621",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.75775",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.58087",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.66156",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.007422742",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03196654",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.902422",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.83179",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.56539427E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84755518E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.56539427E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84755518E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem22 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.007422742",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03196654",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-2.11200745E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.04741946E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-2.11200745E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.04741946E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.03534606",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.949249",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.05071428",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.748497",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-31.307877",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.673187",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-35.001251",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.231445",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "6.58673684E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.04701485",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "187.73802",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "341.63062",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "187.22868",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "327.68744",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "187.25793",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "341.6304",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem21": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem21",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03514523",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "93.860741",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8459.0781",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-798.42993",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1167.0",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-390.24585",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-78.552246",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1547.145",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2017.229",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.9375",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-390.24585",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-79.715332",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-87.295029",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.006958008",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-718.70532",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-69.06958",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.8384171",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.8168526",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.4456549",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.3837366",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "186.94283",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "337.34583",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "186.89653",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "343.29715",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.39112865E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-666.56787",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.713501",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.39148324E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.364258",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "47520.363",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112018.95",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.68290328E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.22187451E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.49449102E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-9.93852012E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.26136570E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-447243.94",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "414588.62",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "956.96875",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-254.3614",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "66.868317",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03069728",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258463",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-686.51904",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "922.63208",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1225.7649",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "192.92139",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.90149034E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.71449322E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1822.0012",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2211.522",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-248962.81",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "612509.5",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "960.67188",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-259.15576",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "36.885666",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.93272",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.3844",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.26697",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "314.36783",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.004195653",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02849989",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.933016",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.91534",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.52236635E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89374841E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.52236635E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89374841E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem21 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.004195653",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02849989",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.84359021E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.80090649E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.84359021E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.80090649E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.03639754",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.792423",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06254905",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "36.297112",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-29.796143",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "30.426712",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-35.246964",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.173058",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.20778395E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03466794",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "190.26938",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "336.55615",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "189.54178",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "325.43985",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "189.77464",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "335.83221",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem20": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem20",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03866864",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "98.627937",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8502.2852",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-793.59009",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1169.0312",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-390.06738",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-75.714844",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1418.8621",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2034.4001",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.875",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-390.06738",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-75.566406",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-88.249756",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.00692749",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-712.6687",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-67.05249",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.1583366",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "3.8886576",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.4079924",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.2083845",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "185.63857",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "336.74167",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "185.61304",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "343.9483",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.10779649E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-662.01245",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.713501",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.10222027E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.255859",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "47987.711",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112612.22",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.04871003E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.31551631E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.77777281E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-8.13151668E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.20625327E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-378904.62",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "434450.81",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "961.90625",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-251.00494",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "78.400284",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03053686",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258463",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-816.09888",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "971.64209",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1386.8057",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "182.36914",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.54544783E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.29262126E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1820.7454",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1875.1362",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-255317.38",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "640387.0",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "961.90625",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-251.00494",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "33.920502",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.27872",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.81421",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "208.64293",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.55176",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.004477467",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02860137",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.975584",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.82178",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.56351362E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.88245613E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.56351362E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.88245613E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem20 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.004477467",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02860137",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.99238389E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.11599604E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.99238389E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.11599604E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.02152784",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.066631",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0398512",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.377182",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-31.358337",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.424835",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-31.422211",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.353348",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "9.24286496E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.04027221",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "188.08136",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "336.24277",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "187.71545",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "325.54608",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "187.96584",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "334.6767",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem19": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem19",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.04262778",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "96.147697",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8483.4961",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-804.1272",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1168.1562",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-395.77783",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-79.622803",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1755.1604",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2748.3533",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.3125",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-395.77783",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-78.857178",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-90.675964",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008544922",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-725.75952",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-70.807861",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.2699871",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.6966934",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.6815405",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.1877384",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "188.13304",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "338.2439",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "188.12976",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "344.54047",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.16362548E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-673.37842",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007568359",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.6533661",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.14110298E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.604248",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48373.738",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112613.75",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.68290328E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.32089439E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.59740284E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-9.48676946E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.20978598E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-437488.44",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "450934.75",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "960.96875",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-269.75439",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "67.220795",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03112814",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.25857",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-742.13574",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "907.5188",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1216.137",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "229.40137",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.86299086E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "9.17306977E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-2029.6868",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2240.6074",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-279580.19",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "627778.81",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "965.17188",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-269.85059",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "25.930542",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.44554",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.23267",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.85231",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "314.00629",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005375572",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03047922",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.650827",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.93295",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.58417952E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.91357412E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.58417952E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.91357412E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem19 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005375572",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03047922",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.97063923E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.96933070E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.97063923E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.96933070E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.01865815",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.020447",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.05361824",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.51923",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-30.863419",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.720856",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-33.712601",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.012161",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.22654171E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.04571583",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "190.82932",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "335.22974",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "190.51503",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "322.69717",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "190.68375",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "332.94482",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem18": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem18",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.04029992",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "94.985886",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8479.9219",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-791.94604",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1167.875",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-380.86963",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-76.989502",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1574.0615",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2476.8088",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.75",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-380.86963",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-77.012939",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-91.784912",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007598877",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-726.97412",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-68.281494",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.4126024",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.1130314",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.5127096",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.9088888",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "186.47401",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "338.21973",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "186.28317",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "346.22266",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.42716851E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-660.47607",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007324219",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7168884",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.18336175E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.377441",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48142.379",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112397.72",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.43031171E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.58325292E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-9.26089413E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.27756857E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-449838.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "452322.75",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "957.95312",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-273.94336",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "74.904404",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03086661",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258289",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-737.57422",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1134.3591",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1299.5688",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "275.37305",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.19661228E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.10111927E-07",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-2308.4822",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2132.2307",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-279367.25",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "661374.75",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "961.34375",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-273.94336",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "40.164474",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.13966",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.28613",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.25827",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.74768",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005396057",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03098723",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.932522",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.70508",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.53264718E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83864886E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.53264718E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83864886E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem18 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005396057",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03098723",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.93689903E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.97950067E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.93689903E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.97950067E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.03311963",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.041348",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.05248883",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.790573",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-30.127609",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.967865",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-32.400864",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.614426",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "5.21389438E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.04498143",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "189.2722",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "335.13983",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "188.91663",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "325.72382",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "188.93127",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "328.41077",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem17": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem17",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.04656384",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "94.300041",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8536.8164",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-794.40405",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1169.2812",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-393.19922",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-77.151367",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1325.6548",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2206.2202",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1172.0312",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-393.19922",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-77.081055",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-88.989639",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008285522",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-725.81079",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-65.629883",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.5079012",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.3560152",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.6323547",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.6262102",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "184.60263",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "338.15851",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "184.51683",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "344.16797",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.21284927E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-659.77319",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.6838379",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.04965875E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "14.905762",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48378.395",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112639.62",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7.05861028E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.29098645E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.86662794E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.23016923E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-439614.06",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "473930.75",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "957.5625",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-266.25781",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "78.572922",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.02918809",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258448",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-743.8877",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1099.7068",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1300.1018",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "185.93433",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.19874277E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.43515045E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1589.5623",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1996.5566",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-291494.44",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "627660.38",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "959.29688",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-266.25781",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "39.36554",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.02803",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.44403",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.17677",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "314.12576",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005992085",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02972812",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-20.006802",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.789",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.48722156E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.86130055E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.48722156E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.86130055E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem17 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005992085",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02972812",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.95227199E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.06973345E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.95227199E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.06973345E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.02887729",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.402393",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.04415586",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.099499",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-28.833679",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.03595",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-32.353516",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.628235",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "7.68371251E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03598361",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "187.52017",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "336.33044",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "187.07755",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "323.3844",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "187.14769",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "329.38599",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem16": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem16",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03757982",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "93.427788",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8494.6328",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-789.25269",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1167.8438",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-400.29956",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-74.322754",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1341.4268",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1929.3428",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.4688",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-400.29956",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-74.408691",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-88.91153",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008102417",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-720.39819",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-64.419922",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.2804918",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.1886501",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.5451746",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.4006453",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.78362",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "336.76379",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.63301",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "340.93335",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.31558113E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-666.59595",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7168884",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.13729038E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.489746",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48064.145",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112164.3",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.68290328E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.02712100E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.56261217E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.03902716E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.32244884E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-400468.88",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "460543.81",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "964.21875",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-266.47876",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "78.336655",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03146613",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258392",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-729.94092",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1555.7266",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-2187.0928",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "192.21582",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-8.74557202E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.68636710E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1770.6411",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2661.9663",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-245368.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "616549.75",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "964.3125",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-266.47876",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "31.741013",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.86035",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.46973",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "208.98189",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.31836",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.004273631",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02835153",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-20.146965",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.74237",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.58765470E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.87278783E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.58765470E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.87278783E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem16 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.004273631",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02835153",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.92746325E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.05960441E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.92746325E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.05960441E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.03357822",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "36.621872",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.07019055",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "36.943516",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-30.213699",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.371399",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-36.071442",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.867691",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "3.04173291E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03541768",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "187.52611",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "342.06573",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "187.33499",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "327.37341",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "187.33957",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "332.763",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem15": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem15",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03781841",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "93.111786",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8516.1992",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-800.62622",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1169.4688",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-390.55298",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-72.460449",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1515.8213",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1956.3811",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.3125",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-390.55298",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-72.569824",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-92.975861",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007247925",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-747.16357",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-61.129639",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.0893764",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "3.9988155",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.7796535",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.2585025",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "181.30821",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "339.69598",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "181.18692",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "349.67676",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.11060331E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-669.08594",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.713501",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.01575279E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.945801",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "47740.953",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112200.95",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.76465199E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.34864875E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.86817704E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.33303115E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-379616.19",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "423566.5",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "954.70312",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-289.14624",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "69.33429",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03094388",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258448",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-732.65942",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "995.04443",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1501.7451",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "185.42041",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-6.00505871E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.41432302E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1955.2976",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2287.0176",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-295374.38",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "667537.81",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "964.45312",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-289.14624",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "44.952499",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.20049",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.78687",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.37515",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.79745",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.008126404",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02935555",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-20.127817",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.65192",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.55383223E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83452175E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.55383223E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83452175E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem15 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.008126404",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02935555",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.99682904E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.98379075E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.99682904E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.98379075E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.02516389",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "38.52388",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03494264",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "40.877903",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-31.283615",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "29.015488",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-31.667114",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.644409",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "5.39492753E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.04398182",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "185.24361",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "335.74231",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "184.86858",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "324.54288",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "185.02313",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "333.32431",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem14": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem14",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.04341244",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "95.39534",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8454.8867",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-792.27832",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1169.2812",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-392.06763",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-75.604248",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1325.8257",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2089.9668",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.5312",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-392.06763",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-75.476318",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-91.577621",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008483887",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-744.97925",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-64.206543",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.7931738",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "3.8570013",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.0254936",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.5476179",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.63739",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "338.8371",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.52348",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "344.73541",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.28080569E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-671.36621",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007568359",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.6760406",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.22413621E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.394775",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48644.391",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112309.22",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.41163143E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.27885072E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.45206798E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.62630428E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.36358608E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-423705.94",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "430251.56",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "960.54688",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-272.30322",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "64.414673",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03115814",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258411",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-678.65991",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "886.29077",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1350.8518",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "217.31372",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.40167775E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.68948860E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1842.1414",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2125.9009",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-259423.19",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "610488.0",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "960.54688",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-272.30322",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "32.1008",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.31915",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.49884",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.47",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "314.26013",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005901825",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03097559",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.934704",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.59531",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.58556286E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.74158631E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.58556286E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.74158631E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem14 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005901825",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03097559",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.96881388E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84601595E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.96881388E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84601595E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.03226512",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.036728",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06386524",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.823467",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-30.993942",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.099915",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-34.644958",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.698807",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "6.13366637E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.04552379",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "186.83087",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "334.76001",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "186.39818",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "328.04449",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "186.39818",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "333.13101",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem13": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem13",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03564486",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "94.11174",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8515.1016",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-789.89673",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1169.625",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-392.23486",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-75.183594",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1320.4421",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2562.6748",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.6875",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-392.84131",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-75.183594",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-88.6138",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.00730896",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-712.70361",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-64.162842",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.327013",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.5054665",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.4558277",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.031085",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.57344",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "336.41449",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.56461",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "342.89948",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.15190619E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-673.26074",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.6700287",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.11860572E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.913086",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48181.398",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112144.56",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.41163143E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.65660638E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "2.04605590E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.30213141E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-390574.5",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "432374.69",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "960.01562",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-273.32959",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "79.655411",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03006638",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258377",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-702.77466",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1055.2634",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1401.0095",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "217.47656",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.60224521E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.69583801E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1774.9604",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2291.647",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-270785.56",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "635046.44",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "960.29688",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-275.37158",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "33.820465",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.88824",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.52533",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "208.96399",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "314.0733",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.003840312",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.0281175",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.91927",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.84769",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.50277456E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.80927855E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.50277456E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.80927855E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem13 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.003840312",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.0281175",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.97284112E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.09316545E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.97284112E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.09316545E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.03696674",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.011555",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06446868",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "38.238159",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-34.906662",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "29.399948",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-37.123688",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.135361",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8.47624619E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.04707075",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "186.95497",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "337.9136",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "186.7453",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "325.16156",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "186.79736",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "330.05609",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem12": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem12",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.04613349",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "97.391968",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8503.543",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-798.17676",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1169.75",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-387.58276",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-78.664062",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1646.2141",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2198.6804",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1170.8125",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-387.58276",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-77.842773",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-88.062744",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007766724",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-721.05884",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-66.0354",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.7822781",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "3.8954601",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.3011112",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.0362921",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "184.8522",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "337.71127",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "184.80034",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "344.41577",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.19972003E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-665.6106",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.713501",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.16115552E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.677246",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48120.145",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112165.38",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.76465199E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.56876239E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.79484289E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.19127185E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-403988.94",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "401838.69",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "955.65625",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-276.90845",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "64.116653",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03076117",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258467",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-665.71411",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1008.9993",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1384.4314",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "233.49976",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.53595385E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "9.33701472E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1729.8469",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2162.7825",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-273577.12",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "598350.38",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "957.07812",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-277.61548",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "42.648087",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.11128",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.19135",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.36104",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "314.08417",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005880672",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03161234",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.834826",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.65158",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.54139525E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.77415368E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.54139525E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.77415368E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem12 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005880672",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03161234",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.90100195E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89693742E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.90100195E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89693742E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.03310617",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.160297",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06876171",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.452457",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-30.196259",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "30.901093",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-36.485641",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.539093",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.54276165E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03426967",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "188.79115",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "333.86722",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "188.40823",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "324.8783",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "188.42776",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "329.74554",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem11": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem11",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03967568",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "94.852394",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8478.5078",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-795.50439",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1167.8125",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-391.86255",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-72.137695",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1246.5061",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2439.1064",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.6562",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-391.86255",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-72.132324",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-85.557663",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-743.8125",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-61.164062",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.4239473",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.0922327",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.1541491",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "8.7743645",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "181.40698",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "340.46368",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "181.42432",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "341.98102",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.22391953E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-674.42578",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007568359",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7168884",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.22393249E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "14.274902",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "47735.629",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112351.11",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.41163143E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.92858338E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.64604262E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.29629620E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-422030.88",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "425384.69",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "955.57812",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-264.84058",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "74.176193",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03100655",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.25843",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-765.00415",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "955.36914",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1385.5881",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "238.27759",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.54057863E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "9.52805124E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1895.8816",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1897.4175",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-338603.44",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "619909.62",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "968.32812",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-264.84058",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "31.541702",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.5632",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.88385",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.80731",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.69614",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.004879571",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03103255",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.900963",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.866",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.57704853E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.86239595E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.57704853E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.86239595E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem11 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.004879571",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03103255",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-2.14626334E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.85671058E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-2.14626334E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.85671058E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.02009317",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "39.309048",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.04949378",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "40.378372",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-29.43248",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "29.196594",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-37.760162",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.736313",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "5.84143258E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03559441",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "184.89082",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "337.73474",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "184.77397",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "328.68161",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "184.80574",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "331.90924",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03481611",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "97.61322",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8529.7969",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-797.44556",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1168.5625",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-388.19971",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-73.275879",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1280.1138",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1853.1277",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.125",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-388.19971",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-73.275879",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-92.550385",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008560181",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-723.83008",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-63.406006",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.9519606",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "3.7605314",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.8483353",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.38908",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "182.98566",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "338.12152",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "182.98219",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "345.66415",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.19349033E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-670.03857",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7168579",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.09762186E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.146484",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "47991.168",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112689.19",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.46262174E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.40812904E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-8.13151668E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.30215869E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-416350.44",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "419455.19",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "951.96875",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-248.24506",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "67.935791",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.0307496",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258442",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-813.79443",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "796.40723",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1319.729",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "174.1665",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.27722705E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.96421694E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1995.3215",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1890.1892",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-282437.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "620205.56",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "955.15625",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-248.59332",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "28.593384",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.17728",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.20267",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.34129",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.67273",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005055789",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.0284679",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.813108",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.6091",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.59209740E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82207696E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.59209740E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82207696E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem10 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005055789",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.0284679",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.93745200E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.92124548E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.93745200E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.92124548E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.02283666",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.099304",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03813545",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.818707",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-29.59758",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.472214",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-31.49202",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.012573",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "4.87873102E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03745127",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "186.27261",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "332.62436",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "185.98476",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "325.96631",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "186.05264",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "329.47073",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem09": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem09",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.04558111",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "93.092339",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8516.7188",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-795.91895",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1169.3125",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-387.2876",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-75.178223",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1466.3154",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1818.3999",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1170.0312",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-387.2876",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-75.178223",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-93.156418",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.006851196",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-734.52686",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-65.01709",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.1710682",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.5248823",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.9179029",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.5852337",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "184.15056",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "337.65311",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "184.11711",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "343.74295",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.24514531E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-659.69434",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.6737213",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.04727224E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.491455",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48447.027",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112354.61",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-8.82326093E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.72214378E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.56134979E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.80700392E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.38450935E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-449870.5",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "425841.5",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "961.01562",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-251.65804",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "70.943085",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03069667",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258476",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-756.69165",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1038.8188",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1301.1301",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "224.625",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.20285482E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.98212704E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1837.9265",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1983.928",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-296737.31",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "680255.56",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "961.65625",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-252.15152",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "27.851303",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.3338",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.53302",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.67659",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.52258",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.003838741",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02833218",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-20.030651",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.92191",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.54400313E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.86621437E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.54400313E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.86621437E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem09 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.003838741",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02833218",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.97522195E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.02622186E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.97522195E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.02622186E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.03373763",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.130836",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06036199",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.894215",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-31.368362",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "27.918365",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-32.213181",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.713669",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "5.82630548E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03743863",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "188.04436",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "336.349",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "187.74263",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "328.67679",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "187.75108",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "333.51392",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem08": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem08",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03517635",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "95.668839",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8489.3867",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-797.30176",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1167.9688",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-393.12793",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-73.209473",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1296.4817",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2333.6589",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1172.3438",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-393.12793",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-72.771973",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-89.627426",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007568359",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-739.19214",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-63.5354",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.5383425",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.691494",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.9987555",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.9848824",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.09326",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "339.914",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.04968",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "345.01083",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.09911730E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-669.67725",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7123108",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.08807581E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "14.861084",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48052.77",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112509.86",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.68290328E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.12655435E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.32940966E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.27027931E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-431171.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "452631.81",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "962.57812",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-267.03491",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "70.165039",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03109925",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258337",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-792.6543",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "924.44702",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1332.509",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "206.58179",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.32832985E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.26071300E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-2048.1848",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2205.4263",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-231804.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "602698.62",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "962.57812",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-267.03491",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "40.433105",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.31403",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.05475",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.47182",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "314.07916",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.004782464",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02999657",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-20.101488",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.48999",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.62243377E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.87354763E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.62243377E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.87354763E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem08 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.004782464",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02999657",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.88952367E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.21377854E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.88952367E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.21377854E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.03202853",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.950382",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.05985192",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "36.857407",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-32.390259",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.587128",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-33.839127",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.385681",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "7.58664100E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.04277638",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "186.50656",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "337.29031",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "186.15089",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "327.3772",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "186.15295",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "334.47058",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem07": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem07",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03832833",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "90.852272",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8535.9062",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-791.5813",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1169.9062",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-386.7373",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-79.259277",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1475.4744",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2404.1624",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.7812",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-386.7373",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-78.759277",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-89.694946",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007583618",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-735.31592",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-69.179199",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.6686745",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.2017612",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.9405413",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.6369982",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "187.05103",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "339.61963",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "187.0751",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "343.34119",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.33110882E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-668.64185",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.713501",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.33135472E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.026855",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48038.598",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112239.06",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.68290328E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.04293405E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.58471107E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.52658311E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-424241.5",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "426823.94",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "955.32812",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-286.44507",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "67.942307",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.02993716",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258459",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-719.15576",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1263.5232",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1547.1462",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "261.24585",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-6.18660408E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.04467063E-07",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1875.719",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2311.5061",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-259819.69",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "628105.12",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "958.3125",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-286.44507",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "36.897003",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.23271",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.09015",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.54002",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "314.16748",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.009193584",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03132462",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.965832",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.84216",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.56791048E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82082113E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.56791048E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82082113E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem07 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.009193584",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03132462",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-2.04300068E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.21615664E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-2.04300068E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.21615664E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.04265173",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "36.745544",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06084841",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.155041",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-28.288895",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.214691",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-34.096786",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.773941",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.41364865E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03507928",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "190.8121",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "339.08405",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "190.59053",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "325.4097",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "190.59335",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "330.60425",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem06": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem06",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03096338",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "95.142593",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8536.4219",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-796.47363",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1166.5312",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-396.86499",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-75.921875",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1360.0461",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2106.978",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1170.7812",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-396.86499",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-75.523438",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-91.997559",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008331299",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-742.34717",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-64.546143",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.1999226",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "3.6102495",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.3593464",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.8863707",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.90764",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "340.25714",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.95682",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "346.28864",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.32296202E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-676.07812",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.713501",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.14450813E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "13.836914",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48314.953",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112221.95",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "9.81286917E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.62623110E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-9.93852012E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.18282969E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-416094.5",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "469685.94",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "951.45312",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-286.07373",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "73.290451",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.02953475",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258356",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-726.09644",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "876.35938",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1258.9399",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "187.48193",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.03414810E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.49695914E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1929.0986",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2320.7759",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-260272.0",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "615904.81",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "953.17188",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-286.07373",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "43.853546",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.95282",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.66962",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.01553",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "314.47345",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005304933",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03128016",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-20.251757",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.55316",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.60652780E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.74555298E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.60652780E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.74555298E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem06 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005304933",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03128016",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.94677341E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.99798797E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.94677341E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.99798797E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.03203366",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.566845",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.05675222",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.749786",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-32.0616",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.091446",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-32.982742",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.40918",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.00038164E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03413464",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "186.68591",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "336.19189",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "186.37849",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "324.21036",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "186.57793",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "331.37372",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem05": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem05",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.04937177",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "96.610733",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8458.6719",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-792.0022",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1169.4062",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-393.91064",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-81.494141",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1295.9902",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1943.9036",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.3438",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-393.91064",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-81.304443",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-90.818863",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008377075",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-730.37891",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-70.261719",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.6293125",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.8304205",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.7192116",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.8193035",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "187.67201",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "338.69037",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "187.50378",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "346.84717",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.44878959E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-672.62451",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.6533661",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.00344187E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "13.029785",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "47954.977",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112573.76",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.68290328E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.12964665E-06",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.75460275E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.47952414E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-397096.38",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "420577.75",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "957.78125",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-266.5376",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "78.044312",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.02918461",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258356",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-729.16675",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "940.66455",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1494.9124",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "169.15601",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.97773635E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.76378988E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1534.3352",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2079.8467",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-263260.69",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "646724.44",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "957.78125",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-266.5376",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "40.568069",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.21835",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.10703",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.37245",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.96429",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005054839",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02893314",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.715223",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.58044",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.56504011E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.92037551E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.56504011E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.92037551E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem05 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005054839",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02893314",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-2.23289680E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83103657E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-2.23289680E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83103657E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.02818051",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "36.827576",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.04851267",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "38.137196",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-30.074142",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "30.187592",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-34.134872",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "36.860809",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.33118533E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03538367",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "191.79327",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "337.14325",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "191.47289",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "326.70844",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "191.63455",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "336.60611",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem04": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem04",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.04316976",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "96.671486",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8489.6914",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-793.57739",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1166.8125",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-391.84741",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-72.695312",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1523.9856",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2128.9626",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1170.7188",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-391.84741",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-72.497803",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-96.058121",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007705688",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-729.95459",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-62.006592",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.5929079",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "3.6767759",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.1299191",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.2482176",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "181.97424",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "338.78394",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "181.92728",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "344.54883",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.41487612E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-664.19482",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.650177",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.08173117E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.731689",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "47887.219",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112918.14",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-8.82326093E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.68250743E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.95040479E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.17477475E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-459463.94",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "404358.94",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "955.34375",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-259.17798",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "76.202774",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.029931",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258438",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-948.36133",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "892.69873",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1302.668",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "163.44092",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.20900414E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.53582504E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-2028.8489",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2084.3997",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-244997.38",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "614864.81",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "968.23438",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-259.17798",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "29.983902",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.08191",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.35199",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.14067",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "314.22906",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005579222",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03029954",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-20.02375",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.55765",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.60663931E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79887211E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.60663931E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79887211E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem04 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005579222",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03029954",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.83953864E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.08880283E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.83953864E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.08880283E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.0304205",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.512447",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.04414386",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.626076",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-31.335159",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "29.731552",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-30.621353",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.30899",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "2.88214537E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03559331",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "186.56049",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "335.46146",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "186.31674",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "326.5051",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "186.3409",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "335.46252",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem03": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem03",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.04408936",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "94.75106",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8476.8711",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-788.18872",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1167.5625",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-386.7915",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-77.394531",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1411.9531",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1894.4688",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1171.5",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-388.10913",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-77.582031",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-88.659805",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008056641",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-732.12573",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-67.439209",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.0576048",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "3.7733574",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.4367619",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.6182814",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "185.90761",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "339.19104",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "185.8073",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "344.3941",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.13413591E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-667.49414",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.713501",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.11880945E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "13.670654",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48209.648",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "111979.96",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-8.82326093E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.80616381E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.80616041E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.35525294E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.36802930E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-405845.5",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "449725.06",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "962.09375",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-257.51489",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "61.782867",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03097113",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258484",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-773.71729",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1126.4158",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1314.6858",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "159.41724",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.25706071E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.37476205E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1690.6228",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1973.9719",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-253891.38",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "672955.56",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "962.09375",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-257.77808",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "37.908859",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.35362",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.24426",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.63432",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "314.22018",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005324714",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02871624",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-20.166105",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.79279",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.56248698E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81628002E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.56248698E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81628002E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem03 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005324714",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02871624",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.75606294E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82671863E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.75606294E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82671863E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.03627097",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "36.111164",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0559615",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.730503",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-29.14978",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.050873",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-34.851486",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.491928",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "9.62239710E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03847663",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "189.83794",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "337.38367",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "189.5327",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "327.47968",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "189.54568",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "331.23303",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem02": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem02",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.03440752",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "93.901711",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8525.7773",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-797.80029",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1168.4062",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-402.04858",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-72.82959",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1523.6743",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1893.4158",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1170.4062",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-402.04858",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-72.774902",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-92.549927",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007110596",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-732.04639",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-61.397461",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.1113863",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.0237293",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.0230522",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.3839722",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "181.52063",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "339.04034",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "181.45631",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "345.00369",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.33042113E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-665.43408",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.6829071",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.00614852E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "14.756348",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "48478.594",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112412.94",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "9.21152207E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.43562886E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.33994979E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-428278.62",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "440287.44",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "961.51562",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-278.5354",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "75.268692",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03047107",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.2584",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-759.37646",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "917.7998",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1271.1587",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "169.76416",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.08300786E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.78826098E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1845.0322",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2044.8064",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-286479.25",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "645005.56",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "961.51562",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-280.38721",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "47.128067",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.85835",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.01105",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "208.96236",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.90906",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005917057",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02891647",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.552084",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.75446",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.59009705E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.80108382E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.59009705E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.80108382E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem02 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005917057",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02891647",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.89773743E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.92265566E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.89773743E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.92265566E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.03003817",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.897312",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0557458",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.426144",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-31.194809",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.65184",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-32.242813",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.640976",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "2.75820398E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03799369",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "185.44023",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "338.68842",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "185.31055",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "327.33725",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "185.41882",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "331.63998",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.01789523",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "95.775757",
                                            "PTVersion": "128",
                                            "gribparam": "230",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "8495.4414",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "PTVersion": "128",
                                            "gribparam": "217",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-795.38623",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "203",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1167.2812",
                                                "PTVersion": "128",
                                                "gribparam": "178",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-388.72388",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-73.193359",
                                                "PTVersion": "128",
                                                "gribparam": "179",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1461.9722",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1822.9722",
                                                    "PTVersion": "128",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1170.9688",
                                                    "PTVersion": "128",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-388.72388",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-72.748047",
                                                    "PTVersion": "128",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "PTVersion": "128",
                                            "gribparam": "129",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-90.381668",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.006912231",
                                            "PTVersion": "128",
                                            "gribparam": "220",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-726.46533",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-63.882568",
                                            "PTVersion": "128",
                                            "gribparam": "205",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.3253355",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.8405657",
                                            "PTVersion": "128",
                                            "gribparam": "181",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-4.6843452",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "9.1268787",
                                            "PTVersion": "128",
                                            "gribparam": "180",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.37685",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "337.48398",
                                            "PTVersion": "128",
                                            "gribparam": "169",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "183.34595",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "345.95837",
                                            "gribparam": "139",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.27012390E-06",
                                            "gribparam": "160",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-660.0918",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "PTVersion": "128",
                                            "gribparam": "204",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7023468",
                                            "gribparam": "140",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.13516580E-06",
                                            "PTVersion": "128",
                                            "gribparam": "218",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.414795",
                                            "PTVersion": "128",
                                            "gribparam": "141",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_08",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "PTVersion": "128",
                                            "gribparam": "211",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "PTVersion": "128",
                                            "gribparam": "173",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "47950.457",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112610.98",
                                            "PTVersion": "128",
                                            "gribparam": "134",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.14268310E-07",
                                            "gribparam": "144",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.77612549E-06",
                                            "PTVersion": "128",
                                            "gribparam": "142",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.20480138E-06",
                                            "PTVersion": "128",
                                            "gribparam": "143",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-419494.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "429479.0",
                                            "PTVersion": "128",
                                            "gribparam": "108",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "959.95312",
                                                "PTVersion": "128",
                                                "gribparam": "176",
                                                "process": "50",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "PDS_TimeRange": "10",
                                                "calendar": "standard",
                                                "scale_min": "-278.771",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "83.518982",
                                                "PTVersion": "128",
                                                "gribparam": "177",
                                                "process": "50",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "PTVersion": "128",
                                            "gribparam": "172",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.03114224",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "gribNumBits": "16",
                                            "scale_max": "16.258347",
                                            "PTVersion": "128",
                                            "gribparam": "152",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-702.06494",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1323.7126",
                                            "PTVersion": "128",
                                            "gribparam": "146",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1385.8418",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "186.43262",
                                            "PTVersion": "128",
                                            "gribparam": "147",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-5.54159328E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.45476143E-08",
                                            "PTVersion": "128",
                                            "gribparam": "182",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-1782.0159",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2153.7517",
                                                    "PTVersion": "128",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-225052.5",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "665011.12",
                                                    "PTVersion": "128",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "959.95312",
                                                    "PTVersion": "128",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "PDS_TimeRange": "10",
                                                    "calendar": "standard",
                                                    "scale_min": "-278.771",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "30.783813",
                                                    "PTVersion": "128",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "PTVersion": "128",
                                            "gribparam": "175",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "210.51982",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.01007",
                                            "PTVersion": "128",
                                            "gribparam": "183",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "209.61876",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.90274",
                                            "PTVersion": "128",
                                            "gribparam": "170",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005076483",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03041875",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-19.796242",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.44614",
                                            "PTVersion": "128",
                                            "gribparam": "130",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.58814601E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83202483E-05",
                                            "PTVersion": "128",
                                            "gribparam": "138",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.58814601E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83202483E-05",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY mem01 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-0.005076483",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03041875",
                                            "PTVersion": "128",
                                            "gribparam": "133",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.91779600E-06",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.95129360E-06",
                                            "PTVersion": "128",
                                            "gribparam": "155",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-1.91779600E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.95129360E-06",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "0.02843878",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.404736",
                                            "gribparam": "171",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "0.05114594",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.205086",
                                            "PTVersion": "128",
                                            "gribparam": "216",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-30.295547",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "29.495789",
                                            "PTVersion": "128",
                                            "gribparam": "166",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "-31.385956",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.837234",
                                            "PTVersion": "128",
                                            "gribparam": "165",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "9.20232424E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03650392",
                                            "PTVersion": "128",
                                            "gribparam": "168",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "187.38249",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "332.55487",
                                            "gribparam": "201",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "scale_min": "187.15407",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "321.77676",
                                            "gribparam": "202",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "scale_min": "187.2619",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "328.65747",
                                            "PTVersion": "128",
                                            "gribparam": "167",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "hybrid_lev": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "hybrid_lev",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "v": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "v",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "132",
                                        "long_name": "meridional velocity",
                                        "grib_name": "va",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribleveltype": "109",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "u": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "u",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "131",
                                        "long_name": "zonal velocity",
                                        "grib_name": "ua",
                                        "units": "m/s",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribleveltype": "109",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "ta": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "ta",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Temperature",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-20.251757",
                                        "units": "Kelvin_scale",
                                        "grib_name": "ta",
                                        "gribleveltype": "109",
                                        "gribNumBits": "16",
                                        "scale_max": "410.93295",
                                        "gribparam": "130",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "rvort": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "rvort",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "vorticity",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-1.62243377E-05",
                                        "units": "s-1",
                                        "grib_name": "rvort",
                                        "gribleveltype": "109",
                                        "gribNumBits": "16",
                                        "scale_max": "1.92037551E-05",
                                        "gribparam": "138",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "Rv": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rv",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for moist air"
                                    },
                                    "Rd": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Rd",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "J/kg/K",
                                        "long_name": "gas constant for dry air"
                                    },
                                    "psi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "psi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "148",
                                        "long_name": "streamfunction",
                                        "grib_name": "strm",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-1.62243377E-05",
                                        "gribleveltype": "109",
                                        "gribNumBits": "16",
                                        "scale_max": "1.92037551E-05",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "phi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "phi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "156",
                                        "long_name": "geopotential height",
                                        "grib_name": "zg",
                                        "units": "m",
                                        "fnname": "max",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "long_name": "pressure",
                                        "units": "Pa",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribNumBits": "16",
                                        "gribleveltype": "1",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "omega": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "omega",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "135",
                                        "long_name": "vertical pressure velocity",
                                        "units": "Pa/s",
                                        "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst aug2001 SIX-HOURLY hybrid_lev omegahalf",
                                        "grib_name": "ua",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "gribleveltype": "109",
                                        "gribNumBits": "16",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "hus": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hus",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Specific Humidity",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-0.009193584",
                                        "units": "unitless",
                                        "grib_name": "hus",
                                        "gribNumBits": "16",
                                        "gribleveltype": "109",
                                        "scale_max": "0.03196654",
                                        "gribparam": "133",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "gravity": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "gravity",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m/s2",
                                        "long_name": "earth\\'s gravity"
                                    },
                                    "Div": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Div",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Divergence",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-2.23289680E-06",
                                        "units": "s-1",
                                        "grib_name": "div",
                                        "gribleveltype": "109",
                                        "gribNumBits": "16",
                                        "scale_max": "2.21615664E-06",
                                        "gribparam": "155",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "chi": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "chi",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "gribparam": "149",
                                        "long_name": "velocity potential",
                                        "grib_name": "vpot",
                                        "units": "meter2 second-1",
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-2.23289680E-06",
                                        "gribleveltype": "109",
                                        "gribNumBits": "16",
                                        "scale_max": "2.21615664E-06",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "BC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "BC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless"
                                    },
                                    "AC": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "AC",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "Pa"
                                    }
                                },
                                "filepattern": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "filepattern",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless"
                                },
                                "above_ground": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "above_ground",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "wind10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "wind10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "10m windspeed",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "0.01865815",
                                        "units": "unitless",
                                        "grib_name": "wind10",
                                        "gribNumBits": "16",
                                        "gribleveltype": "105",
                                        "scale_max": "39.309048",
                                        "gribparam": "171",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "WIMAX": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "WIMAX",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "maximum 10m wind speed",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "0.03494264",
                                        "units": "m/s",
                                        "grib_name": "WIMAX",
                                        "gribNumBits": "16",
                                        "gribleveltype": "105",
                                        "scale_max": "40.877903",
                                        "gribparam": "216",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "vas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "vas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "V-wind at 10",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-34.906662",
                                        "units": "m/s",
                                        "grib_name": "vas",
                                        "gribNumBits": "16",
                                        "gribleveltype": "105",
                                        "scale_max": "34.587128",
                                        "gribparam": "166",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "uas": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "uas",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "U-wind at 10",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "-37.760162",
                                        "units": "m/s",
                                        "grib_name": "uas",
                                        "gribNumBits": "16",
                                        "gribleveltype": "105",
                                        "scale_max": "36.860809",
                                        "gribparam": "165",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "td2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "td2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Dewpoint at 2 m",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "2.75820398E-08",
                                        "units": "Kelvin_scale",
                                        "grib_name": "td2m",
                                        "gribNumBits": "16",
                                        "gribleveltype": "105",
                                        "scale_max": "0.04707075",
                                        "gribparam": "168",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "t2mmx": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmx",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "max 2m temp",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "184.89082",
                                        "units": "unitless",
                                        "grib_name": "t2mmx",
                                        "gribNumBits": "16",
                                        "gribleveltype": "105",
                                        "scale_max": "342.06573",
                                        "gribparam": "201",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "t2mmn": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2mmn",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "min 2m temp",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "184.77397",
                                        "units": "unitless",
                                        "grib_name": "t2mmn",
                                        "gribNumBits": "16",
                                        "gribleveltype": "105",
                                        "scale_max": "328.68161",
                                        "gribparam": "202",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    },
                                    "t2m": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "t2m",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                        "long_name": "Temperature at 2 m",
                                        "PDS_TimeRange": "10",
                                        "calendar": "standard",
                                        "scale_min": "184.80574",
                                        "units": "Kelvin_scale",
                                        "grib_name": "t2m",
                                        "gribNumBits": "16",
                                        "gribleveltype": "105",
                                        "scale_max": "341.6304",
                                        "gribparam": "167",
                                        "PTVersion": "128",
                                        "process": "50",
                                        "subcenter": "255"
                                    }
                                }
                            },
                            "MONTHLY": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "MONTHLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "mem24": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem24",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem23": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem23",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem22": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem22",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem21": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem21",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem20": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem20",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem19": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem19",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem18": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem18",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem17": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem17",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem16": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem16",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem15": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem15",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem14": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem14",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem13": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem13",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem12": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem12",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem11": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem11",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem09": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem09",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem08": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem08",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem07": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem07",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem06": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem06",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem05": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem05",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem04": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem04",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem03": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem03",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem02": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem02",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "500.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "500",
                                            "units": "mm/(30 days)",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                }
                            },
                            "DAILY": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "DAILY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "mem24": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem24",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem23": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem23",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem22": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem22",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem21": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem21",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem20": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem20",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem19": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem19",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem18": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem18",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem17": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem17",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem16": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem16",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem15": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem15",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem14": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem14",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem13": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem13",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem12": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem12",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem11": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem11",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem09": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem09",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem08": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem08",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem07": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem07",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem06": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem06",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem05": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem05",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem04": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem04",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem03": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem03",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem02": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem02",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "colormap": "12800",
                                            "scale_max": "20.0",
                                            "maxncolor": "13",
                                            "ncolor": "13",
                                            "scale_min": "0.0",
                                            "CS": "0",
                                            "CE": "20",
                                            "units": "mm/day",
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    }
                                }
                            },
                            "Z_08": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_08",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0",
                                "long_name": "Height"
                            },
                            "Z_07": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_07",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "cm_down",
                                "gridtype": "0",
                                "pointwidth": "0",
                                "long_name": "Depth"
                            },
                            "Z_06": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_06",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "cm_down",
                                "gridtype": "0",
                                "pointwidth": "0",
                                "long_name": "Depth"
                            },
                            "P": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "P",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "mb",
                                "gridtype": "0",
                                "long_name": "pressure"
                            },
                            "sp_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "C": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "C",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "ids",
                                "gridtype": "2",
                                "long_name": "complex"
                            },
                            "Z_05": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_05",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Z_04": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_04",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0"
                            },
                            "Y_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "Z_03": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_03",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "long_name": "Height",
                                "pointwidth": "1.0"
                            },
                            "sp": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "sp",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "1.0"
                            },
                            "Z_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "pointwidth": "0.0"
                            },
                            "Z_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m_above_gnd",
                                "gridtype": "0",
                                "long_name": "Height",
                                "pointwidth": "0"
                            },
                            "Z": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Z",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "m_above_gnd",
                                "gridtype": "0",
                                "long_name": "Height",
                                "pointwidth": "0"
                            },
                            "T_02": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T_02",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "0.25",
                                "defaultvalue": "333.75"
                            },
                            "M": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "M",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "unitless",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "1.0"
                            },
                            "S": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "S",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "long_name": "Start Time",
                                "pointwidth": "0"
                            },
                            "T_01": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T_01",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "30.0"
                            },
                            "Y": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "Y",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_north",
                                "gridtype": "0"
                            },
                            "T": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "T",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "days since 2001-01-01 00:00:00",
                                "gridtype": "0",
                                "calendar": "standard",
                                "pointwidth": "1.0"
                            },
                            "X": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "X",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "units": "degree_east",
                                "gridtype": "1",
                                "pointwidth": "2.8125",
                                "modulus": "360.0"
                            },
                            "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/aug2001"
                        },
                        "dec2001": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/dec2001",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "dec2001",
                            "restriction": "Public",
                            "SIXHOURLY": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "SIX-HOURLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "NC_GLOBAL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "NC_GLOBAL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "mem24PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem24griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem24/.griblist.html",
                                    "mem24filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc24_%6d.01",
                                    "mem24year0": "200206",
                                    "mem23PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem23griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem23/.griblist.html",
                                    "mem23filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc23_%6d.01",
                                    "mem23year0": "200206",
                                    "mem22PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem22griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem22/.griblist.html",
                                    "mem22filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc22_%6d.01",
                                    "mem22year0": "200206",
                                    "mem21PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem21griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem21/.griblist.html",
                                    "mem21filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc21_%6d.01",
                                    "mem21year0": "200206",
                                    "mem20PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem20griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem20/.griblist.html",
                                    "mem20filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc20_%6d.01",
                                    "mem20year0": "200206",
                                    "mem19PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem19griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem19/.griblist.html",
                                    "mem19filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc19_%6d.01",
                                    "mem19year0": "200206",
                                    "mem18PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem18griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem18/.griblist.html",
                                    "mem18filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc18_%6d.01",
                                    "mem18year0": "200206",
                                    "mem17PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem17griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem17/.griblist.html",
                                    "mem17filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc17_%6d.01",
                                    "mem17year0": "200206",
                                    "mem16PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem16griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem16/.griblist.html",
                                    "mem16filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc16_%6d.01",
                                    "mem16year0": "200206",
                                    "mem15PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem15griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem15/.griblist.html",
                                    "mem15filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc15_%6d.01",
                                    "mem15year0": "200206",
                                    "mem14PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem14griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem14/.griblist.html",
                                    "mem14filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc14_%6d.01",
                                    "mem14year0": "200206",
                                    "mem13PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem13griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem13/.griblist.html",
                                    "mem13filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc13_%6d.01",
                                    "mem13year0": "200206",
                                    "mem12PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem12griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem12/.griblist.html",
                                    "mem12filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc12_%6d.01",
                                    "mem12year0": "200206",
                                    "mem11PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem11griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem11/.griblist.html",
                                    "mem11filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc11_%6d.01",
                                    "mem11year0": "200206",
                                    "mem10PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem10griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem10/.griblist.html",
                                    "mem10filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc10_%6d.01",
                                    "mem10year0": "200206",
                                    "mem09PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem09griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem09/.griblist.html",
                                    "mem09filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc09_%6d.01",
                                    "mem09year0": "200206",
                                    "mem08PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem08griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem08/.griblist.html",
                                    "mem08filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc08_%6d.01",
                                    "mem08year0": "200206",
                                    "mem07PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem07griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem07/.griblist.html",
                                    "mem07filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc07_%6d.01",
                                    "mem07year0": "200206",
                                    "mem06PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem06griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem06/.griblist.html",
                                    "mem06filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc06_%6d.01",
                                    "mem06year0": "200206",
                                    "mem05PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem05griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem05/.griblist.html",
                                    "mem05filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc05_%6d.01",
                                    "mem05year0": "200206",
                                    "mem04PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem04griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem04/.griblist.html",
                                    "mem04filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc04_%6d.01",
                                    "mem04year0": "200206",
                                    "mem03PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem03griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem03/.griblist.html",
                                    "mem03filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc03_%6d.01",
                                    "mem03year0": "200206",
                                    "mem02PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem02griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem02/.griblist.html",
                                    "mem02filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc02_%6d.01",
                                    "mem02year0": "200206",
                                    "mem01PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem01griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.dec2001/.SIX-HOURLY/.mem01/.griblist.html",
                                    "mem01filepattern": "/mstore/iri/forecast/data/echam4/asst/dec01/30004fc01_%6d.01",
                                    "mem01year0": "200206",
                                    "Conventions": "IRIDL"
                                },
                                "mem24": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem24",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.06096204",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "85.145218",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8517.6875",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-812.79492",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1178.9062",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-408.59521",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-76.334229",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1994.8833",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "2453.8953",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1181.0312",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-408.59521",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-82.648926",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-87.958328",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08622742",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-731.77393",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-70.262207",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-3.3541059",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.203434",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.9790316",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.5867071",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.80547",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "339.19366",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.75711",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "347.26279",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.16986666E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-711.33618",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.10012479E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "15.483887",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47457.461",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "111979.53",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.15900080E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.88662079E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.32624473E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-422523.06",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "456099.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "972.14062",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-259.07764",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "54.328339",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03090196",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258459",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-823.79932",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "904.60693",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1158.9258",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "254.64087",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.63421941E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.01822934E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1537.2131",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1971.9771",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-240733.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "614434.38",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "973.5",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-259.07764",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "29.278534",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.14009",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "309.86597",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "198.65204",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "317.52112",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.75711",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "343.26865",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.29054",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "314.04819",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.008421674",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02731079",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.619717",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.74146",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.49430680E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.73479475E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.49430680E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.73479475E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem24 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.008421674",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02731079",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.02339606E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.16499052E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.02339606E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.16499052E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.03225516",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.570789",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05807275",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.236824",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-30.357147",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "31.55629",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-33.210922",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.894958",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.44533658E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03511378",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "191.24055",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "338.07202",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "191.03262",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "327.91937",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "191.10744",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "338.0726",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem23": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem23",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04809247",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "83.603096",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8532.3047",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-807.23071",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1180.0938",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-388.94849",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-74.456055",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1857.4272",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1845.3665",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.5625",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-388.94849",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-74.573242",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-83.947968",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08650208",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-721.8252",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-63.656494",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-5.1407127",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.7197123",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-6.3756132",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.098033",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "183.15521",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "337.99832",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "182.9679",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "345.21222",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.41195301E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-698.80615",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.13467104E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.725098",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "46752.414",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112027.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.46515980E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.62992546E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.45544436E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-448245.75",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "475537.25",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "972.98438",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-269.21924",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "59.726212",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.02921172",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258408",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-712.10059",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1093.6541",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1287.5906",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "184.56885",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.14871374E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.38026813E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1706.3857",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1826.9666",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-305576.38",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "595068.94",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "972.98438",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-269.21924",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "21.904037",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.43694",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.11887",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "196.85962",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "316.60779",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "182.9679",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "341.12628",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.59476",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "314.09341",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.004936144",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02735369",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.744495",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.4635",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.48357867E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.76626781E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.48357867E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.76626781E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem23 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.004936144",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02735369",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.93547385E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.11934525E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.93547385E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.11934525E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.02965785",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.872066",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04734129",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.129158",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.432312",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.575363",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-32.404434",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.616058",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.26546013E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03419112",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "187.49188",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "337.62927",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "187.39978",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.53995",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.40202",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "329.56821",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem22": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem22",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0627625",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "90.773941",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8523.8906",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-807.38818",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.7188",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-399.70874",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-76.46582",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1573.5667",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1912.8499",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.7188",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-399.70874",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-78.996094",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-89.244965",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08688354",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-725.22021",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-66.908203",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-3.8791819",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.9420853",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-6.0600166",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.000206",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.46889",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "338.396",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.51134",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "346.79813",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.09024177E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-735.00732",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.04962965E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "15.518555",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "46911.602",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112358.28",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.20725885E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.73385977E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.76411561E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-7.69388268E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.40647080E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-430579.38",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "458448.06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "979.53125",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-273.74316",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "64.863205",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03170276",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258448",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-814.59766",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1022.8718",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1190.8362",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "174.44409",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.76182038E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.97567373E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1729.3818",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "2014.5042",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-307208.38",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "638189.19",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "979.53125",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-273.74316",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "25.756241",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.40376",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "309.78098",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "197.48206",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "317.38712",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.51134",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "342.73563",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.71509",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "313.61041",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005028557",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02662344",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.591936",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.651",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.45263648E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.70983512E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.45263648E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.70983512E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem22 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005028557",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02662344",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.99413716E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.06452160E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.99413716E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.06452160E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.02500544",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.952812",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04946072",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "37.589531",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-30.066772",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "31.293537",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-30.220093",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.238907",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.02625734E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03706392",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.92841",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "335.46442",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.86655",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "326.95917",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "189.88518",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "332.34363",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem21": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem21",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05504033",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "86.070854",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8523.3203",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-802.47046",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.5312",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-399.72412",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-80.200439",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1716.7693",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1940.9482",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.4375",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-399.72412",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-82.966553",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-84.98053",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08656311",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-732.02588",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-69.929443",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-3.6614733",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.4990263",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7.0853472",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.5778656",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.55455",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "337.70398",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.60176",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "346.88275",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.67187579E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-719.68164",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.09508983E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.672363",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "46567.797",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112655.47",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.41163143E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "9.40657571E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.70002511E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-8.13151668E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.31230433E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-481123.06",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "436748.69",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "985.25",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-290.83179",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "57.605087",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03071016",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258497",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-714.63281",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1156.9846",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1257.4463",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "193.65845",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.02817613E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.74405464E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-2314.0518",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1790.3352",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-284287.12",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "569503.31",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "985.25",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-290.83179",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "37.364334",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.90863",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.28745",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "200.26495",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "316.99139",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.60176",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "342.55811",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "208.98009",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "313.83887",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.004752699",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02731708",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.802567",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.67343",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.39779531E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.80809202E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.39779531E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.80809202E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem21 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.004752699",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02731708",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.91332651E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.16355738E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.91332651E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.16355738E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.02895582",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.151005",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05474818",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "37.262691",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-28.949539",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "30.23761",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-30.221893",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.868805",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "2.36829010E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03743666",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.97949",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "334.20496",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.75224",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.77869",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "189.80943",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "330.45682",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem20": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem20",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05849198",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "83.101624",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8518.7773",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-805.07153",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.3125",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-396.47803",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-76.852295",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1720.7314",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "2099.1194",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1181.2812",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-396.47803",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-80.075684",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-83.376785",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08711243",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-726.70752",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-67.40625",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-3.6608181",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.8466101",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-5.8277884",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.1991692",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.80887",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "338.1759",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.90878",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "347.69806",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.31695890E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-692.47192",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "9.67149390E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.392578",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47223.762",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112600.88",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.18671253E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.67958694E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-8.58326734E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.41105727E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-427817.56",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "443090.75",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "972.15625",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-283.94873",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "57.75882",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03123624",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258453",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-741.19775",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1094.363",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1397.2529",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "172.12305",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.58722320E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.88271484E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1788.2271",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1679.6418",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-332401.88",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "605582.12",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "974.28125",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-283.94873",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "20.256989",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.38374",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "309.9671",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "198.01906",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "317.1806",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.90878",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "343.58087",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "208.98683",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "313.88025",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005370736",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02746325",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.720346",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.90408",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.42391009E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.87862588E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.42391009E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.87862588E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem20 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005370736",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02746325",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.03458603E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.17357547E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.03458603E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.17357547E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.03232504",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.151905",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05092988",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "37.312412",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-32.761475",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.452301",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-35.024048",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.990784",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "7.08861307E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03710635",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.92108",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "333.66437",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.38873",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "325.27972",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "189.4214",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "328.65787",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem19": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem19",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0566018",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "82.962677",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8523.1914",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-803.16138",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.4688",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-387.82471",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-77.894287",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1390.9648",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1950.7715",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.9375",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-387.82471",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-77.894287",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-85.975052",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08651733",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-725.10718",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-66.124268",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-3.2919264",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.7251263",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-6.4390144",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.7333679",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "184.91495",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "338.09192",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "184.81511",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "347.33429",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.26182999E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-695.49854",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.05632353E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "15.787842",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "46953.461",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112112.92",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.04871003E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.00102839E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.83573275E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-7.67976602E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.37527513E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-425190.5",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "497514.94",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "977.78125",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-275.24805",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "63.088913",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03037764",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258512",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-698.52075",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "893.8313",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1435.4321",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "181.36865",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.73989155E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.25254381E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1589.1792",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1785.0232",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-276790.88",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "587743.81",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "977.78125",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-275.24805",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "25.877335",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.32417",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.21429",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "198.21069",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "318.15344",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "184.81511",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "343.1507",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.59361",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "313.82495",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005031977",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02701995",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.625135",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.74731",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.50187379E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.71652191E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.50187379E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.71652191E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem19 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005031977",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02701995",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.15786781E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.08229153E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.15786781E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.08229153E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.03585748",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.787472",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0639863",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.324402",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-32.491272",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "31.19014",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.560349",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.849136",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "4.76864521E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03486459",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.1136",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "330.94528",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "188.9407",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "323.4892",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "188.97723",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "328.92084",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem18": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem18",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.06044411",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "89.536278",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8521.2188",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-810.27417",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.125",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-392.55737",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-75.20752",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1630.0928",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "2148.3042",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.5625",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-392.55737",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-78.212891",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-84.631165",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08670044",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-733.54712",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-65.002686",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-3.9331226",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.2807579",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-3.9643316",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.0791826",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "184.16322",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "339.09198",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "184.15852",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "346.81757",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.53148744E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-699.43457",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "9.91654815E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.583496",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47388.816",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112276.57",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.29395617E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.90260458E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.60162358E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-7.28448359E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.27216356E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-445442.56",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "441815.44",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "969.57812",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-266.99683",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "60.632904",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03068788",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258465",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-874.28247",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1120.0581",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1183.001",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "175.68872",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.73048942E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.02545435E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1726.2222",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1847.5225",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-308002.94",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "601824.25",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "970.14062",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-266.99683",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "38.681763",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.20697",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "309.50412",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "198.73198",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "318.47131",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "184.15852",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "342.78058",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.52249",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "314.31604",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005522326",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02686184",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.98522",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.41",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.48412601E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.71684151E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.48412601E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.71684151E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem18 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005522326",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02686184",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.92302196E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.16090461E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.92302196E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.16090461E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.03359575",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.958454",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05696904",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.464363",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-30.878555",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "30.216354",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.364792",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.474854",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8.44646593E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03493489",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "188.04449",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "336.46008",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "187.95668",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.22925",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "188.03229",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "332.04028",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem17": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem17",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.06420493",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "87.776962",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8519.9844",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-809.51978",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.25",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-390.62329",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-77.640869",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1901.6128",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1792.0806",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1181.1562",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-391.1792",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-77.809326",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-84.079437",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08674622",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-728.81348",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-66.974121",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-3.8919106",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.8377085",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.6051626",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.4023972",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.55408",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "338.4989",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.52197",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "347.22134",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.37941174E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-695.5647",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.17448508E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "15.014404",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47249.863",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "111868.31",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.41163143E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.12283168E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.50722008E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.33630988E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-439787.62",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "450838.56",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "967.45312",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-267.61475",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "70.521301",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.0309034",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258486",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-739.81348",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1198.1335",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1258.594",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "185.01318",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.03276510E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.39806296E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1864.2021",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "2090.6504",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-331987.94",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "610701.75",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "968.6875",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-267.76074",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "24.940979",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.0061",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.62988",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "198.8475",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "317.3288",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.52197",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "343.20059",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.1756",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "314.66095",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.003534186",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02590337",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.514158",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "410.05011",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.47315723E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.72532600E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.47315723E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.72532600E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem17 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.003534186",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02590337",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.96628275E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.95646066E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.96628275E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.95646066E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.02563937",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.906998",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04239379",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.18259",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-30.516022",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "31.167648",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-32.797501",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "31.583481",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8.06544449E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.04103574",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.14731",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "333.94727",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "188.79805",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "325.3869",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "188.84128",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "329.9317",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem16": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem16",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04475382",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "92.073624",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8522.7969",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-805.79126",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.2188",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-384.05762",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-76.025879",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1852.9453",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1648.0598",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.9688",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-384.05762",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-79.049316",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-91.146027",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08717346",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-715.34106",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-66.194336",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.4073153",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.584569",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.6270523",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.3061514",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.01892",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "336.86026",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.18265",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "344.16077",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.27432077E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-694.2915",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.22725032E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.54834",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "46977.926",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112597.11",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.51453808E-29",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.06758351E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.70654266E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-8.13151668E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.26503596E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-461004.44",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "475125.88",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "973.78125",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-265.19141",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "65.048111",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03002039",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258503",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-720.16284",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1141.5098",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1226.9839",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "194.38452",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.90636467E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.77291120E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1682.1335",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "2021.4438",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-272953.0",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "639934.75",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "977.5625",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-265.19141",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "22.334854",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.92035",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "309.40622",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "198.0491",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "316.21268",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.18265",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "340.40686",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.12224",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "312.99054",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.00577959",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02921944",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.126907",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.81949",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.38841260E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.62524266E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.38841260E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.62524266E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem16 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.00577959",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02921944",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.97145459E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.95438724E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.97145459E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.95438724E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.02211021",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.793827",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05098586",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.308655",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-30.804947",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "31.57988",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-32.576691",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.629272",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "3.52528815E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03821049",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "187.62793",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "329.86438",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "186.70796",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "322.51166",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.72757",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "326.7951",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem15": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem15",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.03694575",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "86.135887",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8524.4844",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-806.88159",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.5938",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-386.06812",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-75.92749",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1604.6804",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1846.511",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1181.25",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-386.06812",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-77.311768",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-89.287003",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08638",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-744.58057",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-64.663818",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.2207432",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.9885788",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-6.1928129",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.1859379",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "183.89301",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "338.18866",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "183.89517",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "347.39395",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.37074778E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-727.08813",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.16325100E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.249023",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47469.641",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112074.95",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-2.20581571E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.16497106E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.73242927E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-1.15196482E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.29987791E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-427260.0",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "429928.62",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "969.98438",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-264.01636",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "66.612244",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03060628",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258471",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-747.44189",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1258.6179",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1318.7041",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "162.37622",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.27312807E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.45952696E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1633.8684",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1880.3647",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-276964.69",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "595162.5",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "970.70312",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-264.01636",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "25.3685",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.07954",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "309.75433",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "197.29602",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "317.0892",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "183.89517",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "343.29044",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.1265",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "313.70123",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.004576042",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.0281147",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.608002",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.94379",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.47180954E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.68231145E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.47180954E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.68231145E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem15 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.004576042",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.0281147",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.35462471E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.02825800E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.35462471E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.02825800E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.01584013",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.272411",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0237495",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "37.821777",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-32.070328",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.46965",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-34.768112",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.456161",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8.50336619E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03408257",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "187.05255",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "330.21631",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "186.83302",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "322.35614",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.85571",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "329.03912",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem14": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem14",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.03557465",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "84.739861",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8512.9961",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-804.06152",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.25",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-393.80908",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-77.43457",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1498.7102",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1845.239",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.9688",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-393.80908",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-77.414062",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-84.727005",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08644104",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-736.08911",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-64.824707",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-3.4511776",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.5484161",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-5.3231936",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.0702553",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "184.01724",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "338.58453",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "184.00012",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "346.89362",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.48369702E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-705.90039",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.05224899E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "15.404785",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47214.723",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112474.75",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-2.20581571E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.07251843E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.54700797E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-7.67976602E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.39504175E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-434591.06",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "493870.06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "970.0625",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-275.68481",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "50.680496",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03119552",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258484",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-812.51147",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1015.4075",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1152.7952",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "179.2854",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.60970455E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.16889588E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1768.887",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1911.1938",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-365237.31",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "652532.62",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "972.4375",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-275.69849",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "30.396408",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.28131",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.62042",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "196.32599",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "316.56329",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "184.00012",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "342.8858",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.56404",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "314.47601",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.007046875",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02749709",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.913252",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.65686",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.46959028E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.72165146E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.46959028E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.72165146E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem14 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.007046875",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02749709",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.02195679E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.24969676E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.02195679E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.24969676E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.02722542",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.776497",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05913763",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "38.128517",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-33.361267",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "29.91713",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.810883",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.27417",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.09273003E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03741221",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "187.94194",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "332.49924",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "187.87688",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "326.715",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.88803",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "329.48474",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem13": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem13",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05610841",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "84.467232",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8489.2148",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-803.53394",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.1562",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-395.38208",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-76.845947",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1805.8477",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1852.762",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.75",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-395.38208",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-79.290527",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-81.927643",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08702087",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-728.79712",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-67.056396",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-3.6264524",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.0519886",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.3234978",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.7432785",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.58969",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "337.30002",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.63504",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "345.63852",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.06751725E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-694.05005",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "9.99949407E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "17.081543",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47143.379",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112081.98",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.51453808E-29",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.00534940E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.67078588E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-1.80700392E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.49852917E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-405278.0",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "465212.38",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "971.85938",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-267.37769",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "77.640167",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.02996168",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.25844",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-732.09668",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1067.3723",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1125.7214",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "213.27856",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.50144483E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.52867572E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1998.8901",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1722.0137",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-309973.69",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "646284.69",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "971.85938",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-267.37769",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "18.11972",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.81984",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.61371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "196.58774",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "316.53534",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.63504",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "341.54517",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.03796",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "314.35034",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.00457092",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02696809",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-22.004139",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "410.06427",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.45158519E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.76964822E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.45158519E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.76964822E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem13 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.00457092",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02696809",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.03373725E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.01178364E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.03373725E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.01178364E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.02041094",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "39.124069",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.03888946",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "41.731964",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-28.446213",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "31.556549",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.344193",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "39.749634",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "9.71957093E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03624657",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "188.54678",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "334.02063",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "188.26025",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.31137",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "188.35323",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "330.99225",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem12": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem12",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04182852",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "90.241371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8519.1875",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-810.36108",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.4062",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-392.0498",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-74.581055",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1825.9119",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1681.3674",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.5625",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-392.0498",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-74.960449",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-88.904999",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08631897",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-717.35522",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-64.366943",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.2187557",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.1657438",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.9342966",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.1990433",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "183.757",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "338.04517",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "183.82664",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "347.32605",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.31789466E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-693.96313",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.19063770E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.94043",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "46447.082",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112379.68",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.55230872E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.84232852E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-1.07290842E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.30602973E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-404976.75",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "454269.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "968.84375",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-273.26416",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "57.710327",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.02900807",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258549",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-739.73462",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1135.0269",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1499.7095",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "160.54321",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.99691873E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.41959446E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1765.0947",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1898.469",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-318781.56",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "587355.81",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "969.79688",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-273.28882",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "20.59967",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.03592",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.32373",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "198.44125",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "315.8866",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "183.82664",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "342.99323",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.12932",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "314.43185",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005600169",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02726537",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.828037",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.81775",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.46320253E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.78194678E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.46320253E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.78194678E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem12 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005600169",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02726537",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.82640883E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.03771492E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.82640883E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.03771492E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.02719831",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.430428",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04808723",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.633633",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-29.33786",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "28.965561",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.149994",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.012238",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.14420800E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03884415",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "186.60036",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "332.24432",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "186.31119",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.96021",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.3506",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "329.0481",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem11": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem11",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04832854",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "85.115372",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8518.5195",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-806.07837",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.0312",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-393.95801",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-74.609863",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1751.8008",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1632.5022",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.625",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-396.70996",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-74.940186",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-85.134354",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08680725",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-740.83569",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-64.49707",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.0758696",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.7395105",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-5.4267035",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.6395912",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "183.75562",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "341.13153",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "183.53094",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "347.62766",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.01630587E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-714.42017",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "9.61328624E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "14.560791",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47156.047",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112153.02",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.03988917E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.52783844E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.28680438E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-414103.19",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "444052.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "974.98438",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-267.14453",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "59.328857",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03022772",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258484",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-761.7334",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1083.5649",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1367.5454",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "185.50098",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.46843125E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.41790700E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1437.3369",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1917.0464",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-256517.94",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "614921.12",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "974.98438",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-267.14453",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "26.846802",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.57579",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "309.8631",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "199.32698",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "317.95819",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "183.53094",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "343.60812",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.8447",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "313.64893",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.006836332",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02704061",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.404545",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.6976",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.48369691E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.76593549E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.48369691E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.76593549E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem11 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.006836332",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02704061",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.37937661E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.00181535E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.37937661E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.00181535E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.02956201",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.125961",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05163336",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.421349",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-30.359634",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.528763",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.693756",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.79837",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.65702374E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.0380118",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "187.55002",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "329.71661",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "187.00848",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "319.98517",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.00848",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "326.09869",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05321715",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "89.56115",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8501.3984",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-806.28931",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1180.0938",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-392.87451",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-76.232178",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1980.2576",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1872.8713",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.8125",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-392.87451",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-78.488281",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-87.96022",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08627319",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-717.35571",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-65.860107",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-5.2563295",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.3065081",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-6.4221487",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.0898933",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "184.70508",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "335.80853",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "184.62563",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "344.54782",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.12427449E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-700.25171",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.11971167E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.208984",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "46921.406",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112560.16",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-6.73161534E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.57965665E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.87842511E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-7.25624947E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.37462621E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-440709.69",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "451888.06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "976.125",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-284.65527",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "77.343048",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.02949839",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258539",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-701.96411",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1167.6611",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1195.6921",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "185.92578",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.66653091E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.43489750E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1623.1101",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1939.5935",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-313932.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "638496.44",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "976.125",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-284.65527",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "23.742355",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.29166",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "309.23685",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "196.28421",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "316.85828",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "184.62563",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "340.41501",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.66847",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "313.67462",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005434398",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02713685",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.278648",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.93411",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.47778946E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.62583710E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.47778946E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.62583710E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem10 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005434398",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02713685",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.01551529E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.06936670E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.01551529E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.06936670E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.02550181",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.147903",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04131255",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.258045",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.382828",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "30.448975",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.15918",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.717255",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.10157544E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03599995",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "188.10641",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "329.56384",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "187.85217",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "321.75146",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.94858",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "326.81149",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem09": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem09",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05413573",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "88.38488",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8520.1992",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-804.89746",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1178.5938",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-388.74146",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-73.749023",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1776.0593",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1782.1973",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.7188",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-388.74146",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-80.237793",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-87.279221",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0869751",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-724.49146",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-70.175537",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.9193687",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.2636194",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.5056372",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.607749",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.69534",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "338.27686",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.69867",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "346.39062",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.36767608E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-698.03149",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.11619011E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "15.73291",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47238.078",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "111934.08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-2.52435502E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.41083852E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.52906910E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.22727704E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-482765.56",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "459394.94",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "966.79688",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-263.87646",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "56.404587",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03202488",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.25848",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-858.37939",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1183.0249",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1269.0542",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "180.35059",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.07459220E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.21177571E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1505.9207",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1819.1614",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-315441.56",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "590211.38",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "972.42188",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-263.92578",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "23.697922",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.16641",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "309.51031",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "197.59271",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "316.92044",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.69867",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "342.29492",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.22108",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "313.32269",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.003917776",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02685288",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.643211",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.63751",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.43707375E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.68979695E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.43707375E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.68979695E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem09 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.003917776",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02685288",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.94973813E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.12504438E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.94973813E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.12504438E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.02553649",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.964989",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04480355",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.443504",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.324997",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "30.135681",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-34.799179",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.792267",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "5.68191787E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.04341219",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.74536",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "338.50604",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.58191",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.40005",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "189.58257",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "329.18326",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem08": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem08",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0498033",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "86.512062",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8513.6914",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-806.87695",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.0312",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-384.86792",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-75.959473",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1853.6362",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1972.1089",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.5938",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-384.86792",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-79.424805",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-86.130112",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08703613",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-732.73389",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-66.993652",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-5.9358654",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.3185329",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-5.8548717",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.123621",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.54065",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "337.77609",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.48949",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "347.19128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.27508258E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-698.89478",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.26363011E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "14.954834",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47169.93",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112296.81",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.24857045E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.78680534E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-9.93852012E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.54814097E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-407954.25",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "473789.38",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "974.07812",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-277.51709",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "55.152695",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03103033",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258423",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-813.34888",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1383.1174",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1437.8906",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "206.43066",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.74972205E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.25470750E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-2342.7966",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1825.2693",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-293375.5",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "649283.38",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "977.28125",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-277.51709",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "22.261887",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.27263",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.09918",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "198.12381",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "317.02881",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.48949",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "343.06628",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.36327",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "314.24713",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.004138488",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02912056",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.868626",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.57193",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.44785727E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.69489540E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.44785727E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.69489540E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem08 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.004138488",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02912056",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.02557089E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.37325298E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.02557089E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.37325298E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.03182838",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.897617",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05299102",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.644585",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-34.219193",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.619751",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.387665",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.139069",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "9.81439712E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03801184",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.05281",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "336.07776",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "188.89684",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "326.3739",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "188.90558",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "330.85242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem07": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem07",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04741511",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "88.284286",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8523.8047",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-807.99268",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.1875",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-381.65405",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-73.959961",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1913.1572",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "2007.2388",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1181.125",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-381.65405",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-78.718994",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-86.407364",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08709717",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-746.68018",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-64.478027",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-3.8596201",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.4589396",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.721797",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.8696308",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "183.75117",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "339.51929",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "183.65381",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "347.49103",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.46031175E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-702.19092",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.03685306E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.192383",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47318.527",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112766.77",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-8.82326093E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.23909261E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "2.07052426E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.24385747E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-410919.69",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "455246.94",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "969.125",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-262.40112",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "71.272263",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03066769",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258392",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-735.6731",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "832.4126",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1136.429",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "223.87305",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.54426157E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.95186076E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1699.5693",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1927.1382",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-382793.56",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "588411.06",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "973.82812",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-263.11426",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "31.554672",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.25874",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.06815",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "197.30563",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "317.02979",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "183.65381",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "343.5047",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.62914",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "313.92303",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.004736818",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.0288047",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.91576",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.50632",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.47198343E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.75062360E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.47198343E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.75062360E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem07 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.004736818",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.0288047",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.02556726E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.21233245E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.02556726E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.21233245E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.03065771",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.615463",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0635193",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.342854",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-30.840057",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.762024",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-33.158798",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.427155",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "7.34708010E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03506192",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "188.12833",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "336.0546",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "187.7312",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "321.63269",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "187.86038",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "327.03683",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem06": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem06",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0578686",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "85.736069",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8520.8125",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-803.73193",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.0",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-387.26855",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-77.060547",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1926.251",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1834.9126",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1181.25",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-387.26855",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-79.631592",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-83.242142",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08676147",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-726.52515",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-67.250244",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.6725864",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.8316889",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-5.4968729",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.1069813",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.70668",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "338.67975",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.64095",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "345.0329",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.31837260E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-696.28345",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.10099791E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "14.047852",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "46991.188",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "111839.44",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.42827581E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.85978570E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.36863798E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-404571.69",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "442147.56",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "973.51562",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-260.43481",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "60.864288",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.0305633",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258392",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-705.81738",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1034.2935",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1125.9412",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "190.61792",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.50232363E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.62249215E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1770.0518",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1994.5457",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-315860.44",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "618525.06",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "973.51562",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-260.43481",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "30.842361",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.94521",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.67249",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "197.51076",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "317.4248",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.64095",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "341.39227",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.08003",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "314.57584",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005337454",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02747997",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.941751",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.95206",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.44362875E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.78243990E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.44362875E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.78243990E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem06 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005337454",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02747997",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.82400618E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.97795930E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.82400618E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.97795930E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.02530574",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.365665",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04451274",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.675068",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.913818",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "31.313629",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.228088",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.128204",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.17251886E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03529721",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "188.54718",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "337.50061",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "188.28238",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.40112",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "188.28738",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "328.99841",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem05": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem05",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04390636",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "88.494125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8522.8242",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-810.07593",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1178.4688",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-385.92358",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-78.300781",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1453.2324",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1729.0837",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.8125",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-385.92358",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-80.209473",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-83.490036",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08674622",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-731.15894",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-67.875488",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.7494955",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.5746412",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.5354843",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.7538548",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.1554",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "338.25714",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.00171",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "345.95853",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.11175700E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-707.55835",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.02727790E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "13.165283",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47533.344",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112728.86",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.03811020E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.51214567E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-1.10678976E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.20818743E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-488946.94",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "482359.38",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "972.39062",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-267.45508",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "63.441635",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03007261",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258471",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-722.03174",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1193.0566",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1298.396",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "206.32446",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.19192213E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.25061193E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1395.8342",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1759.3198",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-317681.56",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "560669.5",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "975.0625",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-267.45508",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "32.882263",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.21001",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.05325",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "198.8111",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "317.08557",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.00171",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "341.91556",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.45262",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "313.81842",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.004937336",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02809255",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.671879",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.75009",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.41088867E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.73106964E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.41088867E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.73106964E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem05 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.004937336",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02809255",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.89894786E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.92928610E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.89894786E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.92928610E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0313176",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.777016",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04916658",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.459019",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-30.60083",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "31.842178",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.721725",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.429245",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.54371548E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03513223",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "190.02856",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "333.59772",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.75717",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "323.41388",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "189.80602",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "327.17218",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem04": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem04",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05436542",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "82.55925",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8531.7969",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-809.84424",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1178.4688",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-395.92163",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-74.643555",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1839.2119",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "2359.054",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1181.0312",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-396.85303",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-80.353027",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-86.464615",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08680725",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-732.84058",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-68.073242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.8660107",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.2187691",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.2071953",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.312007",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.25391",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "338.31952",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.25941",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "347.75391",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.15760452E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-697.4397",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.08024688E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "15.778564",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47065.195",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112042.95",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.41163066E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.51022355E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.80928453E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-1.03902716E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.36528377E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-415327.0",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "463183.81",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "966.14062",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-281.83032",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "69.360535",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03019963",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258429",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-758.05103",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "857.49561",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1159.0459",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "194.31128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-4.63470030E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.76978766E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-2031.0005",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "2289.6626",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-316610.0",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "652948.62",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "977.40625",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-282.40723",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "26.983429",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.11546",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.3623",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "198.1032",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "317.01965",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.25941",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "343.42578",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.286",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "313.97394",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.01055825",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.03030396",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.69525",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.76044",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.50287642E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.72700820E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.50287642E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.72700820E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem04 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.01055825",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.03030396",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.98092630E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.13496082E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.98092630E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.13496082E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.01853678",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.713219",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0425308",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.316925",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.266663",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.595856",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-33.574081",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.296097",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.36981612E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03355908",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "186.1965",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "339.62634",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "185.91681",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "323.93292",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.94714",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "331.52106",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem03": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem03",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05896141",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "86.972015",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8512.7656",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-807.24658",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.3125",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-382.85181",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-76.313477",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-2118.4343",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "2401.9768",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.125",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-387.01855",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-80.633545",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-87.147629",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08630371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-734.65698",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-68.270264",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.2433395",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.397995",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-5.5000496",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.2625055",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.42099",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "338.27899",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.44853",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "348.00699",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.10778103E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-700.86206",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.02334889E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "13.888184",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "46657.898",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "111658.06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.19169884E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.72013745E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-1.03902716E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.26754765E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-403409.56",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "505826.25",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "974.25",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-277.88135",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "55.276291",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.0311228",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258507",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-718.8938",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1034.7104",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1355.3547",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "167.19434",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.41968461E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "6.68545397E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-2008.9448",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1925.3584",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-306884.44",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "621471.56",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "974.25",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-277.98242",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "17.543243",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.28671",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.27167",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "198.65067",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "316.92255",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.44853",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "343.45621",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.58839",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "314.11963",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.00568828",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02742949",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.443005",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.65927",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.46820230E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.74566176E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.46820230E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.74566176E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem03 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.00568828",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.02742949",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.25888880E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.07468702E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.25888880E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.07468702E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.03042387",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.49617",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04951522",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.364025",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-32.349167",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "32.425552",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-33.198212",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.683655",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8.73153567E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03629125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.58881",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "334.07715",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.41214",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "322.98657",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "189.48634",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "327.58423",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem02": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem02",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.04491301",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "90.663857",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8518.332",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "99999.984",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-805.33276",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.875",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-382.56299",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-79.866455",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1599.667",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1918.5347",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.7188",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-383.66528",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-79.343994",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-83.449203",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.08662415",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-730.23291",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-68.878418",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.2236843",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.8073578",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-5.2065973",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.8635817",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.85286",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "340.36176",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.46997",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "347.72211",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.14391935E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-703.42236",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "9.31293471E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "14.773193",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47407.211",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112142.98",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-1.68290328E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.00702367E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.45716763E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.46877471E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-434077.75",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "475616.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "974.40625",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-279.42871",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "52.135757",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.02954675",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258471",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-765.43481",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1021.8035",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1276.5872",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "184.50293",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.10471466E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.37783239E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1579.0559",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "2029.655",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-350539.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "585172.25",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "974.40625",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-279.46973",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "32.745941",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.81882",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "309.95746",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "198.59674",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "316.94104",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.46997",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "343.51562",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "208.90562",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "313.50848",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005718019",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.028378",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.257761",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.62131",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.44227652E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.70953663E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.44227652E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.70953663E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem02 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.005718019",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.028378",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.09789391E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.17130446E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.09789391E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.17130446E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.03461502",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.507328",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05859202",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "36.376053",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-30.767975",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "30.766159",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.641495",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.831604",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.21057496E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03370344",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.48521",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "334.24774",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "189.37456",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "324.14944",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "189.38301",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "331.97366",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05072445",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "87.294205",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "8511.7539",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "100000.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-804.60815",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "1179.1562",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-386.28833",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "-74.313965",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1912.9836",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "2054.4441",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1180.4375",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-386.28833",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "-79.126953",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "58762.242",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-87.30661",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0868988",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-716.86914",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "-66.201416",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.4074945",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "4.3097076",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-4.612855",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "5.5417938",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.07951",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "337.07513",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.0546",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "345.3848",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.19399260E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-697.7627",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.0078125",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.7324371",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.05198706E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "15.661133",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.5",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "20.00148",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "47130.465",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "112344.6",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "7.66861035E-07",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.53183510E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.33778121E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-471467.31",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "471988.69",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "974.25",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "process": "50",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "scale_min": "-270.7063",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1",
                                                "PTVersion": "128",
                                                "scale_max": "60.277176",
                                                "PDS_TimeRange": "10",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "1.0",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.03006977",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "16.258492",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-696.97827",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "997.1897",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1324.9443",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "218.729",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vegetation type",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.9492188",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "212",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "scale_min": "-5.29808176E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "8.74662476E-08",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-1642.5115",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "1918.467",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-311553.31",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "608373.5",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "976.375",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "process": "50",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "scale_min": "-270.7063",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1",
                                                    "PTVersion": "128",
                                                    "scale_max": "34.238342",
                                                    "PDS_TimeRange": "10",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "scale_max": "0.8004687",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "210.50818",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "310.06149",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "199.16801",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "317.05606",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "209",
                                            "subcenter": "255"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "185.0546",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "341.05667",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "207",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "209.66765",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111",
                                            "PTVersion": "128",
                                            "scale_max": "313.91928",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.006932687",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.0270142",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-21.650505",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "409.79636",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.44958149E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.67411108E-05",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-1.44958149E-05",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "1.67411108E-05",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst dec2001 SIX-HOURLY mem01 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-0.006932687",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "0.0270142",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.24190535E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.04435491E-06",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-2.24190535E-06",
                                            "gribleveltype": "109",
                                            "PTVersion": "128",
                                            "scale_max": "2.04435491E-06",
                                            "PDS_TimeRange": "10",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "0.02307386",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.402786",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "0.05570711",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "35.825317",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.65715",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "33.622787",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "-31.581894",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "34.024536",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "7.98306701E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "0.03740445",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "187.45447",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "336.2601",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "process": "50",
                                            "calendar": "standard",
                                            "units": "unitless",
                                            "gribNumBits": "16",
                                            "scale_min": "186.37027",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "325.88104",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "process": "50",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "scale_min": "186.72334",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105",
                                            "PTVersion": "128",
                                            "scale_max": "331.10425",
                                            "PDS_TimeRange": "10",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "Z_10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "1.0",
                                    "long_name": "Height"
                                },
                                "Z_09": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_09",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "cm_down",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Depth"
                                },
                                "Z_08": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_08",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "cm_down",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Depth"
                                },
                                "Z_07": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_07",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "cm_down",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Depth"
                                },
                                "Z_06": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_06",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "cm_down",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Depth"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "mb",
                                    "gridtype": "0",
                                    "long_name": "pressure"
                                },
                                "sp_01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sp_01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "1.0"
                                },
                                "C": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "C",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "ids",
                                    "gridtype": "2",
                                    "long_name": "complex"
                                },
                                "Z_05": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_05",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "0.0"
                                },
                                "Z_04": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_04",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0"
                                },
                                "Y_01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Y_01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "degree_north",
                                    "gridtype": "0"
                                },
                                "Z_03": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_03",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "1.0",
                                    "long_name": "Height"
                                },
                                "sp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "1.0"
                                },
                                "Z_02": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_02",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "0.0"
                                },
                                "Z_01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m_above_gnd",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Height"
                                },
                                "Z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m_above_gnd",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Height"
                                },
                                "Y": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Y",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "degree_north",
                                    "gridtype": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "days since 2001-01-01 00:00:00",
                                    "gridtype": "0",
                                    "pointwidth": "0.25",
                                    "calendar": "standard",
                                    "defaultvalue": "545.75"
                                },
                                "X": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "X",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "degree_east",
                                    "gridtype": "1",
                                    "pointwidth": "2.8125",
                                    "modulus": "360.0"
                                },
                                "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/dec2001/SIX-HOURLY"
                            },
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type",
                                "SIXHOURLY"
                            ]
                        },
                        "ensemble": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/ensemble",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "ensemble",
                            "restriction": "Public",
                            "MONTHLY": {
                                "iridl_type": "Source",
                                "invalid": [],
                                "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/ensemble/MONTHLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "iridl_ds_name": "MONTHLY",
                                "restriction": "Public",
                                "banned_long": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ]
                            },
                            "SIXHOURLY": {
                                "iridl_type": "Source",
                                "invalid": [],
                                "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/ensemble/SIX-HOURLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "iridl_ds_name": "SIX-HOURLY",
                                "restriction": "requires dlauth tokens"
                            },
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type",
                                "MONTHLY",
                                "SIXHOURLY"
                            ]
                        },
                        "ensemble_mean": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/ensemble_mean",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "ensemble_mean",
                            "restriction": "requires dlauth tokens"
                        },
                        "feb2002": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "feb2002",
                            "restriction": "Public",
                            "SIXHOURLY": {
                                "iridl_type": "Source",
                                "invalid": [],
                                "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "iridl_ds_name": "SIX-HOURLY",
                                "restriction": "Public",
                                "mem01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem01/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc01_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.03488032",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "95.077095",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8458.4922",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-805.22119",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1178.6562",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-389.98022",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-73.057861",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1648.1514",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1904.2825",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.625",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-389.98022",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-72.128174",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-95.238434",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01908875",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-728.72241",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-62.304932",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.4381027",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.212512",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.4564505",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "7.4811993",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "182.21982",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "338.33496",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "182.21048",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "344.34692",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.28818090E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-702.94678",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.17931631E-06",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.750732",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "47164.758",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112628.94",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-8.82326093E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.36718562E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.44748992E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-9.93852012E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.42796773E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-402558.38",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "444864.06",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "971.53125",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-254.89418",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "84.088242",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.03090336",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258432",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-756.97974",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1076.3059",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1111.0049",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "197.44116",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.44259740E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.89542867E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1767.1284",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1781.8442",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-324796.81",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "655723.06",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "972.73438",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-255.40681",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "37.216766",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "210.50764",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.06464",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "196.72845",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "318.52817",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "182.21048",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "340.58716",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "210.00009",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "312.71103",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.005170345",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02917336",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-21.732273",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.5939",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.51960394E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.76433114E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.51960394E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.76433114E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem01 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.005170345",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02917336",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.90294668E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.01958028E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.90294668E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.01958028E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.02341348",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.368389",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.04330809",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "36.757362",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-31.156937",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.130432",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-32.238602",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.371033",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "6.68954954E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03295515",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "185.12122",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "334.54208",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "185.09016",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "322.61832",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.11751",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "330.47418",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem01"
                                },
                                "mem02": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem02",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "year0": "200208",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem02/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc02_%6d.01"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "98.81926",
                                            "gribparam": "230",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.04276282",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "8522.7812",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-804.95459",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "1179.7188",
                                                "gribparam": "178",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "-75.303711",
                                                "gribparam": "179",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-385.35254",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1672.5664",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1894.8735",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1180.7188",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "-78.598389",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-385.35254",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.01832581",
                                            "gribparam": "220",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-89.792328",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-67.27417",
                                            "gribparam": "205",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-740.28052",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "4.2595749",
                                            "gribparam": "181",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-3.9084082",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "6.2958317",
                                            "gribparam": "180",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-5.2600908",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "339.67004",
                                            "gribparam": "169",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "185.72554",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "348.68488",
                                            "gribparam": "139",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "185.67429",
                                            "subcenter": "255",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.25729969E-06",
                                            "gribparam": "160",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "srun",
                                            "gribleveltype": "1"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-704.36572",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.17599848E-06",
                                            "gribparam": "218",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "14.708496",
                                            "gribparam": "141",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "gribparam": "151",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "112075.73",
                                            "gribparam": "134",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "46993.48",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "7.95344761E-07",
                                            "gribparam": "144",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "-4.41163143E-28",
                                            "subcenter": "255",
                                            "grib_name": "prs",
                                            "gribleveltype": "1"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.53729138E-06",
                                            "gribparam": "142",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "gribparam": "260",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.30737408E-06",
                                            "gribparam": "143",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "445456.56",
                                            "gribparam": "108",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-416438.56",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "974.39062",
                                                "gribparam": "176",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "66.287186",
                                                "gribparam": "177",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-267.56079",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "16.258471",
                                            "gribparam": "152",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "-0.02897309",
                                            "subcenter": "255",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1123.5874",
                                            "gribparam": "146",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-726.65234",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "236.85815",
                                            "gribparam": "147",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1223.1711",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "9.47138972E-08",
                                            "gribparam": "182",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-4.89111926E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "gribparam": "274",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "gribparam": "273",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1693.5654",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1290.5366",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "618190.88",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-313905.19",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "975.10938",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "48.082016",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-267.57568",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "309.94876",
                                            "gribparam": "183",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "209.81793",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "319.67297",
                                            "gribparam": "209",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "198.08801",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "344.43097",
                                            "gribparam": "207",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "185.67429",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "313.40765",
                                            "gribparam": "170",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "209.32759",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "scale_max": "0.02953452",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.009155676",
                                            "units": "unitless",
                                            "grib_name": "hus"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "410.42059",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-21.727173",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.78297742E-05",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.55095840E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "scale_max": "1.78297742E-05",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.55095840E-05",
                                            "gribleveltype": "109"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem02 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.02953452",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.009155676",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "2.05900392E-06",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-2.20497554E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "scale_max": "2.05900392E-06",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-2.20497554E-06",
                                            "gribleveltype": "109"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "38.656155",
                                            "gribparam": "171",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.0280535",
                                            "subcenter": "255",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "39.055088",
                                            "gribparam": "216",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.04866822",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "31.653625",
                                            "gribparam": "166",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-30.330078",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "34.395279",
                                            "gribparam": "165",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-34.236343",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03649212",
                                            "gribparam": "168",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "5.09457969E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "335.68982",
                                            "gribparam": "201",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "188.79263",
                                            "subcenter": "255",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "322.91681",
                                            "gribparam": "202",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "188.68698",
                                            "subcenter": "255",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "331.19968",
                                            "gribparam": "167",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "188.69518",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem02"
                                },
                                "mem03": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem03",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "year0": "200208",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem03/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc03_%6d.01"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "97.067986",
                                            "gribparam": "230",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0453477",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "8534.5938",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-804.80054",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "1178.75",
                                                "gribparam": "178",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "-75.208008",
                                                "gribparam": "179",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-389.01929",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1693.8364",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1654.6855",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1180.5625",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "-80.130859",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-389.01929",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.01850891",
                                            "gribparam": "220",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-87.004517",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-71.790527",
                                            "gribparam": "205",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-714.99146",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "5.6253538",
                                            "gribparam": "181",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-3.6376038",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "7.083396",
                                            "gribparam": "180",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-6.9264154",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "335.90915",
                                            "gribparam": "169",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "188.78645",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "344.00842",
                                            "gribparam": "139",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "188.80197",
                                            "subcenter": "255",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.26288126E-06",
                                            "gribparam": "160",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "srun",
                                            "gribleveltype": "1"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-704.74585",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.04648643E-06",
                                            "gribparam": "218",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "13.797607",
                                            "gribparam": "141",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "gribparam": "151",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "111908.62",
                                            "gribparam": "134",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "46989.82",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "9.20112029E-07",
                                            "gribparam": "144",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "-3.52930514E-27",
                                            "subcenter": "255",
                                            "grib_name": "prs",
                                            "gribleveltype": "1"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.60706190E-06",
                                            "gribparam": "142",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "gribparam": "260",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.19927290E-06",
                                            "gribparam": "143",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "451984.88",
                                            "gribparam": "108",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-430271.38",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "969.32812",
                                                "gribparam": "176",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "75.512619",
                                                "gribparam": "177",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-247.5403",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "16.258539",
                                            "gribparam": "152",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "-0.02990128",
                                            "subcenter": "255",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1087.707",
                                            "gribparam": "146",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-783.06226",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "167.61938",
                                            "gribparam": "147",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1170.8308",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "6.70280826E-08",
                                            "gribparam": "182",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-4.68182463E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "gribparam": "274",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "gribparam": "273",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1855.8188",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1671.4058",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "613777.75",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-318953.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "973.10938",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "36.449326",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-247.5403",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "310.26587",
                                            "gribparam": "183",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "210.29163",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "318.26569",
                                            "gribparam": "209",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "200.58659",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "340.02405",
                                            "gribparam": "207",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "188.80197",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "313.44214",
                                            "gribparam": "170",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "210.09277",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "scale_max": "0.03105408",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.005720329",
                                            "units": "unitless",
                                            "grib_name": "hus"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "410.48273",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-21.892567",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.68562638E-05",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.60753152E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "scale_max": "1.68562638E-05",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.60753152E-05",
                                            "gribleveltype": "109"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem03 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03105408",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.005720329",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "2.03613263E-06",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.96227234E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "scale_max": "2.03613263E-06",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.96227234E-06",
                                            "gribleveltype": "109"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "35.659973",
                                            "gribparam": "171",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.02030093",
                                            "subcenter": "255",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "37.710258",
                                            "gribparam": "216",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0385045",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "30.49704",
                                            "gribparam": "166",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-37.634888",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "35.467438",
                                            "gribparam": "165",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-34.10054",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03587871",
                                            "gribparam": "168",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "8.18392891E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "337.90747",
                                            "gribparam": "201",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "191.13155",
                                            "subcenter": "255",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "326.13458",
                                            "gribparam": "202",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "190.75394",
                                            "subcenter": "255",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "331.23178",
                                            "gribparam": "167",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "191.0553",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem03"
                                },
                                "mem04": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem04",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "year0": "200208",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem04/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc04_%6d.01"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "93.30706",
                                            "gribparam": "230",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.04274746",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "8504.1016",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-809.25",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "1179.1875",
                                                "gribparam": "178",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "-75.342041",
                                                "gribparam": "179",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-396.22339",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "2203.4553",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1606.4102",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1180.5312",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "-78.19043",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-396.22339",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.01908875",
                                            "gribparam": "220",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-92.937485",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-67.860107",
                                            "gribparam": "205",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-753.16504",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "4.6651421",
                                            "gribparam": "181",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-4.9504795",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "5.8506784",
                                            "gribparam": "180",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-4.6977844",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "340.32678",
                                            "gribparam": "169",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "186.15236",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "348.2435",
                                            "gribparam": "139",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "186.13531",
                                            "subcenter": "255",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.53536507E-06",
                                            "gribparam": "160",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "srun",
                                            "gribleveltype": "1"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-697.95557",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.01450132E-06",
                                            "gribparam": "218",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "15.683594",
                                            "gribparam": "141",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "gribparam": "151",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "112154.83",
                                            "gribparam": "134",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "47332.309",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "7.62668435E-07",
                                            "gribparam": "144",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "-3.36580767E-33",
                                            "subcenter": "255",
                                            "grib_name": "prs",
                                            "gribleveltype": "1"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.58677381E-06",
                                            "gribparam": "142",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "gribparam": "260",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.14991451E-06",
                                            "gribparam": "143",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-1.31007763E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "460176.0",
                                            "gribparam": "108",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-415616.12",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "969.60938",
                                                "gribparam": "176",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "72.51088",
                                                "gribparam": "177",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-274.88647",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "16.258425",
                                            "gribparam": "152",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "-0.0311103",
                                            "subcenter": "255",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1168.7429",
                                            "gribparam": "146",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-812.97998",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "212.9043",
                                            "gribparam": "147",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1630.6382",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "8.51344453E-08",
                                            "gribparam": "182",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-6.52046538E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "gribparam": "274",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "gribparam": "273",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1793.4373",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1548.6409",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "631980.69",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-303636.62",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "971.75",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "34.735001",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-274.88647",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "310.35019",
                                            "gribparam": "183",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "210.11488",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "318.85413",
                                            "gribparam": "209",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "197.94704",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "344.30765",
                                            "gribparam": "207",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "186.13531",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "313.18585",
                                            "gribparam": "170",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "209.62923",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "scale_max": "0.02935112",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.006896093",
                                            "units": "unitless",
                                            "grib_name": "hus"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "410.30768",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-22.143236",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.85822773E-05",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.55192811E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "scale_max": "1.85822773E-05",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.55192811E-05",
                                            "gribleveltype": "109"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem04 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.02935112",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.006896093",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "2.05270430E-06",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.89607056E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "scale_max": "2.05270430E-06",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.89607056E-06",
                                            "gribleveltype": "109"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "35.176552",
                                            "gribparam": "171",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.03049442",
                                            "subcenter": "255",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "36.981773",
                                            "gribparam": "216",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.04651314",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "32.998367",
                                            "gribparam": "166",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-30.302185",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "33.799072",
                                            "gribparam": "165",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-32.074417",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.04050127",
                                            "gribparam": "168",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "8.43855901E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "336.70117",
                                            "gribparam": "201",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "189.14931",
                                            "subcenter": "255",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "328.03485",
                                            "gribparam": "202",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "188.99518",
                                            "subcenter": "255",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "331.65948",
                                            "gribparam": "167",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "189.03857",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem04"
                                },
                                "mem05": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem05",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "year0": "200208",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem05/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc05_%6d.01"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "95.323235",
                                            "gribparam": "230",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.04527728",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "8523.957",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-808.08813",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "1179.4062",
                                                "gribparam": "178",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "-75.203125",
                                                "gribparam": "179",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-391.21216",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1561.5371",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1534.4172",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1181.1875",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "-75.27832",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-391.21216",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.01856995",
                                            "gribparam": "220",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-87.021927",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-64.257812",
                                            "gribparam": "205",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-715.33105",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "4.2615089",
                                            "gribparam": "181",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-4.4836702",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "5.7107639",
                                            "gribparam": "180",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-5.2324572",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "336.99268",
                                            "gribparam": "169",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "183.59457",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "342.9382",
                                            "gribparam": "139",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "183.51051",
                                            "subcenter": "255",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.26149621E-06",
                                            "gribparam": "160",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "srun",
                                            "gribleveltype": "1"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-691.81543",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.02113700E-06",
                                            "gribparam": "218",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "13.072754",
                                            "gribparam": "141",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "gribparam": "151",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "112875.64",
                                            "gribparam": "134",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "47597.289",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "7.62480454E-07",
                                            "gribparam": "144",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "-5.04871003E-33",
                                            "subcenter": "255",
                                            "grib_name": "prs",
                                            "gribleveltype": "1"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.51581628E-06",
                                            "gribparam": "142",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "gribparam": "260",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.34308459E-06",
                                            "gribparam": "143",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-1.62630428E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "441579.0",
                                            "gribparam": "108",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-406589.94",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "966.75",
                                                "gribparam": "176",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "70.373535",
                                                "gribparam": "177",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-239.74797",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "16.25845",
                                            "gribparam": "152",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "-0.03106262",
                                            "subcenter": "255",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1103.4629",
                                            "gribparam": "146",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-727.62964",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "211.19556",
                                            "gribparam": "147",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1670.2886",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "8.44501642E-08",
                                            "gribparam": "182",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-6.67901645E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "gribparam": "274",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "gribparam": "273",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1744.9028",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1442.71",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "627734.31",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-248225.38",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "967.34375",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "29.137375",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-239.74797",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "310.05676",
                                            "gribparam": "183",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "210.21242",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "318.55118",
                                            "gribparam": "209",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "198.16426",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "339.04535",
                                            "gribparam": "207",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "183.51051",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "312.44067",
                                            "gribparam": "170",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "209.83183",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "scale_max": "0.02730217",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.005546246",
                                            "units": "unitless",
                                            "grib_name": "hus"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "410.37088",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-21.499807",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.75738551E-05",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.61985918E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "scale_max": "1.75738551E-05",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.61985918E-05",
                                            "gribleveltype": "109"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem05 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.02730217",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.005546246",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.87506669E-06",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.86478064E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "scale_max": "1.87506669E-06",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.86478064E-06",
                                            "gribleveltype": "109"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "35.993969",
                                            "gribparam": "171",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.02184784",
                                            "subcenter": "255",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "36.412357",
                                            "gribparam": "216",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.03938604",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "32.876312",
                                            "gribparam": "166",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-30.391632",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "34.489197",
                                            "gribparam": "165",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-32.618927",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03904601",
                                            "gribparam": "168",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "4.21688142E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "338.93958",
                                            "gribparam": "201",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "187.22169",
                                            "subcenter": "255",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "326.19196",
                                            "gribparam": "202",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "187.00183",
                                            "subcenter": "255",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "336.37604",
                                            "gribparam": "167",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "187.19719",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem05"
                                },
                                "mem06": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem06",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "year0": "200208",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem06/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc06_%6d.01"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "99.648224",
                                            "gribparam": "230",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.04191466",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "8458.5352",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-806.74609",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "1179.1875",
                                                "gribparam": "178",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "-74.78125",
                                                "gribparam": "179",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-386.22974",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1958.9626",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1745.3997",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1180.5938",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "-74.79834",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-386.22974",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0188446",
                                            "gribparam": "220",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-91.375854",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-64.260498",
                                            "gribparam": "205",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-729.40381",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "3.8375072",
                                            "gribparam": "181",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-5.4187765",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "5.4871817",
                                            "gribparam": "180",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-5.531146",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "338.53845",
                                            "gribparam": "169",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "183.61624",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "344.25897",
                                            "gribparam": "139",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "183.57129",
                                            "subcenter": "255",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.26435680E-06",
                                            "gribparam": "160",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "srun",
                                            "gribleveltype": "1"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-713.85815",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.16316369E-06",
                                            "gribparam": "218",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "14.031494",
                                            "gribparam": "141",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "gribparam": "151",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "112605.67",
                                            "gribparam": "134",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "46769.922",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "7.68565371E-07",
                                            "gribparam": "144",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "-3.52930514E-27",
                                            "subcenter": "255",
                                            "grib_name": "prs",
                                            "gribleveltype": "1"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.75610990E-06",
                                            "gribparam": "142",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "gribparam": "260",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.26455689E-06",
                                            "gribparam": "143",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "438615.88",
                                            "gribparam": "108",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-435148.56",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "976.6875",
                                                "gribparam": "176",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "75.971725",
                                                "gribparam": "177",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-266.64014",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "16.258545",
                                            "gribparam": "152",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "-0.02984527",
                                            "subcenter": "255",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1279.0212",
                                            "gribparam": "146",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-768.94556",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "215.29956",
                                            "gribparam": "147",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1320.1326",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "8.60904095E-08",
                                            "gribparam": "182",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-5.27884083E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "gribparam": "274",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "gribparam": "273",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "2185.7769",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1614.4695",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "631635.19",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-281691.25",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "976.6875",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "40.929367",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-269.84839",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "310.67847",
                                            "gribparam": "183",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "209.94679",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "319.28741",
                                            "gribparam": "209",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "196.36455",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "340.25116",
                                            "gribparam": "207",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "183.57129",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "313.95959",
                                            "gribparam": "170",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "209.30139",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "scale_max": "0.02983397",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.00436943",
                                            "units": "unitless",
                                            "grib_name": "hus"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "410.44958",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-21.867619",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.84561268E-05",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.57175364E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "scale_max": "1.84561268E-05",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.57175364E-05",
                                            "gribleveltype": "109"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem06 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.02983397",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.00436943",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "2.11346492E-06",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-2.38839561E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "scale_max": "2.11346492E-06",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-2.38839561E-06",
                                            "gribleveltype": "109"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "34.999798",
                                            "gribparam": "171",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.03152627",
                                            "subcenter": "255",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "36.499302",
                                            "gribparam": "216",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.06772685",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "30.781418",
                                            "gribparam": "166",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-31.389969",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "32.767883",
                                            "gribparam": "165",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-34.956711",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03959474",
                                            "gribparam": "168",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "7.39723873E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "337.69025",
                                            "gribparam": "201",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "186.71094",
                                            "subcenter": "255",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "323.17072",
                                            "gribparam": "202",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "185.97527",
                                            "subcenter": "255",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "332.35071",
                                            "gribparam": "167",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "186.06921",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem06"
                                },
                                "mem07": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem07",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "year0": "200208",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem07/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc07_%6d.01"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "94.97744",
                                            "gribparam": "230",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.04520214",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "8455.1797",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-809.1438",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "1179.3438",
                                                "gribparam": "178",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "-74.495361",
                                                "gribparam": "179",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-389.70483",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1627.5615",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1805.8469",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1180.875",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "-74.393799",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-395.94556",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.01896667",
                                            "gribparam": "220",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-86.138794",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-63.660156",
                                            "gribparam": "205",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-714.81787",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "4.3032789",
                                            "gribparam": "181",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-4.8586245",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "5.8389177",
                                            "gribparam": "180",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-4.7107058",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "336.867",
                                            "gribparam": "169",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "183.24281",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "341.99014",
                                            "gribparam": "139",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "183.17583",
                                            "subcenter": "255",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.32176478E-06",
                                            "gribparam": "160",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "srun",
                                            "gribleveltype": "1"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-697.44873",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.14279101E-06",
                                            "gribparam": "218",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "16.287598",
                                            "gribparam": "141",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "gribparam": "151",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "112416.41",
                                            "gribparam": "134",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "46828.113",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "8.17218222E-07",
                                            "gribparam": "144",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "-7.05861028E-27",
                                            "subcenter": "255",
                                            "grib_name": "prs",
                                            "gribleveltype": "1"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.49931066E-06",
                                            "gribparam": "142",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "gribparam": "260",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.23925781E-06",
                                            "gribparam": "143",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "450047.31",
                                            "gribparam": "108",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-397412.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "969.64062",
                                                "gribparam": "176",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "80.334854",
                                                "gribparam": "177",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-244.33914",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "16.258478",
                                            "gribparam": "152",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "-0.03017085",
                                            "subcenter": "255",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1093.9358",
                                            "gribparam": "146",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-716.08325",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "205.20532",
                                            "gribparam": "147",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1107.7986",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "8.20560331E-08",
                                            "gribparam": "182",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-4.42977608E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "gribparam": "274",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "gribparam": "273",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1806.9419",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1757.4438",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "619208.62",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-301141.88",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "972.42188",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "36.059479",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-244.33914",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "310.05597",
                                            "gribparam": "183",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "210.25484",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "316.99335",
                                            "gribparam": "209",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "196.2019",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "338.38663",
                                            "gribparam": "207",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "183.17583",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "312.12515",
                                            "gribparam": "170",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "209.59976",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "scale_max": "0.02806846",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.003661568",
                                            "units": "unitless",
                                            "grib_name": "hus"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "410.14438",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-21.652559",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.73745539E-05",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.58541643E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "scale_max": "1.73745539E-05",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.58541643E-05",
                                            "gribleveltype": "109"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem07 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.02806846",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.003661568",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "2.05745755E-06",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.94625500E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "scale_max": "2.05745755E-06",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.94625500E-06",
                                            "gribleveltype": "109"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "34.170635",
                                            "gribparam": "171",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.02473689",
                                            "subcenter": "255",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "34.807312",
                                            "gribparam": "216",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.04560766",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "29.913406",
                                            "gribparam": "166",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-29.729843",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "33.348816",
                                            "gribparam": "165",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-34.677658",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03826763",
                                            "gribparam": "168",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "4.00979197E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "332.90881",
                                            "gribparam": "201",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "187.32143",
                                            "subcenter": "255",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "322.91327",
                                            "gribparam": "202",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "186.85199",
                                            "subcenter": "255",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "330.61954",
                                            "gribparam": "167",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "186.87843",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem07"
                                },
                                "mem08": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem08",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "year0": "200208",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem08/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc08_%6d.01"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "92.789284",
                                            "gribparam": "230",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.04560963",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "8515.3945",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-808.41626",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "1179.1875",
                                                "gribparam": "178",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "-73.5896",
                                                "gribparam": "179",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-390.08984",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1774.1982",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1841.1257",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1180.625",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "-73.591553",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-390.08984",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.01841736",
                                            "gribparam": "220",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-88.532257",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-62.357666",
                                            "gribparam": "205",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-729.56689",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "5.2393627",
                                            "gribparam": "181",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-5.4302969",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "7.6453075",
                                            "gribparam": "180",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-5.2534657",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "338.64459",
                                            "gribparam": "169",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "182.2478",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "343.43018",
                                            "gribparam": "139",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "182.237",
                                            "subcenter": "255",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.35714947E-06",
                                            "gribparam": "160",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "srun",
                                            "gribleveltype": "1"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.007568359",
                                            "gribparam": "204",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-694.77612",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.06781954E-06",
                                            "gribparam": "218",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "15.036133",
                                            "gribparam": "141",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "gribparam": "151",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "112240.66",
                                            "gribparam": "134",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "47059.43",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "7.79405752E-07",
                                            "gribparam": "144",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "-7.05861028E-27",
                                            "subcenter": "255",
                                            "grib_name": "prs",
                                            "gribleveltype": "1"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.69983434E-06",
                                            "gribparam": "142",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "gribparam": "260",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.28635531E-06",
                                            "gribparam": "143",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-1.44560339E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "456138.06",
                                            "gribparam": "108",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-420124.75",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "975.64062",
                                                "gribparam": "176",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "79.064728",
                                                "gribparam": "177",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-248.86343",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "16.258516",
                                            "gribparam": "152",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "-0.03020328",
                                            "subcenter": "255",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1084.2874",
                                            "gribparam": "146",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-790.81372",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "197.43042",
                                            "gribparam": "147",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1511.5088",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "7.89489150E-08",
                                            "gribparam": "182",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-6.04410047E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "gribparam": "274",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "gribparam": "273",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "2145.0815",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1803.2527",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "626133.62",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-268477.69",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "978.14062",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "43.24614",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-248.9095",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "310.10614",
                                            "gribparam": "183",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "210.26604",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "319.03015",
                                            "gribparam": "209",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "196.73662",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "339.87939",
                                            "gribparam": "207",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "182.237",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "313.15405",
                                            "gribparam": "170",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "209.63452",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "scale_max": "0.02949612",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.007123571",
                                            "units": "unitless",
                                            "grib_name": "hus"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "410.30734",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-21.861467",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.71975753E-05",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.60222135E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "scale_max": "1.71975753E-05",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.60222135E-05",
                                            "gribleveltype": "109"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem08 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.02949612",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.007123571",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "2.01052353E-06",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-2.05218544E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "scale_max": "2.01052353E-06",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-2.05218544E-06",
                                            "gribleveltype": "109"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "37.302349",
                                            "gribparam": "171",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.0264616",
                                            "subcenter": "255",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "37.953617",
                                            "gribparam": "216",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.04259541",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "31.080963",
                                            "gribparam": "166",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-34.325241",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "34.630035",
                                            "gribparam": "165",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-37.424118",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03962543",
                                            "gribparam": "168",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "1.16015258E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "336.41339",
                                            "gribparam": "201",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "186.23291",
                                            "subcenter": "255",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "323.54242",
                                            "gribparam": "202",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "186.10732",
                                            "subcenter": "255",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "329.82025",
                                            "gribparam": "167",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "186.12779",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem08"
                                },
                                "mem09": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem09",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "year0": "200208",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem09/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc09_%6d.01"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "97.322105",
                                            "gribparam": "230",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.04032446",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "8524.3242",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-809.47363",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "1179.2188",
                                                "gribparam": "178",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "-73.195068",
                                                "gribparam": "179",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-385.06152",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1963.7295",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1798.2959",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1180.875",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "-73.288818",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-385.06152",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.01873779",
                                            "gribparam": "220",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-91.952087",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-61.618652",
                                            "gribparam": "205",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-732.62256",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "4.7925215",
                                            "gribparam": "181",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-5.2736444",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "6.2713909",
                                            "gribparam": "180",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-4.4755507",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "339.71597",
                                            "gribparam": "169",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "181.70511",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "347.76172",
                                            "gribparam": "139",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "181.70885",
                                            "subcenter": "255",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.42729061E-06",
                                            "gribparam": "160",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "srun",
                                            "gribleveltype": "1"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-709.41626",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "9.60164471E-07",
                                            "gribparam": "218",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "15.769531",
                                            "gribparam": "141",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "gribparam": "151",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "112007.73",
                                            "gribparam": "134",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "46560.832",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "8.58618648E-07",
                                            "gribparam": "144",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "-8.82326093E-28",
                                            "subcenter": "255",
                                            "grib_name": "prs",
                                            "gribleveltype": "1"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.68092322E-06",
                                            "gribparam": "142",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "gribparam": "260",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.29294165E-06",
                                            "gribparam": "143",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "466568.88",
                                            "gribparam": "108",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-445130.75",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "972.0",
                                                "gribparam": "176",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "69.770813",
                                                "gribparam": "177",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-257.89038",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "16.258442",
                                            "gribparam": "152",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "-0.02922774",
                                            "subcenter": "255",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "879.9231",
                                            "gribparam": "146",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-697.14795",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "222.2251",
                                            "gribparam": "147",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1299.6917",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "8.88620946E-08",
                                            "gribparam": "182",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-5.19710341E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "gribparam": "274",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "gribparam": "273",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1968.1167",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1579.5769",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "597574.5",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-315619.5",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "972.0",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "29.348907",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-257.89038",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "309.48621",
                                            "gribparam": "183",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "210.17307",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "318.42572",
                                            "gribparam": "209",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "195.51579",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "343.69922",
                                            "gribparam": "207",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "181.70885",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "312.28436",
                                            "gribparam": "170",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "209.65222",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "scale_max": "0.02991978",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.004838075",
                                            "units": "unitless",
                                            "grib_name": "hus"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "410.26453",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-21.389551",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.78445534E-05",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.55661255E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "scale_max": "1.78445534E-05",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.55661255E-05",
                                            "gribleveltype": "109"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem09 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.02991978",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.004838075",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.97638474E-06",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-2.00544173E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "scale_max": "1.97638474E-06",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-2.00544173E-06",
                                            "gribleveltype": "109"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "37.264683",
                                            "gribparam": "171",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.02811874",
                                            "subcenter": "255",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "38.101879",
                                            "gribparam": "216",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.04231608",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "32.079865",
                                            "gribparam": "166",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-31.659882",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "30.437515",
                                            "gribparam": "165",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-35.64949",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03537877",
                                            "gribparam": "168",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "8.56950919E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "335.69638",
                                            "gribparam": "201",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "185.30931",
                                            "subcenter": "255",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "323.80768",
                                            "gribparam": "202",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "185.17531",
                                            "subcenter": "255",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "329.84607",
                                            "gribparam": "167",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "185.18958",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem09"
                                },
                                "mem10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "year0": "200208",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem10/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc10_%6d.01"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "94.477043",
                                            "gribparam": "230",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.03746678",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribleveltype": "1"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "8517.6562",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribleveltype": "1"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "cltm",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-806.64478",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "1178.0625",
                                                "gribparam": "178",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "-75.802002",
                                                "gribparam": "179",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-387.61523",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1918.8186",
                                                    "gribparam": "105",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1704.4329",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1180.9688",
                                                    "gribparam": "187",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "-78.403809",
                                                    "gribparam": "188",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-388.0481",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribleveltype": "1"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.01913452",
                                            "gribparam": "220",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-87.541565",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribleveltype": "1"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "-68.654053",
                                            "gribparam": "205",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-734.41748",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "4.6782875",
                                            "gribparam": "181",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-4.4819717",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribleveltype": "1"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "6.2275352",
                                            "gribparam": "180",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-4.7704659",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribleveltype": "1"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "337.67484",
                                            "gribparam": "169",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "186.67175",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribleveltype": "1"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "348.35706",
                                            "gribparam": "139",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "186.64255",
                                            "subcenter": "255",
                                            "grib_name": "stemp",
                                            "gribleveltype": "1"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.15294608E-06",
                                            "gribparam": "160",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "srun",
                                            "gribleveltype": "1"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-699.69702",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribleveltype": "1"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "soilm",
                                            "gribleveltype": "1"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.12128328E-06",
                                            "gribparam": "218",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribleveltype": "1"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "16.166992",
                                            "gribparam": "141",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribleveltype": "1"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "gribparam": "151",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribleveltype": "1"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribleveltype": "1"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "SEAICE",
                                            "gribleveltype": "1"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "112606.4",
                                            "gribparam": "134",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "47313.863",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribleveltype": "1"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "8.26263999E-07",
                                            "gribparam": "144",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "units": "unitless",
                                            "scale_min": "-3.52930514E-27",
                                            "subcenter": "255",
                                            "grib_name": "prs",
                                            "gribleveltype": "1"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.70797432E-06",
                                            "gribparam": "142",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribleveltype": "1"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "gribparam": "260",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.25821305E-06",
                                            "gribparam": "143",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribleveltype": "1"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "474018.69",
                                            "gribparam": "108",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-445982.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribleveltype": "1"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "973.3125",
                                                "gribparam": "176",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribleveltype": "1"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "scale_max": "63.400589",
                                                "gribparam": "177",
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "PTVersion": "128",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "gribNumBits": "16",
                                                "subcenter": "255",
                                                "scale_min": "-260.00513",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribleveltype": "1"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribleveltype": "1"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "16.258425",
                                            "gribparam": "152",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "-0.02972448",
                                            "subcenter": "255",
                                            "grib_name": "logpsl",
                                            "gribleveltype": "1"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1358.167",
                                            "gribparam": "146",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-781.69922",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribleveltype": "1"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "211.83472",
                                            "gribparam": "147",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1446.8623",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribleveltype": "1"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.9492188",
                                            "gribparam": "212",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "units": "unitless",
                                            "scale_min": "0.0",
                                            "subcenter": "255",
                                            "grib_name": "FOREST",
                                            "gribleveltype": "1"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "8.47041122E-08",
                                            "gribparam": "182",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "gribNumBits": "24",
                                            "subcenter": "255",
                                            "scale_min": "-5.78559707E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "gribparam": "274",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "gribparam": "273",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "1910.0908",
                                                    "gribparam": "106",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-1606.1335",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "608417.88",
                                                    "gribparam": "107",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-293880.44",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribleveltype": "1"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "976.125",
                                                    "gribparam": "185",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribleveltype": "1"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "scale_max": "36.101044",
                                                    "gribparam": "186",
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "PTVersion": "128",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "gribNumBits": "16",
                                                    "subcenter": "255",
                                                    "scale_min": "-265.87842",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribleveltype": "1"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "gribNumBits": "8",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribleveltype": "1"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "309.21326",
                                            "gribparam": "183",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "210.28976",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribleveltype": "111"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "318.15918",
                                            "gribparam": "209",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "198.91429",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribleveltype": "111"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "343.90317",
                                            "gribparam": "207",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "186.64255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribleveltype": "111"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "312.03534",
                                            "gribparam": "170",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "209.86931",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribleveltype": "111"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "scale_max": "0.02842269",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.007144462",
                                            "units": "unitless",
                                            "grib_name": "hus"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "missing_value": "NaN",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "gribparam": "132",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "gribparam": "131",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "410.27731",
                                            "gribparam": "130",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-22.075171",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribleveltype": "109"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "1.72541677E-05",
                                            "gribparam": "138",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.56366605E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribleveltype": "109"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "gribparam": "148",
                                            "units": "meter2 second-1",
                                            "scale_max": "1.72541677E-05",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.56366605E-05",
                                            "gribleveltype": "109"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "gribparam": "156",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "gribparam": "135",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem10 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.02842269",
                                            "gribparam": "133",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-0.007144462",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribleveltype": "109"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "2.14816964E-06",
                                            "gribparam": "155",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.92894504E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribleveltype": "109"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "gribparam": "149",
                                            "units": "meter2 second-1",
                                            "scale_max": "2.14816964E-06",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-1.92894504E-06",
                                            "gribleveltype": "109"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "35.397903",
                                            "gribparam": "171",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "0.02507722",
                                            "subcenter": "255",
                                            "grib_name": "wind10",
                                            "gribleveltype": "105"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "38.391483",
                                            "gribparam": "216",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "0.04738655",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribleveltype": "105"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "31.742569",
                                            "gribparam": "166",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-33.480743",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribleveltype": "105"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "38.367371",
                                            "gribparam": "165",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "-35.707062",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribleveltype": "105"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "0.03984717",
                                            "gribparam": "168",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "9.34953732E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "341.68939",
                                            "gribparam": "201",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "189.70744",
                                            "subcenter": "255",
                                            "grib_name": "t2mmx",
                                            "gribleveltype": "105"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "326.24609",
                                            "gribparam": "202",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "units": "unitless",
                                            "scale_min": "189.64722",
                                            "subcenter": "255",
                                            "grib_name": "t2mmn",
                                            "gribleveltype": "105"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "scale_max": "332.62216",
                                            "gribparam": "167",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "gribNumBits": "16",
                                            "subcenter": "255",
                                            "scale_min": "189.66231",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribleveltype": "105"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem10"
                                },
                                "mem11": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem11",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem11/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc11_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.03971796",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "91.025414",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8515.4492",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-808.4856",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.0625",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-385.51416",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-75.380127",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1860.083",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1655.6941",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.875",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-385.51416",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-75.288086",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-92.057434",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01876831",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-733.07495",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-63.92627",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.4546604",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.6790428",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.6239223",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.4707422",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "183.38908",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "338.42114",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "183.39259",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "346.78513",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.44804756E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-695.5188",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "9.68895620E-07",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "14.50415",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "46961.715",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112433.67",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7.05861028E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "9.32469050E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.57677118E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.26490257E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.39206304E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-420794.06",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "422455.0",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "974.23438",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-260.323",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "57.73439",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.03029409",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258457",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-793.30835",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1116.5159",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1369.1597",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "238.58105",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.47488582E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "9.54036636E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1561.717",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1961.5229",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-272453.25",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "635946.19",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "980.625",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-260.323",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "35.692978",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "210.57622",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.89426",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "196.37498",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "319.30334",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "183.39259",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "342.52383",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "210.06892",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.815",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.008112136",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02939897",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-21.551443",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.423",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.58716630E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.74406887E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.58716630E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.74406887E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem11 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.008112136",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02939897",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.88692684E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.02307479E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.88692684E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.02307479E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.03319329",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.385342",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06484956",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.232479",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-31.401413",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.012939",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-32.610733",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.997467",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "5.81832040E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03627416",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "185.99541",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "334.35559",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "185.34279",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "324.9892",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.5999",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "333.53247",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem11"
                                },
                                "mem12": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem12",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem12/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc12_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.04547535",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "95.863571",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8530.5586",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-802.67407",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1178.9062",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-391.61792",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-74.543945",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1959.1526",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1664.3015",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.5312",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-392.32593",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-76.255127",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-85.067215",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01890564",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-724.23755",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-65.052734",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-3.3967266",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.2995119",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.1604929",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.6173849",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "184.15768",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "337.80884",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "184.19888",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "344.8576",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.25195481E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-702.08203",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.21456105E-06",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.753906",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "47345.164",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112317.02",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.65286416E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.55695534E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.36911626E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-440615.62",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "456415.56",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "970.42188",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-265.28882",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "75.59198",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.03072255",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258438",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-734.90918",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1144.0374",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1445.678",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "227.40527",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.78086201E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "9.09344635E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1573.9883",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1702.8406",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-301266.62",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "616329.88",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "973.96875",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-265.28882",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "42.590469",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "210.04556",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.29547",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "195.5347",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "318.65295",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "184.19888",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "340.55096",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.64536",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.08148",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.008144587",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02789818",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-21.583612",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.32736",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.56206970E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.71268603E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.56206970E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.71268603E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem12 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.008144587",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02789818",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.94551671E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.10762914E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.94551671E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.10762914E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.03496195",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.744625",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.04887621",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.008606",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-31.780365",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.021164",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-32.791122",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.554306",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "9.74868613E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03686246",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "187.06981",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "336.99908",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "186.8204",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "323.58749",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "186.86913",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "329.75116",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem12"
                                },
                                "mem13": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem13",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem13/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc13_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.04566569",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "97.857491",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8519.9922",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-805.34448",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.7812",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-392.2981",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-74.906982",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1692.4331",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1889.3792",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.9062",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-392.2981",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-74.598633",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-89.357376",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01882935",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-728.24072",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-64.326172",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-3.7112055",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.6411533",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-6.2549582",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.112978",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "183.67355",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "337.14178",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "183.66278",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "346.84174",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.73317585E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-696.56323",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.00160833E-06",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.998535",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "46999.652",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112104.97",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-8.82326093E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.21151446E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.64443622E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.28556724E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-422308.5",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "468759.75",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "974.3125",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-262.76855",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "63.375916",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.0301673",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258501",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-781.26025",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1122.6265",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1400.095",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "192.12646",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.59858734E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.68231132E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1548.9558",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1748.5432",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-350935.25",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "637249.19",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "974.3125",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-262.76855",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "44.553436",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.82065",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.59686",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "197.10612",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "317.39111",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "183.66278",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "342.67963",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.17693",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "312.23944",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.005342346",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03203404",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-22.09362",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.34879",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.55676662E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79882118E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.55676662E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79882118E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem13 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.005342346",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03203404",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.80973439E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.10759526E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.80973439E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.10759526E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.02518647",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.127953",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.04315287",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.731323",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-31.095871",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "29.528641",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-32.372269",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.199234",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "7.40247401E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03649069",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "187.79118",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "333.21643",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "187.50235",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "322.33588",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "187.75281",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "328.89478",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem13"
                                },
                                "mem14": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem14",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem14/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc14_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.03879613",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "99.846771",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8512.2227",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-812.47632",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.25",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-388.52222",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-76.843994",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1973.9509",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2130.5188",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.7812",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-388.52222",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-76.072998",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-88.925079",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01829529",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-731.646",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-66.515869",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.575984",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.3185196",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.7019062",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.4772339",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.20253",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "339.03101",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.22194",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "346.17007",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.50694973E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-705.42871",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.11039844E-06",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.334961",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "47363.512",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112685.27",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.76465199E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "9.37710695E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.73538297E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.31397019E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-412895.0",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "450425.19",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "969.5",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-259.5481",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "65.811981",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.02951626",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258507",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-722.47974",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1294.3457",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1703.7241",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "217.79248",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-6.81271615E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.70883810E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1470.1814",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2090.2761",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-319690.56",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "634588.69",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "969.5",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-259.5481",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "30.2379",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "210.28348",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.59766",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "197.70985",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "319.37753",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.22194",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "342.13867",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.86739",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.11346",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.006574143",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03062735",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-21.793133",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.33841",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.52874672E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81516316E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.52874672E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81516316E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem14 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.006574143",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03062735",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.96935298E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.88972047E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.96935298E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.88972047E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.02018339",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.531559",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.05210032",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "36.087399",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-34.068634",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "29.600204",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-29.667709",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.99614",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8.83770213E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03675773",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "188.24223",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "334.07837",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "187.49481",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "325.64001",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "187.51477",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "330.14398",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem14"
                                },
                                "mem15": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem15",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem15/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc15_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.04030621",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "95.552299",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8518.8984",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-803.52246",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.0938",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-391.23755",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-76.382324",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1768.3682",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1615.8145",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.9688",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-391.23755",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-75.562012",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-88.047073",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01858521",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-739.9104",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-66.082275",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.163847",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.2479296",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.1419029",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.505475",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "184.91759",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "339.99573",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.0399",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "348.22748",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.57302247E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-696.88281",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.10588735E-06",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.137207",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "47385.332",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112391.8",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.76465199E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.82311417E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.55908083E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.25626445E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-421510.94",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "437075.31",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "979.3125",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-267.88989",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "76.306259",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.02944251",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258526",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-728.98022",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1150.1521",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1486.7383",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "222.28345",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.94505025E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.88879583E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1350.7048",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1666.1345",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-266466.12",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "664182.56",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "979.3125",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-267.88989",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "34.044907",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "210.07243",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.76514",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "197.73033",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "319.30533",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.0399",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "344.00275",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.49835",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.21783",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.01137783",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03360097",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-21.685377",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.47101",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.59266820E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.72469390E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.59266820E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.72469390E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem15 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.01137783",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03360097",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.07443190E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.95581674E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.07443190E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.95581674E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.0267345",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "38.243908",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.03395388",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "38.870758",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-34.412262",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.456253",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-36.926376",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.244766",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "7.62226477E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.04436133",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "188.26192",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "336.51465",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "187.92419",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "324.74838",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "187.99831",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "336.51465",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem15"
                                },
                                "mem16": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem16",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem16/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc16_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.04422385",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "93.343781",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8478.6055",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-802.42725",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1178.8438",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-390.37305",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-77.278564",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-2003.9387",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1990.9253",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.375",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-390.37305",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-78.083984",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-87.774139",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01876831",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-733.97778",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-64.793945",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.2330132",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.5071793",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.1486702",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "7.4476709",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "184.00945",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "338.68469",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "184.01306",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "347.08862",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.57986187E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-701.08643",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.23851351E-06",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.646973",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "46926.887",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112257.91",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.20725885E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.11897314E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.94595054E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.12937729E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.34364677E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-408295.69",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "490131.88",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "968.48438",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-268.6377",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "77.0905",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.03038144",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258541",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-836.48462",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1075.6292",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1203.186",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "184.16626",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.81120424E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.36445429E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1647.6885",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2167.7158",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-286051.06",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "616413.06",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "968.48438",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-268.6377",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "28.274582",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.92268",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.37616",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "195.23721",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "318.34674",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "184.01306",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "342.63745",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.39633",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "312.32797",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.006739642",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.0298213",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-22.187309",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.76309",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.51709082E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79186136E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.51709082E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79186136E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem16 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.006739642",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.0298213",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.00851059E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.07736070E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.00851059E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.07736070E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.02163803",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.432945",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.05523648",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "36.18335",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-30.111053",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.271317",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-36.146652",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.445847",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "5.64501086E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03399777",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "187.53459",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "337.32538",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "187.38838",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "326.06573",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "187.49272",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "330.44049",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem16"
                                },
                                "mem17": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem17",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem17/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc17_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.03619625",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "93.332062",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8480.207",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-813.09912",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.2188",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-393.96875",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-70.805908",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-2247.2288",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1741.8501",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.7812",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-395.18384",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-70.860596",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-89.683609",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01869202",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-748.12402",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-60.475342",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-3.6563587",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.3808193",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.9627609",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.6853914",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "180.87392",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "339.11646",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "180.81883",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "348.03735",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.58398586E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-698.82349",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.04057835E-06",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.005859",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "47218.07",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112062.82",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-8.82326093E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.92490334E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.69942223E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.24618714E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-429533.94",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "468215.31",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "969.76562",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-277.52539",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "79.353973",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.03026057",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258417",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-740.83057",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "940.87305",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1235.4656",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "187.73364",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.94028143E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.50701759E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1809.0818",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1755.8606",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-284850.56",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "618210.69",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "974.76562",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-277.56885",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "36.682648",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "210.00525",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.62451",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "196.20677",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "319.0101",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "180.81883",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "343.84506",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.52437",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.46185",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.00777626",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02791874",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-21.593433",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.15887",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.61034386E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81336709E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.61034386E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81336709E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem17 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.00777626",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02791874",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.15222894E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.00771160E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.15222894E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.00771160E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.03311005",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.200039",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0591724",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.730003",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-31.367416",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "30.410751",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-37.069183",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.654556",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "4.61523229E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03348602",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "183.55582",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "336.32233",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "183.24422",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "324.87592",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "183.2849",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "329.67523",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem17"
                                },
                                "mem18": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem18",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem18/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc18_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0432536",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "90.054497",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8547.0273",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-805.43579",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.6875",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-385.57251",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-74.419434",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1846.7776",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1643.2515",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1181.0",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-387.82056",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-74.419434",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-87.093979",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01864624",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-736.01904",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-64.027344",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.4970922",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.0192785",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.5726786",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.7917986",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "183.4409",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "338.16528",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "183.40289",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "346.56863",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.22156337E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-699.12598",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.05437357E-06",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.491699",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "46947.215",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112119.42",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.65385630E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.62625668E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.26490257E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.33085666E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-407014.5",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "471819.62",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "971.78125",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-262.04126",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "76.498856",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.03035204",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.25852",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-702.37988",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1004.7976",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1430.9187",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "184.27124",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.72184319E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.36820027E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1599.105",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1786.343",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-300843.25",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "660891.69",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "972.6875",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-262.05518",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "35.527649",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "210.21176",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.49942",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "195.9144",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "317.2215",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "183.40289",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "342.5434",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.73444",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "311.89957",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.004676051",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02941443",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-21.68063",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.25211",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.53297369E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81102496E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.53297369E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81102496E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem18 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.004676051",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02941443",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.97541226E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.07478797E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.97541226E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.07478797E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.03264575",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "36.952175",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.04982528",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.700592",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-28.579178",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.438751",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-35.866135",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.521744",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "3.75571254E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03918955",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "186.57626",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "334.42346",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "186.16808",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "323.1076",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "186.21103",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "331.51642",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem18"
                                },
                                "mem19": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem19",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem19/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc19_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.04979943",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "95.030197",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8522.0859",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-805.18896",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1178.9062",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-397.24756",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-73.815674",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1842.0481",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1556.0312",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.9688",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-397.24756",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-73.971924",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-85.726349",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.019104",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-723.67114",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-62.814209",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.4466925",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.8579388",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.0262041",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.4762659",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "182.6676",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "336.88058",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "182.53455",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "345.28467",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.19281412E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-735.54175",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.03842467E-06",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.717529",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "47256.035",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112399.16",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.56212728E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.74736090E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.44149487E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-426273.31",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "426726.25",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "971.1875",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-275.90527",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "73.644653",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.03009525",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258457",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-703.38989",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1054.8357",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1617.7383",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "192.38794",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-6.46888282E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.69276483E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1680.3882",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1701.0757",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-280587.56",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "630957.19",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "971.1875",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-277.4231",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "49.658936",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "210.3241",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.21655",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "197.74638",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "318.34705",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "182.53455",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "341.36481",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.70119",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.12109",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.003698813",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03102643",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-21.693596",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.3443",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.54293248E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.72573600E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.54293248E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.72573600E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem19 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.003698813",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03102643",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.93176447E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.10999974E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.93176447E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.10999974E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.02980011",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.815674",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.04700363",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.246487",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-30.72876",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "29.708389",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-33.598007",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.437592",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "7.80850655E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03494457",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "185.9599",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "338.5014",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "185.24738",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "324.54892",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.30319",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "329.23859",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem19"
                                },
                                "mem20": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem20",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem20/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc20_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.04721825",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "95.239792",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8532.4766",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "99999.992",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-801.14453",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.4062",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-383.41016",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-76.028564",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1630.3757",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1829.9702",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.5",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-383.41016",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-75.955811",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-90.832672",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01911926",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-745.78418",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-64.638672",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.2079821",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.3215284",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.6489906",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.2728491",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "183.93419",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "339.40302",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "183.79375",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "348.13818",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.65669735E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-701.40088",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.04287756E-06",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.521484",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "47032.113",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112455.38",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "9.05278682E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.70029364E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.17455236E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.22555571E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-433983.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "483176.56",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "976.6875",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-266.09766",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "77.37204",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.03066443",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258488",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-772.96899",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1178.5049",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1438.9141",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "194.60181",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.75381421E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.78152298E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1739.8279",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1925.7007",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-321661.25",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "635262.19",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "976.6875",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-266.09766",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "29.860794",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.38564",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.96997",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "194.97694",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "316.62067",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "183.79375",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "343.98975",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "208.70685",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "311.49854",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.006048303",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02921246",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-21.828112",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.12607",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.56102760E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82233034E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.56102760E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82233034E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem20 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.006048303",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02921246",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.00980321E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.08688380E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.00980321E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.08688380E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.02515552",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.353672",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06672525",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.073124",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-31.214249",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.956772",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-32.653183",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.850937",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "4.75210129E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03433353",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "186.26361",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "337.36197",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "186.00362",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "323.81534",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "186.06644",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "337.36197",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem20"
                                },
                                "mem21": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem21",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem21/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc21_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.05752024",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "98.356857",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8519.4492",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-805.43408",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.25",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-394.63892",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-76.158447",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1776.4946",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1613.6619",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.9375",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-394.63892",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-79.677979",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-85.154007",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01832581",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-726.87109",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-67.570557",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-3.9431372",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.7379322",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.7269564",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.1294985",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.94495",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "338.3898",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.9619",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "344.90826",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.13043791E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-697.01538",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.04409992E-06",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.572754",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "47380.914",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112456.56",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-3.36580767E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.01760166E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.84512805E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.50068547E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-404129.94",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "496051.56",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "972.32812",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-249.84319",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "63.847488",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.03073005",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258497",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-727.05493",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1127.467",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1210.5498",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "190.32544",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.84064969E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.61071703E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1442.3811",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1813.9158",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-321107.25",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "635973.69",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "976.04688",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-249.88515",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "23.99147",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.9111",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.29297",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "198.64383",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "320.0224",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.9619",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "340.79694",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.48497",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "314.1283",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.007486403",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02964471",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-21.424946",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.51761",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.48114095E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79897852E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.48114095E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.79897852E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem21 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.007486403",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02964471",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.06279924E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.23808661E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.06279924E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.23808661E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.02488391",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.591034",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.04686807",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "36.129704",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-30.448425",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.171936",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-33.016083",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.249344",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8.16950205E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03834465",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "189.20699",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "332.77051",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "189.06142",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "321.81796",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "189.08229",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "329.3884",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem21"
                                },
                                "mem22": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem22",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem22/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc22_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0385423",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "91.68515",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8481.3633",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-806.36768",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.6562",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-384.93164",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-73.03418",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1923.8003",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1513.8752",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.875",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-384.93164",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-72.66333",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-88.415146",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01875305",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-728.76392",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-61.221436",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.705698",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "7.4612103",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.9681273",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.0165997",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "181.42435",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "340.07693",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "181.40503",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "347.78061",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.37495419E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-694.71631",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.01310434E-06",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.639648",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "46762.82",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112366.53",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7.05861028E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.50767890E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "2.04583489E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.20157290E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-425264.69",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "490630.62",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "968.15625",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-255.69225",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "62.846939",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.02999176",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258453",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-776.14966",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1366.1519",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1429.5635",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "200.88647",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.71642374E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.03313753E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1701.0334",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1749.8396",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-337354.19",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "626532.94",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "976.17188",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-262.2959",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "26.100662",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "210.40489",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.78448",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "195.64877",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "317.71588",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "181.40503",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "343.65756",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.48387",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "312.28662",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.006928936",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02765715",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-22.061617",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.22931",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.52107077E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.74756224E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.52107077E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.74756224E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem22 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.006928936",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02765715",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.09172140E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.26970610E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.09172140E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.26970610E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.01536447",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "34.441578",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.03377423",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.436737",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-30.439865",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "31.107086",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-33.236115",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.130722",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "6.44949409E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03746915",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "185.06287",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "336.52805",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "185.03304",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "321.87463",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.06287",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "336.52805",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem22"
                                },
                                "mem23": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem23",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem23/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc23_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.03567115",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "91.995598",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8512.2422",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-809.32495",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1178.6875",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-386.06226",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-71.540527",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1687.5352",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1403.4602",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.4062",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-386.06226",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-71.438965",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-88.428894",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01913452",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-719.84204",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-62.206055",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-4.2196655",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "4.2135963",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.1027727",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.30196",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "182.12036",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "336.52823",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "182.12129",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "345.68323",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.59250260E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-696.91748",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "9.97970346E-07",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.632324",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "47271.816",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112234.11",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-8.82327826E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "6.74273565E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.65151789E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.44560339E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.23002701E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-394089.25",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "462051.38",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "972.76562",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-254.1398",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "79.692001",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.03105781",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258482",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-771.59668",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1173.9685",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1253.8079",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "205.55688",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.01362706E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "8.21968342E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1370.9836",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1847.3733",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-278015.5",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "627232.06",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "973.09375",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-254.1398",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "43.620773",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "210.43504",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "310.11169",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "195.85025",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "317.22675",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "182.12129",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "341.6507",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.51457",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "311.9306",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.004145872",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.02905769",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-21.943607",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.22552",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.58958046E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.74009529E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.58958046E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.74009529E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem23 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.004145872",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02905769",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.90063668E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.09907603E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.90063668E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.09907603E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.02228612",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.557777",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.04366729",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.893261",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-33.47435",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.280258",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-37.42041",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "33.917694",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "5.19664276E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03676822",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "185.09262",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "334.67667",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "184.32697",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "323.73996",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "184.55055",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "330.83716",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem23"
                                },
                                "mem24": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem24",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "NC_GLOBAL": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "NC_GLOBAL",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                        "griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.feb2002/.SIX-HOURLY/.mem24/.griblist.html",
                                        "Conventions": "IRIDL",
                                        "filepattern": "/mstore/iri/forecast/data/echam4/asst/feb02/30006fc24_%6d.01",
                                        "year0": "200208"
                                    },
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.05364768",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "99.082947",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "8518.5156",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-804.46606",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.0625",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-389.48169",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "-76.771484",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1988.2046",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1842.4702",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1181.0312",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-389.48169",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-78.871826",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-85.499924",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.01831055",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-719.91699",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "-67.439941",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.0191488",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "5.7083797",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.1626644",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "6.8764572",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.86497",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "337.69098",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.88556",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "345.13892",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.29305101E-06",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-700.81226",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.08696986E-06",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "15.497803",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "47155.406",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "112702.78",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "9.14384998E-07",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.87069236E-06",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "1.23031748E-06",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-419247.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "426683.12",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "967.90625",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "PDS_TimeRange": "10",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "subcenter": "255",
                                                "scale_min": "-254.45477",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "gribNumBits": "16",
                                                "gribleveltype": "1",
                                                "scale_max": "69.947937",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.02955252",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258469",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-856.79688",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "1025.6418",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1297.6865",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1",
                                            "scale_max": "185.67065",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-5.18908507E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "gribNumBits": "24",
                                            "gribleveltype": "1",
                                            "scale_max": "7.42474526E-08",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-1341.9639",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1810.5801",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-256077.62",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "660511.62",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "971.26562",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "PDS_TimeRange": "10",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "subcenter": "255",
                                                    "scale_min": "-254.45477",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "gribNumBits": "16",
                                                    "gribleveltype": "1",
                                                    "scale_max": "31.611328",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "gribNumBits": "8",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "210.13968",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "309.87695",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "198.95137",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "319.05112",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "185.88556",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "341.09454",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "209.73093",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "gribNumBits": "16",
                                            "gribleveltype": "111",
                                            "scale_max": "313.13275",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.007042486",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "scale_max": "0.03041704",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-21.772392",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "410.73926",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.54915288E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.77279762E-05",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-1.54915288E-05",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "1.77279762E-05"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "1"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst feb2002 SIX-HOURLY mem24 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-0.007042486",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03041704",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.00409363E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.13811586E-06",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-2.00409363E-06",
                                            "gribNumBits": "16",
                                            "gribleveltype": "109",
                                            "scale_max": "2.13811586E-06"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "0.02311429",
                                            "grib_name": "wind10",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "35.722454",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "0.02947626",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "37.324894",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-30.461014",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.121185",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "-31.273605",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "32.53598",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "1.23189409E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03471608",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "190.50206",
                                            "grib_name": "t2mmx",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "334.84827",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "subcenter": "255",
                                            "scale_min": "190.41159",
                                            "grib_name": "t2mmn",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "323.87366",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "PDS_TimeRange": "10",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "scale_min": "190.42464",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "gribNumBits": "16",
                                            "gribleveltype": "105",
                                            "scale_max": "331.07886",
                                            "gribparam": "167"
                                        }
                                    },
                                    "Z_10": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_10",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "Z_09": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_09",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_08": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_08",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_07": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_07",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "Z_06": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_06",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "cm_down",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Depth"
                                    },
                                    "P": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "P",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "mb",
                                        "gridtype": "0",
                                        "long_name": "pressure"
                                    },
                                    "sp_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "C": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "C",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "ids",
                                        "gridtype": "2",
                                        "long_name": "complex"
                                    },
                                    "Z_05": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_05",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_04": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_04",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0"
                                    },
                                    "Y_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "Z_03": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_03",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0",
                                        "long_name": "Height"
                                    },
                                    "sp": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "sp",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "1.0"
                                    },
                                    "Z_02": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_02",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "unitless",
                                        "gridtype": "0",
                                        "pointwidth": "0.0"
                                    },
                                    "Z_01": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z_01",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Z": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Z",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "m_above_gnd",
                                        "gridtype": "0",
                                        "pointwidth": "0",
                                        "long_name": "Height"
                                    },
                                    "Y": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "Y",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_north",
                                        "gridtype": "0"
                                    },
                                    "T": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "T",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "days since 2001-01-01 00:00:00",
                                        "gridtype": "0",
                                        "pointwidth": "0.25",
                                        "calendar": "standard",
                                        "defaultvalue": "607.75"
                                    },
                                    "X": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "X",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "units": "degree_east",
                                        "gridtype": "1",
                                        "pointwidth": "2.8125",
                                        "modulus": "360.0"
                                    },
                                    "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/feb2002/SIX-HOURLY/mem24"
                                },
                                "banned_long": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type",
                                    "mem01",
                                    "mem02",
                                    "mem03",
                                    "mem04",
                                    "mem05",
                                    "mem06",
                                    "mem07",
                                    "mem08",
                                    "mem09",
                                    "mem10",
                                    "mem11",
                                    "mem12",
                                    "mem13",
                                    "mem14",
                                    "mem15",
                                    "mem16",
                                    "mem17",
                                    "mem18",
                                    "mem19",
                                    "mem20",
                                    "mem21",
                                    "mem22",
                                    "mem23",
                                    "mem24"
                                ]
                            },
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type",
                                "SIXHOURLY"
                            ]
                        },
                        "jan2002": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/jan2002",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "jan2002",
                            "restriction": "Public",
                            "SIXHOURLY": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "SIX-HOURLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "NC_GLOBAL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "NC_GLOBAL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "mem24PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem24griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem24/.griblist.html",
                                    "mem24filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc24_%6d.01",
                                    "mem24year0": "200207",
                                    "mem23PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem23griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem23/.griblist.html",
                                    "mem23filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc23_%6d.01",
                                    "mem23year0": "200207",
                                    "mem22PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem22griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem22/.griblist.html",
                                    "mem22filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc22_%6d.01",
                                    "mem22year0": "200207",
                                    "mem21PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem21griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem21/.griblist.html",
                                    "mem21filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc21_%6d.01",
                                    "mem21year0": "200207",
                                    "mem20PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem20griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem20/.griblist.html",
                                    "mem20filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc20_%6d.01",
                                    "mem20year0": "200207",
                                    "mem19PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem19griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem19/.griblist.html",
                                    "mem19filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc19_%6d.01",
                                    "mem19year0": "200207",
                                    "mem18PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem18griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem18/.griblist.html",
                                    "mem18filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc18_%6d.01",
                                    "mem18year0": "200207",
                                    "mem17PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem17griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem17/.griblist.html",
                                    "mem17filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc17_%6d.01",
                                    "mem17year0": "200207",
                                    "mem16PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem16griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem16/.griblist.html",
                                    "mem16filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc16_%6d.01",
                                    "mem16year0": "200207",
                                    "mem15PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem15griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem15/.griblist.html",
                                    "mem15filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc15_%6d.01",
                                    "mem15year0": "200207",
                                    "mem14PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem14griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem14/.griblist.html",
                                    "mem14filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc14_%6d.01",
                                    "mem14year0": "200207",
                                    "mem13PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem13griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem13/.griblist.html",
                                    "mem13filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc13_%6d.01",
                                    "mem13year0": "200207",
                                    "mem12PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem12griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem12/.griblist.html",
                                    "mem12filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc12_%6d.01",
                                    "mem12year0": "200207",
                                    "mem11PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem11griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem11/.griblist.html",
                                    "mem11filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc11_%6d.01",
                                    "mem11year0": "200207",
                                    "mem10PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem10griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem10/.griblist.html",
                                    "mem10filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc10_%6d.01",
                                    "mem10year0": "200207",
                                    "mem09PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem09griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem09/.griblist.html",
                                    "mem09filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc09_%6d.01",
                                    "mem09year0": "200207",
                                    "mem08PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem08griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem08/.griblist.html",
                                    "mem08filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc08_%6d.01",
                                    "mem08year0": "200207",
                                    "mem07PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem07griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem07/.griblist.html",
                                    "mem07filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc07_%6d.01",
                                    "mem07year0": "200207",
                                    "mem06PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem06griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem06/.griblist.html",
                                    "mem06filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc06_%6d.01",
                                    "mem06year0": "200207",
                                    "mem05PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem05griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem05/.griblist.html",
                                    "mem05filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc05_%6d.01",
                                    "mem05year0": "200207",
                                    "mem04PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem04griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem04/.griblist.html",
                                    "mem04filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc04_%6d.01",
                                    "mem04year0": "200207",
                                    "mem03PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem03griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem03/.griblist.html",
                                    "mem03filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc03_%6d.01",
                                    "mem03year0": "200207",
                                    "mem02PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem02griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem02/.griblist.html",
                                    "mem02filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc02_%6d.01",
                                    "mem02year0": "200207",
                                    "mem01PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem01griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jan2002/.SIX-HOURLY/.mem01/.griblist.html",
                                    "mem01filepattern": "/mstore/iri/forecast/data/echam4/asst/jan02/30005fc01_%6d.01",
                                    "mem01year0": "200207",
                                    "Conventions": "IRIDL"
                                },
                                "mem24": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem24",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.03279812",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "97.225235",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8500.2812",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-806.89868",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.5938",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-395.25537",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-76.350342",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1632.6357",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1577.9519",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.8438",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-395.25537",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-77.894531",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-85.914627",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05238342",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-734.14819",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-66.22998",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.0943336",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.2203341",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.354372",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.9699869",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.00592",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "339.00983",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.06052",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "348.37756",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.17132845E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-690.50195",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.17407762E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "15.450684",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "47256.039",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112357.41",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "8.26761720E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.51063603E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.57770251E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-438272.88",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "432658.06",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "973.59375",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-270.00464",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "80.493744",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03084312",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258516",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-718.38354",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1125.4028",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1568.3291",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "171.06714",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-6.27130930E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.84055692E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1792.4719",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1913.467",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-289124.0",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "615150.25",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "973.59375",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-270.00464",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "45.660675",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.14034",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "309.87772",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "197.26282",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "318.31683",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.06052",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "343.97131",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.35413",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.1217",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004251331",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.03199366",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.438604",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.34326",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.60094605E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.59809952E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.60094605E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.59809952E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem24 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004251331",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03199366",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.30605565E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.11836937E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.30605565E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.11836937E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.03376244",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "36.521477",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05518175",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "37.099377",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-33.202881",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "31.820618",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-34.347733",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.849823",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "7.81673180E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03302071",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "188.48289",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "341.30835",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "187.98793",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "325.15393",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "187.99562",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "332.68643",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem23": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem23",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04006007",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "92.057632",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8519.0508",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-807.69653",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.5938",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-392.00024",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-71.692139",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1584.6614",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1881.8127",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1181.125",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-392.00024",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-71.535889",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-88.635284",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.051651",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-745.65698",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-60.435791",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.1146107",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.202817",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.3115196",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.6078076",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "180.83926",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "340.57379",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "180.84174",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "348.33826",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.42241299E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-692.87988",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.08595123E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "16.549805",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "47081.293",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112359.53",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.41163143E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.02190177E-06",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.53074677E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.46323271E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-463740.62",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "475793.06",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "969.20312",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-261.90186",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "75.64595",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.02875724",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258442",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-736.70483",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1228.6924",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1390.3154",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "175.25854",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.55948247E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.00810858E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1533.7637",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1781.7795",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-283966.5",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "623171.06",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "982.35938",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-261.90186",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "42.206696",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.43488",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.11285",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "196.2632",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "317.62549",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "180.84174",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "344.10956",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.72362",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.28027",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.003125117",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.03018439",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.733534",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.24762",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.58440580E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.63477907E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.58440580E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.63477907E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem23 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.003125117",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03018439",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.28358658E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.13500539E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.28358658E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.13500539E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.02137032",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.921795",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04602501",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.851433",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-31.580704",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "31.08461",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-30.899567",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.246017",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "6.66346978E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.041143",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "185.91922",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "336.85797",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "185.86748",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "326.52509",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.88808",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "329.34811",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem22": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem22",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05126878",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "94.104141",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8485.9648",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-807.71387",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.0312",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-391.87744",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-79.266602",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1750.5046",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2117.6084",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1181.0625",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-391.87744",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-79.571289",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-88.635254",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05221558",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-720.56177",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-68.435059",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.0646782",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.1932049",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.2460251",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.060936",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "186.5253",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "337.40137",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "186.48264",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "343.76971",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.25546626E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-708.54492",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "9.76433512E-07",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "15.593262",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "47149.25",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112263.62",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.68290328E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "9.76716478E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.37047084E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.44606906E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-444396.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "475064.81",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "972.65625",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-246.76799",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "67.669724",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03163538",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.25848",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-741.47046",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1046.9246",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1392.4131",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "204.3335",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.56787029E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.76335014E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1786.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1888.1938",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-335424.12",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "599436.06",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "972.65625",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-247.5544",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "34.194534",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.40459",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "309.78571",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "197.30493",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "318.40085",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "186.48264",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "339.65253",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.78809",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "312.96973",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004741929",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.0288264",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.85808",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.30319",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.58756866E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.61638636E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.58756866E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.61638636E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem22 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004741929",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.0288264",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.97664053E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.15659702E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.97664053E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.15659702E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.02938361",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "36.99411",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05482521",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "38.446007",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-30.400024",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "35.957397",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-33.795868",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.70639",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.19425522E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03667312",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "189.78923",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "333.7359",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "189.47435",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "324.17978",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "189.47763",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "330.15173",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem21": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem21",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.03611544",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "90.966675",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8512.1953",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-803.50562",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.6562",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-408.27173",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-72.88916",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1706.1235",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1782.1711",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.4062",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-408.27173",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-72.641602",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-91.60318",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05215454",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-732.73145",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-61.888428",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.3289557",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "4.6718168",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.5546198",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.3105526",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "181.89104",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "338.48611",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "181.88492",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "345.98593",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.90316405E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-693.58252",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.08539825E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "16.663086",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "47111.961",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "113060.6",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7.05861028E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "9.03516309E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.69953591E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7.67976602E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.36645599E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-418641.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "470164.56",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "983.51562",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-268.87183",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "66.934845",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03134108",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258432",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-725.3623",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1193.4043",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1231.1169",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "204.17041",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.92289246E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "8.16447994E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1980.0046",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2128.6934",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-296588.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "633484.12",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "983.51562",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-268.87183",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "37.345459",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.91118",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.2933",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "195.19817",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "319.07098",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "181.88492",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "342.05304",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.04863",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "312.82599",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004750445",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02762971",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.743299",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.31079",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.55550915E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.56345213E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.55550915E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.56345213E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem21 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004750445",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02762971",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.93227766E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.25611598E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.93227766E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.25611598E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.02800023",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "35.1007",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04699022",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "37.336403",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-31.028549",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "35.132065",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-31.618958",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.874207",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "4.93001835E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03735365",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "185.09473",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "340.39551",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "184.89044",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "328.38965",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "184.96484",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "333.52753",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem20": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem20",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04498257",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "90.544495",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8554.6836",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-803.15161",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.375",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-405.1394",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-72.142822",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1482.03",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1802.7585",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.3125",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-405.1394",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-72.174072",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-90.207062",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05163574",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-732.34668",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-61.14624",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.2932177",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.3532238",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.861042",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.5176497",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "181.36237",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "338.33081",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "181.37109",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "347.4317",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.29262412E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-723.51343",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.21825724E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "16.375977",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "46882.258",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112402.22",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.76465199E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.05872196E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.52536506E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.45871786E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-445410.06",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "435317.5",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "978.07812",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-279.00171",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "65.31485",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03051428",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258429",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-860.63208",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1121.8218",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1315.4978",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "192.27686",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.26030760E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.68854420E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1677.7432",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1890.4641",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-293880.31",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "578967.44",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "978.07812",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-279.01392",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "44.392975",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.38565",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "309.97159",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "195.61125",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "317.05743",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "181.37109",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "343.17194",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.03781",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.41086",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.006879296",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02972195",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.367874",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.2345",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.57540962E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.55899907E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.57540962E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.55899907E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem20 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.006879296",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02972195",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.88441993E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.95235702E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.88441993E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.95235702E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.03565289",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.650909",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04870835",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "35.742775",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-34.371262",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.316101",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-32.623749",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.270294",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "4.76401354E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.04108543",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "185.54251",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "335.34613",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "185.48283",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "325.71625",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.49136",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "335.34357",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem19": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem19",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05060116",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "99.05706",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8457.8008",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-803.25732",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.375",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-401.82642",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-77.196045",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1945.0286",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1925.5295",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1181.0938",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-401.82642",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-79.417236",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-90.077042",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05221558",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-736.03101",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-67.163086",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-3.9406404",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.4874477",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.909688",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.0060225",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.72763",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "339.77493",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.56387",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "348.14719",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.23699851E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-693.46558",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.15102739E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "15.705078",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "46922.699",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112676.48",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-8.82326093E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "8.79904803E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.58186208E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.39460064E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-433913.25",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "466470.5",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "969.53125",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-295.24146",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "64.778366",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.02979471",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258453",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-789.5874",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "879.54395",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1222.7153",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "190.55273",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.88929629E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.61966987E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1618.0498",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1705.9099",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-242484.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "666316.19",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "973.20312",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-295.24146",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "29.731064",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.32439",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.21576",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "197.79915",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "319.03992",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.56387",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "343.85422",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.63492",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.1564",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004803076",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.03144464",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.868572",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.57181",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.52222947E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.58550938E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.52222947E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.58550938E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem19 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004803076",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03144464",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.92358925E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.17095726E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.92358925E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.17095726E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.02262837",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.194168",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.03729128",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.546478",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-28.542221",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.133606",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-32.608994",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.625443",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.17230059E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03793859",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "189.40215",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "334.8631",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "188.72005",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "325.96393",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "188.77191",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "333.04657",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem18": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem18",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.03899765",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "89.061218",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8511.5977",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-807.31982",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.4062",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-389.51367",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-75.829346",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1758.3281",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1588.8745",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.9062",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-389.51367",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-75.516846",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-84.098999",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05218506",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-737.85498",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-63.5271",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-3.9464703",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.3121967",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-6.0395536",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.2973509",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.10489",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "339.24951",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.02737",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "348.38504",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.21316873E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-697.9585",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.21380435E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "16.452637",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "46992.512",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112072.17",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.20581571E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.09270434E-06",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.79728238E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.26490257E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.53576866E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-420203.25",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "496806.38",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "966.17188",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-276.07349",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "73.992004",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.0305696",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258448",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-698.55298",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "894.33398",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1354.4272",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "172.93457",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.41597558E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.91497348E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1913.7119",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1799.7153",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-306146.25",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "567819.25",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "967.32812",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-276.07349",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "32.765656",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.21188",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "309.49744",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "195.43736",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "318.10278",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.02737",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "344.16629",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.53528",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.38098",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.005792174",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02837262",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.744999",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.25244",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.50210390E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.63083678E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.50210390E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.63083678E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem18 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.005792174",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02837262",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.09455106E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.05732658E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.09455106E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.05732658E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.02800053",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.196156",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04838804",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "35.501789",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-30.181412",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "30.630005",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-33.465454",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.52066",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "5.33332596E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03433188",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "187.17746",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "333.94928",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "187.07631",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "323.07098",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "187.08644",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "329.60229",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem17": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem17",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.03966185",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "92.447487",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8477.8047",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-805.14062",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.0",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-395.68066",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-73.176758",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1818.2913",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2122.9744",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1181.0625",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-395.68066",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-73.176758",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-93.540085",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05215454",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-730.9751",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-63.003662",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-3.5814095",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "4.0994453",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.4713268",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.2417889",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "182.74713",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "337.94653",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "182.71964",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "345.51416",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.29032742E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-699.92236",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.04110222E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "15.040771",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "46848.309",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112192.61",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "8.65673712E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.78467337E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.45444085E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-443597.38",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "439058.31",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "968.5625",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-293.12402",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "78.429672",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03014309",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258453",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-704.18457",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1143.5249",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1496.7195",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "202.25415",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.98496229E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "8.08732921E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-2131.4304",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2109.075",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-339525.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "625059.06",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "969.64062",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-293.12402",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "29.67514",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.00504",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.62341",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "196.40877",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "318.30923",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "182.71964",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "341.31567",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.25827",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "314.04733",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004841097",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02909963",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.66663",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.49863",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.59029278E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.66425070E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.59029278E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.66425070E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem17 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004841097",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02909963",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.93792152E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.04340199E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.93792152E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.04340199E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.02963049",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.104858",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04266725",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "37.345242",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-31.740768",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.518311",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-34.060211",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.32489",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "7.33830916E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03351516",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "185.59526",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "336.04593",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "185.37758",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "325.9519",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.49203",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "330.65894",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem16": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem16",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0356346",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "94.446312",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8518.4531",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-809.83984",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1178.3125",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-388.77002",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-70.566406",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1956.4802",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1769.3997",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1181.2188",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-397.87695",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-70.566406",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-90.790436",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05197144",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-735.62451",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-60.554199",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.0827684",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.2612991",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.8833761",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.5485878",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "181.01338",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "338.07169",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "180.79222",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "346.39389",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.21750145E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-695.24194",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.22151687E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "16.773438",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "47242.879",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112508.13",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.76465199E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.47398929E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.92768357E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.29040836E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-398324.12",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "458848.25",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "969.79688",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-272.77295",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "70.074371",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03236537",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258587",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-784.30127",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1341.2334",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1440.4893",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "173.48145",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.76011359E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.93687525E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1711.0359",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1795.8096",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-299680.69",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "601905.62",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "972.07812",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-272.77295",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "37.63269",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.92264",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "309.37616",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "195.3829",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "317.46155",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "180.79222",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "342.36655",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.20789",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "311.88171",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004022695",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02859046",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.491917",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.30942",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.61573480E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.57902414E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.61573480E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.57902414E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem16 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004022695",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02859046",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.04243588E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.06388791E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.04243588E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.06388791E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.03171047",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.44099",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05216129",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "35.471706",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-32.626251",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "30.868515",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-31.207779",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.785187",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "7.48028697E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03664187",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "185.36783",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "333.34235",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "185.27301",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "326.62311",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.29552",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "330.56342",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem15": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem15",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05597227",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "94.933403",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8522.1484",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-810.3125",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1180.1875",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-390.65747",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-79.790527",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1576.4248",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1430.7568",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.6875",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-390.65747",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-79.532715",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-84.71405",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05183411",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-760.85596",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-67.495117",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.643796",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "4.2671671",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.65306",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.2528014",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.89026",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "341.70184",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.83757",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "349.86002",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.28474221E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-700.22217",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.16458978E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "16.285645",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "46702.785",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112107.2",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.76465199E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.90381932E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.46359673E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.34745017E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-442532.62",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "438224.12",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "976.78125",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-279.60718",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "64.658478",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.02995696",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258402",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-731.23242",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "900.22534",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1370.3633",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "177.78052",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.47969876E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.10916765E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1679.4573",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1719.6831",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-291717.81",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "588296.25",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "976.78125",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-279.60718",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "31.552109",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.07327",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "309.76413",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "198.90617",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "317.28162",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.83757",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "345.82489",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.14102",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "312.73282",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.009485044",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02740366",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.876225",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.46927",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.53322853E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.62049073E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.53322853E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.62049073E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem15 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.009485044",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02740366",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.85698366E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.05982178E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.85698366E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.05982178E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.03155332",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.762329",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05714053",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.663895",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-29.822418",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "31.692535",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-29.649582",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.993393",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "6.93519837E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03924335",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "189.10191",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "337.31281",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "188.94115",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "326.94342",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "188.94115",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "329.81061",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem14": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem14",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04938572",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "90.727654",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8504.4961",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-807.76221",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.5",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-390.02197",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-73.771484",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1771.354",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1912.9563",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.8125",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-390.02197",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-79.862793",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-87.807205",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05213928",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-731.3855",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-68.494873",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.5844803",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "4.9598546",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.2690716",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.4266367",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "186.58937",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "337.88647",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "186.56416",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "346.3302",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.44870296E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-696.71509",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.16619049E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "15.390869",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "47023.828",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112199.43",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7.05861028E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.80253686E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.92273160E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.14813179E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-430034.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "459570.31",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "974.875",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-268.66089",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "73.835495",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03020157",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258501",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-878.58374",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1089.5068",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1159.3208",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "195.67798",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.63579909E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.82475524E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1894.9229",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1751.0674",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-335053.81",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "619088.38",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "983.29688",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-269.1853",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "42.68663",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.28362",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.59756",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "198.91042",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "316.59357",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "186.56416",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "342.13684",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.58946",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.84143",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.005498942",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02744494",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem14 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.664064",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.23621",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.53595756E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.67605667E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.53595756E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.67605667E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem14 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.005498942",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02744494",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.00473028E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.04061121E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.00473028E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.04061121E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.03332272",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "37.155285",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04762281",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "37.727703",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-30.120178",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "31.435349",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-33.892334",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.639771",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "5.33502096E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03793893",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "189.43275",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "338.40424",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "189.23453",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "324.44659",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "189.39766",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "329.01019",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem13": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem13",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.03409821",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "93.502769",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8514.9414",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-809.2356",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1178.6875",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-411.1792",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-73.308594",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1895.583",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1855.5569",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1181.0312",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-411.1792",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-73.308594",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-90.09433",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05212402",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-739.21899",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-64.095703",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.5563583",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.9443369",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.4869928",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.7466087",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.53238",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "339.92249",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.47168",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "348.17508",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.32881075E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-703.95483",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.05498475E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "16.998535",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "46868.449",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112079.42",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7.05861028E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "8.32926617E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.51699612E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.40192287E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-426770.44",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "455653.69",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "967.84375",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-314.95898",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "78.17305",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03043221",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258402",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-690.81055",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "967.75854",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1373.167",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "174.42236",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.49090998E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.97449707E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1912.5901",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1814.6387",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-282337.25",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "644283.5",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "971.59375",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-314.95898",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "32.593521",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.82104",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.59723",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "196.15997",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "318.50259",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.47168",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "343.87625",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.05002",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.4758",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.007330321",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.03081967",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem13 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.320656",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.26556",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.62245615E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.48649196E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.62245615E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.48649196E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem13 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.007330321",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03081967",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.04192793E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.13113867E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.04192793E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.13113867E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.0223157",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.20401",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.03619342",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "36.585072",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-30.990356",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.881088",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-30.507782",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.5168",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "4.85105431E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03785572",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "186.97919",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "344.71381",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "186.82626",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "323.79913",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "186.97919",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "330.91821",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem12": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem12",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.02704778",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "94.398422",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8482.8242",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-802.84839",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1178.9062",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-389.7627",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-71.842529",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1909.1248",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1547.0107",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.625",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-390.92944",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-71.574951",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-92.033768",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05213928",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-704.625",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-61.902832",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.0119781",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.4134712",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.6073332",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.9822607",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "181.95769",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "336.5004",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "182.04222",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "345.48111",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.32596904E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-699.52124",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.15370494E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "16.808105",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "46923.617",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112509.55",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.41163143E-28",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.46217324E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.48276956E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.48447759E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-411764.0",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "485170.0",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "968.25",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-261.16699",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "63.818146",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03074288",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258425",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1032.5278",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "991.00806",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1335.8572",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "184.62354",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.34171932E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.38276640E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1569.3582",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1758.4185",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-357191.88",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "599382.81",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "970.32812",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-261.16699",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "35.750778",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.04518",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.29541",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "195.78352",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "315.74091",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "182.04222",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "341.52502",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.17505",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.39185",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.00599841",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02891124",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem12 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.697838",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.14056",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.55716261E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.68355782E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.55716261E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.68355782E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem12 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.00599841",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02891124",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.04385469E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.08635220E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.04385469E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.08635220E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.02115323",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.892544",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04966527",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "36.22068",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-32.678558",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "30.451752",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-32.114853",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "36.056549",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "3.84435701E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03647654",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "184.83257",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "331.96512",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "184.08356",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "323.6228",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "184.25795",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "329.88434",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem11": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem11",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04218566",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "91.303787",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8517.3633",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-809.5874",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.5938",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-383.89526",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-73.699463",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-2064.3323",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1864.8279",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.5312",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-383.89526",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-73.56665",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-87.192719",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05210876",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-732.62939",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-63.654297",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.6626625",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "4.9591379",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.0629911",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.2269163",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.22867",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "338.76599",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.19493",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "346.64899",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.65341612E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-695.58423",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.01278420E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "14.537109",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "46932.477",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112227.91",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7.05861028E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.16188651E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.69701559E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7.34095262E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.22080144E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-424263.12",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "442846.19",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "969.625",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-256.8772",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "62.120911",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03040779",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258438",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-888.04956",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "846.32764",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1206.8157",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "196.17847",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.82571863E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.84432359E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1884.7866",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1955.9961",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-336994.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "597975.69",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "971.01562",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-256.8772",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "36.757523",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.57643",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "309.89383",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "196.27771",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "319.1582",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.19493",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "342.28458",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.88618",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "312.98578",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.006261572",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.03119425",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem11 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.498901",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.45477",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.57569502E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.68601400E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.57569502E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.68601400E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem11 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.006261572",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03119425",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.09248401E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.01493049E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.09248401E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.01493049E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.02573823",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.195007",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05046295",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "35.401577",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-30.666992",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "30.449127",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-31.644287",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.895599",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "6.23577989E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03420636",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "185.79378",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "334.09125",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "185.51808",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "324.08624",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.52065",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "328.29376",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04414987",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "96.771675",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8504.4922",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-802.14648",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1178.4062",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-383.54834",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-74.707764",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1655.5645",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1535.7678",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.625",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-384.49365",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-74.418701",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-89.27742",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05149841",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-731.43579",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-63.592285",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.7693205",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "4.6260643",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-6.2384787",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.3612852",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.12581",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "338.70551",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.09435",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "347.77435",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.17960053E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-697.93848",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.07489177E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "16.248047",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "46913.012",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112075.81",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.41172175E-26",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.52167523E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.73657793E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.16029355E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-388502.12",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "452151.94",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "976.57812",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-262.63135",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "70.832169",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.02934751",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258493",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-722.30908",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "982.99414",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1534.5149",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "190.27539",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-6.13609529E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.60851435E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1528.4319",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1612.4421",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-317798.62",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "596853.31",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "976.57812",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-263.27417",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "28.871521",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.28973",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "309.21228",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "197.75945",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "318.37695",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.09435",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "343.64502",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.95753",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "312.77588",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.006482229",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.0282005",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem10 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.835667",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.38226",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.56462283E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.51251052E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.56462283E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.51251052E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem10 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.006482229",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.0282005",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.89728985E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.26322118E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.89728985E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.26322118E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.03244055",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.988735",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04464823",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "36.407391",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-29.402298",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.580032",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-32.413437",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.025604",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "4.37112107E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03653794",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "186.64999",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "335.98254",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "186.17793",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "323.61426",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "186.17793",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "330.06702",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem09": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem09",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04614032",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "92.514168",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8512.8047",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-810.58423",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.1875",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-388.93237",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-76.442627",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1897.4287",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1812.728",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.625",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-388.93237",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-76.442627",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-92.112137",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05224609",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-723.90869",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-63.865723",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.8388367",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.5554543",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-6.8249741",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.1821613",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.35645",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "337.51422",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.30656",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "345.62476",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.80100710E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-702.35474",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.06365769E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "15.715332",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "47230.652",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112215.58",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "8.01387785E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.70521253E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.08420222E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.17190871E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-442281.0",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "433112.81",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "976.73438",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-267.6272",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "62.00946",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03049485",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258425",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-784.40137",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1284.3999",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1581.0083",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "219.11768",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-6.32200965E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "8.76215154E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1757.6069",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1894.9675",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-296595.19",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "591633.44",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "976.73438",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-270.90698",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "22.280106",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.17378",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "309.48572",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "195.86752",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "318.22565",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.30656",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "341.46655",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.24294",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "312.79565",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.006971192",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02715807",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem09 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.278519",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.57147",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.56006463E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.58825642E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.56006463E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.58825642E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem09 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.006971192",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02715807",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.85703766E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.00471914E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.85703766E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.00471914E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.02789206",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.117619",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05609382",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "35.070274",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-29.551178",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "30.439209",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-33.14975",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.113373",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "7.77322384E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03683176",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "187.40707",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "334.66171",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "187.29153",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "323.75635",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "187.36113",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "329.48541",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem08": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem08",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05403472",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "97.768181",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8523.0781",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-808.10059",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.4688",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-399.81494",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-76.330811",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1860.6182",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1977.2305",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.7188",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-399.81494",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-78.733154",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-86.235764",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05209351",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-736.64258",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-67.655518",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.4534636",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.4356747",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-6.1733646",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.8793154",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "186.00966",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "338.95096",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.9626",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "347.18298",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.21402934E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-694.37109",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.02564809E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "14.991699",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "46987.027",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112547.71",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.04871003E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.68794962E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.96745236E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-8.58326734E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.68647409E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-424217.88",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "436854.31",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "968.17188",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-279.99219",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "62.329636",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03045795",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258444",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-706.98291",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1088.6675",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1613.6641",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "162.33398",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-6.45259036E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.49145875E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1750.0569",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1927.0166",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-278473.12",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "591021.25",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "971.85938",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-279.99219",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "39.1241",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.26651",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.10553",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "199.82089",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "318.33484",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.9626",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "343.08044",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.39912",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.35809",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.00491865",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02879396",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem08 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.348112",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.19617",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.57802988E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.50224841E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.57802988E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.50224841E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem08 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.00491865",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02879396",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.90265860E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89156651E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.90265860E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89156651E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.03528754",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "37.692329",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05359773",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "38.572929",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-33.779816",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "31.216873",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-32.351868",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.212585",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.23061454E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03695253",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "188.65788",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "339.17105",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "188.20444",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "327.33344",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "188.42421",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "332.33252",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem07": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem07",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.03605553",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "89.509308",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8536.4141",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-804.34131",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.4375",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-382.86133",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-76.600586",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1616.2898",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1888.9238",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.125",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-382.86133",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-75.936523",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-90.401733",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05227661",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-737.20068",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-66.482422",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.0461493",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "4.8971701",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.1601133",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.6567783",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.22368",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "337.82547",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.10495",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "347.03714",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.30477611E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-704.7937",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.30294939E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "16.197754",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "47077.98",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112364.7",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.29395617E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.53446272E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.67835958E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-9.26089413E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.22891424E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-391688.88",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "451744.19",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "971.40625",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-249.99353",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "68.62941",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03098821",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258442",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-747.93066",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "944.7749",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1348.2615",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "203.38794",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.39131975E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "8.13269594E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1625.0085",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1680.2285",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-295384.94",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "629478.81",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "974.65625",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-249.99353",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "39.495377",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.25461",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.05753",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "196.82031",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "317.67786",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.10495",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "342.78827",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.63701",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.25226",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.006320141",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02859681",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem07 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.768345",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.10501",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.53425553E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.69213108E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.53425553E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.69213108E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem07 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.006320141",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02859681",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.88246622E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.01711782E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.88246622E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.01711782E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.02531172",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "36.175854",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04556179",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "37.344608",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-31.822845",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.660461",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-32.518097",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "33.707794",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "7.62810828E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.0372132",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "188.07147",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "340.95773",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "187.58464",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "321.89133",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "187.61833",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "328.30457",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem06": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem06",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04874225",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "98.421356",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8531.4297",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-805.45361",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.7812",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-390.66235",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-75.237549",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1650.155",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2017.9797",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1181.0938",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-390.66235",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-75.241211",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-90.817841",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05148315",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-734.23145",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-62.475098",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-3.4429245",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.0998211",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.7600975",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.319418",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "182.33348",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "337.75192",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "182.35077",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "347.16177",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.22711754E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-709.42554",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.05996151E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "13.946533",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "47260.566",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112032.58",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.52435502E-33",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "8.51159484E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.55424971E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.49077924E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.63122502E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-412197.0",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "458816.38",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "973.78125",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-274.99902",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "70.419022",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.0303196",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258442",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-780.40576",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1016.458",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1252.823",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "196.11743",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.00968895E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.84241081E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1523.5752",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2284.9915",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-317867.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "611444.25",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "973.78125",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-279.78174",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "27.529205",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.94676",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.6785",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "196.2005",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "317.87231",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "182.35077",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "342.98209",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.14098",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.82458",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.00595966",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.0311178",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem06 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.953468",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.30457",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.56364313E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.53520868E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.56364313E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.53520868E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem06 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.00595966",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.0311178",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.94796439E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.11104248E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.94796439E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.11104248E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.03342896",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "35.85685",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05077953",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "38.737904",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-31.113052",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "29.912766",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-32.752579",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "36.203125",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.06056973E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03392826",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "186.27612",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "337.9805",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "186.0318",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "326.27905",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "186.06033",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "337.98111",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem05": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem05",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0445964",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "96.7882",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8524.3438",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-801.09766",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.1562",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-390.88403",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-72.644775",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-2011.8225",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2031.509",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1181.0938",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-391.25708",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-72.62915",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-90.06041",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05239868",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-720.41211",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-62.65625",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-3.5776205",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "4.3731356",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.6289701",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.3961868",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "182.53214",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "338.43054",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "182.38744",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "345.01642",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.32723994E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-696.25366",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.09651592E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "13.210938",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "47416.82",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112183.82",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.76465199E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "8.87477370E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.43939963E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7.22801456E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.26918974E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-446150.81",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "425485.62",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "967.42188",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-260.69482",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "76.303299",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03030113",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.25845",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-730.80762",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1142.9199",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1189.2068",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "179.89551",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.75530499E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.19379329E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1736.7664",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1840.3982",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-268744.0",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "624381.31",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "967.71875",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-262.19092",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "30.616394",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.21236",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.05704",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "196.37326",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "317.46515",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "182.38744",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "341.27032",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.48595",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "312.78284",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004980434",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02886491",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem05 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.835546",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.35947",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.59279898E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.56204296E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.59279898E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.56204296E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem05 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004980434",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02886491",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.99958163E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.06741220E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.99958163E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.06741220E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.03338828",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "35.349583",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05666662",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "37.117123",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-31.896454",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.030029",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-34.075546",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.323654",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "6.93093511E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03490199",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "186.38229",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "338.66315",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "185.7036",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "322.77542",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.89119",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "332.32916",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem04": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem04",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04908485",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "91.789597",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8512.1719",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-807.37939",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.6875",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-388.43408",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-73.151367",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1767.2705",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1904.4141",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1181.0312",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-388.43408",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-76.32666",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-88.314774",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05224609",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-734.83325",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-65.151123",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.4310846",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.0010128",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.6712866",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.3827791",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "184.25935",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "337.7182",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "184.23154",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "346.58411",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.21380197E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-696.18652",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.08455424E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "15.729004",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "47121.355",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112358.91",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "8.04031117E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.79799588E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-8.13151668E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.23547125E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-420490.31",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "476893.75",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "966.84375",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-256.24365",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "76.789505",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03026856",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258471",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-729.03516",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1076.3977",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1474.2642",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "187.4187",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.89516958E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.49417950E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1936.8181",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1907.5146",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-332268.88",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "591512.88",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "970.82812",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-256.60278",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "27.052032",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.11485",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.35098",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "197.18584",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "318.0878",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "184.23154",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "342.39661",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.31364",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.24921",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.003503979",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02834012",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem04 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.358381",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.53555",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.58753828E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.58417315E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.58753828E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.58417315E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem04 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.003503979",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02834012",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.88473894E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.99224792E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.88473894E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.99224792E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.02334919",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "37.324478",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04029099",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "38.036888",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-30.797104",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.956955",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-33.662659",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "31.642548",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "7.97745656E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03626347",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "187.70351",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "331.65561",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "187.63727",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "323.5",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "187.65932",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "328.86627",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem03": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem03",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.03888816",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "95.818436",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8532.1836",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-807.19434",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1178.3438",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-389.56494",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-74.677979",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1461.5278",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1679.533",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1181.5312",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-389.56494",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-74.677979",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-89.737167",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05213928",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-731.00977",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-63.669434",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-3.8425198",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.3218298",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.3176908",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.5346527",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.22136",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "338.91541",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.25844",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "345.70758",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.27990563E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-701.1272",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.14939758E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "13.932129",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "47094.793",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112797.95",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.76465199E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.84349459E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.49832749E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.17455236E-23",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.54046688E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-413327.38",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "455002.56",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "970.35938",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-254.58681",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "70.34729",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.02986815",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.25845",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-760.03101",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1137.5684",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1603.552",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "198.06567",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-6.41215593E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.85367433E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1625.0674",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2061.8118",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-347516.56",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "608180.31",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "970.9375",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-254.98",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "38.227951",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.29164",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.26508",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "195.52803",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "318.48767",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.25844",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "341.60764",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.73802",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.22046",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.008416511",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.03170512",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem03 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.631538",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.57355",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.59093797E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.70162366E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.59093797E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.70162366E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem03 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.008416511",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03170512",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.02356955E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.04615048E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.02356955E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.04615048E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.02525222",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.011684",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05357008",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.653114",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-30.932541",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "30.933014",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-31.350296",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.824188",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "7.78225058E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03402502",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "186.57471",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "335.14569",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "186.44406",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "325.66605",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "186.55554",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "329.8316",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem02": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem02",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04283427",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "93.013771",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8485.2617",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-807.92944",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.4062",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-398.68555",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-76.822266",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1621.4053",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1839.0784",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1181.1562",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-398.68555",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-77.464355",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-88.592575",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05197144",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-726.95923",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-67.514648",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.3195877",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.3174629",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-6.1522007",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "5.8812227",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.92535",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "337.69073",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.84503",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "347.18256",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.38425560E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-699.91382",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.25277438E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "14.827637",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "46888.219",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112675.24",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-3.52930514E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.16775844E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.61342052E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-8.13151668E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.52901930E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-444703.56",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "454519.75",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "975.1875",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-294.35107",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "65.985886",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03017535",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258394",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-754.63916",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1102.9612",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1489.3342",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "186.68896",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-5.95543042E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "7.46494493E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1540.6165",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1925.1445",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-262390.62",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "599799.56",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "975.1875",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-294.35107",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "46.585953",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.81747",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "309.94843",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "199.4393",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "318.53467",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "185.84503",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "342.7702",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "208.92708",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "312.96613",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.006867442",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.02938985",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem02 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.5478",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.5083",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.62666965E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.48525323E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.62666965E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.48525323E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem02 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.006867442",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02938985",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.15438467E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.26295447E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.15438467E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "2.26295447E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.02168142",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.86187",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.03339912",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "36.074627",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-31.864487",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "35.253052",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-34.24678",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.483414",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.22318170E-07",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03773588",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "188.82751",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "339.29404",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "188.29436",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "323.63757",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "188.6481",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "330.09454",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "mem01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.04409193",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "91.617813",
                                            "subcenter": "255",
                                            "gribparam": "230"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "8513.1914",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "subcenter": "255",
                                            "gribparam": "217"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "164"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-806.99854",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "203"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "1179.4688",
                                                "subcenter": "255",
                                                "gribparam": "178"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-386.47314",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "-75.358154",
                                                "subcenter": "255",
                                                "gribparam": "179"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1546.0066",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2299.7405",
                                                    "subcenter": "255",
                                                    "gribparam": "105"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1180.6875",
                                                    "subcenter": "255",
                                                    "gribparam": "187"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-386.47314",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-75.264404",
                                                    "subcenter": "255",
                                                    "gribparam": "188"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7517.7578",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "subcenter": "255",
                                            "gribparam": "129"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-89.800339",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.05238342",
                                            "subcenter": "255",
                                            "gribparam": "220"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-735.51343",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "-63.820312",
                                            "subcenter": "255",
                                            "gribparam": "205"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-4.2508774",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "4.9066935",
                                            "subcenter": "255",
                                            "gribparam": "181"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-6.3047886",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "6.3555784",
                                            "subcenter": "255",
                                            "gribparam": "180"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.3044",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "339.29962",
                                            "subcenter": "255",
                                            "gribparam": "169"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.2473",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "344.59583",
                                            "subcenter": "255",
                                            "gribparam": "139"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.51761787E-06",
                                            "subcenter": "255",
                                            "gribparam": "160"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-696.15015",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "subcenter": "255",
                                            "gribparam": "204"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "subcenter": "255",
                                            "gribparam": "140"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.14319846E-06",
                                            "subcenter": "255",
                                            "gribparam": "218"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "15.822754",
                                            "subcenter": "255",
                                            "gribparam": "141"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_10",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "subcenter": "255",
                                            "gribparam": "211"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "1.49999996E-05",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "subcenter": "255",
                                            "gribparam": "173"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "210"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "46835.125",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "112517.27",
                                            "subcenter": "255",
                                            "gribparam": "134"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-7.05861028E-27",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "8.02887541E-07",
                                            "subcenter": "255",
                                            "gribparam": "144"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.56984845E-06",
                                            "subcenter": "255",
                                            "gribparam": "142"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-9.03501880E-24",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.29922944E-06",
                                            "subcenter": "255",
                                            "gribparam": "143"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-447561.12",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "475817.94",
                                            "subcenter": "255",
                                            "gribparam": "108"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "0.0",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "969.71875",
                                                "subcenter": "255",
                                                "gribparam": "176"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "process": "50",
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "gribNumBits": "16",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PDS_TimeRange": "10",
                                                "scale_min": "-251.55209",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "PTVersion": "128",
                                                "gribleveltype": "1",
                                                "scale_max": "63.991547",
                                                "subcenter": "255",
                                                "gribparam": "177"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "subcenter": "255",
                                            "gribparam": "172"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.03153343",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255",
                                            "scale_max": "16.258469",
                                            "gribparam": "152"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-722.63452",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "1547.8467",
                                            "subcenter": "255",
                                            "gribparam": "146"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1624.7356",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "238.63062",
                                            "subcenter": "255",
                                            "gribparam": "147"
                                        },
                                        "FOREST": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "FOREST",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "vegetation type",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.0",
                                            "units": "unitless",
                                            "grib_name": "FOREST",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.9492188",
                                            "subcenter": "255",
                                            "gribparam": "212"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "24",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-6.49686342E-07",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "9.54233599E-08",
                                            "subcenter": "255",
                                            "gribparam": "182"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-1507.386",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2110.5459",
                                                    "subcenter": "255",
                                                    "gribparam": "106"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-302183.75",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "610031.94",
                                                    "subcenter": "255",
                                                    "gribparam": "107"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "0.0",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "973.09375",
                                                    "subcenter": "255",
                                                    "gribparam": "185"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "process": "50",
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "gribNumBits": "16",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PDS_TimeRange": "10",
                                                    "scale_min": "-251.55209",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "PTVersion": "128",
                                                    "gribleveltype": "1",
                                                    "scale_max": "23.24823",
                                                    "subcenter": "255",
                                                    "gribparam": "186"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "8",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.06999999",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "subcenter": "255",
                                            "gribparam": "175"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "210.50774",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "310.06244",
                                            "subcenter": "255",
                                            "gribparam": "183"
                                        },
                                        "TD5": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD5",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "196.12741",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD5",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "319.10074",
                                            "subcenter": "255",
                                            "gribparam": "209"
                                        },
                                        "TD3": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TD3",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "183.2473",
                                            "units": "Kelvin_scale",
                                            "grib_name": "TD3",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "340.87317",
                                            "subcenter": "255",
                                            "gribparam": "207"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "209.74632",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "PTVersion": "128",
                                            "gribleveltype": "111",
                                            "scale_max": "313.34009",
                                            "subcenter": "255",
                                            "gribparam": "170"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004592661",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "scale_max": "0.03026059",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem01 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-21.342884",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "410.53833",
                                            "subcenter": "255",
                                            "gribparam": "130"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.54697045E-05",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.58903222E-05",
                                            "subcenter": "255",
                                            "gribparam": "138"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-1.54697045E-05",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.58903222E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jan2002 SIX-HOURLY mem01 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-0.004592661",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03026059",
                                            "subcenter": "255",
                                            "gribparam": "133"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.09767768E-06",
                                            "units": "s-1",
                                            "grib_name": "Div",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89318041E-06",
                                            "subcenter": "255",
                                            "gribparam": "155"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-2.09767768E-06",
                                            "PTVersion": "128",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89318041E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "0.0283514",
                                            "grib_name": "wind10",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "34.488647",
                                            "subcenter": "255",
                                            "gribparam": "171"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "0.05477377",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "35.84407",
                                            "subcenter": "255",
                                            "gribparam": "216"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-30.235947",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.364716",
                                            "subcenter": "255",
                                            "gribparam": "166"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "-31.000931",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "32.793594",
                                            "subcenter": "255",
                                            "gribparam": "165"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "6.95265499E-08",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03794711",
                                            "subcenter": "255",
                                            "gribparam": "168"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "184.48193",
                                            "grib_name": "t2mmx",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "337.57458",
                                            "subcenter": "255",
                                            "gribparam": "201"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "scale_min": "184.29979",
                                            "grib_name": "t2mmn",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "325.30627",
                                            "subcenter": "255",
                                            "gribparam": "202"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "process": "50",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "gribNumBits": "16",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PDS_TimeRange": "10",
                                            "scale_min": "184.44638",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "PTVersion": "128",
                                            "gribleveltype": "105",
                                            "scale_max": "328.8252",
                                            "subcenter": "255",
                                            "gribparam": "167"
                                        }
                                    }
                                },
                                "Z_10": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_10",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "1.0",
                                    "long_name": "Height"
                                },
                                "Z_09": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_09",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "cm_down",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Depth"
                                },
                                "Z_08": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_08",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "cm_down",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Depth"
                                },
                                "Z_07": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_07",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "cm_down",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Depth"
                                },
                                "Z_06": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_06",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "cm_down",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Depth"
                                },
                                "P": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "P",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "mb",
                                    "gridtype": "0",
                                    "long_name": "pressure"
                                },
                                "sp_01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sp_01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "1.0"
                                },
                                "C": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "C",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "ids",
                                    "gridtype": "2",
                                    "long_name": "complex"
                                },
                                "Z_05": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_05",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "0.0"
                                },
                                "Z_04": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_04",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0"
                                },
                                "Y_01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Y_01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "degree_north",
                                    "gridtype": "0"
                                },
                                "Z_03": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_03",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "1.0",
                                    "long_name": "Height"
                                },
                                "sp": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "sp",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "1.0"
                                },
                                "Z_02": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_02",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "unitless",
                                    "gridtype": "0",
                                    "pointwidth": "0.0"
                                },
                                "Z_01": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z_01",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m_above_gnd",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Height"
                                },
                                "Z": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Z",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "m_above_gnd",
                                    "gridtype": "0",
                                    "pointwidth": "0",
                                    "long_name": "Height"
                                },
                                "Y": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "Y",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "degree_north",
                                    "gridtype": "0"
                                },
                                "T": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "T",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "days since 2001-01-01 00:00:00",
                                    "gridtype": "0",
                                    "pointwidth": "0.25",
                                    "calendar": "standard",
                                    "defaultvalue": "576.75"
                                },
                                "X": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "X",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "units": "degree_east",
                                    "gridtype": "1",
                                    "pointwidth": "2.8125",
                                    "modulus": "360.0"
                                },
                                "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/jan2002/SIX-HOURLY"
                            },
                            "banned_long": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type",
                                "SIXHOURLY"
                            ]
                        },
                        "jul2001": {
                            "iridl_type": "Source",
                            "invalid": [],
                            "dir": "SOURCES/IRI/FD/ECHAM4p5/Forecast/asst/jul2001",
                            "banned": [
                                "dir",
                                "invalid",
                                "parent",
                                "name",
                                "banned",
                                "banned_long",
                                "iridl_ds_name",
                                "iridl_type"
                            ],
                            "iridl_ds_name": "jul2001",
                            "restriction": "Public",
                            "SIXHOURLY": {
                                "iridl_type": "DataSet",
                                "iridl_ds_name": "SIX-HOURLY",
                                "banned": [
                                    "dir",
                                    "invalid",
                                    "parent",
                                    "name",
                                    "banned",
                                    "banned_long",
                                    "iridl_ds_name",
                                    "iridl_type"
                                ],
                                "NC_GLOBAL": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "NC_GLOBAL",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "mem24PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem24griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem24/.griblist.html",
                                    "mem24filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong24.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem24year0": "200110",
                                    "mem23PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem23griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem23/.griblist.html",
                                    "mem23filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong23.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem23year0": "200110",
                                    "mem22PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem22griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem22/.griblist.html",
                                    "mem22filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong22.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem22year0": "200110",
                                    "mem21PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem21griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem21/.griblist.html",
                                    "mem21filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong21.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem21year0": "200110",
                                    "mem20PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem20griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem20/.griblist.html",
                                    "mem20filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong20.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem20year0": "200110",
                                    "mem19PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem19griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem19/.griblist.html",
                                    "mem19filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong19.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem19year0": "200110",
                                    "mem18PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem18griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem18/.griblist.html",
                                    "mem18filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong18.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem18year0": "200110",
                                    "mem17PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem17griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem17/.griblist.html",
                                    "mem17filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong17.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem17year0": "200110",
                                    "mem16PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem16griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem16/.griblist.html",
                                    "mem16filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong16.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem16year0": "200110",
                                    "mem15PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem15griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem15/.griblist.html",
                                    "mem15filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong15.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem15year0": "200110",
                                    "mem14PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem14griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem14/.griblist.html",
                                    "mem14filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong14.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem14year0": "200110",
                                    "mem13PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem13griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem13/.griblist.html",
                                    "mem13filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong13.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem13year0": "200110",
                                    "mem12PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem12griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem12/.griblist.html",
                                    "mem12filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong12.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem12year0": "200110",
                                    "mem11PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem11griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem11/.griblist.html",
                                    "mem11filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong11.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem11year0": "200110",
                                    "mem10PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem10griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem10/.griblist.html",
                                    "mem10filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong10.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem10year0": "200110",
                                    "mem09PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem09griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem09/.griblist.html",
                                    "mem09filepattern": "/mstore/iri_1/forecast_usr/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong9.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem09year0": "200110",
                                    "mem08PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem08griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem08/.griblist.html",
                                    "mem08filepattern": "/mstore/iri_1/modelling/daved/Makos.D/ForcastDiv.D/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong8.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem08year0": "200110",
                                    "mem07PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem07griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem07/.griblist.html",
                                    "mem07filepattern": "/mstore/iri_1/modelling/daved/Makos.D/ForcastDiv.D/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong7.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem07year0": "200110",
                                    "mem06PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem06griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem06/.griblist.html",
                                    "mem06filepattern": "/mstore/iri_1/modelling/daved/Makos.D/ForcastDiv.D/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong6.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem06year0": "200110",
                                    "mem05PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem05griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem05/.griblist.html",
                                    "mem05filepattern": "/mstore/iri_1/modelling/daved/Makos.D/ForcastDiv.D/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong5.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem05year0": "200110",
                                    "mem04PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem04griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem04/.griblist.html",
                                    "mem04filepattern": "/mstore/iri_1/modelling/daved/Makos.D/ForcastDiv.D/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong5.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem04year0": "200110",
                                    "mem03PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem03griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem03/.griblist.html",
                                    "mem03filepattern": "/mstore/iri_1/modelling/daved/Makos.D/ForcastDiv.D/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong3.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem03year0": "200110",
                                    "mem02PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem02griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem02/.griblist.html",
                                    "mem02filepattern": "/mstore/iri_1/modelling/daved/Makos.D/ForcastDiv.D/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong2.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem02year0": "200110",
                                    "mem01PressureLeveldescription": "gaussian grid at standard Pressure Levels -- below surface values marked as missing",
                                    "mem01griblisthtml": "http://iridl.ldeo.columbia.edu/SOURCES/.IRI/.FD/.ECHAM4p5/.Forecast/.asst/.jul2001/.SIX-HOURLY/.mem01/.griblist.html",
                                    "mem01filepattern": "/mstore/iri_1/modelling/daved/Makos.D/ForcastDiv.D/ECHAM4_3.23.D/EXP.D/LongRun1.D/IriLong1.D/AnomSSTFcst2sea.D/Yr2001.D/July.D/00001test_%6d.01",
                                    "mem01year0": "200110",
                                    "Conventions": "IRIDL"
                                },
                                "mem24": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem24",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.03866624",
                                            "PDS_TimeRange": "10",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "94.791679",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8458.0547",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-784.69067",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "1144.5625",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-395.76733",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "-77.441162",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1321.0066",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1799.5298",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1144.9062",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-395.76733",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-76.917725",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-7517.7578",
                                            "PDS_TimeRange": "10",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-92.429016",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.009216309",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-717.14648",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "-67.208252",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-3.8965282",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "3.6507511",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-3.686492",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "5.8821621",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "185.69197",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "337.2355",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "185.59848",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "341.03546",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.13039755E-06",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-690.21729",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007324219",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7160492",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.05897197E-06",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "15.345703",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_11",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "1.49999996E-05",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "48662.617",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "112095.48",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-8.82326093E-28",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "6.80591143E-07",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.59876367E-06",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.17455236E-23",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.33237836E-06",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-395871.0",
                                            "PDS_TimeRange": "10",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "441107.25",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "924.54688",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-262.28101",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "63.044647",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.03061344",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258406",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-664.30908",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "957.49951",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1409.9768",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "174.51221",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-5.63810261E-07",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "6.96549307E-08",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1907.1758",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2040.2917",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-268943.75",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "610605.31",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "924.54688",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-262.28101",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "39.167313",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.06999999",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "210.26273",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "309.38382",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "209.42175",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "313.03983",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.007428661",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "scale_max": "0.02841302",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem24 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "scale_min": "-19.591063",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "410.78589",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.56475617E-05",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89177445E-05",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.56475617E-05",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89177445E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem24 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.007428661",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02841302",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.94894324E-06",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.85466070E-06",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.94894324E-06",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.85466070E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "0.02591996",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "wind10",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "37.07021",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.04684515",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "37.405247",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-33.347534",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "31.164551",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-36.103256",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "33.603653",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8.65357492E-08",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03569947",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "189.33195",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmx",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "336.9967",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "188.66733",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmn",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "325.44217",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "188.74684",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "331.44592",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem23": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem23",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.03844948",
                                            "PDS_TimeRange": "10",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "101.17027",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8536.3984",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-772.47461",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "1142.0",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-398.72339",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "-79.787354",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1370.7817",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2266.3049",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1144.9062",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-398.72339",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-79.334229",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-7517.7578",
                                            "PDS_TimeRange": "10",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-89.409012",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008056641",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-722.9375",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "-68.447266",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-4.7465982",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "4.5289555",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-3.9978037",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "4.9899683",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "186.52776",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "336.77539",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "186.35402",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "342.45941",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.23170378E-06",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-678.68237",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.6806335",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.23181962E-06",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.58252",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_11",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "1.49999996E-05",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "48712.418",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "112300.16",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-3.52930514E-27",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "8.14820282E-07",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.67549479E-06",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-9.93852012E-24",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.34583536E-06",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-412702.69",
                                            "PDS_TimeRange": "10",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "437121.19",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "928.10938",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-254.73161",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "74.215347",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.0300893",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258419",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-722.81055",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "856.79761",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1325.543",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "212.2085",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-5.30047544E-07",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "8.48532409E-08",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-2074.5251",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2392.3755",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-279106.88",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "630042.06",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "933.90625",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-254.73161",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "40.351028",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.06999999",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "210.50047",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "309.75244",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "209.81976",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "313.70746",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.00714374",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "scale_max": "0.03197506",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem23 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-19.713448",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "410.79175",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.59464344E-05",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82137701E-05",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.59464344E-05",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82137701E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem23 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.00714374",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03197506",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.98916450E-06",
                                            "PDS_TimeRange": "10",
                                            "units": "s-1",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84850228E-06",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.98916450E-06",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84850228E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "0.03321928",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "wind10",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "36.880623",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.05638257",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "37.551842",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-30.046677",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "29.407852",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-36.505432",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "30.224243",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8.84875249E-08",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03728871",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "189.52885",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmx",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "335.73303",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "188.58665",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmn",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "326.46716",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "188.76131",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "331.0033",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem22": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem22",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.04849542",
                                            "PDS_TimeRange": "10",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "95.604218",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8458.2734",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-776.76855",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "1141.6875",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-412.96924",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "-77.394043",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1464.2444",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2259.9675",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1145.3125",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-412.96924",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-77.300293",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-7517.7578",
                                            "PDS_TimeRange": "10",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-93.23233",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008712769",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-742.17017",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "-65.812012",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-3.7971601",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "4.1234818",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-4.1058397",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "4.8892441",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "184.76189",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "338.56207",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "184.73726",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "343.03235",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.24292171E-06",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-701.02368",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007568359",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.17631862E-06",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "15.468018",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_11",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "1.49999996E-05",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "48382.582",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "112497.88",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-2.52435502E-33",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "7.53700988E-07",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.49000618E-06",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-9.03501880E-24",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.36490701E-06",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-449221.0",
                                            "PDS_TimeRange": "10",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "431755.69",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "928.6875",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-266.53955",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "64.828613",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.0298923",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258471",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-840.12378",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "937.30615",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1433.6448",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "198.14941",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-5.73274463E-07",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "7.92341552E-08",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1861.9026",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2065.5769",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-298588.38",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "659826.38",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "934.67188",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-266.53955",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "35.156174",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.06999999",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "210.46231",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "309.57169",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "209.59503",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "313.66721",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.007412553",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "scale_max": "0.02954119",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem22 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "scale_min": "-19.720533",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "410.67642",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.55261005E-05",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.86996367E-05",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.55261005E-05",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.86996367E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem22 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.007412553",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02954119",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.83218276E-06",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.93438223E-06",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.83218276E-06",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.93438223E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "0.03889553",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "wind10",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "36.507786",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.08091432",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "37.293713",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-30.251297",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "29.601639",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-34.787476",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "32.868576",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8.26349265E-08",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03543973",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "188.30057",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmx",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "336.7515",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "187.39931",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmn",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "328.89813",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "187.63255",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "334.2287",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem21": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem21",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.03989686",
                                            "PDS_TimeRange": "10",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "94.465836",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8478.1836",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-774.22046",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "1141.1875",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-400.28979",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "-74.550293",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1514.6235",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2352.7463",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1144.875",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-400.28979",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-74.425293",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-7517.7578",
                                            "PDS_TimeRange": "10",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-89.519699",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008895874",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-727.01416",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "-65.445801",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-4.6929989",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "3.498539",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-4.1224594",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "6.4617529",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "184.49461",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "338.36914",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "184.515",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "342.06055",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.30605474E-06",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-684.38159",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.30696571E-06",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.371094",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_11",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "1.49999996E-05",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "48519.934",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "112606.97",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.76465199E-27",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "6.03416197E-07",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.73524063E-06",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-7.45389068E-24",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.42755914E-06",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-460868.44",
                                            "PDS_TimeRange": "10",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "438294.81",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "918.375",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-249.91837",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "69.952835",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.03140584",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258438",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-768.01392",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "943.43384",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1145.3845",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "197.08154",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-4.58007150E-07",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "7.88072327E-08",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1734.8196",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1959.1404",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-285902.62",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "649081.75",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "923.96875",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-249.91837",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "40.572708",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.06999999",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "209.93538",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "310.11505",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "209.24294",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "313.78339",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.00452242",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "scale_max": "0.03080042",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem21 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "scale_min": "-19.174923",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "410.52692",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.52460889E-05",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83872689E-05",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.52460889E-05",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83872689E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem21 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.00452242",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03080042",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.80544998E-06",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.96009114E-06",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.80544998E-06",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.96009114E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "0.02913274",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "wind10",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "36.227104",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.07799965",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "37.244335",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-35.624176",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "27.923935",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-36.848404",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "32.526199",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8.94501682E-08",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03642153",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "187.27066",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmx",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "337.99139",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "187.16499",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmn",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "327.95267",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "187.16678",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "331.12845",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem20": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem20",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0359844",
                                            "PDS_TimeRange": "10",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "93.653503",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8502.2734",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-783.46533",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "1142.875",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-397.75732",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "-77.295166",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1551.8926",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1930.2683",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1144.4375",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-397.75732",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-77.115234",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-7517.7578",
                                            "PDS_TimeRange": "10",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-91.292374",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008575439",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-724.62183",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "-64.755371",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-3.5830278",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "4.4161539",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-4.6325598",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "7.3359842",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "184.03728",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "338.05646",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "183.81032",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "340.72742",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.28159922E-06",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-695.75952",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7235718",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.04520586E-06",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.245605",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_11",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "1.49999996E-05",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "48380.793",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "112181.57",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-3.36580767E-33",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "7.67212100E-07",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.47130856E-06",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.44560339E-23",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.53136034E-06",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-416865.25",
                                            "PDS_TimeRange": "10",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "411222.38",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "923.07812",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-255.8905",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "61.709946",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.02948213",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.25849",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-826.38477",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1236.5505",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1275.5908",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "171.91357",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-5.10073107E-07",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "6.87465445E-08",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1754.519",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1754.6467",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-286993.31",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "635082.25",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "924.875",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-255.8905",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "35.562012",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.06999999",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "209.29379",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "309.52426",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "208.61066",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "313.38245",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.008699935",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "scale_max": "0.02880456",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem20 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "scale_min": "-19.662691",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "410.76691",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.57272680E-05",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84359978E-05",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.57272680E-05",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84359978E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem20 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.008699935",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02880456",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-2.13626186E-06",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.92747098E-06",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-2.13626186E-06",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.92747098E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "0.03540614",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "wind10",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "38.338215",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.05963349",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "39.340786",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-31.290176",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "28.697449",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-37.129379",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "35.825897",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "9.77121317E-08",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "0.04144982",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "187.59723",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmx",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "339.30682",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "187.48744",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmn",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "328.54041",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "187.52884",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "332.20148",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem19": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem19",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.038732",
                                            "PDS_TimeRange": "10",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "100.20322",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8517.0312",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-767.66675",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "1141.125",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-392.90088",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "-72.021484",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1283.0557",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2025.3125",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1144.5",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-392.90088",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-71.865479",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-7517.7578",
                                            "PDS_TimeRange": "10",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-91.817291",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008682251",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-720.91479",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "-60.715088",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-3.752964",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "4.6480732",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-4.6035347",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "5.0071869",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "181.05554",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "337.75623",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "181.04097",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "340.203",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.58945977E-06",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-691.86694",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.00434409E-06",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "15.608398",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_11",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "1.49999996E-05",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "48541.773",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "112194.62",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.10290750E-28",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "8.51937102E-07",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.63717050E-06",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-7.67976602E-24",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.36639994E-06",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-400449.0",
                                            "PDS_TimeRange": "10",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "452345.44",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "944.79688",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-276.28784",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "65.159576",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.03102097",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.25841",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-714.7334",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "930.72754",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1366.1072",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "199.79736",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-5.46268041E-07",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "7.98933115E-08",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1781.4431",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1978.2292",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-248135.75",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "606193.62",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "947.8125",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-276.48462",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "34.452118",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.06999999",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "210.38626",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "310.12845",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "209.4509",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "314.57465",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.004787728",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "scale_max": "0.02875421",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem19 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "scale_min": "-19.357212",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "410.72925",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.60634863E-05",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.76438316E-05",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.60634863E-05",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.76438316E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem19 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.004787728",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02875421",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-2.00044087E-06",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.93773644E-06",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-2.00044087E-06",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.93773644E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "0.03763886",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "wind10",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "35.137035",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.06418443",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "35.791328",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-34.700333",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "30.755539",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-35.074692",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "31.609222",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "6.60731985E-08",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "0.0353042",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "184.1353",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmx",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "341.21796",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "184.03157",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmn",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "324.77441",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "184.06358",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "332.87814",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem18": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem18",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0445215",
                                            "PDS_TimeRange": "10",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "96.951385",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8536.1562",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-775.68188",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "1142.3438",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-392.4375",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "-76.991455",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1265.7939",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2402.0977",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1144.8125",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-392.4375",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-76.968018",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-7517.7578",
                                            "PDS_TimeRange": "10",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-86.820984",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.00881958",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-736.44165",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "-66.095703",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-4.1329565",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "4.2564545",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-5.779376",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "5.5563612",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "184.91451",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "339.35297",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "184.92442",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "344.39569",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.19278798E-06",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-667.55444",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.6918182",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.16086449E-06",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.365234",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_11",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "1.49999996E-05",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "48182.223",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "111945.35",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.41172175E-26",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "6.67987536E-07",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "2.03632612E-06",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.44560339E-23",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.39755502E-06",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-403104.0",
                                            "PDS_TimeRange": "10",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "441287.31",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "928.51562",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-264.79688",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "69.388031",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.0312351",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.25844",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-681.22241",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1048.3491",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1524.2534",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "267.17627",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-6.09506230E-07",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.06836183E-07",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1521.946",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2152.1919",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-277091.56",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "652764.25",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "928.96875",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-264.92114",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "43.621948",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.06999999",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "210.28032",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "309.08502",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "209.49255",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "313.89227",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.005027343",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "scale_max": "0.03110487",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem18 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "scale_min": "-19.668598",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "410.81073",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.53242472E-05",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84431210E-05",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.53242472E-05",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84431210E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem18 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.005027343",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03110487",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-2.00952809E-06",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.98886869E-06",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-2.00952809E-06",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.98886869E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "0.02248749",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "wind10",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "36.185589",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.05810932",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "36.550922",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-29.053238",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "26.911591",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-33.905167",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "33.544163",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "5.01773627E-08",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03481604",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "188.18031",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmx",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "333.56708",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "187.68405",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmn",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "325.05774",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "187.72867",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "333.27795",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem17": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem17",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.04017264",
                                            "PDS_TimeRange": "10",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "97.05407",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8455.1211",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-769.41797",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "1144.1562",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-392.97266",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "-77.137939",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1404.9734",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1781.3145",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1144.625",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-392.97266",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-77.04248",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-7517.7578",
                                            "PDS_TimeRange": "10",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-87.791977",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.008590698",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-733.30029",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "-65.247314",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-4.1660814",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "4.0492172",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-3.9812565",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "6.711813",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "184.36412",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "339.07947",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "184.33275",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "340.2326",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.09177768E-06",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-727.77148",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7085266",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.05632353E-06",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "14.924805",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_11",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "1.49999996E-05",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "48446.73",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "112325.54",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-3.36580767E-33",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "6.59399404E-07",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.63030393E-06",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-9.93852012E-24",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.29357625E-06",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-408915.75",
                                            "PDS_TimeRange": "10",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "436202.75",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "922.76562",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-271.74316",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "74.659576",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.0305462",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.25848",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-805.88208",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "944.28613",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1242.8596",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "242.55298",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-4.96984740E-07",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "9.69895098E-08",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1808.4873",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1934.0405",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-240296.19",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "656218.44",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "924.10938",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-271.74316",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "29.478638",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.06999999",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "210.12805",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "310.25696",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "209.31114",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "314.24927",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.003355325",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "scale_max": "0.028828",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem17 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "scale_min": "-19.561535",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "410.61844",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.48494228E-05",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84783748E-05",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.48494228E-05",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.84783748E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem17 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.003355325",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "0.028828",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.88081469E-06",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89431103E-06",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.88081469E-06",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.89431103E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "0.03450508",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "wind10",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "35.10535",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.05833186",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "35.823601",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-29.170517",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "30.837357",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-34.502289",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "31.064102",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8.74068178E-08",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03752092",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "187.31563",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmx",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "340.56342",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "187.1776",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmn",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "327.10477",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "187.19762",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "333.66724",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem16": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem16",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.04908027",
                                            "PDS_TimeRange": "10",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "93.20977",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8461.8086",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-778.80664",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "1144.4375",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-394.64209",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "-80.508301",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1412.886",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2423.8904",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1144.4375",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-394.64209",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-80.398926",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-7517.7578",
                                            "PDS_TimeRange": "10",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-88.05545",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.009231567",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-731.41992",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "-67.182617",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-4.4566841",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "4.4499197",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-6.2210569",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "6.4564934",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "185.67117",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "338.13397",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "185.59906",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "342.64417",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.26910356E-06",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-702.10132",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.007080078",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.27081876E-06",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.500488",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_11",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "1.49999996E-05",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "48485.691",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "112927.09",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-8.41451733E-34",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "7.13840961E-07",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "2.14469014E-06",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-7.45389068E-24",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.24785561E-06",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-405953.19",
                                            "PDS_TimeRange": "10",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "422807.75",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "927.53125",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-248.96336",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "74.710312",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.02891107",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258558",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-656.79785",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "974.60107",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1435.7776",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "187.96118",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-5.74127228E-07",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "7.51590221E-08",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1755.6223",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "2090.3137",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-308121.31",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "629608.62",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "927.53125",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-248.96336",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "46.218842",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.06999999",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "210.06314",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "309.33853",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "209.34193",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "313.4967",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.005404826",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "scale_max": "0.03197567",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem16 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "scale_min": "-19.41507",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "410.73755",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.58948806E-05",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82201675E-05",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.58948806E-05",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.82201675E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem16 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.005404826",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "0.03197567",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.95598273E-06",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81225130E-06",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.95598273E-06",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.81225130E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "0.03276161",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "wind10",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "41.064026",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.06462514",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "41.418961",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-28.877167",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "28.065674",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-39.686447",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "33.264587",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "1.08764539E-07",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "0.03491605",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "189.07005",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmx",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "336.97113",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "188.77318",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmn",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "327.91891",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "188.86201",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "333.75",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem15": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem15",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.03723556",
                                            "PDS_TimeRange": "10",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "95.15667",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum height of convective cloud tops",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "8489.3281",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "CLTOPMAX",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "100000.0",
                                            "gribparam": "217",
                                            "subcenter": "255"
                                        },
                                        "cltm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "cltm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "cloud cover total mean[0-1]",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "cltm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "164",
                                            "subcenter": "255"
                                        }
                                    },
                                    "top": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "top",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "SRAD0U": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRAD0U",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (top)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-771.24316",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRAD0U",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "203",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (top)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rst",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "1143.4375",
                                                "gribparam": "178",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-395.88599",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rlt",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "-74.206543",
                                                "gribparam": "179",
                                                "subcenter": "255"
                                            }
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1443.0676",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0U",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1788.3577",
                                                    "gribparam": "105",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1144.6875",
                                                    "gribparam": "187",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-395.88599",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAF0",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "-73.808105",
                                                    "gribparam": "188",
                                                    "subcenter": "255"
                                                }
                                            }
                                        }
                                    },
                                    "surface": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "surface",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "zg": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "zg",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Geopotential",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-7517.7578",
                                            "PDS_TimeRange": "10",
                                            "units": "m2 s-2",
                                            "grib_name": "zg",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "58762.242",
                                            "gribparam": "129",
                                            "subcenter": "255"
                                        },
                                        "TSLIN": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TSLIN",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "TSLIN heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-91.673172",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TSLIN",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.009094238",
                                            "gribparam": "220",
                                            "subcenter": "255"
                                        },
                                        "TRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "longwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-725.58032",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "TRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "-64.051025",
                                            "gribparam": "205",
                                            "subcenter": "255"
                                        },
                                        "tauv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-5.1218185",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauv",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "3.9294486",
                                            "gribparam": "181",
                                            "subcenter": "255"
                                        },
                                        "tauu": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tauu",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-component of Surface Wind Stress",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-4.7619591",
                                            "PDS_TimeRange": "10",
                                            "units": "Nm-2",
                                            "grib_name": "tauu",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "4.8176727",
                                            "gribparam": "180",
                                            "subcenter": "255"
                                        },
                                        "tas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "tas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "air temperature (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "183.48752",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "tas",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "336.71661",
                                            "gribparam": "169",
                                            "subcenter": "255"
                                        },
                                        "stemp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "stemp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "183.32143",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "stemp",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "342.62775",
                                            "gribparam": "139",
                                            "subcenter": "255"
                                        },
                                        "srun": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "srun",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "surface runoff",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "srun",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.44610556E-06",
                                            "gribparam": "160",
                                            "subcenter": "255"
                                        },
                                        "SRADSU": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SRADSU",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "shortwave radiation upward (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-669.60254",
                                            "PDS_TimeRange": "10",
                                            "units": "W/m2",
                                            "grib_name": "SRADSU",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.0078125",
                                            "gribparam": "204",
                                            "subcenter": "255"
                                        },
                                        "soilm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "soilm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil wetness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "soilm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.7324371",
                                            "gribparam": "140",
                                            "subcenter": "255"
                                        },
                                        "SNMEL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SNMEL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "snow melt",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "SNMEL",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.15169678E-06",
                                            "gribparam": "218",
                                            "subcenter": "255"
                                        },
                                        "snd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "snd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "snd",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "15.886963",
                                            "gribparam": "141",
                                            "subcenter": "255"
                                        },
                                        "slp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "slp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "151",
                                            "long_name": "mean sea level pressure",
                                            "gribleveltype": "102",
                                            "Z": "Z_11",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "SICED": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SICED",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice depth",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "SICED",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.5",
                                            "gribparam": "211",
                                            "subcenter": "255"
                                        },
                                        "sfr": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "sfr",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sfc roughness",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "1.49999996E-05",
                                            "PDS_TimeRange": "10",
                                            "units": "m",
                                            "grib_name": "sfr",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "20.00148",
                                            "gribparam": "173",
                                            "subcenter": "255"
                                        },
                                        "SEAICE": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "SEAICE",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "sea ice cover",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "SEAICE",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "210",
                                            "subcenter": "255"
                                        },
                                        "pss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "pss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "48302.504",
                                            "PDS_TimeRange": "10",
                                            "units": "Pa",
                                            "grib_name": "pss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "113119.16",
                                            "gribparam": "134",
                                            "subcenter": "255"
                                        },
                                        "prs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Snow Fall",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.68290328E-33",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "prs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "8.47852107E-07",
                                            "gribparam": "144",
                                            "subcenter": "255"
                                        },
                                        "prl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Large Scale Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.49321522E-06",
                                            "gribparam": "142",
                                            "subcenter": "255"
                                        },
                                        "prcp": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prcp",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "260",
                                            "long_name": "Total Precipitation",
                                            "grib_name": "totprcp",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "prc": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "prc",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Convective Precipitation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.10678976E-23",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "prc",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.27584383E-06",
                                            "gribparam": "143",
                                            "subcenter": "255"
                                        },
                                        "PERPW": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "PERPW",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Primary wave mean period",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-419720.94",
                                            "PDS_TimeRange": "10",
                                            "units": "s",
                                            "grib_name": "PERPW",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "447204.94",
                                            "gribparam": "108",
                                            "subcenter": "255"
                                        },
                                        "net": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "net",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "swflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "swflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "Net Shortwave Radiation (surface)",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "0.0",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rss",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "925.79688",
                                                "gribparam": "176",
                                                "subcenter": "255"
                                            },
                                            "lwflx": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "lwflx",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                "long_name": "longwave flux",
                                                "calendar": "standard",
                                                "PTVersion": "128",
                                                "scale_min": "-249.45203",
                                                "PDS_TimeRange": "10",
                                                "units": "Wm-2",
                                                "grib_name": "rls",
                                                "process": "50",
                                                "gribleveltype": "1",
                                                "scale_max": "79.338928",
                                                "gribparam": "177",
                                                "subcenter": "255"
                                            }
                                        },
                                        "lsm": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "lsm",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "land-sea mask",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.0",
                                            "PDS_TimeRange": "10",
                                            "units": "(0,1)",
                                            "grib_name": "lsm",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "1.0",
                                            "gribparam": "172",
                                            "subcenter": "255"
                                        },
                                        "logpsl": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "logpsl",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Log Surface Pressure",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.03134177",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "logpsl",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "16.258396",
                                            "gribparam": "152",
                                            "subcenter": "255"
                                        },
                                        "hfss": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfss",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Sensible Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-670.87671",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfss",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "900.16406",
                                            "gribparam": "146",
                                            "subcenter": "255"
                                        },
                                        "hfls": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hfls",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Surface Flux of Latent Heat",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1205.5957",
                                            "PDS_TimeRange": "10",
                                            "units": "Wm-2",
                                            "grib_name": "hfls",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "237.29907",
                                            "gribparam": "147",
                                            "subcenter": "255"
                                        },
                                        "evs": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "evs",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Evaporation",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-4.82083976E-07",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "evs",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "9.48900833E-08",
                                            "gribparam": "182",
                                            "subcenter": "255"
                                        },
                                        "dpsdy": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdy",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "274",
                                            "long_name": "Meridional Deriv. of Surface Pres.",
                                            "grib_name": "dpsdy",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "dpsdx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "dpsdx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "273",
                                            "long_name": "Zonal Deriv. of Surface Pres.",
                                            "grib_name": "dpsdx",
                                            "units": "kilogram meter-2 second-2",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "clear_sky": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "clear_sky",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "upward": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "upward",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-1771.2585",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "1977.75",
                                                    "gribparam": "106",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-295614.06",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFSU",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "620319.5",
                                                    "gribparam": "107",
                                                    "subcenter": "255"
                                                }
                                            },
                                            "net": {
                                                "iridl_type": "DataSet",
                                                "iridl_ds_name": "net",
                                                "banned": [
                                                    "dir",
                                                    "invalid",
                                                    "parent",
                                                    "name",
                                                    "banned",
                                                    "banned_long",
                                                    "iridl_ds_name",
                                                    "iridl_type"
                                                ],
                                                "solr": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "solr",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "solar flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "0.0",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "SRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "926.07812",
                                                    "gribparam": "185",
                                                    "subcenter": "255"
                                                },
                                                "lwflx": {
                                                    "iridl_type": "DataSet",
                                                    "iridl_ds_name": "lwflx",
                                                    "banned": [
                                                        "dir",
                                                        "invalid",
                                                        "parent",
                                                        "name",
                                                        "banned",
                                                        "banned_long",
                                                        "iridl_ds_name",
                                                        "iridl_type"
                                                    ],
                                                    "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                                    "long_name": "longwave flux",
                                                    "calendar": "standard",
                                                    "PTVersion": "128",
                                                    "scale_min": "-249.51799",
                                                    "PDS_TimeRange": "10",
                                                    "units": "W/m2",
                                                    "grib_name": "TRAFS",
                                                    "process": "50",
                                                    "gribleveltype": "1",
                                                    "scale_max": "42.663101",
                                                    "gribparam": "186",
                                                    "subcenter": "255"
                                                }
                                            }
                                        },
                                        "ALBEDO": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ALBEDO",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Albedo (surface)",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.06999999",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "ALBEDO",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "0.8004687",
                                            "gribparam": "175",
                                            "subcenter": "255"
                                        }
                                    },
                                    "soil": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "soil",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "TDCL": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "TDCL",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "soil temp level CL",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "210.33493",
                                            "PDS_TimeRange": "10",
                                            "units": "m (H2O)",
                                            "grib_name": "TDCL",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "309.44431",
                                            "gribparam": "183",
                                            "subcenter": "255"
                                        },
                                        "td": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "deep soil temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "209.45415",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td",
                                            "process": "50",
                                            "gribleveltype": "111",
                                            "scale_max": "313.07495",
                                            "gribparam": "170",
                                            "subcenter": "255"
                                        }
                                    },
                                    "PressureLevel": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "PressureLevel",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.005061593",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "scale_max": "0.02808245",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribleveltype": "100",
                                            "history": "toS: regridded Z to IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem15 hybrid_lev P",
                                            "missing_value": "NaN",
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "subcenter": "255"
                                        }
                                    },
                                    "hybrid_lev": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "hybrid_lev",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "v": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "v",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "132",
                                            "long_name": "meridional velocity",
                                            "grib_name": "va",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "u": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "u",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "131",
                                            "long_name": "zonal velocity",
                                            "grib_name": "ua",
                                            "units": "m/s",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "ta": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "ta",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "Kelvin_scale",
                                            "scale_min": "-19.776009",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "ta",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "410.74066",
                                            "gribparam": "130",
                                            "subcenter": "255"
                                        },
                                        "rvort": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "rvort",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vorticity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.56854567E-05",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "rvort",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83744214E-05",
                                            "gribparam": "138",
                                            "subcenter": "255"
                                        },
                                        "Rv": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rv",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for moist air"
                                        },
                                        "Rd": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Rd",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "J/kg/K",
                                            "long_name": "gas constant for dry air"
                                        },
                                        "psi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "psi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "148",
                                            "long_name": "streamfunction",
                                            "grib_name": "strm",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.56854567E-05",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "1.83744214E-05",
                                            "subcenter": "255"
                                        },
                                        "phi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "phi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "156",
                                            "long_name": "geopotential height",
                                            "grib_name": "zg",
                                            "units": "m",
                                            "fnname": "max",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "P": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "P",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "long_name": "pressure",
                                            "units": "Pa",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "subcenter": "255"
                                        },
                                        "omega": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "omega",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "135",
                                            "long_name": "vertical pressure velocity",
                                            "units": "Pa/s",
                                            "history": "Z regridded on IRI FD ECHAM4p5 Forecast asst jul2001 SIX-HOURLY mem15 hybrid_lev omegahalf",
                                            "grib_name": "ua",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "subcenter": "255"
                                        },
                                        "hus": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "hus",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Specific Humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-0.005061593",
                                            "PDS_TimeRange": "10",
                                            "units": "unitless",
                                            "grib_name": "hus",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "0.02808245",
                                            "gribparam": "133",
                                            "subcenter": "255"
                                        },
                                        "gravity": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "gravity",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "m/s2",
                                            "long_name": "earth\\'s gravity"
                                        },
                                        "Div": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "Div",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Divergence",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "s-1",
                                            "scale_min": "-1.85347733E-06",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "div",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "2.00923228E-06",
                                            "gribparam": "155",
                                            "subcenter": "255"
                                        },
                                        "chi": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "chi",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "gribparam": "149",
                                            "long_name": "velocity potential",
                                            "grib_name": "vpot",
                                            "units": "meter2 second-1",
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-1.85347733E-06",
                                            "PDS_TimeRange": "10",
                                            "process": "50",
                                            "gribleveltype": "109",
                                            "scale_max": "2.00923228E-06",
                                            "subcenter": "255"
                                        },
                                        "BC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "BC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "unitless"
                                        },
                                        "AC": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "AC",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "units": "Pa"
                                        }
                                    },
                                    "above_ground": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "above_ground",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "wind10": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "wind10",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "10m windspeed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "0.03609338",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "wind10",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "34.475132",
                                            "gribparam": "171",
                                            "subcenter": "255"
                                        },
                                        "WIMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "WIMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "maximum 10m wind speed",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.05502368",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "WIMAX",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "35.597672",
                                            "gribparam": "216",
                                            "subcenter": "255"
                                        },
                                        "vas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "vas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "V-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-30.655975",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "vas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "29.872772",
                                            "gribparam": "166",
                                            "subcenter": "255"
                                        },
                                        "uas": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "uas",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "U-wind at 10",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "-31.732468",
                                            "PDS_TimeRange": "10",
                                            "units": "m/s",
                                            "grib_name": "uas",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "31.017609",
                                            "gribparam": "165",
                                            "subcenter": "255"
                                        },
                                        "td2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "td2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Dewpoint at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "7.21893798E-08",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "td2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "0.0463423",
                                            "gribparam": "168",
                                            "subcenter": "255"
                                        },
                                        "t2mmx": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmx",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "max 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "186.81743",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmx",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "337.6503",
                                            "gribparam": "201",
                                            "subcenter": "255"
                                        },
                                        "t2mmn": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2mmn",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "min 2m temp",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "units": "unitless",
                                            "scale_min": "186.30321",
                                            "PDS_TimeRange": "10",
                                            "grib_name": "t2mmn",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "326.25388",
                                            "gribparam": "202",
                                            "subcenter": "255"
                                        },
                                        "t2m": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "t2m",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "Temperature at 2 m",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "186.37892",
                                            "PDS_TimeRange": "10",
                                            "units": "Kelvin_scale",
                                            "grib_name": "t2m",
                                            "process": "50",
                                            "gribleveltype": "105",
                                            "scale_max": "329.6221",
                                            "gribparam": "167",
                                            "subcenter": "255"
                                        }
                                    }
                                },
                                "mem14": {
                                    "iridl_type": "DataSet",
                                    "iridl_ds_name": "mem14",
                                    "banned": [
                                        "dir",
                                        "invalid",
                                        "parent",
                                        "name",
                                        "banned",
                                        "banned_long",
                                        "iridl_ds_name",
                                        "iridl_type"
                                    ],
                                    "total_air_column": {
                                        "iridl_type": "DataSet",
                                        "iridl_ds_name": "total_air_column",
                                        "banned": [
                                            "dir",
                                            "invalid",
                                            "parent",
                                            "name",
                                            "banned",
                                            "banned_long",
                                            "iridl_ds_name",
                                            "iridl_type"
                                        ],
                                        "QVI": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "QVI",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
                                                "iridl_type"
                                            ],
                                            "center": "European Center for Medium-Range Weather Forecasts - Reading",
                                            "long_name": "vertically integrated specific humidity",
                                            "calendar": "standard",
                                            "PTVersion": "128",
                                            "scale_min": "0.03933365",
                                            "PDS_TimeRange": "10",
                                            "units": "kg/m2",
                                            "grib_name": "QVI",
                                            "process": "50",
                                            "gribleveltype": "1",
                                            "scale_max": "97.481758",
                                            "gribparam": "230",
                                            "subcenter": "255"
                                        },
                                        "CLTOPMAX": {
                                            "iridl_type": "DataSet",
                                            "iridl_ds_name": "CLTOPMAX",
                                            "banned": [
                                                "dir",
                                                "invalid",
                                                "parent",
                                                "name",
                                                "banned",
                                                "banned_long",
                                                "iridl_ds_name",
            